﻿Imports System.IO
Imports System.Text
Imports rsrtm_read_waveform_example.InstrumentDriversVB

Public Class rsrtm_read_waveform_example

    Private Sub ExitButton_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles ExitButton.Click
        Close()
    End Sub

    Private Sub MeasureAndSaveButton_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles MeasureAndSaveButton.Click
        Dim m_Instrument As rsrtm
        Dim actualPoints As Integer
        Dim InitialX As Double
        Dim XIncrement As Double
        Dim saveFileSW As StreamWriter = Nothing
        Dim statusData As New StringBuilder()

        Try
            If SaveMeasuredDataDialog.ShowDialog() = Windows.Forms.DialogResult.OK Then
                UseWaitCursor = True
                System.Windows.Forms.Cursor.Current = Cursors.WaitCursor

                'initialize driver
                m_Instrument = New rsrtm(ResourceDescriptor.Text, IDQuery.Checked, ResetDevice.Checked)

                ''configures how the oscilloscope acquires data and fills the waveform record
                m_Instrument.ConfigureAcquisitionType(rsrtmConstants.Channel1, acquisitionType.SelectedIndex)

                '' configures the method to reduce the data stream of the ADC to 
                '' a stream of waveform points with lower sample rate 
                m_Instrument.ConfigureWaveformArithmetic(rsrtmConstants.Channel1, arithmetics.SelectedIndex)

                ''configures the time of one acquisition, that is the time across
                ''the 10 divisions of the diagram */
                m_Instrument.ConfigureAcquisitionRecord(10 * Convert.ToDouble(horizontalScale.Value), 0)

                ''configures the axis scaling */
                m_Instrument.ConfigureChannelVerticalScale(rsrtmConstants.Channel1, Convert.ToDouble(verticalScale.Value))
                m_Instrument.ConfigureTimeBase(Convert.ToDouble(horizontalScale.Value), 50)

                '' trigger configuration */ 
                m_Instrument.ConfigureEdgeTriggerSource(rsrtmConstants.TriggerA, rsrtmConstants.Channel1, 1, Convert.ToDouble(triggerLevel.Value), triggerSlope.SelectedIndex)

                ''configures the offset voltage, the offset is subtracted to
                ''correct an offset-affected signal */
                m_Instrument.ConfigureChannelOffset(rsrtmConstants.Channel1, Convert.ToDouble(offset.Value))
                Dim length As Integer

                m_Instrument.QueryWaveformSamplesRange(rsrtmConstants.Channel1, length)
                Dim waveform(length) As Double

                ''This function initiates an acquisition on the channels that you enable with the rsscope_ConfigureChannel function.  It then
                ''waits for the acquisition to complete, and returns the waveform for the channel you specify */
                m_Instrument.ReadWaveform(rsrtmConstants.Channel1, length, Me.timeout.Value, waveform, actualPoints, InitialX, XIncrement)

                'open save file
                saveFileSW = New StreamWriter(SaveMeasuredDataDialog.FileName, False, Encoding.Default)

                'write data to file
                saveFileSW.WriteLine("Waveform data")
                For Each data As Double In waveform
                    saveFileSW.WriteLine(data.ToString())
                Next

            End If
        Catch ex As Exception
            Dim message As String

            message = "Instrument Status Error: "
            message += ex.Message
            MessageBox.Show(message)

        Finally
            'close file if opened
            If Not (saveFileSW Is Nothing) Then
                saveFileSW.Close()
            End If

            UseWaitCursor = False
            System.Windows.Forms.Cursor.Current = Cursors.Default
        End Try
    End Sub

    Private Sub rsrtm_read_waveform_example_Load(sender As System.Object, e As System.EventArgs) Handles MyBase.Load
        Me.acquisitionType.SelectedIndex = 0
        Me.arithmetics.SelectedIndex = 0
        Me.triggerSlope.SelectedIndex = 0
    End Sub
End Class
