Option Strict Off
Option Explicit On

Imports System
Imports System.Runtime.InteropServices

Namespace InstrumentDriversVB
    
    Public Class rsrtm
        Inherits Object
        Implements System.IDisposable
        
        Private _handle As System.Runtime.InteropServices.HandleRef
        
        Private _disposed As Boolean = true
        
        '''<summary>
        '''This function creates an IVI instrument driver session, typically using the C session instrument handle.
        '''</summary>
        '''<param name="Instrument_Handle">
        '''The instrument handle that is used to create an IVI instrument driver session.
        '''</param>
        Public Sub New(ByVal Instrument_Handle As System.IntPtr)
            MyBase.New
            Me._handle = New System.Runtime.InteropServices.HandleRef(Me, Instrument_Handle)
            Me._disposed = false
        End Sub
        
        '''<summary>
        '''This function performs the following initialization actions:
        '''
        '''- Creates a new IVI instrument driver session.
        '''
        '''- Opens a session to the specified device using the interface and address you specify for the Resource Name parameter.
        '''
        '''- If the ID Query parameter is set to VI_TRUE, this function queries the instrument ID and checks that it is valid for this instrument driver.
        '''
        '''- If the Reset parameter is set to VI_TRUE, this function resets the instrument to a known state.
        '''
        '''- Sends initialization commands to set the instrument to the state necessary for the operation of the instrument driver.
        '''
        '''- Returns a ViSession handle that you use to identify the instrument in all subsequent instrument driver function calls.
        '''
        '''Note:  This function creates a new session each time you invoke it. Although you can open more than one VISA session for the same resource, it is best not to do so.  You can use the same session in multiple program threads.
        '''</summary>
        '''<param name="Resource_Name">
        '''Pass the resource name of the device to initialize.
        '''
        '''You can also pass the name of a virtual instrument or logical name that you configure with the VISA Configuration utility.  The virtual instrument identifies a specific device and specifies the initial settings for the session. A logical Name identifies a particular virtual instrument.
        '''
        '''Refer to the following table below for the exact grammar to use for this parameter.  Optional fields are shown in square brackets ([]).
        '''
        '''Syntax
        '''------------------------------------------------------
        '''GPIB[board]::&lt;primary address&gt;[::secondary address]::INSTR
        '''VXI[board]::&lt;logical address&gt;::INSTR
        '''GPIB-VXI[board]::&lt;logical address&gt;::INSTR
        '''ASRL&lt;port&gt;::INSTR
        '''&lt;LogicalName&gt;
        '''&lt;DriverSession&gt;
        '''
        '''If you do not specify a value for an optional field, the following values are used:
        '''
        '''Optional Field - Value
        '''------------------------------------------------------
        '''board - 0
        '''secondary address - none (31)
        '''
        '''The following table contains example valid values for this parameter.
        '''
        '''"Valid Value" - Description
        '''------------------------------------------------------
        '''"GPIB::22::INSTR" - GPIB board 0, primary address 22 no
        '''                    secondary address
        '''"GPIB::22::5::INSTR" - GPIB board 0, primary address 22
        '''                       secondary address 5
        '''"GPIB1::22::5::INSTR" - GPIB board 1, primary address 22
        '''                        secondary address 5
        '''"VXI::64::INSTR" - VXI board 0, logical address 64
        '''"VXI1::64::INSTR" - VXI board 1, logical address 64
        '''"GPIB-VXI::64::INSTR" - GPIB-VXI board 0, logical address 64
        '''"GPIB-VXI1::64::INSTR" - GPIB-VXI board 1, logical address 64
        '''"ASRL2::INSTR" - COM port 2
        '''"SampleInstr" - Logical name "SampleInstr"
        '''"xyz432" - Driver Session "xyz432"
        '''
        '''
        '''Default Value:  "GPIB::20::INSTR"
        '''
        '''</param>
        '''<param name="ID_Query">
        '''Specify whether you want the instrument driver to perform an ID Query.
        '''
        '''Valid Range:
        '''VI_TRUE  (1) - Perform ID Query (Default Value)
        '''VI_FALSE (0) - Skip ID Query
        '''
        '''When you set this parameter to VI_TRUE, the driver verifies that the instrument you initialize is a type that this driver supports.  
        '''
        '''Circumstances can arise where it is undesirable to send an ID Query command string to the instrument.  When you set this parameter to VI_FALSE, the function initializes the instrument without performing an ID Query.
        '''</param>
        '''<param name="Reset_Device">
        '''Specify whether you want the to reset the instrument during the initialization procedure.
        '''
        '''Valid Range:
        '''VI_TRUE  (1) - Reset Device (Default Value)
        '''VI_FALSE (0) - Don't Reset
        '''
        '''
        '''</param>
        Public Sub New(ByVal Resource_Name As String, ByVal ID_Query As Boolean, ByVal Reset_Device As Boolean)
            MyBase.New
            Dim instrumentHandle As System.IntPtr
            Dim pInvokeResult As Integer = PInvoke.init(Resource_Name, System.Convert.ToUInt16(ID_Query), System.Convert.ToUInt16(Reset_Device), instrumentHandle)
            Me._handle = New System.Runtime.InteropServices.HandleRef(Me, instrumentHandle)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Me._disposed = false
        End Sub
        
        '''<summary>
        '''This function performs the following initialization actions:
        '''
        '''- Creates a new IVI instrument driver and optionally sets the initial state of the following session attributes:
        '''
        '''    RSRTM_ATTR_RANGE_CHECK         
        '''    RSRTM_ATTR_QUERY_INSTRUMENT_STATUS  
        '''    RSRTM_ATTR_CACHE               
        '''    RSRTM_ATTR_SIMULATE            
        '''    RSRTM_ATTR_RECORD_COERCIONS    
        '''
        '''- Opens a session to the specified device using the interface and address you specify for the Resource Name parameter.
        '''
        '''- If the ID Query parameter is set to VI_TRUE, this function queries the instrument ID and checks that it is valid for this instrument driver.
        '''
        '''- If the Reset parameter is set to VI_TRUE, this function resets the instrument to a known state.
        '''
        '''- Sends initialization commands to set the instrument to the state necessary for the operation of the instrument driver.
        '''
        '''- Returns a ViSession handle that you use to identify the instrument in all subsequent instrument driver function calls.
        '''
        '''Note:  This function creates a new session each time you invoke it. Although you can open more than one VISA session for the same resource, it is best not to do so.  You can use the same session in multiple program threads.
        '''</summary>
        '''<param name="Resource_Name">
        '''Pass the resource name of the device to initialize.
        '''
        '''You can also pass the name of a virtual instrument or logical name that you configure with the VISA Configuration utility.  The virtual instrument identifies a specific device and specifies the initial settings for the session. A logical Name identifies a particular virtual instrument.
        '''
        '''Refer to the following table below for the exact grammar to use for this parameter.  Optional fields are shown in square brackets ([]).
        '''
        '''Syntax
        '''------------------------------------------------------
        '''GPIB[board]::&lt;primary address&gt;[::secondary address]::INSTR
        '''VXI[board]::&lt;logical address&gt;::INSTR
        '''GPIB-VXI[board]::&lt;logical address&gt;::INSTR
        '''ASRL&lt;port&gt;::INSTR
        '''&lt;LogicalName&gt;
        '''&lt;DriverSession&gt;
        '''
        '''If you do not specify a value for an optional field, the following values are used:
        '''
        '''Optional Field - Value
        '''------------------------------------------------------
        '''board - 0
        '''secondary address - none (31)
        '''
        '''The following table contains example valid values for this parameter.
        '''
        '''"Valid Value" - Description
        '''------------------------------------------------------
        '''"GPIB::22::INSTR" - GPIB board 0, primary address 22 no
        '''                    secondary address
        '''"GPIB::22::5::INSTR" - GPIB board 0, primary address 22
        '''                       secondary address 5
        '''"GPIB1::22::5::INSTR" - GPIB board 1, primary address 22
        '''                        secondary address 5
        '''"VXI::64::INSTR" - VXI board 0, logical address 64
        '''"VXI1::64::INSTR" - VXI board 1, logical address 64
        '''"GPIB-VXI::64::INSTR" - GPIB-VXI board 0, logical address 64
        '''"GPIB-VXI1::64::INSTR" - GPIB-VXI board 1, logical address 64
        '''"ASRL2::INSTR" - COM port 2
        '''"SampleInstr" - Logical name "SampleInstr"
        '''"xyz432" - Driver Session "xyz432"
        '''
        '''
        '''Default Value:  "GPIB::20::INSTR"
        '''
        '''</param>
        '''<param name="ID_Query">
        '''Specify whether you want the instrument driver to perform an ID Query.
        '''
        '''Valid Range:
        '''VI_TRUE  (1) - Perform ID Query (Default Value)
        '''VI_FALSE (0) - Skip ID Query
        '''
        '''When you set this parameter to VI_TRUE, the driver verifies that the instrument you initialize is a type that this driver supports.  
        '''
        '''Circumstances can arise where it is undesirable to send an ID Query command string to the instrument.  When you set this parameter to VI_FALSE, the function initializes the instrument without performing an ID Query.
        '''</param>
        '''<param name="Reset_Device">
        '''Specify whether you want the to reset the instrument during the initialization procedure.
        '''
        '''Valid Range:
        '''VI_TRUE  (1) - Reset Device (Default Value)
        '''VI_FALSE (0) - Don't Reset
        '''
        '''
        '''</param>
        '''<param name="Option_String">
        '''You can use this control to set the initial value of certain attributes for the session.  The following table lists the attributes and the name you use in this parameter to identify the attribute.
        '''
        '''Name              Attribute Defined Constant   
        '''--------------------------------------------
        '''RangeCheck        RSRTM_ATTR_RANGE_CHECK
        '''QueryInstrStatus  RSRTM_ATTR_QUERY_INSTRUMENT_STATUS   
        '''Cache             RSRTM_ATTR_CACHE   
        '''Simulate          RSRTM_ATTR_SIMULATE  
        '''RecordCoercions   RSRTM_ATTR_RECORD_COERCIONS
        '''
        '''The format of this string is, "AttributeName=Value" where AttributeName is the name of the attribute and Value is the value to which the attribute will be set.  To set multiple attributes, separate their assignments with a comma.  
        '''
        '''If you pass NULL or an empty string for this parameter, the session uses the default values for the attributes.   You can override the default values by assigning a value explicitly in a string you pass for this parameter.  You do not have to specify all of the attributes and may leave any of them out.  If you do not specify one of the attributes, its default value will be used.  
        '''
        '''The default values for the attributes are shown below:
        '''
        '''    Attribute Name     Default Value
        '''    ----------------   -------------
        '''    RangeCheck         VI_TRUE
        '''    QueryInstrStatus   VI_FALSE
        '''    Cache              VI_TRUE
        '''    Simulate           VI_FALSE
        '''    RecordCoercions    VI_FALSE
        '''    
        '''
        '''The following are the valid values for ViBoolean attributes:
        '''
        '''    True:     1, TRUE, or VI_TRUE
        '''    False:    0, False, or VI_FALSE
        '''
        '''
        '''Default Value:
        '''       "Simulate=0,RangeCheck=1,QueryInstrStatus=0,Cache=1"
        '''
        '''</param>
        Public Sub New(ByVal Resource_Name As String, ByVal ID_Query As Boolean, ByVal Reset_Device As Boolean, ByVal Option_String As String)
            MyBase.New
            Dim instrumentHandle As System.IntPtr
            Dim pInvokeResult As Integer = PInvoke.InitWithOptions(Resource_Name, System.Convert.ToUInt16(ID_Query), System.Convert.ToUInt16(Reset_Device), Option_String, instrumentHandle)
            Me._handle = New System.Runtime.InteropServices.HandleRef(Me, instrumentHandle)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Me._disposed = false
        End Sub
        
        '''<summary>
        '''Gets the instrument handle.
        '''</summary>
        '''<value>
        '''The value is the IntPtr that represents the handle to the instrument.
        '''</value>
        Public ReadOnly Property Handle() As System.IntPtr
            Get
                Return Me._handle.Handle
            End Get
        End Property
        
        '''<summary>
        '''This function performs an autoset process: analyzes the enabled channel signals, and obtains appropriate horizontal, vertical, and trigger settings to display stable waveforms.
        '''
        '''Attribute(s):
        '''RSRTM_ATTR_AUTOSCALE
        '''
        '''Remote-control command(s):
        '''AUToscale
        '''</summary>
        '''<returns>
        '''Returns the status code of this operation.  The status code  either indicates success or describes an error or warning condition.  You examine the status code from each call to an instrument driver function to determine if an error occurred.
        '''
        '''To obtain a text description of the status code, call the rsrtm_error_message function.  To obtain additional information about the error condition, call the rsrtm_GetError function.  To clear the error information from the driver, call the rsrtm_ClearError function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''
        '''Numeric Range (in Hex) Status Code Types
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF VISA Warnings
        '''3FFC0000 to 3FFCFFFF VXIPnP Driver Warnings
        '''
        '''BFFF0000 to BFFFFFFF VISA Errors
        '''BFFC0000 to BFFCFFFF VXIPnP Driver Errors
        '''</returns>
        Public Function Autoset() As Integer
            Dim pInvokeResult As Integer = PInvoke.Autoset(Me._handle)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function configures how the oscilloscope acquires data and fills the waveform record.
        '''
        '''Attribute(s):
        '''RSRTM_ATTR_ACQUISITION_TYPE
        '''
        '''Remote-control command(s):
        '''CHANnel&lt;Channel&gt;:TYPE
        '''</summary>
        '''<param name="Channel">
        '''This control selects the channel.
        '''
        '''Valid Values: 
        '''RSRTM_VAL_CHANNEL_1   (1) - 1
        '''RSRTM_VAL_CHANNEL_2   (2) - 2
        '''RSRTM_VAL_CHANNEL_3   (3) - 3
        '''RSRTM_VAL_CHANNEL_4   (4) - 4
        '''RSRTM_VAL_CHANNEL_EXT (5) - External
        '''
        '''Default Value: RSRTM_VAL_CHANNEL_1 (1)
        '''</param>
        '''<param name="Acquisition_Type">
        '''Specify the manner in which you want the oscilloscope to acquire data and fill the waveform record.
        '''
        '''Valid Values:
        '''RSRTM_VAL_SAMPLE      (0) - Sample
        '''RSRTM_VAL_PEAK_DETECT (1) - Peak Detect
        '''RSRTM_VAL_HI_RES      (2) - High Resolution
        '''
        '''Default value: RSRTM_VAL_SAMPLE (0)
        '''
        '''Attribute:
        '''RSRTM_ATTR_ACQUISITION_TYPE
        '''
        '''
        '''</param>
        '''<returns>
        '''Returns the status code of this operation.  The status code  either indicates success or describes an error or warning condition.  You examine the status code from each call to an instrument driver function to determine if an error occurred.
        '''
        '''To obtain a text description of the status code, call the rsrtm_error_message function.  To obtain additional information about the error condition, call the rsrtm_GetError function.  To clear the error information from the driver, call the rsrtm_ClearError function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''
        '''Numeric Range (in Hex) Status Code Types
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF VISA Warnings
        '''3FFC0000 to 3FFCFFFF VXIPnP Driver Warnings
        '''
        '''BFFF0000 to BFFFFFFF VISA Errors
        '''BFFC0000 to BFFCFFFF VXIPnP Driver Errors
        '''</returns>
        Public Function ConfigureAcquisitionType(ByVal Channel As Integer, ByVal Acquisition_Type As Integer) As Integer
            Dim pInvokeResult As Integer = PInvoke.ConfigureAcquisitionType(Me._handle, Channel, Acquisition_Type)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function configures the common attributes of the acquisition subsystem.  These attributes are the time per record and acquisition start time.
        '''
        '''Attribute(s):
        '''RSRTM_ATTR_HORZ_TIME_PER_RECORD
        '''RSRTM_ATTR_ACQUSITION_START_TIME
        '''
        '''Remote-control command(s):
        '''TIMebase:ACQTime
        '''TIMebase:POSition
        '''</summary>
        '''<param name="Time_Per_Record">
        '''Pass the time in seconds that corresponds to the record length.  
        '''
        '''Units: seconds
        '''
        '''Valid Range: 0.0 to 500.0  
        '''
        '''Default Value: 0.5
        '''
        '''Attribute:
        '''RSRTM_ATTR_HORZ_TIME_PER_RECORD
        '''</param>
        '''<param name="Acquisition_Start_Time__Offset_">
        '''Specifies the length of time from the trigger event to the first point in the waveform record.  If the value is positive, the first point in the waveform record occurs after the trigger event.  If the value is negative, the first point in the waveform record occurs before the trigger event.
        '''
        '''Units: seconds
        '''
        '''Valid Range:  -500.0 to 500.0
        '''
        '''Default Value: 0.0
        '''
        '''Attribute:
        '''RSRTM_ATTR_ACQUSITION_START_TIME
        '''</param>
        '''<returns>
        '''Returns the status code of this operation.  The status code  either indicates success or describes an error or warning condition.  You examine the status code from each call to an instrument driver function to determine if an error occurred.
        '''
        '''To obtain a text description of the status code, call the rsrtm_error_message function.  To obtain additional information about the error condition, call the rsrtm_GetError function.  To clear the error information from the driver, call the rsrtm_ClearError function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''
        '''Numeric Range (in Hex) Status Code Types
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF VISA Warnings
        '''3FFC0000 to 3FFCFFFF VXIPnP Driver Warnings
        '''
        '''BFFF0000 to BFFFFFFF VISA Errors
        '''BFFC0000 to BFFCFFFF VXIPnP Driver Errors
        '''</returns>
        Public Function ConfigureAcquisitionRecord(ByVal Time_Per_Record As Double, ByVal Acquisition_Start_Time__Offset_ As Double) As Integer
            Dim pInvokeResult As Integer = PInvoke.ConfigureAcquisitionRecord(Me._handle, Time_Per_Record, Acquisition_Start_Time__Offset_)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function configures the basic settings for the time axis.
        '''
        '''Attribute(s):
        '''RSRTM_ATTR_HORZ_SCALE
        '''RSRTM_ATTR_HORZ_REFERENCE
        '''
        '''Remote-control command(s):
        '''TIMebase:SCALe
        '''TIMebase:REFerence
        '''</summary>
        '''<param name="Time_Scale">
        '''Sets the horizontal scale - the time per division on the x-axis - for all channel and math waveforms.
        '''
        '''Units: seconds
        '''
        '''Valid Values: 1.0e-9 to 50.0
        '''  
        '''Default value: 100.0e-6
        '''
        '''Attribute:
        '''RSRTM_ATTR_HORZ_SCALE
        '''
        '''</param>
        '''<param name="Reference_Point">
        '''Sets the reference point of the time scale in % of the display.
        '''
        '''Units: %
        '''
        '''Valid Values: 10 to 90
        '''  
        '''Default value: 50
        '''
        '''Attribute:
        '''RSRTM_ATTR_HORZ_REFERENCE
        '''
        '''</param>
        '''<returns>
        '''Returns the status code of this operation.  The status code  either indicates success or describes an error or warning condition.  You examine the status code from each call to an instrument driver function to determine if an error occurred.
        '''
        '''To obtain a text description of the status code, call the rsrtm_error_message function.  To obtain additional information about the error condition, call the rsrtm_GetError function.  To clear the error information from the driver, call the rsrtm_ClearError function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''
        '''Numeric Range (in Hex) Status Code Types
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF VISA Warnings
        '''3FFC0000 to 3FFCFFFF VXIPnP Driver Warnings
        '''
        '''BFFF0000 to BFFFFFFF VISA Errors
        '''BFFC0000 to BFFCFFFF VXIPnP Driver Errors
        '''</returns>
        Public Function ConfigureTimeBase(ByVal Time_Scale As Double, ByVal Reference_Point As Integer) As Integer
            Dim pInvokeResult As Integer = PInvoke.ConfigureTimeBase(Me._handle, Time_Scale, Reference_Point)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''Selects a range of samples that will be returned.
        '''
        '''Attribute(s):
        '''RSRTM_ATTR_HORZ_RECORD_LENGTH
        '''
        '''Remote-control command(s):
        '''CHANnel&lt;Channel&gt;:DATA:POINts
        '''</summary>
        '''<param name="Record_Length">
        '''Selects a range of samples that will be returned.
        '''
        '''Valid Values:
        '''RSRTM_VAL_WAVEFORM_SAMPLES_DEFAULT         (0) - Default
        '''RSRTM_VAL_WAVEFORM_SAMPLES_MAXIMUM         (1) - Maximum
        '''RSRTM_VAL_WAVEFORM_SAMPLES_DISPLAY_MAXIMUM (2) - Display Maximum
        '''
        '''Default Value: RSRTM_VAL_WAVEFORM_SAMPLES_DEFAULT (0)
        '''
        '''Attribute:
        '''RSRTM_ATTR_HORZ_RECORD_LENGTH
        '''
        '''Note(s):
        '''
        '''(1) Default: Waveform samples that are displayed on the screen
        '''
        '''(2) Maximum: All waveform samples that are stored in the memory.
        '''
        '''(3) Display Maximum: Waveform samples stored in the current waveform record but only for the displayed time range
        '''</param>
        '''<returns>
        '''Returns the status code of this operation.  The status code  either indicates success or describes an error or warning condition.  You examine the status code from each call to an instrument driver function to determine if an error occurred.
        '''
        '''To obtain a text description of the status code, call the rsscope_error_message function.  To obtain additional information about the error condition, call the rsscope_GetError function.  To clear the error information from the driver, call the rsscope_ClearError function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''
        '''Numeric Range (in Hex) Status Code Types
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF VISA Warnings
        '''3FFC0000 to 3FFCFFFF VXIPnP Driver Warnings
        '''
        '''BFFF0000 to BFFFFFFF VISA Errors
        '''BFFC0000 to BFFCFFFF VXIPnP Driver Errors
        '''</returns>
        Public Function ConfigureRecordLength(ByVal Record_Length As Integer) As Integer
            Dim pInvokeResult As Integer = PInvoke.ConfigureRecordLength(Me._handle, Record_Length)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function configures the roll mode settings.
        '''
        '''Attribute(s):
        '''RSRTM_ATTR_ROLL_MODE
        '''
        '''Remote-control command(s):
        '''TIMebase:ROLL:ENABle
        '''</summary>
        '''<param name="Mode">
        '''Activates the automatic roll mode.
        '''
        '''Valid Values:
        '''VI_FALSE - On
        '''VI_TRUE - Off
        '''
        '''  
        '''Default value: VI_TRUE (1)
        '''
        '''Attribute:
        '''RSRTM_ATTR_ROLL_MODE
        '''</param>
        '''<returns>
        '''Returns the status code of this operation.  The status code  either indicates success or describes an error or warning condition.  You examine the status code from each call to an instrument driver function to determine if an error occurred.
        '''
        '''To obtain a text description of the status code, call the rsrtm_error_message function.  To obtain additional information about the error condition, call the rsrtm_GetError function.  To clear the error information from the driver, call the rsrtm_ClearError function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''
        '''Numeric Range (in Hex) Status Code Types
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF VISA Warnings
        '''3FFC0000 to 3FFCFFFF VXIPnP Driver Warnings
        '''
        '''BFFF0000 to BFFFFFFF VISA Errors
        '''BFFC0000 to BFFCFFFF VXIPnP Driver Errors
        '''</returns>
        Public Function ConfigureRollMode(ByVal Mode As Boolean) As Integer
            Dim pInvokeResult As Integer = PInvoke.ConfigureRollMode(Me._handle, System.Convert.ToUInt16(Mode))
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function queries the number of horizontal divisions on the screen.
        '''
        '''Attribute(s):
        '''RSRTM_ATTR_HORZ_DIVISIONS
        '''
        '''Remote-control command(s):
        '''TIMebase:DIVisions?
        '''</summary>
        '''<param name="Divisions">
        '''Queries the number of horizontal divisions on the screen
        '''
        '''Attribute:
        '''RSRTM_ATTR_HORZ_DIVISIONS
        '''
        '''</param>
        '''<returns>
        '''Returns the status code of this operation.  The status code  either indicates success or describes an error or warning condition.  You examine the status code from each call to an instrument driver function to determine if an error occurred.
        '''
        '''To obtain a text description of the status code, call the rsrtm_error_message function.  To obtain additional information about the error condition, call the rsrtm_GetError function.  To clear the error information from the driver, call the rsrtm_ClearError function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''
        '''Numeric Range (in Hex) Status Code Types
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF VISA Warnings
        '''3FFC0000 to 3FFCFFFF VXIPnP Driver Warnings
        '''
        '''BFFF0000 to BFFFFFFF VISA Errors
        '''BFFC0000 to BFFCFFFF VXIPnP Driver Errors
        '''</returns>
        Public Function QueryDivisions(ByRef Divisions As Integer) As Integer
            Dim pInvokeResult As Integer = PInvoke.QueryDivisions(Me._handle, Divisions)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function queries the sample rate, that is the number of recorded waveform samples per second.
        '''
        '''Attribute(s):
        '''RSRTM_ATTR_HORZ_SAMPLE_RATE
        '''
        '''Remote-control command(s):
        '''ACQuire:SRATe?
        '''</summary>
        '''<param name="Sample_Rate">
        '''Returns the sample rate, that is the number of recorded waveform samples per second.
        '''
        '''Attribute:
        '''RSRTM_ATTR_HORZ_SAMPLE_RATE
        '''
        '''</param>
        '''<returns>
        '''Returns the status code of this operation.  The status code  either indicates success or describes an error or warning condition.  You examine the status code from each call to an instrument driver function to determine if an error occurred.
        '''
        '''To obtain a text description of the status code, call the rsrtm_error_message function.  To obtain additional information about the error condition, call the rsrtm_GetError function.  To clear the error information from the driver, call the rsrtm_ClearError function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''
        '''Numeric Range (in Hex) Status Code Types
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF VISA Warnings
        '''3FFC0000 to 3FFCFFFF VXIPnP Driver Warnings
        '''
        '''BFFF0000 to BFFFFFFF VISA Errors
        '''BFFC0000 to BFFCFFFF VXIPnP Driver Errors
        '''</returns>
        Public Function QuerySampleRate(ByRef Sample_Rate As Double) As Integer
            Dim pInvokeResult As Integer = PInvoke.QuerySampleRate(Me._handle, Sample_Rate)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''Queries the required acquisition time. If FFT gating is used and the resolution BW is set to constant, record length can be extended to acquire the required number of samples. In this case, the required acquisition time differs from the adjusted acquisition time.
        '''
        '''Attribute(s):
        '''RSRTM_ATTR_ACQUISITION_TIME
        '''
        '''Remote-control command(s):
        '''TIMebase:RATime?
        '''</summary>
        '''<param name="Acquisition_Time">
        '''Queries the required acquisition time. If FFT gating is used and the resolution BW is set to constant, record length can be extended to acquire the required number of samples. In this case, the required acquisition time differs from the adjusted acquisition time.
        '''
        '''Attribute:
        '''RSRTM_ATTR_ACQUISITION_TIME
        '''</param>
        '''<returns>
        '''Returns the status code of this operation.  The status code  either indicates success or describes an error or warning condition.  You examine the status code from each call to an instrument driver function to determine if an error occurred.
        '''
        '''To obtain a text description of the status code, call the rsrtm_error_message function.  To obtain additional information about the error condition, call the rsrtm_GetError function.  To clear the error information from the driver, call the rsrtm_ClearError function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''
        '''Numeric Range (in Hex) Status Code Types
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF VISA Warnings
        '''3FFC0000 to 3FFCFFFF VXIPnP Driver Warnings
        '''
        '''BFFF0000 to BFFFFFFF VISA Errors
        '''BFFC0000 to BFFCFFFF VXIPnP Driver Errors
        '''</returns>
        Public Function QueryAcquisitionTime(ByRef Acquisition_Time As Double) As Integer
            Dim pInvokeResult As Integer = PInvoke.QueryAcquisitionTime(Me._handle, Acquisition_Time)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''Defines the mode to set the sample rate (samples per second saved in the memory) and the waveform acquisition rate (waveforms per second).
        '''
        '''Attribute(s):
        '''RSRTM_ATTR_SAMPLE_RATE
        '''
        '''Remote-control command(s):
        '''ACQuire:WRATe
        '''</summary>
        '''<param name="Waveform_Rate">
        '''Defines the mode to set the sample rate (samples per second saved in the memory) and the waveform acquisition rate (waveforms per second).
        '''
        '''Valid Values:
        '''RSRTM_VAL_RATE_AUTO    (0) - Auto
        '''RSRTM_VAL_RATE_MAX_SAM (1) - Maximum Sample Rate
        '''RSRTM_VAL_RATE_MAX_WAV (2) - Maximum Waveform 
        '''
        '''Default value:  RSRTM_VAL_RATE_AUTO (0)
        '''
        '''Attribute:
        '''RSRTM_ATTR_WAVEFORM_RATE
        '''</param>
        '''<returns>
        '''Returns the status code of this operation.  The status code  either indicates success or describes an error or warning condition.  You examine the status code from each call to an instrument driver function to determine if an error occurred.
        '''
        '''To obtain a text description of the status code, call the rsrtm_error_message function.  To obtain additional information about the error condition, call the rsrtm_GetError function.  To clear the error information from the driver, call the rsrtm_ClearError function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''
        '''Numeric Range (in Hex) Status Code Types
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF VISA Warnings
        '''3FFC0000 to 3FFCFFFF VXIPnP Driver Warnings
        '''
        '''BFFF0000 to BFFFFFFF VISA Errors
        '''BFFC0000 to BFFCFFFF VXIPnP Driver Errors
        '''</returns>
        Public Function ConfigureWaveformAcquisitionRate(ByVal Waveform_Rate As Integer) As Integer
            Dim pInvokeResult As Integer = PInvoke.ConfigureWaveformAcquisitionRate(Me._handle, Waveform_Rate)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function queries the sample rate of the ADC, that is the number of points that are sampled by the ADC in one second.
        '''
        '''Attribute(s):
        '''RSRTM_ATTR_HORZ_ADC_SAMPLE_RATE
        '''
        '''Remote-control command(s):
        '''ACQuire:POINts:ARATe?
        '''</summary>
        '''<param name="ADC_Sample_Rate">
        '''Returns the sample rate of the ADC, that is the number of points that are sampled by the ADC in one second.
        '''
        '''Attribute:
        '''RSRTM_ATTR_HORZ_ADC_SAMPLE_RATE
        '''
        '''</param>
        '''<returns>
        '''Returns the status code of this operation.  The status code  either indicates success or describes an error or warning condition.  You examine the status code from each call to an instrument driver function to determine if an error occurred.
        '''
        '''To obtain a text description of the status code, call the rsrtm_error_message function.  To obtain additional information about the error condition, call the rsrtm_GetError function.  To clear the error information from the driver, call the rsrtm_ClearError function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''
        '''Numeric Range (in Hex) Status Code Types
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF VISA Warnings
        '''3FFC0000 to 3FFCFFFF VXIPnP Driver Warnings
        '''
        '''BFFF0000 to BFFFFFFF VISA Errors
        '''BFFC0000 to BFFCFFFF VXIPnP Driver Errors
        '''</returns>
        Public Function QueryADCSampleRate(ByRef ADC_Sample_Rate As Double) As Integer
            Dim pInvokeResult As Integer = PInvoke.QueryADCSampleRate(Me._handle, ADC_Sample_Rate)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function configures the method of adding waveform points to the samples of the ADC in order to fill the record length.
        '''
        '''Attribute(s):
        '''RSRTM_ATTR_SAMPLE_MODE
        '''
        '''Remote-control command(s):
        '''ACQuire:MODE
        '''</summary>
        '''<param name="Resolution_Enhancement">
        '''Selects the method of adding waveform points to the samples of the ADC in order to fill the record length.
        '''
        '''Note(s):
        '''(1) Value RSRTM_VAL_INTERPOLATED_TIME is only available for R&amp;S RTO instrument.
        '''
        '''(2) Default value for R&amp;S RTM instrument is RSRTM_VAL_REAL_TIME.
        '''
        '''Valid Values:
        '''RSRTM_VAL_REAL_TIME         (0) - Real Time
        '''RSRTM_VAL_EQUIVALENT_TIME   (1) - Equivalent Time
        '''
        '''  
        '''Default value:  RSRTM_VAL_REAL_TIME (2)
        '''
        '''Attribute:
        '''RSRTM_ATTR_SAMPLE_MODE
        '''
        '''</param>
        '''<returns>
        '''Returns the status code of this operation.  The status code  either indicates success or describes an error or warning condition.  You examine the status code from each call to an instrument driver function to determine if an error occurred.
        '''
        '''To obtain a text description of the status code, call the rsrtm_error_message function.  To obtain additional information about the error condition, call the rsrtm_GetError function.  To clear the error information from the driver, call the rsrtm_ClearError function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''
        '''Numeric Range (in Hex) Status Code Types
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF VISA Warnings
        '''3FFC0000 to 3FFCFFFF VXIPnP Driver Warnings
        '''
        '''BFFF0000 to BFFFFFFF VISA Errors
        '''BFFC0000 to BFFCFFFF VXIPnP Driver Errors
        '''</returns>
        Public Function ConfigureResolutionEnhancement(ByVal Resolution_Enhancement As Integer) As Integer
            Dim pInvokeResult As Integer = PInvoke.ConfigureResolutionEnhancement(Me._handle, Resolution_Enhancement)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function configures the interpolation method the oscilloscope uses when it cannot sample a voltage for a point in the waveform record.
        '''
        '''Note(s):
        '''
        '''(1) Set resolution enhancement (rsrtm_ConfigureResolutionEnhancement) to interpolated time to use this function.
        '''
        '''Attribute(s):
        '''RSRTM_ATTR_INTERPOLATION
        '''
        '''Remote-control command(s):
        '''ACQuire:INTerpolate
        '''</summary>
        '''<param name="Interpolation">
        '''Pass the interpolation method you want the oscilloscope to 
        '''use when it cannot sample a voltage for a point in the waveform record.
        '''
        '''Valid Values:
        '''RSRTM_VAL_SINE_X      (0) - sin (x)/x
        '''RSRTM_VAL_LINEAR      (1) - Linear
        '''RSRTM_VAL_SAMPLE_HOLD (2) - Sample/Hold
        '''  
        '''Default value:  RSRTM_VAL_SINE_X (0)
        '''
        '''Attribute:
        '''RSRTM_ATTR_INTERPOLATION
        '''
        '''</param>
        '''<returns>
        '''Returns the status code of this operation.  The status code  either indicates success or describes an error or warning condition.  You examine the status code from each call to an instrument driver function to determine if an error occurred.
        '''
        '''To obtain a text description of the status code, call the rsrtm_error_message function.  To obtain additional information about the error condition, call the rsrtm_GetError function.  To clear the error information from the driver, call the rsrtm_ClearError function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''
        '''Numeric Range (in Hex) Status Code Types
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF VISA Warnings
        '''3FFC0000 to 3FFCFFFF VXIPnP Driver Warnings
        '''
        '''BFFF0000 to BFFFFFFF VISA Errors
        '''BFFC0000 to BFFCFFFF VXIPnP Driver Errors
        '''</returns>
        Public Function ConfigureInterpolation(ByVal Interpolation As Integer) As Integer
            Dim pInvokeResult As Integer = PInvoke.ConfigureInterpolation(Me._handle, Interpolation)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function configures the method to reduce the data stream of the ADC to a stream of waveform points with lower sample rate.
        '''
        '''Attribute(s):
        '''RSRTM_ATTR_WAVEFORM_ACQUISITION_TYPE
        '''
        '''Remote-control command(s):
        '''CHANnel&lt;Channel&gt;:ARIThmetics
        '''</summary>
        '''<param name="Channel">
        '''This control selects the channel.
        '''
        '''Valid Values: 
        '''RSRTM_VAL_CHANNEL_1   (1) - 1
        '''RSRTM_VAL_CHANNEL_2   (2) - 2
        '''RSRTM_VAL_CHANNEL_3   (3) - 3
        '''RSRTM_VAL_CHANNEL_4   (4) - 4
        '''RSRTM_VAL_CHANNEL_EXT (5) - External
        '''
        '''Default Value: RSRTM_VAL_CHANNEL_1 (1)
        '''</param>
        '''<param name="Arithmetic">
        '''Selects the method to reduce the data stream of the ADC to a stream of waveform points with lower sample rate.
        '''
        '''Valid Values:
        '''RSRTM_VAL_OFF      (0) - Off
        '''RSRTM_VAL_ENVELOPE (1) - Envelope
        '''RSRTM_VAL_AVERAGE  (2) - Average
        '''
        '''Default value:  RSRTM_VAL_OFF (0)
        '''
        '''Attribute:
        '''RSRTM_ATTR_WAVEFORM_ACQUISITION_TYPE
        '''
        '''</param>
        '''<returns>
        '''Returns the status code of this operation.  The status code  either indicates success or describes an error or warning condition.  You examine the status code from each call to an instrument driver function to determine if an error occurred.
        '''
        '''To obtain a text description of the status code, call the rsrtm_error_message function.  To obtain additional information about the error condition, call the rsrtm_GetError function.  To clear the error information from the driver, call the rsrtm_ClearError function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''
        '''Numeric Range (in Hex) Status Code Types
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF VISA Warnings
        '''3FFC0000 to 3FFCFFFF VXIPnP Driver Warnings
        '''
        '''BFFF0000 to BFFFFFFF VISA Errors
        '''BFFC0000 to BFFCFFFF VXIPnP Driver Errors
        '''</returns>
        Public Function ConfigureWaveformArithmetic(ByVal Channel As Integer, ByVal Arithmetic As Integer) As Integer
            Dim pInvokeResult As Integer = PInvoke.ConfigureWaveformArithmetic(Me._handle, Channel, Arithmetic)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''Sets the limit frequency if Waveform arithmetics is set to "Smooth".
        '''
        '''Attribute(s):
        '''RSRTM_ATTR_FILTER_FREQUENCY
        '''
        '''Remote-control command(s):
        '''ACQuire:FILTer:FREQency
        '''</summary>
        '''<param name="Filter_Frequency">
        '''Sets the limit frequency if Waveform Arithmetics  is set to "Smooth".
        '''
        '''Units: dB
        '''
        '''Valid Values: not checked
        '''  
        '''Default value: not checked
        '''
        '''Attribute:
        '''RSRTM_ATTR_FILTER_FREQUENCY
        '''
        '''</param>
        '''<returns>
        '''Returns the status code of this operation.  The status code  either indicates success or describes an error or warning condition.  You examine the status code from each call to an instrument driver function to determine if an error occurred.
        '''
        '''To obtain a text description of the status code, call the rsrtm_error_message function.  To obtain additional information about the error condition, call the rsrtm_GetError function.  To clear the error information from the driver, call the rsrtm_ClearError function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''
        '''Numeric Range (in Hex) Status Code Types
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF VISA Warnings
        '''3FFC0000 to 3FFCFFFF VXIPnP Driver Warnings
        '''
        '''BFFF0000 to BFFFFFFF VISA Errors
        '''BFFC0000 to BFFCFFFF VXIPnP Driver Errors
        '''</returns>
        Public Function ConfigureFilterFrequency(ByVal Filter_Frequency As Double) As Integer
            Dim pInvokeResult As Integer = PInvoke.ConfigureFilterFrequency(Me._handle, Filter_Frequency)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function returns the number of samples for the given range.
        '''
        '''Attribute(s):
        '''RSRTM_ATTR_WAVEFORM_SAMPLES
        '''
        '''Remote-control command(s):
        '''CHANnel&lt;Channel&gt;:DATA:POINts?
        '''</summary>
        '''<param name="Channel">
        '''This control selects the channel.
        '''
        '''Valid Values: 
        '''RSRTM_VAL_CHANNEL_1   (1) - 1
        '''RSRTM_VAL_CHANNEL_2   (2) - 2
        '''RSRTM_VAL_CHANNEL_3   (3) - 3
        '''RSRTM_VAL_CHANNEL_4   (4) - 4
        '''RSRTM_VAL_CHANNEL_EXT (5) - External
        '''
        '''Default Value: RSRTM_VAL_CHANNEL_1 (1)
        '''</param>
        '''<param name="Samples">
        '''Returns the number of samples for the given range.
        '''
        '''Attribute:
        '''RSRTM_ATTR_WAVEFORM_SAMPLES
        '''</param>
        '''<returns>
        '''Returns the status code of this operation.  The status code  either indicates success or describes an error or warning condition.  You examine the status code from each call to an instrument driver function to determine if an error occurred.
        '''
        '''To obtain a text description of the status code, call the rsrtm_error_message function.  To obtain additional information about the error condition, call the rsrtm_GetError function.  To clear the error information from the driver, call the rsrtm_ClearError function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''
        '''Numeric Range (in Hex) Status Code Types
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF VISA Warnings
        '''3FFC0000 to 3FFCFFFF VXIPnP Driver Warnings
        '''
        '''BFFF0000 to BFFFFFFF VISA Errors
        '''BFFC0000 to BFFCFFFF VXIPnP Driver Errors
        '''</returns>
        Public Function QueryWaveformSamplesRange(ByVal Channel As Integer, ByRef Samples As Integer) As Integer
            Dim pInvokeResult As Integer = PInvoke.QueryWaveformSamplesRange(Me._handle, Channel, Samples)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function configures the number of waveforms that the oscilloscope  acquires and averages.  After the oscilloscope acquires as many waveforms as you specify, it returns to the idle state.  
        '''
        '''Attribute(s):
        '''RSRTM_ATTR_NUM_AVERAGES
        '''
        '''Remote-control command(s):
        '''ACQuire:AVERage:COUNt
        '''</summary>
        '''<param name="Number_of_Averages">
        '''Pass the number of waveforms you want the oscilloscope to acquire and to average. After the oscilloscope acquires as many waveforms as you specify, it returns to the idle state.
        '''
        '''Valid Values: not checked
        '''
        '''Note(s):
        '''(1) For R&amp;S RTO instrument is range 1 to 16777215.
        '''
        '''(2) For R&amp;S RTM instrument only numbers from the 2n progression are permitted.
        '''
        '''Default Value: 1
        '''
        '''Attribute:
        '''RSRTM_ATTR_NUM_AVERAGES
        '''</param>
        '''<returns>
        '''Returns the status code of this operation.  The status code  either indicates success or describes an error or warning condition.  You examine the status code from each call to an instrument driver function to determine if an error occurred.
        '''
        '''To obtain a text description of the status code, call the rsrtm_error_message function.  To obtain additional information about the error condition, call the rsrtm_GetError function.  To clear the error information from the driver, call the rsrtm_ClearError function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''
        '''Numeric Range (in Hex) Status Code Types
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF VISA Warnings
        '''3FFC0000 to 3FFCFFFF VXIPnP Driver Warnings
        '''
        '''BFFF0000 to BFFFFFFF VISA Errors
        '''BFFC0000 to BFFCFFFF VXIPnP Driver Errors
        '''</returns>
        Public Function ConfigureNumberOfAverages(ByVal Number_of_Averages As Integer) As Integer
            Dim pInvokeResult As Integer = PInvoke.ConfigureNumberOfAverages(Me._handle, Number_of_Averages)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function configures the number of waveforms acquired when single is selected in rsrtm_InitiateAcquisition function.
        '''
        '''Attribute(s):
        '''RSRTM_ATTR_NUMBER_OF_WAVEFORMS
        '''
        '''Remote-control command(s):
        '''ACQuire:NSINgle:COUNt
        '''</summary>
        '''<param name="Number_Of_Waveforms">
        '''Sets the number of waveforms acquired when single is selected in "Initiate Acquisition" function.
        '''
        '''Valid Values:
        '''not checked
        '''
        '''Default Value:
        '''not checked 
        '''
        '''Attribute(s):
        '''RSRTM_ATTR_NUMBER_OF_WAVEFORMS
        '''</param>
        '''<returns>
        '''Returns the status code of this operation.  The status code  either indicates success or describes an error or warning condition.  You examine the status code from each call to an instrument driver function to determine if an error occurred.
        '''
        '''To obtain a text description of the status code, call the rsrtm_error_message function.  To obtain additional information about the error condition, call the rsrtm_GetError function.  To clear the error information from the driver, call the rsrtm_ClearError function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''
        '''Numeric Range (in Hex) Status Code Types
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF VISA Warnings
        '''3FFC0000 to 3FFCFFFF VXIPnP Driver Warnings
        '''
        '''BFFF0000 to BFFFFFFF VISA Errors
        '''BFFC0000 to BFFCFFFF VXIPnP Driver Errors
        '''</returns>
        Public Function ConfigureNumberOfWaveforms(ByVal Number_Of_Waveforms As Integer) As Integer
            Dim pInvokeResult As Integer = PInvoke.ConfigureNumberOfWaveforms(Me._handle, Number_Of_Waveforms)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function configures the common attributes of the oscilloscope's channel subsystem for a particular channel.  These attributes are the vertical range, vertical offset, coupling, probe attenuation, and channel enabled.
        '''
        '''Attribute(s):
        '''RSRTM_ATTR_CHANNEL_ENABLED
        '''RSRTM_ATTR_VERTICAL_RANGE
        '''RSRTM_ATTR_VERTICAL_OFFSET
        '''RSRTM_ATTR_VERTICAL_COUPLING
        '''
        '''Remote-control command(s):
        '''CHANnel&lt;Channel&gt;:STATe
        '''CHANnel&lt;Channel&gt;:RANGe
        '''CHANnel&lt;Channel&gt;:POSition
        '''CHANnel&lt;Channel&gt;:COUPling
        '''</summary>
        '''<param name="Channel">
        '''This control selects the channel.
        '''
        '''Valid Values: 
        '''RSRTM_VAL_CHANNEL_1   (1) - 1
        '''RSRTM_VAL_CHANNEL_2   (2) - 2
        '''RSRTM_VAL_CHANNEL_3   (3) - 3
        '''RSRTM_VAL_CHANNEL_4   (4) - 4
        '''RSRTM_VAL_CHANNEL_EXT (5) - External
        '''
        '''Default Value: RSRTM_VAL_CHANNEL_1 (1)
        '''</param>
        '''<param name="Channel_Enabled">
        '''Switches the channel signal on or off.
        '''
        '''Valid Values:
        '''VI_FALSE (0) - OFF
        '''VI_TRUE  (1) - ON
        '''
        '''Default Value: VI_TRUE  (1)
        '''
        '''Attribute:
        '''RSRTM_ATTR_CHANNEL_ENABLED
        '''</param>
        '''<param name="Vertical_Range">
        '''Sets the voltage range across the 10 vertical divisions of the diagram.
        '''
        '''Units:  volts
        '''  
        '''Valid Values: 8e-3 to 80.0
        '''
        '''Default Value: 0.04 V
        '''
        '''Attribute: 
        '''RSRTM_ATTR_VERTICAL_RANGE
        '''</param>
        '''<param name="Vertical_Offset">
        '''Pass the location of the center of the range that you specify with for the Vertical Range parameter. Express the value with respect to ground.
        '''
        '''For example, to acquire a sine wave that spans between 0.0 and 10.0 volts, pass 5.0 as the value of this parameter.
        '''
        '''Units:  volts
        '''
        '''Valid Values:  -5.0 to 5.0
        '''
        '''Default Value: 0.0
        '''
        '''Attribute:
        '''RSRTM_ATTR_VERTICAL_OFFSET
        '''</param>
        '''<param name="Vertical_Coupling">
        '''Specify how you want the oscilloscope to couple the input signal for the channel.
        '''
        '''Valid Values:
        '''RSRTM_VAL_AC       (0) - AC
        '''RSRTM_VAL_DC       (1) - DC 50 Ohm
        '''RSRTM_VAL_DC_LIMIT (2) - DC 1 MOhm
        ''' 
        '''Default value: RSRTM_VAL_DC (1)
        '''
        '''Attribute:
        '''RSRTM_ATTR_VERTICAL_COUPLING
        '''
        '''</param>
        '''<returns>
        '''Returns the status code of this operation.  The status code  either indicates success or describes an error or warning condition.  You examine the status code from each call to an instrument driver function to determine if an error occurred.
        '''
        '''To obtain a text description of the status code, call the rsrtm_error_message function.  To obtain additional information about the error condition, call the rsrtm_GetError function.  To clear the error information from the driver, call the rsrtm_ClearError function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''
        '''Numeric Range (in Hex) Status Code Types
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF VISA Warnings
        '''3FFC0000 to 3FFCFFFF VXIPnP Driver Warnings
        '''
        '''BFFF0000 to BFFFFFFF VISA Errors
        '''BFFC0000 to BFFCFFFF VXIPnP Driver Errors
        '''</returns>
        Public Function ConfigureChannel(ByVal Channel As Integer, ByVal Channel_Enabled As Boolean, ByVal Vertical_Range As Double, ByVal Vertical_Offset As Double, ByVal Vertical_Coupling As Integer) As Integer
            Dim pInvokeResult As Integer = PInvoke.ConfigureChannel(Me._handle, Channel, System.Convert.ToUInt16(Channel_Enabled), Vertical_Range, Vertical_Offset, Vertical_Coupling)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function configures the offset voltage. The offset is subtracted to correct an offset-affected signal.
        '''
        '''Attribute(s):
        '''RSRTM_ATTR_CHANNEL_OFFSET
        '''
        '''Remote-control command(s):
        '''CHANnel&lt;Channel&gt;:OFFSet
        '''</summary>
        '''<param name="Channel">
        '''This control selects the channel.
        '''
        '''Valid Values: 
        '''RSRTM_VAL_CHANNEL_1   (1) - 1
        '''RSRTM_VAL_CHANNEL_2   (2) - 2
        '''RSRTM_VAL_CHANNEL_3   (3) - 3
        '''RSRTM_VAL_CHANNEL_4   (4) - 4
        '''RSRTM_VAL_CHANNEL_EXT (5) - External
        '''
        '''Default Value: RSRTM_VAL_CHANNEL_1 (1)
        '''</param>
        '''<param name="Offset">
        '''Sets the offset voltage.
        '''
        '''Units:  volts
        '''
        '''Valid Values:  -10.0 to 10.0
        '''
        '''Default Value: 0.0
        '''
        '''Attribute:
        '''RSRTM_ATTR_CHANNEL_OFFSET
        '''</param>
        '''<returns>
        '''Returns the status code of this operation.  The status code  either indicates success or describes an error or warning condition.  You examine the status code from each call to an instrument driver function to determine if an error occurred.
        '''
        '''To obtain a text description of the status code, call the rsrtm_error_message function.  To obtain additional information about the error condition, call the rsrtm_GetError function.  To clear the error information from the driver, call the rsrtm_ClearError function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''
        '''Numeric Range (in Hex) Status Code Types
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF VISA Warnings
        '''3FFC0000 to 3FFCFFFF VXIPnP Driver Warnings
        '''
        '''BFFF0000 to BFFFFFFF VISA Errors
        '''BFFC0000 to BFFCFFFF VXIPnP Driver Errors
        '''</returns>
        Public Function ConfigureChannelOffset(ByVal Channel As Integer, ByVal Offset As Double) As Integer
            Dim pInvokeResult As Integer = PInvoke.ConfigureChannelOffset(Me._handle, Channel, Offset)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''4This function configures the vertical scale for the indicated channel.
        '''
        '''Attribute(s):
        '''RSRTM_ATTR_VERTICAL_SCALE
        '''
        '''Remote-control command(s):
        '''CHANnel&lt;Channel&gt;:SCALe
        '''</summary>
        '''<param name="Channel">
        '''This control selects the channel.
        '''
        '''Valid Values: 
        '''RSRTM_VAL_CHANNEL_1   (1) - 1
        '''RSRTM_VAL_CHANNEL_2   (2) - 2
        '''RSRTM_VAL_CHANNEL_3   (3) - 3
        '''RSRTM_VAL_CHANNEL_4   (4) - 4
        '''RSRTM_VAL_CHANNEL_EXT (5) - External
        '''
        '''Default Value: RSRTM_VAL_CHANNEL_1 (1)
        '''</param>
        '''<param name="Vertical_Scale">
        '''Sets the vertical scale for the indicated channel.
        '''
        '''Units:  volts
        '''  
        '''Valid Values: 0.001 to 10
        '''
        '''Default Value: 0.005 V
        '''
        '''Attribute: 
        '''RSRTM_ATTR_VERTICAL_SCALE
        '''</param>
        '''<returns>
        '''Returns the status code of this operation.  The status code  either indicates success or describes an error or warning condition.  You examine the status code from each call to an instrument driver function to determine if an error occurred.
        '''
        '''To obtain a text description of the status code, call the rsrtm_error_message function.  To obtain additional information about the error condition, call the rsrtm_GetError function.  To clear the error information from the driver, call the rsrtm_ClearError function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''
        '''Numeric Range (in Hex) Status Code Types
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF VISA Warnings
        '''3FFC0000 to 3FFCFFFF VXIPnP Driver Warnings
        '''
        '''BFFF0000 to BFFFFFFF VISA Errors
        '''BFFC0000 to BFFCFFFF VXIPnP Driver Errors
        '''</returns>
        Public Function ConfigureChannelVerticalScale(ByVal Channel As Integer, ByVal Vertical_Scale As Double) As Integer
            Dim pInvokeResult As Integer = PInvoke.ConfigureChannelVerticalScale(Me._handle, Channel, Vertical_Scale)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''Threshold value for digitization of analog signals. If the signal value is higher than the threshold, the signal state is high (1 or true for the boolean logic). Otherwise, the signal state is considered low (0 or false) if the signal value is below the threshold.
        '''
        '''Note(s):
        '''(1) This function is only available for R&amp;S RTM instrument.
        '''
        '''Attribute(s):
        '''RSRTM_ATTR_CHANNEL_THRESHOLD
        '''
        '''Remote-control command(s):
        '''CHANnel&lt;Channel&gt;:THReshold
        '''</summary>
        '''<param name="Channel">
        '''This control selects the channel.
        '''
        '''Valid Values: 
        '''RSRTM_VAL_CHANNEL_1   (1) - 1
        '''RSRTM_VAL_CHANNEL_2   (2) - 2
        '''RSRTM_VAL_CHANNEL_3   (3) - 3
        '''RSRTM_VAL_CHANNEL_4   (4) - 4
        '''RSRTM_VAL_CHANNEL_EXT (5) - External
        '''
        '''Default Value: RSRTM_VAL_CHANNEL_1 (1)
        '''</param>
        '''<param name="Threshold">
        '''Threshold value for digitization of analog signals. If the signal value is higher than the threshold, the signal state is high (1 or true for the boolean logic). Otherwise, the signal state is considered low (0 or false) if the signal value is below the threshold.
        '''  
        '''Valid Values:
        '''not checked
        '''
        '''Default Value: 1.4 V
        '''
        '''Attribute: 
        '''RSRTM_ATTR_CHANNEL_THRESHOLD
        '''</param>
        '''<returns>
        '''Returns the status code of this operation.  The status code  either indicates success or describes an error or warning condition.  You examine the status code from each call to an instrument driver function to determine if an error occurred.
        '''
        '''To obtain a text description of the status code, call the rsrtm_error_message function.  To obtain additional information about the error condition, call the rsrtm_GetError function.  To clear the error information from the driver, call the rsrtm_ClearError function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''
        '''Numeric Range (in Hex) Status Code Types
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF VISA Warnings
        '''3FFC0000 to 3FFCFFFF VXIPnP Driver Warnings
        '''
        '''BFFF0000 to BFFFFFFF VISA Errors
        '''BFFC0000 to BFFCFFFF VXIPnP Driver Errors
        '''</returns>
        Public Function ConfigureChannelThreshold(ByVal Channel As Integer, ByVal Threshold As Double) As Integer
            Dim pInvokeResult As Integer = PInvoke.ConfigureChannelThreshold(Me._handle, Channel, Threshold)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function configures the bandwidth limit for the indicated channel.
        '''
        '''Attribute(s):
        '''RSRTM_ATTR_CHANNEL_BANDWIDTH_LIMIT
        '''
        '''Remote-control command(s):
        '''CHANnel&lt;Channel&gt;:BANDwidth
        '''</summary>
        '''<param name="Channel">
        '''This control selects the channel.
        '''
        '''Valid Values: 
        '''RSRTM_VAL_CHANNEL_1   (1) - 1
        '''RSRTM_VAL_CHANNEL_2   (2) - 2
        '''RSRTM_VAL_CHANNEL_3   (3) - 3
        '''RSRTM_VAL_CHANNEL_4   (4) - 4
        '''RSRTM_VAL_CHANNEL_EXT (5) - External
        '''
        '''Default Value: RSRTM_VAL_CHANNEL_1 (1)
        '''</param>
        '''<param name="Bandwidth">
        '''Selects the bandwidth limit for the indicated channel.
        '''
        '''Valid Values:
        '''RSRTM_VAL_BW_FULL (0) - Full
        '''RSRTM_VAL_BW_400  (1) - 400 MHz
        '''RSRTM_VAL_BW_200  (2) - 200 MHz
        '''RSRTM_VAL_BW_20   (3) - 20 MHz
        ''' 
        '''Default value: RSRTM_VAL_BW_FULL (0)
        '''
        '''Attribute:
        '''RSRTM_ATTR_CHANNEL_BANDWIDTH_LIMIT
        '''
        '''</param>
        '''<returns>
        '''Returns the status code of this operation.  The status code  either indicates success or describes an error or warning condition.  You examine the status code from each call to an instrument driver function to determine if an error occurred.
        '''
        '''To obtain a text description of the status code, call the rsrtm_error_message function.  To obtain additional information about the error condition, call the rsrtm_GetError function.  To clear the error information from the driver, call the rsrtm_ClearError function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''
        '''Numeric Range (in Hex) Status Code Types
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF VISA Warnings
        '''3FFC0000 to 3FFCFFFF VXIPnP Driver Warnings
        '''
        '''BFFF0000 to BFFFFFFF VISA Errors
        '''BFFC0000 to BFFCFFFF VXIPnP Driver Errors
        '''</returns>
        Public Function ConfigureChannelBandwidth(ByVal Channel As Integer, ByVal Bandwidth As Integer) As Integer
            Dim pInvokeResult As Integer = PInvoke.ConfigureChannelBandwidth(Me._handle, Channel, Bandwidth)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function turns the inversion of the signal amplitude on or off. To invert means to reflect the voltage values of all signal components against the ground level. Inversion affects only the display of the signal but not the trigger.
        '''
        '''Attribute(s):
        '''RSRTM_ATTR_CHANNEL_POLARITY
        '''
        '''Remote-control command(s):
        '''CHANnel&lt;channel&gt;:POLarity
        '''</summary>
        '''<param name="Channel">
        '''This control selects the channel.
        '''
        '''Valid Values: 
        '''RSRTM_VAL_CHANNEL_1   (1) - 1
        '''RSRTM_VAL_CHANNEL_2   (2) - 2
        '''RSRTM_VAL_CHANNEL_3   (3) - 3
        '''RSRTM_VAL_CHANNEL_4   (4) - 4
        '''RSRTM_VAL_CHANNEL_EXT (5) - External
        '''
        '''Default Value: RSRTM_VAL_CHANNEL_1 (1)
        '''</param>
        '''<param name="Polarity">
        '''Selects polarity.
        '''
        '''Valid Values:
        '''RSRTM_VAL_POLARITY_NORM (0) - Normal
        '''RSRTM_VAL_POLARITY_INV  (1) - Inverted
        '''
        ''' 
        '''Default value: RSRTM_VAL_POLARITY_NORM (0)
        '''
        '''Attribute:
        '''RSRTM_ATTR_CHANNEL_POLARITY
        '''
        '''</param>
        '''<returns>
        '''Returns the status code of this operation.  The status code  either indicates success or describes an error or warning condition.  You examine the status code from each call to an instrument driver function to determine if an error occurred.
        '''
        '''To obtain a text description of the status code, call the rsrtm_error_message function.  To obtain additional information about the error condition, call the rsrtm_GetError function.  To clear the error information from the driver, call the rsrtm_ClearError function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''
        '''Numeric Range (in Hex) Status Code Types
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF VISA Warnings
        '''3FFC0000 to 3FFCFFFF VXIPnP Driver Warnings
        '''
        '''BFFF0000 to BFFFFFFF VISA Errors
        '''BFFC0000 to BFFCFFFF VXIPnP Driver Errors
        '''</returns>
        Public Function ConfigureChannelPolarity(ByVal Channel As Integer, ByVal Polarity As Integer) As Integer
            Dim pInvokeResult As Integer = PInvoke.ConfigureChannelPolarity(Me._handle, Channel, Polarity)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function configures the overload status of the specified channel from the status bit.
        '''
        '''Attribute(s):
        '''RSRTM_ATTR_CHANNEL_OVERLOAD
        '''
        '''Remote-control command(s):
        '''CHANnel&lt;Channel&gt;:OVERload
        '''</summary>
        '''<param name="Channel">
        '''This control selects the channel.
        '''
        '''Valid Values: 
        '''RSRTM_VAL_CHANNEL_1   (1) - 1
        '''RSRTM_VAL_CHANNEL_2   (2) - 2
        '''RSRTM_VAL_CHANNEL_3   (3) - 3
        '''RSRTM_VAL_CHANNEL_4   (4) - 4
        '''RSRTM_VAL_CHANNEL_EXT (5) - External
        '''
        '''Default Value: RSRTM_VAL_CHANNEL_1 (1)
        '''</param>
        '''<param name="Overload">
        '''Retrieves the overload status of the specified channel from the status bit. When the overload problem is solved, the command resets the status bit. Use VI_FALSE to clear the overload condition.
        '''
        '''Valid Values:
        '''VI_FALSE (0) - Off
        '''VI_TRUE  (1) - On
        '''
        '''Default Value: VI_FALSE (0) 
        '''
        '''Attribute: RSRTM_ATTR_CHANNEL_OVERLOAD
        '''</param>
        '''<returns>
        '''Returns the status code of this operation.  The status code  either indicates success or describes an error or warning condition.  You examine the status code from each call to an instrument driver function to determine if an error occurred.
        '''
        '''To obtain a text description of the status code, call the rsrtm_error_message function.  To obtain additional information about the error condition, call the rsrtm_GetError function.  To clear the error information from the driver, call the rsrtm_ClearError function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''
        '''Numeric Range (in Hex) Status Code Types
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF VISA Warnings
        '''3FFC0000 to 3FFCFFFF VXIPnP Driver Warnings
        '''
        '''BFFF0000 to BFFFFFFF VISA Errors
        '''BFFC0000 to BFFCFFFF VXIPnP Driver Errors
        '''</returns>
        Public Function ConfigureChannelOverload(ByVal Channel As Integer, ByVal Overload As Boolean) As Integer
            Dim pInvokeResult As Integer = PInvoke.ConfigureChannelOverload(Me._handle, Channel, System.Convert.ToUInt16(Overload))
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''Skew or deskew compensates delay differences between channels caused by the different length of cables, probes, and other sources. Correct deskew values are important for accurate triggering.
        '''
        '''Attribute(s):
        '''RSRTM_ATTR_CHANNEL_SKEW
        '''
        '''Remote-control command(s):
        '''CHANnel&lt;Channel&gt;:SKEW
        '''</summary>
        '''<param name="Channel">
        '''This control selects the channel.
        '''
        '''Valid Values: 
        '''RSRTM_VAL_CHANNEL_1   (1) - 1
        '''RSRTM_VAL_CHANNEL_2   (2) - 2
        '''RSRTM_VAL_CHANNEL_3   (3) - 3
        '''RSRTM_VAL_CHANNEL_4   (4) - 4
        '''RSRTM_VAL_CHANNEL_EXT (5) - External
        '''
        '''Default Value: RSRTM_VAL_CHANNEL_1 (1)
        '''</param>
        '''<param name="Deskew_Value">
        '''Skew or deskew compensates delay differences between channels caused by the different length of cables, probes, and other sources. Correct deskew values are important for accurate triggering.
        '''
        '''Valid Values:
        '''Not checked
        '''
        '''Default Value: 0.0 s
        '''
        '''Attribute: RSRTM_ATTR_CHANNEL_SKEW
        '''</param>
        '''<returns>
        '''Returns the status code of this operation.  The status code  either indicates success or describes an error or warning condition.  You examine the status code from each call to an instrument driver function to determine if an error occurred.
        '''
        '''To obtain a text description of the status code, call the rsrtm_error_message function.  To obtain additional information about the error condition, call the rsrtm_GetError function.  To clear the error information from the driver, call the rsrtm_ClearError function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''
        '''Numeric Range (in Hex) Status Code Types
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF VISA Warnings
        '''3FFC0000 to 3FFCFFFF VXIPnP Driver Warnings
        '''
        '''BFFF0000 to BFFFFFFF VISA Errors
        '''BFFC0000 to BFFCFFFF VXIPnP Driver Errors
        '''</returns>
        Public Function ConfigureChannelSkew(ByVal Channel As Integer, ByVal Deskew_Value As Double) As Integer
            Dim pInvokeResult As Integer = PInvoke.ConfigureChannelSkew(Me._handle, Channel, Deskew_Value)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function configures the probe settings.
        '''
        '''Attribute(s):
        '''RSRTM_ATTR_CHANNEL_ENABLED
        '''RSRTM_ATTR_CHANNEL_OFFSET
        '''
        '''Remote-control command(s):
        '''CHANnel&lt;Channel&gt;:STATe
        '''CHANnel&lt;Channel&gt;:OFFSet
        '''</summary>
        '''<param name="Channel">
        '''This control selects the channel.
        '''
        '''Valid Values: 
        '''RSRTM_VAL_CHANNEL_1   (1) - 1
        '''RSRTM_VAL_CHANNEL_2   (2) - 2
        '''RSRTM_VAL_CHANNEL_3   (3) - 3
        '''RSRTM_VAL_CHANNEL_4   (4) - 4
        '''
        '''Default Value: RSRTM_VAL_CHANNEL_1 (1)
        '''</param>
        '''<param name="Channel_Visible">
        '''Switches the channel signal on or off.
        '''
        '''Valid Values:
        '''VI_FALSE (0) - OFF
        '''VI_TRUE  (1) - ON
        '''
        '''Default Value: VI_TRUE  (1)
        '''
        '''Attribute:
        '''RSRTM_ATTR_CHANNEL_ENABLED
        '''</param>
        '''<param name="Offset">
        '''Sets the offset voltage.
        '''
        '''Units:  volts
        '''
        '''Valid Values:  -1.0 to 1.0
        '''
        '''Default Value: 0.0
        '''
        '''Attribute:
        '''RSRTM_ATTR_CHANNEL_OFFSET
        '''</param>
        '''<returns>
        '''Returns the status code of this operation.  The status code  either indicates success or describes an error or warning condition.  You examine the status code from each call to an instrument driver function to determine if an error occurred.
        '''
        '''To obtain a text description of the status code, call the rsrtm_error_message function.  To obtain additional information about the error condition, call the rsrtm_GetError function.  To clear the error information from the driver, call the rsrtm_ClearError function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''
        '''Numeric Range (in Hex) Status Code Types
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF VISA Warnings
        '''3FFC0000 to 3FFCFFFF VXIPnP Driver Warnings
        '''
        '''BFFF0000 to BFFFFFFF VISA Errors
        '''BFFC0000 to BFFCFFFF VXIPnP Driver Errors
        '''</returns>
        Public Function ConfigureProbe(ByVal Channel As Integer, ByVal Channel_Visible As Boolean, ByVal Offset As Double) As Integer
            Dim pInvokeResult As Integer = PInvoke.ConfigureProbe(Me._handle, Channel, System.Convert.ToUInt16(Channel_Visible), Offset)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function returns the probe characteristics.
        '''
        '''Attribute(s):
        '''RSRTM_ATTR_PROBE_TYPE
        '''RSRTM_ATTR_PROBE_NAME
        '''RSRTM_ATTR_PROBE_INPUT_IMPEDANCE
        '''RSRTM_ATTR_PROBE_INPUT_CAPACITANCE
        '''RSRTM_ATTR_PROBE_ATTENUATION
        '''RSRTM_ATTR_PROBE_BANDWIDTH
        '''
        '''Remote-control command(s):
        '''PROBe&lt;Channel&gt;:SETup:TYPE?
        '''PROBe&lt;Channel&gt;:SETup:NAME?
        '''PROBe&lt;Channel&gt;:SETup:IMPedance?
        '''PROBe&lt;Channel&gt;:SETup:CAPacitance?
        '''PROBe&lt;Channel&gt;:SETup:ATTenuation?
        '''PROBe&lt;Channel&gt;:SETup:BANDwidth?
        '''</summary>
        '''<param name="Channel">
        '''This control selects the channel.
        '''
        '''Valid Values: 
        '''RSRTM_VAL_CHANNEL_1   (1) - 1
        '''RSRTM_VAL_CHANNEL_2   (2) - 2
        '''RSRTM_VAL_CHANNEL_3   (3) - 3
        '''RSRTM_VAL_CHANNEL_4   (4) - 4
        '''
        '''Default Value: RSRTM_VAL_CHANNEL_1 (1)
        '''</param>
        '''<param name="Buffer_Size">
        '''Pass the number of bytes in the ViChar array you specify for the Type, Name and Attenuation values.
        '''
        '''Valid Values:
        '''not checked
        '''
        '''Default Value: 32
        '''</param>
        '''<param name="Type">
        '''Queries the type of the probe.
        '''
        '''
        '''Attribute:
        '''RSRTM_ATTR_PROBE_TYPE
        '''</param>
        '''<param name="Name">
        '''Queries the name of the probe.
        '''
        '''Attribute:
        '''RSRTM_ATTR_PROBE_NAME
        '''</param>
        '''<param name="Input_Impedance">
        '''Queries the termination of the probe.
        '''
        '''Attribute:
        '''RSRTM_ATTR_PROBE_INPUT_IMPEDANCE
        '''</param>
        '''<param name="Input_Capacitance">
        '''Queries the input capacitance of the probe.
        '''
        '''Attribute:
        '''RSRTM_ATTR_PROBE_INPUT_CAPACITANCE
        '''</param>
        '''<param name="Attenuation">
        '''Queries the attenuation of the probe.
        '''
        '''Attribute:
        '''RSRTM_ATTR_PROBE_ATTENUATION
        '''</param>
        '''<param name="Bandwidth">
        '''Queries the bandwidth of the probe.
        '''
        '''Attribute:
        '''RSRTM_ATTR_PROBE_BANDWIDTH
        '''</param>
        '''<returns>
        '''Returns the status code of this operation.  The status code  either indicates success or describes an error or warning condition.  You examine the status code from each call to an instrument driver function to determine if an error occurred.
        '''
        '''To obtain a text description of the status code, call the rsrtm_error_message function.  To obtain additional information about the error condition, call the rsrtm_GetError function.  To clear the error information from the driver, call the rsrtm_ClearError function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''
        '''Numeric Range (in Hex) Status Code Types
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF VISA Warnings
        '''3FFC0000 to 3FFCFFFF VXIPnP Driver Warnings
        '''
        '''BFFF0000 to BFFFFFFF VISA Errors
        '''BFFC0000 to BFFCFFFF VXIPnP Driver Errors
        '''</returns>
        Public Function QueryProbeCharacteristics(ByVal Channel As Integer, ByVal Buffer_Size As Integer, ByVal Type As System.Text.StringBuilder, ByVal Name As System.Text.StringBuilder, ByRef Input_Impedance As Double, ByRef Input_Capacitance As Double, ByVal Attenuation As System.Text.StringBuilder, ByRef Bandwidth As Double) As Integer
            Dim pInvokeResult As Integer = PInvoke.QueryProbeCharacteristics(Me._handle, Channel, Buffer_Size, Type, Name, Input_Impedance, Input_Capacitance, Attenuation, Bandwidth)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function configures the action that is started with the micro button on the probe head.
        '''
        '''Attribute(s):
        '''RSRTM_ATTR_PROBE_MICRO_BUTTON_ACTION
        '''
        '''Remote-control command(s):
        '''PROBe&lt;Channel&gt;:SETup:MODE
        '''</summary>
        '''<param name="Channel">
        '''This control selects the channel.
        '''
        '''Valid Values: 
        '''RSRTM_VAL_CHANNEL_1   (1) - 1
        '''RSRTM_VAL_CHANNEL_2   (2) - 2
        '''RSRTM_VAL_CHANNEL_3   (3) - 3
        '''RSRTM_VAL_CHANNEL_4   (4) - 4
        '''
        '''Default Value: RSRTM_VAL_CHANNEL_1 (1)
        '''</param>
        '''<param name="Micro_Button_Action">
        '''Select the action that is started with the micro button on the probe head.
        '''
        '''Valid Values:
        '''RSRTM_VAL_PROBE_BUTTON_NO_ACTION          (0) - No Action
        '''RSRTM_VAL_PROBE_BUTTON_RUN_CONTINUOUS     (1) - Run Continuous
        '''RSRTM_VAL_PROBE_BUTTON_RUN_SINGLE         (2) - Run Single
        '''RSRTM_VAL_PROBE_BUTTON_AUTOSET            (3) - Autoset
        '''
        '''Default Value: RSRTM_VAL_PROBE_BUTTON_RUN_CONTINUOUS (1)
        '''
        '''Attribute:
        '''RSRTM_ATTR_PROBE_MICRO_BUTTON_ACTION
        '''
        '''Note(s):
        '''
        '''(1) Nothing is started on pressing the micro button.
        '''
        '''(2) Run continuous: The acquisition is running as long as the probe button is pressed.
        '''
        '''(3) Run single: starts one acquisition.
        '''
        '''(4) Autoset: Starts the autoset procedure.
        '''</param>
        '''<returns>
        '''Returns the status code of this operation.  The status code  either indicates success or describes an error or warning condition.  You examine the status code from each call to an instrument driver function to determine if an error occurred.
        '''
        '''To obtain a text description of the status code, call the rsrtm_error_message function.  To obtain additional information about the error condition, call the rsrtm_GetError function.  To clear the error information from the driver, call the rsrtm_ClearError function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''
        '''Numeric Range (in Hex) Status Code Types
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF VISA Warnings
        '''3FFC0000 to 3FFCFFFF VXIPnP Driver Warnings
        '''
        '''BFFF0000 to BFFFFFFF VISA Errors
        '''BFFC0000 to BFFCFFFF VXIPnP Driver Errors
        '''</returns>
        Public Function ConfigureProbeMicroButtonAction(ByVal Channel As Integer, ByVal Micro_Button_Action As Integer) As Integer
            Dim pInvokeResult As Integer = PInvoke.ConfigureProbeMicroButtonAction(Me._handle, Channel, Micro_Button_Action)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''Retrieves the DC voltage that is measured by the integrated voltmeter of R&amp;S active probes.
        '''
        '''Attribute(s):
        '''RSRTM_ATTR_PROBE_DC_OFFSET
        '''
        '''Remote-control command(s):
        '''PROBe&lt;Channel&gt;:SETup:DCOFfset?
        '''</summary>
        '''<param name="Channel">
        '''This control selects the input channel. The number of channels depends on the instrument.
        '''
        '''Valid Values:
        '''RSRTM_VAL_CHANNEL_1 (0) - 1
        '''RSRTM_VAL_CHANNEL_2 (1) - 2
        '''RSRTM_VAL_CHANNEL_3 (2) - 3
        '''RSRTM_VAL_CHANNEL_4 (3) - 4
        '''
        '''Default Value:
        '''RSRTM_VAL_CHANNEL_1 (0)
        '''
        '''Attribute(s):
        '''-
        '''</param>
        '''<param name="DC_Offset">
        '''Returns the the DC voltage.
        '''
        '''Valid Values:
        '''-1.0e26 to 1.0e-26
        '''
        '''Attribute:
        '''RSRTM_ATTR_PROBE_DC_OFFSET
        '''</param>
        '''<returns>
        '''Returns the status code of this operation.  The status code  either indicates success or describes an error or warning condition.  You examine the status code from each call to an instrument driver function to determine if an error occurred.
        '''
        '''To obtain a text description of the status code, call the rsrtm_error_message function.  To obtain additional information about the error condition, call the rsrtm_GetError function.  To clear the error information from the driver, call the rsrtm_ClearError function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''
        '''Numeric Range (in Hex) Status Code Types
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF VISA Warnings
        '''3FFC0000 to 3FFCFFFF VXIPnP Driver Warnings
        '''
        '''BFFF0000 to BFFFFFFF VISA Errors
        '''BFFC0000 to BFFCFFFF VXIPnP Driver Errors
        '''</returns>
        Public Function QueryProbeDCOffset(ByVal Channel As Integer, ByRef DC_Offset As Double) As Integer
            Dim pInvokeResult As Integer = PInvoke.QueryProbeDCOffset(Me._handle, Channel, DC_Offset)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This Function sets an additional probe offset.
        '''
        '''Attribute(s):
        '''RSRTM_ATTR_PROBE_ADDITIONAL_OFFSET
        '''
        '''Remote-control command(s):
        '''PROBe&lt;Channel&gt;:SETup:UOFFset
        '''</summary>
        '''<param name="Channel">
        '''This control selects the input channel. The number of channels depends on the instrument.
        '''
        '''Valid Values:
        '''RSRTM_VAL_CHANNEL_1 (0) - 1
        '''RSRTM_VAL_CHANNEL_2 (1) - 2
        '''RSRTM_VAL_CHANNEL_3 (2) - 3
        '''RSRTM_VAL_CHANNEL_4 (3) - 4
        '''
        '''Default Value:
        '''RSRTM_VAL_CHANNEL_1 (0)
        '''
        '''Attribute(s):
        '''-
        '''</param>
        '''<param name="Probe_Offset">
        '''Sets an additional probe offset.
        '''
        '''Valid Values: 
        '''-4.0 to 4.0
        '''
        '''Default Value:
        '''0.000
        '''
        '''Attribute:
        '''RSRTM_ATTR_PROBE_ADDITIONAL_OFFSET
        '''</param>
        '''<returns>
        '''Returns the status code of this operation.  The status code  either indicates success or describes an error or warning condition.  You examine the status code from each call to an instrument driver function to determine if an error occurred.
        '''
        '''To obtain a text description of the status code, call the rsrtm_error_message function.  To obtain additional information about the error condition, call the rsrtm_GetError function.  To clear the error information from the driver, call the rsrtm_ClearError function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''
        '''Numeric Range (in Hex) Status Code Types
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF VISA Warnings
        '''3FFC0000 to 3FFCFFFF VXIPnP Driver Warnings
        '''
        '''BFFF0000 to BFFFFFFF VISA Errors
        '''BFFC0000 to BFFCFFFF VXIPnP Driver Errors
        '''</returns>
        Public Function ConfigureProbeAdditionalOffset(ByVal Channel As Integer, ByVal Probe_Offset As Double) As Integer
            Dim pInvokeResult As Integer = PInvoke.ConfigureProbeAdditionalOffset(Me._handle, Channel, Probe_Offset)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function switches the integrated voltmeter of an R&amp;S active probe on or off.
        '''
        '''Attribute(s):
        '''RSRTM_ATTR_PROBE_VOLTMETER_STATE
        '''
        '''Remote-control command(s):
        '''PROBe&lt;Channel&gt;:SETup:OFFSwitch
        '''</summary>
        '''<param name="Channel">
        '''This control selects the input channel. The number of channels depends on the instrument.
        '''
        '''Valid Values:
        '''RSRTM_VAL_CHANNEL_1 (0) - 1
        '''RSRTM_VAL_CHANNEL_2 (1) - 2
        '''RSRTM_VAL_CHANNEL_3 (2) - 3
        '''RSRTM_VAL_CHANNEL_4 (3) - 4
        '''
        '''Default Value:
        '''RSRTM_VAL_CHANNEL_1 (0)
        '''
        '''Attribute(s):
        '''-
        '''</param>
        '''<param name="Probe_Active">
        '''This Control switches the integrated voltmeter of an R&amp;S active probe on or off.
        '''
        '''Valid Values:
        '''VI_FALSE (0) - OFF
        '''VI_TRUE  (1) - ON
        '''
        '''Default Value: VI_FALSE  (0)
        '''
        '''Attribute:
        '''RSRTM_ATTR_PROBE_VOLTMETER_STATE
        '''</param>
        '''<returns>
        '''Returns the status code of this operation.  The status code  either indicates success or describes an error or warning condition.  You examine the status code from each call to an instrument driver function to determine if an error occurred.
        '''
        '''To obtain a text description of the status code, call the rsrtm_error_message function.  To obtain additional information about the error condition, call the rsrtm_GetError function.  To clear the error information from the driver, call the rsrtm_ClearError function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''
        '''Numeric Range (in Hex) Status Code Types
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF VISA Warnings
        '''3FFC0000 to 3FFCFFFF VXIPnP Driver Warnings
        '''
        '''BFFF0000 to BFFFFFFF VISA Errors
        '''BFFC0000 to BFFCFFFF VXIPnP Driver Errors
        '''</returns>
        Public Function ConfigureProbeVoltmeterState(ByVal Channel As Integer, ByVal Probe_Active As Boolean) As Integer
            Dim pInvokeResult As Integer = PInvoke.ConfigureProbeVoltmeterState(Me._handle, Channel, System.Convert.ToUInt16(Probe_Active))
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function selects the unit that the probe can measure.
        '''
        '''Attribute(s):
        '''RSRTM_ATTR_PROBE_ATTENUATION_UNIT
        '''
        '''Remote-control command(s):
        '''PROBe&lt;Channel&gt;:SETup:ATTenuation:UNIT
        '''</summary>
        '''<param name="Channel">
        '''This control selects the channel.
        '''
        '''Valid Values: 
        '''RSRTM_VAL_CHANNEL_1   (1) - 1
        '''RSRTM_VAL_CHANNEL_2   (2) - 2
        '''RSRTM_VAL_CHANNEL_3   (3) - 3
        '''RSRTM_VAL_CHANNEL_4   (4) - 4
        '''
        '''Default Value: RSRTM_VAL_CHANNEL_1 (1)
        '''</param>
        '''<param name="Unit">
        '''Selects the unit that the probe can measure.
        '''
        '''Valid Values:
        '''RSRTM_VAL_PROBE_UNIT_V (0) - V
        '''RSRTM_VAL_PROBE_UNIT_A (1) - A
        '''
        '''
        '''Default Value: RSRTM_VAL_PROBE_UNIT_V (0)
        '''
        '''Attribute:
        '''RSRTM_ATTR_PROBE_ATTENUATION_UNIT
        '''
        '''
        '''</param>
        '''<returns>
        '''Returns the status code of this operation.  The status code  either indicates success or describes an error or warning condition.  You examine the status code from each call to an instrument driver function to determine if an error occurred.
        '''
        '''To obtain a text description of the status code, call the rsrtm_error_message function.  To obtain additional information about the error condition, call the rsrtm_GetError function.  To clear the error information from the driver, call the rsrtm_ClearError function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''
        '''Numeric Range (in Hex) Status Code Types
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF VISA Warnings
        '''3FFC0000 to 3FFCFFFF VXIPnP Driver Warnings
        '''
        '''BFFF0000 to BFFFFFFF VISA Errors
        '''BFFC0000 to BFFCFFFF VXIPnP Driver Errors
        '''</returns>
        Public Function ConfigureProbeAttenuationUnit(ByVal Channel As Integer, ByVal Unit As Integer) As Integer
            Dim pInvokeResult As Integer = PInvoke.ConfigureProbeAttenuationUnit(Me._handle, Channel, Unit)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function sets the attenuation or gain of the probe if the probe was not detected by the instrument.
        '''
        '''Attribute(s):
        '''RSRTM_ATTR_PROBE_ATTENUATION_MANUAL
        '''
        '''Remote-control command(s):
        '''PROBe&lt;Channel&gt;:SETup:ATTenuation:MANual
        '''</summary>
        '''<param name="Channel">
        '''This control selects the channel.
        '''
        '''Valid Values: 
        '''RSRTM_VAL_CHANNEL_1   (1) - 1
        '''RSRTM_VAL_CHANNEL_2   (2) - 2
        '''RSRTM_VAL_CHANNEL_3   (3) - 3
        '''RSRTM_VAL_CHANNEL_4   (4) - 4
        '''
        '''Default Value: RSRTM_VAL_CHANNEL_1 (1)
        '''</param>
        '''<param name="Attenuation">
        '''Sets the attenuation or gain of the probe if the probe was not detected by the instrument.
        '''
        '''Units:  volts
        '''
        '''Valid Values:  0.001 to 10000
        '''
        '''Default Value: 1.0
        '''
        '''Attribute:
        '''RSRTM_ATTR_PROBE_ATTENUATION_MANUAL
        '''</param>
        '''<returns>
        '''Returns the status code of this operation.  The status code  either indicates success or describes an error or warning condition.  You examine the status code from each call to an instrument driver function to determine if an error occurred.
        '''
        '''To obtain a text description of the status code, call the rsrtm_error_message function.  To obtain additional information about the error condition, call the rsrtm_GetError function.  To clear the error information from the driver, call the rsrtm_ClearError function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''
        '''Numeric Range (in Hex) Status Code Types
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF VISA Warnings
        '''3FFC0000 to 3FFCFFFF VXIPnP Driver Warnings
        '''
        '''BFFF0000 to BFFFFFFF VISA Errors
        '''BFFC0000 to BFFCFFFF VXIPnP Driver Errors
        '''</returns>
        Public Function ConfigureProbeAttenuationManual(ByVal Channel As Integer, ByVal Attenuation As Double) As Integer
            Dim pInvokeResult As Integer = PInvoke.ConfigureProbeAttenuationManual(Me._handle, Channel, Attenuation)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function returns the probe attributes.
        '''
        '''Attribute(s):
        '''RSRTM_ATTR_PROBE_SOFTWARE_VERSION
        '''RSRTM_ATTR_PROBE_PRODUCTION_DATE
        '''RSRTM_ATTR_PROBE_PART_NUMBER
        '''RSRTM_ATTR_PROBE_SERIAL_NUMBER
        '''
        '''Remote-control command(s):
        '''PROBe&lt;Channel&gt;:ID:SWVersion?
        '''PROBe&lt;Channel&gt;:ID:PRDate?
        '''PROBe&lt;Channel&gt;:ID:PARTnumber?
        '''PROBe&lt;Channel&gt;:ID:SRNumber?
        '''</summary>
        '''<param name="Channel">
        '''This control selects the channel.
        '''
        '''Valid Values: 
        '''RSRTM_VAL_CHANNEL_1   (1) - 1
        '''RSRTM_VAL_CHANNEL_2   (2) - 2
        '''RSRTM_VAL_CHANNEL_3   (3) - 3
        '''RSRTM_VAL_CHANNEL_4   (4) - 4
        '''
        '''Default Value: RSRTM_VAL_CHANNEL_1 (1)
        '''</param>
        '''<param name="Buffer_Size">
        '''Pass the number of bytes in the ViChar array you specify for the Software Version, Production Date, Part Number and Serial Number values.
        '''
        '''Valid Values:
        '''not checked
        '''
        '''Default Value: 30
        '''</param>
        '''<param name="Software_Version">
        '''Queries the version of the probe firmware.
        '''
        '''Attribute:
        '''RSRTM_ATTR_PROBE_SOFTWARE_VERSION
        '''</param>
        '''<param name="Production_Date">
        '''Queries the production date of the probe.
        '''
        '''
        '''Attribute:
        '''RSRTM_ATTR_PROBE_PRODUCTION_DATE
        '''</param>
        '''<param name="Part_Number">
        '''Queries the R&amp;S part number of the probe.
        '''
        '''
        '''Attribute:
        '''RSRTM_ATTR_PROBE_PART_NUMBER
        '''</param>
        '''<param name="Serial_Number">
        '''Queries the serial number of the probe.
        '''
        '''Attribute:
        '''RSRTM_ATTR_PROBE_SERIAL_NUMBER
        '''</param>
        '''<returns>
        '''Returns the status code of this operation.  The status code  either indicates success or describes an error or warning condition.  You examine the status code from each call to an instrument driver function to determine if an error occurred.
        '''
        '''To obtain a text description of the status code, call the rsrtm_error_message function.  To obtain additional information about the error condition, call the rsrtm_GetError function.  To clear the error information from the driver, call the rsrtm_ClearError function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''
        '''Numeric Range (in Hex) Status Code Types
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF VISA Warnings
        '''3FFC0000 to 3FFCFFFF VXIPnP Driver Warnings
        '''
        '''BFFF0000 to BFFFFFFF VISA Errors
        '''BFFC0000 to BFFCFFFF VXIPnP Driver Errors
        '''</returns>
        Public Function QueryProbeAttributes(ByVal Channel As Integer, ByVal Buffer_Size As Integer, ByVal Software_Version As System.Text.StringBuilder, ByVal Production_Date As System.Text.StringBuilder, ByVal Part_Number As System.Text.StringBuilder, ByVal Serial_Number As System.Text.StringBuilder) As Integer
            Dim pInvokeResult As Integer = PInvoke.QueryProbeAttributes(Me._handle, Channel, Buffer_Size, Software_Version, Production_Date, Part_Number, Serial_Number)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''Queries the build number of the probe software.
        '''
        '''Attribute(s):
        '''RSRTM_ATTR_PROBE_BUILD_NUMBER
        '''
        '''Remote-control command(s):
        '''PROBe&lt;Channel&gt;:ID:BUILd?
        '''</summary>
        '''<param name="Channel">
        '''This control selects the channel.
        '''
        '''Valid Values: 
        '''RSRTM_VAL_CHANNEL_1   (1) - 1
        '''RSRTM_VAL_CHANNEL_2   (2) - 2
        '''RSRTM_VAL_CHANNEL_3   (3) - 3
        '''RSRTM_VAL_CHANNEL_4   (4) - 4
        '''
        '''Default Value: RSRTM_VAL_CHANNEL_1 (1)
        '''</param>
        '''<param name="Build_Number">
        '''Returns the build number.
        '''
        '''Valid Values:
        '''0 to INT_MAX
        '''
        '''Attribute:
        '''RSRTM_ATTR_PROBE_BUILD_NUMBER
        '''</param>
        '''<returns>
        '''Returns the status code of this operation.  The status code  either indicates success or describes an error or warning condition.  You examine the status code from each call to an instrument driver function to determine if an error occurred.
        '''
        '''To obtain a text description of the status code, call the rsrtm_error_message function.  To obtain additional information about the error condition, call the rsrtm_GetError function.  To clear the error information from the driver, call the rsrtm_ClearError function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''
        '''Numeric Range (in Hex) Status Code Types
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF VISA Warnings
        '''3FFC0000 to 3FFCFFFF VXIPnP Driver Warnings
        '''
        '''BFFF0000 to BFFFFFFF VISA Errors
        '''BFFC0000 to BFFCFFFF VXIPnP Driver Errors
        '''</returns>
        Public Function QueryProbeBuildNumber(ByVal Channel As Integer, ByRef Build_Number As Integer) As Integer
            Dim pInvokeResult As Integer = PInvoke.QueryProbeBuildNumber(Me._handle, Channel, Build_Number)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function configures the common attributes of the trigger subsystem.  These attributes are the trigger type and holdoff.
        '''
        '''If the oscilloscope requires multiple waveform acquisitions to build a complete waveform, it waits for the length of time you specify with the Holdoff parameter to elapse since the previous trigger.  The oscilloscope then waits for the next trigger.  Once the oscilloscope acquires a complete waveform, it returns to the Idle state.
        '''
        '''Notes:
        '''
        '''(1) After you call this function, you must call the trigger configuration function that corresponds to the Trigger Type you select to completely specify the trigger.  For example, if you set the Trigger Type to RSRTM_VAL_EDGE_TRIGGER, you use the rsrtm_ConfigureEdgeTriggerSource function to completely specify the trigger.
        '''
        '''Attribute(s):
        '''RSRTM_ATTR_TRIGGER_TYPE
        '''
        '''Remote-Control Command(s):
        '''TRIGger:A:TYPE
        '''TRIGger:B:TYPE
        '''</summary>
        '''<param name="Trigger">
        '''Selects trigger event.
        '''
        '''Valid Values:
        '''RSRTM_VAL_TRIGGER_A (0) - A
        '''RSRTM_VAL_TRIGGER_B (1) - B
        '''
        '''Default Value: RSRTM_VAL_TRIGGER_A
        '''</param>
        '''<param name="Trigger_Type">
        '''4Sets the trigger type.
        '''
        '''Valid Values:
        '''RSRTM_VAL_EDGE_TRIGGER    (0) - Edge
        '''RSRTM_VAL_WIDTH_TRIGGER   (1) - Width
        '''RSRTM_VAL_VIDEO_TRIGGER   (2) - Video
        '''RSRTM_VAL_PATTERN_TRIGGER (3) - Pattern
        '''RSRTM_VAL_BUS_TRIGGER     (4) - Bus
        '''
        '''Default Value: RSRTM_VAL_EDGE_TRIGGER (0)
        '''
        '''Attribute:
        '''RSRTM_ATTR_TRIGGER_TYPE
        '''</param>
        '''<returns>
        '''Returns the status code of this operation.  The status code  either indicates success or describes an error or warning condition.  You examine the status code from each call to an instrument driver function to determine if an error occurred.
        '''
        '''To obtain a text description of the status code, call the rsrtm_error_message function.  To obtain additional information about the error condition, call the rsrtm_GetError function.  To clear the error information from the driver, call the rsrtm_ClearError function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''
        '''Numeric Range (in Hex) Status Code Types
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF VISA Warnings
        '''3FFC0000 to 3FFCFFFF VXIPnP Driver Warnings
        '''
        '''BFFF0000 to BFFFFFFF VISA Errors
        '''BFFC0000 to BFFCFFFF VXIPnP Driver Errors
        '''</returns>
        Public Function ConfigureTrigger(ByVal Trigger As Integer, ByVal Trigger_Type As Integer) As Integer
            Dim pInvokeResult As Integer = PInvoke.ConfigureTrigger(Me._handle, Trigger, Trigger_Type)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''Sets the trigger source for the selected trigger type.
        '''
        '''Attribute(s):
        '''RSRTM_ATTR_TRIGGER_SOURCE
        '''
        '''Remote-control command(s):
        '''TRIGger:&lt;TriggerChannelRTM&gt;:SOURce
        '''</summary>
        '''<param name="Trigger">
        '''Selects trigger event.
        '''
        '''Valid Values:
        '''RSRTM_VAL_TRIGGER_A (1) - A
        '''RSRTM_VAL_TRIGGER_B (2) - B
        '''
        '''Default Value: RSRTM_VAL_TRIGGER_A (1)
        '''</param>
        '''<param name="Channel">
        '''Selects the source.
        '''
        '''Valid Values:
        '''RSRTM_VAL_CHANNEL1 (1) - Channel 1
        '''RSRTM_VAL_CHANNEL2 (2) - Channel 2
        '''RSRTM_VAL_CHANNEL3 (3) - Channel 3
        '''RSRTM_VAL_CHANNEL4 (4) - Channel 4
        '''RSRTM_VAL_EXTERNAL (5) - External
        '''RSRTM_VAL_LINE     (6) - AC Line
        '''
        '''Default Value: RSRTM_VAL_CHANNEL1 (1)
        '''
        '''Attribute:
        '''RSRTM_ATTR_TRIGGER_SOURCE
        '''</param>
        '''<returns>
        '''Returns the status code of this operation.  The status code  either indicates success or describes an error or warning condition.  You examine the status code from each call to an instrument driver function to determine if an error occurred.
        '''
        '''To obtain a text description of the status code, call the rsrtm_error_message function.  To obtain additional information about the error condition, call the rsrtm_GetError function.  To clear the error information from the driver, call the rsrtm_ClearError function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''
        '''Numeric Range (in Hex) Status Code Types
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF VISA Warnings
        '''3FFC0000 to 3FFCFFFF VXIPnP Driver Warnings
        '''
        '''BFFF0000 to BFFFFFFF VISA Errors
        '''BFFC0000 to BFFCFFFF VXIPnP Driver Errors
        '''</returns>
        Public Function ConfigureTriggerSource(ByVal Trigger As Integer, ByVal Channel As Integer) As Integer
            Dim pInvokeResult As Integer = PInvoke.ConfigureTriggerSource(Me._handle, Trigger, Channel)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''Sets the coupling for the external trigger input. The command is relevant if source in rsrtm_ConfigureTriggerSource is set to external.
        '''
        '''Attribute(s):
        '''RSRTM_ATTR_EXTERNAL_TRIGGER_COUPLING
        '''
        '''Remote-control command(s):
        '''TRIGger:EXTern:COUPling
        '''</summary>
        '''<param name="External_Coupling">
        '''Sets the coupling for the external trigger input.
        '''
        '''Valid Values:
        '''RSRTM_VAL_COUPLING_AC (0) - AC
        '''RSRTM_VAL_COUPLING_DC (1) - DC
        '''
        '''
        '''Default Value: RSRTM_VAL_COUPLING_AC (0)
        '''
        '''Attribute:
        '''RSRTM_ATTR_EXTERNAL_TRIGGER_COUPLING
        '''</param>
        '''<returns>
        '''Returns the status code of this operation.  The status code  either indicates success or describes an error or warning condition.  You examine the status code from each call to an instrument driver function to determine if an error occurred.
        '''
        '''To obtain a text description of the status code, call the rsrtm_error_message function.  To obtain additional information about the error condition, call the rsrtm_GetError function.  To clear the error information from the driver, call the rsrtm_ClearError function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''
        '''Numeric Range (in Hex) Status Code Types
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF VISA Warnings
        '''3FFC0000 to 3FFCFFFF VXIPnP Driver Warnings
        '''
        '''BFFF0000 to BFFFFFFF VISA Errors
        '''BFFC0000 to BFFCFFFF VXIPnP Driver Errors
        '''</returns>
        Public Function ConfigureExternalTriggerCoupling(ByVal External_Coupling As Integer) As Integer
            Dim pInvokeResult As Integer = PInvoke.ConfigureExternalTriggerCoupling(Me._handle, External_Coupling)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function activates or deactivates the second trigger. The instrument triggers if both trigger event conditions (A and B) are fulfilled.
        '''
        '''Attribute(s):
        '''RSRTM_ATTR_TRIGGER_STATE
        '''
        '''Remote-control command(s):
        '''TRIGger:B:ENABle
        '''</summary>
        '''<param name="State">
        '''This Control activates or deactivates the second trigger.
        '''
        '''Valid Values:
        '''VI_FALSE (0) - Off
        '''VI_TRUE  (1) - On
        '''
        '''Default Value: VI_FALSE (0) 
        '''
        '''Attribute: 
        '''RSRTM_ATTR_TRIGGER_STATE
        '''</param>
        '''<returns>
        '''Returns the status code of this operation.  The status code  either indicates success or describes an error or warning condition.  You examine the status code from each call to an instrument driver function to determine if an error occurred.
        '''
        '''To obtain a text description of the status code, call the rsrtm_error_message function.  To obtain additional information about the error condition, call the rsrtm_GetError function.  To clear the error information from the driver, call the rsrtm_ClearError function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''
        '''Numeric Range (in Hex) Status Code Types
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF VISA Warnings
        '''3FFC0000 to 3FFCFFFF VXIPnP Driver Warnings
        '''
        '''BFFF0000 to BFFFFFFF VISA Errors
        '''BFFC0000 to BFFCFFFF VXIPnP Driver Errors
        '''</returns>
        Public Function ConfigureTriggerBState(ByVal State As Boolean) As Integer
            Dim pInvokeResult As Integer = PInvoke.ConfigureTriggerBState(Me._handle, System.Convert.ToUInt16(State))
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''Sets the trigger mode. The trigger mode determines the behaviour of the instrument if no trigger occurs.
        '''
        '''Attribute(s):
        '''RSRTM_ATTR_TRIGGER_MODIFIER
        '''
        '''Remote-control command(s):
        '''TRIGger&lt;Trigger&gt;:MODE
        '''</summary>
        '''<param name="Trigger">
        '''Selects trigger event.
        '''
        '''Valid Values:
        '''RSRTM_VAL_TRIGGER_A (0) - A
        '''RSRTM_VAL_TRIGGER_B (1) - B
        '''
        '''Default Value: RSRTM_VAL_TRIGGER_A
        '''</param>
        '''<param name="Trigger_Modifier">
        '''This control selects the trigger mode.
        '''
        '''Valid Values:
        '''RSRTM_VAL_TRIGGER_AUTO   (0) - Auto
        '''RSRTM_VAL_TRIGGER_NORMAL (1) - Normal
        '''RSRTM_VAL_TRIGGER_DELAY  (2) - Delay
        '''RSRTM_VAL_TRIGGER_EVENTS (3) - Events
        '''
        '''Default Value:
        '''RSRTM_VAL_TRIGGER__AUTO (0)
        '''
        '''Attribute(s):
        '''RSRTM_ATTR_TRIGGER_MODIFIER
        '''
        '''Note(s):
        '''
        '''(1) Auto: The instrument triggers repeatedly after a time interval if the trigger conditions are not fulfilled. If a real trigger occurs, it takes  precedence.
        '''
        '''(2) Normal: The instrument acquires a waveform only if a trigger occurs.
        '''
        '''(3) Delay: Time delay, set with TRIGger:B:DELay. Defines the delay type of the B-trigger.
        '''
        '''(4) Events: Event count delay, set with TRIGger:B:EVENt:COUNt. Defines the delay type of the B-trigger.
        '''</param>
        '''<returns>
        '''Returns the status code of this operation.  The status code  either indicates success or describes an error or warning condition.  You examine the status code from each call to an instrument driver function to determine if an error occurred.
        '''
        '''To obtain a text description of the status code, call the rsrtm_error_message function.  To obtain additional information about the error condition, call the rsrtm_GetError function.  To clear the error information from the driver, call the rsrtm_ClearError function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''
        '''Numeric Range (in Hex) Status Code Types
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF VISA Warnings
        '''3FFC0000 to 3FFCFFFF VXIPnP Driver Warnings
        '''
        '''BFFF0000 to BFFFFFFF VISA Errors
        '''BFFC0000 to BFFCFFFF VXIPnP Driver Errors
        '''</returns>
        Public Function ConfigureTriggerModifier(ByVal Trigger As Integer, ByVal Trigger_Modifier As Integer) As Integer
            Dim pInvokeResult As Integer = PInvoke.ConfigureTriggerModifier(Me._handle, Trigger, Trigger_Modifier)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''Sets a number of B-trigger events that fulfill all B-trigger conditions but do not cause the trigger. The oscilloscope triggers on the n-th event (the last of the specified number of
        '''events).
        '''
        '''Note(s):
        '''(1) Before setting the event number, TRIGger:B:MODE must be set to EVENts.
        '''
        '''Attribute(s):
        '''RSRTM_ATTR_TRIGGER_EVENT_COUNT
        '''
        '''Remote-control command(s):
        '''TRIGger:B:EVENt:COUNt
        '''</summary>
        '''<param name="Event_Count">
        '''This Control sets a number of B-trigger events.
        '''
        '''Valid Values:
        '''1 to 65535
        '''
        '''Default Value: 1
        '''
        '''Attribute:
        '''RSRTM_ATTR_TRIGGER_EVENT_COUNT
        '''</param>
        '''<returns>
        '''Returns the status code of this operation.  The status code  either indicates success or describes an error or warning condition.  You examine the status code from each call to an instrument driver function to determine if an error occurred.
        '''
        '''To obtain a text description of the status code, call the rsrtm_error_message function.  To obtain additional information about the error condition, call the rsrtm_GetError function.  To clear the error information from the driver, call the rsrtm_ClearError function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''
        '''Numeric Range (in Hex) Status Code Types
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF VISA Warnings
        '''3FFC0000 to 3FFCFFFF VXIPnP Driver Warnings
        '''
        '''BFFF0000 to BFFFFFFF VISA Errors
        '''BFFC0000 to BFFCFFFF VXIPnP Driver Errors
        '''</returns>
        Public Function ConfigureTriggerEventCount(ByVal Event_Count As Integer) As Integer
            Dim pInvokeResult As Integer = PInvoke.ConfigureTriggerEventCount(Me._handle, Event_Count)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''Sets the A-trigger level automatically. The attribute is not available for an external trigger source.
        '''
        '''Attribute(s):
        '''RSRTM_ATTR_TRIGGER_LEVEL_AUTO_FIND
        '''
        '''Remote-Control Command(s):
        '''TRIGger:&lt;Trigger&gt;:FINDlevel
        '''</summary>
        '''<param name="Trigger">
        '''Selects trigger event.
        '''
        '''Valid Values:
        '''RSRTM_VAL_TRIGGER_A (1) - A
        '''RSRTM_VAL_TRIGGER_B (2) - B
        '''
        '''Default Value: RSRTM_VAL_TRIGGER_A
        '''</param>
        '''<returns>
        '''Returns the status code of this operation.  The status code  either indicates success or describes an error or warning condition.  You examine the status code from each call to an instrument driver function to determine if an error occurred.
        '''
        '''To obtain a text description of the status code, call the rsrtm_error_message function.  To obtain additional information about the error condition, call the rsrtm_GetError function.  To clear the error information from the driver, call the rsrtm_ClearError function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''
        '''Numeric Range (in Hex) Status Code Types
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF VISA Warnings
        '''3FFC0000 to 3FFCFFFF VXIPnP Driver Warnings
        '''
        '''BFFF0000 to BFFFFFFF VISA Errors
        '''BFFC0000 to BFFCFFFF VXIPnP Driver Errors
        '''</returns>
        Public Function TriggerLevelAutoFind(ByVal Trigger As Integer) As Integer
            Dim pInvokeResult As Integer = PInvoke.TriggerLevelAutoFind(Me._handle, Trigger)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function configures selected trigger level.
        '''
        '''Attribute(s):
        '''RSRTM_ATTR_TRIGGER_LEVEL
        '''
        '''Remote-control command(s):
        '''TRIGger&lt;Trigger&gt;:LEVel&lt;Channel&gt;[:VALue]
        '''</summary>
        '''<param name="Trigger">
        '''Selects trigger event.
        '''
        '''Valid Values:
        '''RSRTM_VAL_TRIGGER_A (1) - A
        '''RSRTM_VAL_TRIGGER_B (2) - B
        '''
        '''Default Value: RSRTM_VAL_TRIGGER_A
        '''
        '''Note(s):
        '''
        '''(1) This control is valid only if 'Trigger Source' is not set to 'External'.
        '''</param>
        '''<param name="Channel">
        '''Sets the trigger source for the selected trigger type.
        '''
        '''Valid Values:
        '''RSRTM_VAL_CHANNEL1 (1) - Channel 1
        '''RSRTM_VAL_CHANNEL2 (2) - Channel 2
        '''RSRTM_VAL_CHANNEL3 (3) - Channel 3
        '''RSRTM_VAL_CHANNEL4 (4) - Channel 4
        '''
        '''Default Value: RSRTM_VAL_CHANNEL1 (1)
        '''
        '''Attribute:
        '''-
        '''</param>
        '''<param name="Trigger_Level">
        '''Sets the trigger level for the specified event and channel.
        '''
        '''Valid Values:
        '''-10.0 to 10.0 V
        '''
        '''Default Value: 0.0
        '''
        '''Attribute:
        '''RSRTM_ATTR_TRIGGER_LEVEL
        '''</param>
        '''<returns>
        '''Returns the status code of this operation.  The status code  either indicates success or describes an error or warning condition.  You examine the status code from each call to an instrument driver function to determine if an error occurred.
        '''
        '''To obtain a text description of the status code, call the rsrtm_error_message function.  To obtain additional information about the error condition, call the rsrtm_GetError function.  To clear the error information from the driver, call the rsrtm_ClearError function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''
        '''Numeric Range (in Hex) Status Code Types
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF VISA Warnings
        '''3FFC0000 to 3FFCFFFF VXIPnP Driver Warnings
        '''
        '''BFFF0000 to BFFFFFFF VISA Errors
        '''BFFC0000 to BFFCFFFF VXIPnP Driver Errors
        '''</returns>
        Public Function ConfigureTriggerChannelLevel(ByVal Trigger As Integer, ByVal Channel As Integer, ByVal Trigger_Level As Double) As Integer
            Dim pInvokeResult As Integer = PInvoke.ConfigureTriggerChannelLevel(Me._handle, Trigger, Channel, Trigger_Level)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function sets a hysteresis range around the trigger level.
        '''
        '''Attribute(s):
        '''RSRTM_ATTR_TRIGGER_HYSTERESIS
        '''
        '''Remote-control command(s):
        '''TRIGger:&lt;Trigger&gt;:HYSTeresis
        '''</summary>
        '''<param name="Trigger">
        '''Selects trigger event.
        '''
        '''Valid Values:
        '''RSRTM_VAL_TRIGGER_A (1) - A
        '''RSRTM_VAL_TRIGGER_B (2) - B
        '''
        '''Default Value: RSRTM_VAL_TRIGGER_A (1)
        '''</param>
        '''<param name="Hysteresis">
        '''Sets hysteresis range.
        '''
        '''Valid Values:
        '''RSRTM_VAL_HYSTERESIS_AUTO   (0) - Auto
        '''RSRTM_VAL_HYSTERESIS_SMALL  (1) - Small
        '''RSRTM_VAL_HYSTERESIS_MEDIUM (2) - Medium
        '''RSRTM_VAL_HYSTERESIS_LARGE  (3) - Large
        '''
        '''Default Value: RSRTM_VAL_HYST_AUTO (0)
        '''
        '''Attribute:
        '''RSRTM_ATTR_TRIGGER_HYSTERESIS
        '''</param>
        '''<returns>
        '''Returns the status code of this operation.  The status code  either indicates success or describes an error or warning condition.  You examine the status code from each call to an instrument driver function to determine if an error occurred.
        '''
        '''To obtain a text description of the status code, call the rsrtm_error_message function.  To obtain additional information about the error condition, call the rsrtm_GetError function.  To clear the error information from the driver, call the rsrtm_ClearError function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''
        '''Numeric Range (in Hex) Status Code Types
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF VISA Warnings
        '''3FFC0000 to 3FFCFFFF VXIPnP Driver Warnings
        '''
        '''BFFF0000 to BFFFFFFF VISA Errors
        '''BFFC0000 to BFFCFFFF VXIPnP Driver Errors
        '''</returns>
        Public Function ConfigureTriggerHysteresis(ByVal Trigger As Integer, ByVal Hysteresis As Integer) As Integer
            Dim pInvokeResult As Integer = PInvoke.ConfigureTriggerHysteresis(Me._handle, Trigger, Hysteresis)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function configures the trigger.
        '''
        '''Attribute(s):
        '''RSRTM_ATTR_TRIGGER_SOURCE
        '''RSRTM_ATTR_TRIGGER_LEVEL
        '''RSRTM_ATTR_TRIGGER_SLOPE
        '''
        '''Remote-control command(s):
        '''TRIGger:&lt;Trigger&gt;:SOURce
        '''TRIGger:&lt;Trigger&gt;:LEVel&lt;Channel&gt;[:VALue]
        '''TRIGger:{Trigger}:EDGE:SLOPe
        '''</summary>
        '''<param name="Trigger">
        '''Selects trigger event.
        '''
        '''Valid Values:
        '''RSRTM_VAL_TRIGGER_A (1) - A
        '''RSRTM_VAL_TRIGGER_B (2) - B
        '''
        '''Default Value: RSRTM_VAL_TRIGGER_A
        '''</param>
        '''<param name="Channel">
        '''Sets the trigger source for the selected trigger type.
        '''
        '''Valid Values:
        '''RSRTM_VAL_CHANNEL1 (1) - Channel 1
        '''RSRTM_VAL_CHANNEL2 (2) - Channel 2
        '''RSRTM_VAL_CHANNEL3 (3) - Channel 3
        '''RSRTM_VAL_CHANNEL4 (4) - Channel 4
        '''
        '''Default Value: RSRTM_VAL_CHANNEL1 (1)
        '''
        '''Attribute:
        '''-
        '''</param>
        '''<param name="Trigger_Source">
        '''This control selects the channel.
        '''
        '''Valid Values:
        '''RSRTM_VAL_CHANNELRTM_1 (0) - Channel 1
        '''RSRTM_VAL_CHANNELRTM_2 (1) - Channel 2
        '''RSRTM_VAL_CHANNELRTM_3 (2) - Channel 3
        '''RSRTM_VAL_CHANNELRTM_4 (3) - Channel 4
        '''
        '''Default Value:
        '''RSRTM_VAL_CHANNELRTM_1 (0) 
        '''
        '''Attribute(s):
        '''RSRTM_ATTR_TRIGGER_SOURCE
        '''
        '''Note:
        '''(1) The number of channels depends on the instrument.
        '''</param>
        '''<param name="Trigger_Level">
        '''This control sets the trigger threshold voltage.
        '''
        '''Valid Values: 
        '''0.0 to 10.0
        '''
        '''Default Value: 0.0
        '''
        '''Attribute(s):
        '''RSRTM_ATTR_TRIGGER_LEVEL
        '''</param>
        '''<param name="Trigger_Slope">
        '''Selects the slope.
        '''
        '''Valid Values:
        '''RSRTM_VAL_POSITIVE  (0) - Rising Edge
        '''RSRTM_VAL_NEGATIVE  (1) - Falling Edge
        '''RSRTM_VAL_EITHER    (2) - Either
        '''
        '''Default Value: RSRTM_VAL_POSITIVE (0)
        '''
        '''Attribute(s):
        '''RSRTM_ATTR_TRIGGER_SLOPE
        '''</param>
        '''<returns>
        '''Returns the status code of this operation.  The status code  either indicates success or describes an error or warning condition.  You examine the status code from each call to an instrument driver function to determine if an error occurred.
        '''
        '''To obtain a text description of the status code, call the rsrtm_error_message function.  To obtain additional information about the error condition, call the rsrtm_GetError function.  To clear the error information from the driver, call the rsrtm_ClearError function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''
        '''Numeric Range (in Hex) Status Code Types
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF VISA Warnings
        '''3FFC0000 to 3FFCFFFF VXIPnP Driver Warnings
        '''
        '''BFFF0000 to BFFFFFFF VISA Errors
        '''BFFC0000 to BFFCFFFF VXIPnP Driver Errors
        '''</returns>
        Public Function ConfigureEdgeTriggerSource(ByVal Trigger As Integer, ByVal Channel As Integer, ByVal Trigger_Source As Integer, ByVal Trigger_Level As Double, ByVal Trigger_Slope As Integer) As Integer
            Dim pInvokeResult As Integer = PInvoke.ConfigureEdgeTriggerSource(Me._handle, Trigger, Channel, Trigger_Source, Trigger_Level, Trigger_Slope)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''Sets the coupling for the trigger source.
        '''
        '''Attribute(s):
        '''RSRTM_ATTR_TRIGGER_COUPLING
        '''
        '''Remote-control command(s):
        '''TRIGger:A:EDGE:COUPling
        '''</summary>
        '''<param name="Coupling">
        '''Selects coupling event for the trigger source.
        '''
        '''Valid Values:
        '''RSRTM_VAL_COUPLING_DIRECT      (0) - Direct Current
        '''RSRTM_VAL_COUPLING_ALTERNATING (1) - Alternating Current
        '''RSRTM_VAL_COUPLING_HIGHFREQ    (2) - High frequency
        '''
        '''Default Value: RSRTM_VAL_COUPLING_DIRECT (0)
        '''
        '''Attribute(s):
        '''RSRTM_ATTR_TRIGGER_COUPLING
        '''</param>
        '''<returns>
        '''Returns the status code of this operation.  The status code  either indicates success or describes an error or warning condition.  You examine the status code from each call to an instrument driver function to determine if an error occurred.
        '''
        '''To obtain a text description of the status code, call the rsrtm_error_message function.  To obtain additional information about the error condition, call the rsrtm_GetError function.  To clear the error information from the driver, call the rsrtm_ClearError function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''
        '''Numeric Range (in Hex) Status Code Types
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF VISA Warnings
        '''3FFC0000 to 3FFCFFFF VXIPnP Driver Warnings
        '''
        '''BFFF0000 to BFFFFFFF VISA Errors
        '''BFFC0000 to BFFCFFFF VXIPnP Driver Errors
        '''</returns>
        Public Function ConfigureEdgeTriggerCoupling(ByVal Coupling As Integer) As Integer
            Dim pInvokeResult As Integer = PInvoke.ConfigureEdgeTriggerCoupling(Me._handle, Coupling)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''Turns an additional 5 kHz or 100 MHz low-pass filter in the trigger path on or off. This filter removes higher frequencies and is available with AC and DC coupling.
        '''
        '''Attribute(s):
        '''RSRTM_ATTR_TRIGGER_FILTER
        '''
        '''Remote-control command(s):
        '''TRIGger:A:EDGE:FILTer:&lt;TriggerFilterRTM&gt;
        '''</summary>
        '''<param name="Filter_Type">
        '''Selects the filter type.
        '''
        '''Valid Values:
        '''RSRTM_VAL_TRIGGER_FILTER_LOW  (0) - Low    5 kHz
        '''RSRTM_VAL_TRIGGER_FILTER_HIGH (1) - High 100 MHz
        '''
        '''Default Value: RSRTM_VAL_TRIGGER_FILTER_LOW (0)
        '''</param>
        '''<param name="Filter_State">
        '''Activates or deactivates a low-pass filter in the trigger path.
        '''
        '''Valid Values:
        '''VI_FALSE (0) - OFF
        '''VI_TRUE  (1) - ON
        '''
        '''Default Value: VI_FALSE  (0)
        '''
        '''Attribute:
        '''RSRTM_ATTR_TRIGGER_FILTER
        '''</param>
        '''<returns>
        '''Returns the status code of this operation.  The status code  either indicates success or describes an error or warning condition.  You examine the status code from each call to an instrument driver function to determine if an error occurred.
        '''
        '''To obtain a text description of the status code, call the rsrtm_error_message function.  To obtain additional information about the error condition, call the rsrtm_GetError function.  To clear the error information from the driver, call the rsrtm_ClearError function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''
        '''Numeric Range (in Hex) Status Code Types
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF VISA Warnings
        '''3FFC0000 to 3FFCFFFF VXIPnP Driver Warnings
        '''
        '''BFFF0000 to BFFFFFFF VISA Errors
        '''BFFC0000 to BFFCFFFF VXIPnP Driver Errors
        '''</returns>
        Public Function ConfigureEdgeTriggerFilter(ByVal Filter_Type As Integer, ByVal Filter_State As Boolean) As Integer
            Dim pInvokeResult As Integer = PInvoke.ConfigureEdgeTriggerFilter(Me._handle, Filter_Type, System.Convert.ToUInt16(Filter_State))
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function configures the width trigger.  A width trigger occurs when the oscilloscope detects a positive or negative pulse with a width between, or optionally outside, the width thresholds.  You specify the width thresholds with the Width Low Threshold and Width High Threshold parameters.  You specify whether the oscilloscope triggers on pulse widths that are within or outside the width thresholds with the Width Condition parameter.  You specify the polarity of the pulse with the Width Polarity parameter.  The trigger does not actually occur until the edge of a pulse that corresponds to the Width Low Threshold, Width High Threshold, Width Condition, and Width Polarity crosses the threshold you specify in the Trigger Level parameter.
        '''
        '''Notes:
        '''
        '''(1)  This function affects instrument behavior only if the Trigger Type is RSRTM_VAL_WIDTH_TRIGGER.  Call the rsrtm_ConfigureTrigger function to set the Trigger Type before you call this function.
        '''
        '''Attribute(s):
        '''RSRTM_ATTR_TRIGGER_SOURCE
        '''RSRTM_ATTR_TRIGGER_LEVEL
        '''RSRTM_ATTR_WIDTH
        '''RSRTM_ATTR_WIDTH_DELTA
        '''RSRTM_ATTR_WIDTH_POLARITY
        '''RSRTM_ATTR_WIDTH_CONDITION
        '''
        '''Remote-control command(s):
        '''TRIGger:A:SOURce
        '''TRIGger:A:LEVel&lt;Channel&gt;[:VALue]
        '''TRIGger:A:WIDTh:WIDTh
        '''TRIGger:A:WIDTh:DELTa
        '''TRIGger:A:WIDTh:POLarity
        '''TRIGger:A:WIDTh:RANGe
        '''</summary>
        '''<param name="Trigger_Source">
        '''Sets the trigger source for the selected trigger type.
        '''
        '''Valid Values:
        '''RSRTM_VAL_CHANNEL1 (1) - Channel 1
        '''RSRTM_VAL_CHANNEL2 (2) - Channel 2
        '''RSRTM_VAL_CHANNEL3 (3) - Channel 3
        '''RSRTM_VAL_CHANNEL4 (4) - Channel 4
        '''RSRTM_VAL_EXTERNAL (5) - Analog External
        '''RSRTM_VAL_LINE     (6) - Line
        '''
        '''Default Value: RSRTM_VAL_CHANNEL1 (1)
        '''
        '''Attribute:
        '''RSRTM_ATTR_TRIGGER_SOURCE
        '''</param>
        '''<param name="Trigger_Level">
        '''Sets the trigger level for the specified event and source.
        '''
        '''Valid Values:
        '''-10.0 to 10.0 V
        '''
        '''Default Value: 0.0
        '''
        '''Attribute:
        '''RSRTM_ATTR_TRIGGER_LEVEL
        '''RSRTM_ATTR_EXTERNAL_TRIGGER_LEVEL
        '''</param>
        '''<param name="Width">
        '''For the ranges "Within" and "Outside", the width defines the center of a range which is defined by the limits "+/-Delta". For the ranges "Shorter" and "Longer", the width defines the maximum and minimum pulse width, respectively.
        '''
        '''Valid Values:
        '''not checked
        '''
        '''Default Value: 19.2E-9 s
        '''
        '''Attribute:
        '''RSRTM_ATTR_WIDTH
        '''</param>
        '''<param name="Width_Delta">
        '''Defines a range around the width value.
        '''
        '''Valid Values:
        '''not checked
        '''
        '''Default Value: 0.0
        '''
        '''Attribute:
        '''RSRTM_ATTR_WIDTH_DELTA
        '''</param>
        '''<param name="Width_Polarity">
        '''Sets the polarity of the pulse.
        '''
        '''Valid Values:
        '''RSRTM_VAL_POSITIVE (0) - Positive
        '''RSRTM_VAL_NEGATIVE (1) - Negative
        '''
        '''Default Value: RSRTM_VAL_POSITIVE (0)
        '''
        '''Attribute:
        '''RSRTM_ATTR_WIDTH_POLARITY
        '''
        '''Note(s):
        '''
        '''(1) Positive: Rising Edge, a positive voltage change
        '''
        '''(2) Negative: Falling Edge, a negative voltage change
        '''</param>
        '''<param name="Width_Condition">
        '''Sets how the measured pulse width is compared with the given limit(s).
        '''
        '''Valid Values:
        '''RSRTM_VAL_SHORTER (0) - Shorter
        '''RSRTM_VAL_LONGER  (1) - Longer
        '''RSRTM_VAL_WITHIN  (2) - Within
        '''RSRTM_VAL_OUTSIDE (3) - Outside
        '''
        '''Default Value: RSRTM_VAL_WITHIN (2)
        '''
        '''Attribute:
        '''RSRTM_ATTR_WIDTH_CONDITION
        '''
        '''Note(s):
        '''
        '''(1) Shorter: Triggers on pulses shorter than the reference time
        '''
        '''(2) Longer: Triggers on pulses longer than the reference time
        '''
        '''(3) Within: Triggers on pulses inside a specified range
        '''
        '''(4) Outside: Triggers on pulses outside a specified range
        '''</param>
        '''<returns>
        '''Returns the status code of this operation.  The status code  either indicates success or describes an error or warning condition.  You examine the status code from each call to an instrument driver function to determine if an error occurred.
        '''
        '''To obtain a text description of the status code, call the rsrtm_error_message function.  To obtain additional information about the error condition, call the rsrtm_GetError function.  To clear the error information from the driver, call the rsrtm_ClearError function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''
        '''Numeric Range (in Hex) Status Code Types
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF VISA Warnings
        '''3FFC0000 to 3FFCFFFF VXIPnP Driver Warnings
        '''
        '''BFFF0000 to BFFFFFFF VISA Errors
        '''BFFC0000 to BFFCFFFF VXIPnP Driver Errors
        '''</returns>
        Public Function ConfigureWidthTriggerSource(ByVal Trigger_Source As Integer, ByVal Trigger_Level As Double, ByVal Width As Double, ByVal Width_Delta As Double, ByVal Width_Polarity As Integer, ByVal Width_Condition As Integer) As Integer
            Dim pInvokeResult As Integer = PInvoke.ConfigureWidthTriggerSource(Me._handle, Trigger_Source, Trigger_Level, Width, Width_Delta, Width_Polarity, Width_Condition)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function:
        '''Select the state for each digital channel.
        '''Sets the logical combination of the trigger states of the channels.
        '''Sets the trigger point depending on the result of the logical combination of the channel states.
        '''
        '''Attribute(s):
        '''RSRTM_ATTR_TRIGGER_PATTERN_SOURCE
        '''RSRTM_ATTR_TRIGGER_PETTERN_FUNCTION
        '''RSRTM_ATTR_TRIGGER_PATTERN_POINT_STATE
        '''
        '''Remote-control command(s):
        '''TRIGger:&lt;TriggerChannelRTM&gt;:PATTern:SOURce
        '''TRIGger:&lt;TriggerChannelRTM&gt;:PATTern:FUNCtion
        '''TRIGger:&lt;TriggerChannelRTM&gt;:PATTern:CONDition
        '''</summary>
        '''<param name="Pattern_Source">
        '''This control sets the state for each digital channel.
        '''
        '''Valid Values:
        '''not checked
        '''
        '''Default Value:
        '''""
        '''
        '''Attribute(s):
        '''RSRTM_ATTR_TRIGGER_PATTERN_SOURCE
        '''
        '''Note:
        '''(1) Characters 0, 1, and X are allowed.
        '''</param>
        '''<param name="Pattern_Function">
        '''Sets the logical combination of the trigger states of the channels.
        '''
        '''Valid Values:
        '''RSRTM_VAL_TRG_PATTERN_AND (0) - And
        '''RSRTM_VAL_TRG_PATTERN_OR  (1) - Or
        '''
        '''Default Value: RSRTM_VAL_TRG_PATTERN_AND (0)
        '''
        '''Attribute:
        '''RSRTM_ATTR_TRIGGER_PATTERN_FUNCTION
        '''</param>
        '''<param name="Pattern_Condition">
        '''This Control sets the trigger point depending on the result of the logical combination of the channel states.
        '''
        '''Valid Values:
        '''VI_FALSE (0) - OFF
        '''VI_TRUE  (1) - ON
        '''
        '''Default Value: VI_TRUE  (1)
        '''
        '''Attribute(s):
        '''RSRTM_ATTR_TRIGGER_PATTERN_POINT_STATE
        '''</param>
        '''<returns>
        '''Returns the status code of this operation.  The status code  either indicates success or describes an error or warning condition.  You examine the status code from each call to an instrument driver function to determine if an error occurred.
        '''
        '''To obtain a text description of the status code, call the rsrtm_error_message function.  To obtain additional information about the error condition, call the rsrtm_GetError function.  To clear the error information from the driver, call the rsrtm_ClearError function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''
        '''Numeric Range (in Hex) Status Code Types
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF VISA Warnings
        '''3FFC0000 to 3FFCFFFF VXIPnP Driver Warnings
        '''
        '''BFFF0000 to BFFFFFFF VISA Errors
        '''BFFC0000 to BFFCFFFF VXIPnP Driver Errors
        '''</returns>
        Public Function ConfigurePatternTriggerSource(ByVal Pattern_Source As String, ByVal Pattern_Function As Integer, ByVal Pattern_Condition As Boolean) As Integer
            Dim pInvokeResult As Integer = PInvoke.ConfigurePatternTriggerSource(Me._handle, Pattern_Source, Pattern_Function, System.Convert.ToUInt16(Pattern_Condition))
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function configures the TV trigger.
        '''
        '''Attribute(s):
        '''RSRTM_ATTR_TV_TRIGGER_EVENT
        '''RSRTM_ATTR_TV_TRIGGER_LINE_NUMBER
        '''RSRTM_ATTR_TV_TRIGGER_POLARITY
        '''RSRTM_ATTR_TV_STANDARD
        '''
        '''Remote-control command(s):
        '''TRIGger:A:TV:FIELd
        '''TRIGger:A:TV:LINE
        '''TRIGger:A:TV:POLarity
        '''TRIGger:A:TV:STANdard
        '''</summary>
        '''<param name="Standard">
        '''This Control sets the color television standard.
        '''
        '''Valid Values:
        '''RSRTM_VAL_TV_STANDART_PAL   (0) - PAL
        '''RSRTM_VAL_TV_STANDART_NTSC  (1) - NTSC
        '''RSRTM_VAL_TV_STANDART_SECAM (2) - Secam
        '''RSRTM_VAL_TV_STANDART_PALM  (3) - PALM
        '''RSRTM_VAL_TV_STANDART_I576  (4) - I576
        '''RSRTM_VAL_TV_STANDART_P720  (5) - P720
        '''RSRTM_VAL_TV_STANDART_P1080 (6) - P1080
        '''RSRTM_VAL_TV_STANDART_I1080 (7) - I1080
        '''
        '''Default Value: RSRTM_VAL_TV_STANDART_PAL 
        '''
        '''Attribute:
        '''RSRTM_ATTR_TV_STANDARD
        '''</param>
        '''<param name="Polarity">
        '''This Control sets the polarity.
        '''
        '''Valid Values:
        '''RSRTM_VAL_POSITIVE  (0) - Positive
        '''RSRTM_VAL_NEGATIVE  (1) - Negative
        '''
        '''Default Value: RSRTM_VAL_NEGATIVE (1)
        '''
        '''Attribute:
        '''RSRTM_ATTR_TV_TRIGGER_POLARITY_FOR_TV
        '''</param>
        '''<param name="Field">
        '''Selects the frame or line.
        '''
        '''Valid Values:
        '''RSRTM_VAL_TV_EVENT_EVEN       (0) - Even frame
        '''RSRTM_VAL_TV_EVENT_ODD        (1) - Odd frame
        '''RSRTM_VAL_TV_EVENT_ANY_FIELD  (2) - All frames
        '''RSRTM_VAL_TV_EVENT_LINE       (3) - Line
        '''RSRTM_VAL_TV_EVENT_ANY_LINE   (4) - All Line
        '''
        '''Default Value: RSRTM_VAL_TV_EVENT_ANY_FIELD
        '''</param>
        '''<param name="Line">
        '''This Control sets an exact line number.
        '''
        '''Valid Values: 1 to 525, 625,,...., 1080 depending on the TV standard
        '''
        '''Default Value: 1
        '''
        '''Attribute:
        '''RSRTM_ATTR_TV_TRIGGER_LINE_NUMBER
        '''</param>
        '''<returns>
        '''Returns the status code of this operation.  The status code  either indicates success or describes an error or warning condition.  You examine the status code from each call to an instrument driver function to determine if an error occurred.
        '''
        '''To obtain a text description of the status code, call the rsrtm_error_message function.  To obtain additional information about the error condition, call the rsrtm_GetError function.  To clear the error information from the driver, call the rsrtm_ClearError function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''
        '''Numeric Range (in Hex) Status Code Types
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF VISA Warnings
        '''3FFC0000 to 3FFCFFFF VXIPnP Driver Warnings
        '''
        '''BFFF0000 to BFFFFFFF VISA Errors
        '''BFFC0000 to BFFCFFFF VXIPnP Driver Errors
        '''</returns>
        Public Function ConfigureVideoTriggerSource(ByVal Standard As Integer, ByVal Polarity As Integer, ByVal Field As Integer, ByVal Line As Integer) As Integer
            Dim pInvokeResult As Integer = PInvoke.ConfigureVideoTriggerSource(Me._handle, Standard, Polarity, Field, Line)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function sets the time the instrument waits after an A-event until it recognizes B-events.
        '''
        '''Attribute(s):
        '''RSRTM_ATTR_TRIGGER_DELAY
        '''
        '''Remote-control command(s):
        '''TRIGger:B:DELay
        '''</summary>
        '''<param name="Delay_Time">
        '''Sets the time the instrument waits after an A-event until it recognizes B-events.
        '''
        '''Valid Values:
        '''8E-9 to 134.21E-3
        '''not checked
        '''
        '''Default Value: 8.0E-9
        '''
        '''Attribute:
        '''RSRTM_ATTR_TRIGGER_DELAY
        '''</param>
        '''<returns>
        '''Returns the status code of this operation.  The status code  either indicates success or describes an error or warning condition.  You examine the status code from each call to an instrument driver function to determine if an error occurred.
        '''
        '''To obtain a text description of the status code, call the rsrtm_error_message function.  To obtain additional information about the error condition, call the rsrtm_GetError function.  To clear the error information from the driver, call the rsrtm_ClearError function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''
        '''Numeric Range (in Hex) Status Code Types
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF VISA Warnings
        '''3FFC0000 to 3FFCFFFF VXIPnP Driver Warnings
        '''
        '''BFFF0000 to BFFFFFFF VISA Errors
        '''BFFC0000 to BFFCFFFF VXIPnP Driver Errors
        '''</returns>
        Public Function ConfigureTriggerDelay(ByVal Delay_Time As Double) As Integer
            Dim pInvokeResult As Integer = PInvoke.ConfigureTriggerDelay(Me._handle, Delay_Time)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function configures signal intensity and style.
        '''
        '''Attribute(s):
        '''RSRTM_ATTR_SIGNAL_STYLE
        '''
        '''Remote-control command(s):
        '''DISPlay:STYLe
        '''</summary>
        '''<param name="Style">
        '''Select the style in which the waveform is displayed.
        '''
        '''Valid Values:
        '''RSRTM_VAL_SIGNAL_STYLE_VECTORS (0) - Vectors
        '''RSRTM_VAL_SIGNAL_STYLE_DOTS    (1) - Dots
        '''
        '''Default Value: RSRTM_VAL_SIGNAL_STYLE_VECTORS (0)
        '''
        '''Attribute(s):
        '''RSRTM_ATTR_SIGNAL_STYLE
        '''</param>
        '''<returns>
        '''Returns the status code of this operation.  The status code  either indicates success or describes an error or warning condition.  You examine the status code from each call to an instrument driver function to determine if an error occurred.
        '''
        '''To obtain a text description of the status code, call the rsrtm_error_message function.  To obtain additional information about the error condition, call the rsrtm_GetError function.  To clear the error information from the driver, call the rsrtm_ClearError function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''
        '''Numeric Range (in Hex) Status Code Types
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF VISA Warnings
        '''3FFC0000 to 3FFCFFFF VXIPnP Driver Warnings
        '''
        '''BFFF0000 to BFFFFFFF VISA Errors
        '''BFFC0000 to BFFCFFFF VXIPnP Driver Errors
        '''</returns>
        Public Function ConfigureSignalStyle(ByVal Style As Integer) As Integer
            Dim pInvokeResult As Integer = PInvoke.ConfigureSignalStyle(Me._handle, Style)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function defines the intensity of selected display element.
        '''
        '''Attribute(s):
        '''RSRTM_ATTR_BACKGROUND_INTENSITY
        '''RSRTM_ATTR_GRID_INTENSITY
        '''RSRTM_ATTR_WAVEFORM_INTENSITY
        '''
        '''Remote-control command(s):
        '''DISPlay:INTensity:BACKlight
        '''DISPlay:INTensity:GRID
        '''DISPlay:INTensity:WAVeform
        '''</summary>
        '''<param name="Element">
        '''Selects the element.
        '''
        '''Valid Values:
        '''RSRTM_VAL_DISPLAY_BACKGROUND (0) - Background
        '''RSRTM_VAL_DISPLAY_GRID       (1) - Grid
        '''RSRTM_VAL_DISPLAY_WAVEFORM   (2) - Waveform
        '''
        '''Default Value: RSRTM_VAL_DISPLAY_BACKGROUND
        '''</param>
        '''<param name="Intensity">
        '''This value defines the intensity of the lighting of the selected display element.
        '''
        '''Valid Values:
        '''10 to 100 %
        '''
        '''Default Value: 50
        '''
        '''Attribute:
        '''RSRTM_ATTR_BACKGROUND_INTENSITY
        '''RSRTM_ATTR_WAVEFORM_INTENSITY
        '''RSRTM_ATTR_GRID_INTENSITY
        '''</param>
        '''<returns>
        '''Returns the status code of this operation.  The status code  either indicates success or describes an error or warning condition.  You examine the status code from each call to an instrument driver function to determine if an error occurred.
        '''
        '''To obtain a text description of the status code, call the rsrtm_error_message function.  To obtain additional information about the error condition, call the rsrtm_GetError function.  To clear the error information from the driver, call the rsrtm_ClearError function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''
        '''Numeric Range (in Hex) Status Code Types
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF VISA Warnings
        '''3FFC0000 to 3FFCFFFF VXIPnP Driver Warnings
        '''
        '''BFFF0000 to BFFFFFFF VISA Errors
        '''BFFC0000 to BFFCFFFF VXIPnP Driver Errors
        '''</returns>
        Public Function ConfigureDisplayIntensity(ByVal Element As Integer, ByVal Intensity As Double) As Integer
            Dim pInvokeResult As Integer = PInvoke.ConfigureDisplayIntensity(Me._handle, Element, Intensity)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function sets the color and brightness of the displayed waveform samples depending on their cumulative occurance.
        '''
        '''Attribute(s):
        '''RSRTM_ATTR_COLOR_AND_BRIGHTNESS
        '''
        '''Remote-control command(s):
        '''DISPlay:PALette &lt;Palette&gt;
        '''</summary>
        '''<param name="Palette">
        '''Selects the color and brightness of the displayed waveform samples.
        '''
        '''Valid Values:
        '''RSRTM_VAL_COLOR_NORM     (0) - Normal
        '''RSRTM_VAL_COLOR_INVERSE  (1) - Inverse
        '''RSRTM_VAL_COLOR_FCOLOR   (2) - FColor
        '''RSRTM_VAL_COLOR_INVCOLOR (3) - ICFolor
        '''
        '''Default Value: RSRTM_VAL_COLOR_NORM (0)
        '''
        '''Attribute(s):
        '''RSRTM_ATTR_COLOR_AND_BRIGHTNESS
        '''</param>
        '''<returns>
        '''Returns the status code of this operation.  The status code  either indicates success or describes an error or warning condition.  You examine the status code from each call to an instrument driver function to determine if an error occurred.
        '''
        '''To obtain a text description of the status code, call the rsrtm_error_message function.  To obtain additional information about the error condition, call the rsrtm_GetError function.  To clear the error information from the driver, call the rsrtm_ClearError function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''
        '''Numeric Range (in Hex) Status Code Types
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF VISA Warnings
        '''3FFC0000 to 3FFCFFFF VXIPnP Driver Warnings
        '''
        '''BFFF0000 to BFFFFFFF VISA Errors
        '''BFFC0000 to BFFCFFFF VXIPnP Driver Errors
        '''</returns>
        Public Function ConfigureColorAndBrightness(ByVal Palette As Integer) As Integer
            Dim pInvokeResult As Integer = PInvoke.ConfigureColorAndBrightness(Me._handle, Palette)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function defines how the grid is displayed.
        '''
        '''Attribute(s):
        '''RSRTM_ATTR_DIAGRAM_GRID_STYLE
        '''
        '''Remote-control command(s):
        '''DISPlay:GRID:STYLe &lt;Style&gt;
        '''</summary>
        '''<param name="Style">
        '''Selects the grid style.
        '''
        '''Valid Values:
        '''RSRTM_VAL_GRID_LINES  (0) - Lines
        '''RSRTM_VAL_GRID_CROSS  (1) - Reticle
        '''RSRTM_VAL_GRID_NONE   (2) - None
        '''
        '''Default Value: RSRTM_VAL_GRID_LINES  (0)
        '''
        '''Attribute(s):
        '''RSRTM_ATTR_DIAGRAM_GRID_STYLE
        '''</param>
        '''<returns>
        '''Returns the status code of this operation.  The status code  either indicates success or describes an error or warning condition.  You examine the status code from each call to an instrument driver function to determine if an error occurred.
        '''
        '''To obtain a text description of the status code, call the rsrtm_error_message function.  To obtain additional information about the error condition, call the rsrtm_GetError function.  To clear the error information from the driver, call the rsrtm_ClearError function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''
        '''Numeric Range (in Hex) Status Code Types
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF VISA Warnings
        '''3FFC0000 to 3FFCFFFF VXIPnP Driver Warnings
        '''
        '''BFFF0000 to BFFFFFFF VISA Errors
        '''BFFC0000 to BFFCFFFF VXIPnP Driver Errors
        '''</returns>
        Public Function ConfigureDisplayGridStyle(ByVal Style As Integer) As Integer
            Dim pInvokeResult As Integer = PInvoke.ConfigureDisplayGridStyle(Me._handle, Style)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function sets the language in which the softkey labels, help and other screen information can be displayed.
        '''
        '''Attribute(s):
        '''RSRTM_ATTR_DISPLAY_LANGUAGE
        '''
        '''Remote-control command(s):
        '''DISPlay:LANGuage &lt;Language&gt;
        '''</summary>
        '''<param name="Language">
        '''Selects the language.
        '''
        '''Valid Values:
        '''RSRTM_VAL_DISPLAY_ENGLISH (0) - English
        '''RSRTM_VAL_DISPLAY_GERMAN  (1) - German
        '''
        '''Default Value: RSRTM_VAL_DISPLAY_ENGLISH  (0)
        '''
        '''Attribute(s):
        '''RSRTM_ATTR_DISPLAY_LANGUAGE
        '''</param>
        '''<returns>
        '''Returns the status code of this operation.  The status code  either indicates success or describes an error or warning condition.  You examine the status code from each call to an instrument driver function to determine if an error occurred.
        '''
        '''To obtain a text description of the status code, call the rsrtm_error_message function.  To obtain additional information about the error condition, call the rsrtm_GetError function.  To clear the error information from the driver, call the rsrtm_ClearError function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''
        '''Numeric Range (in Hex) Status Code Types
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF VISA Warnings
        '''3FFC0000 to 3FFCFFFF VXIPnP Driver Warnings
        '''
        '''BFFF0000 to BFFFFFFF VISA Errors
        '''BFFC0000 to BFFCFFFF VXIPnP Driver Errors
        '''</returns>
        Public Function ConfigureDisplayLanguage(ByVal Language As Integer) As Integer
            Dim pInvokeResult As Integer = PInvoke.ConfigureDisplayLanguage(Me._handle, Language)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function sets the diagram mode.
        '''
        '''Attribute(s):
        '''RSRTM_ATTR_DIAGRAM_MODE
        '''
        '''Remote-control command(s):
        '''DISPlay:MODE
        '''</summary>
        '''<param name="Mode">
        '''Selects the diagram mode.
        '''
        '''Valid Values:
        '''RSRTM_VAL_DISPLAY_YT (0) - YT
        '''RSRTM_VAL_DISPLAY_XY (1) - XY
        '''
        '''Default Value: RSRTM_VAL_DISPLAY_YT  (0)
        '''
        '''Attribute(s):
        '''RSRTM_ATTR_DIAGRAM_MODE
        '''</param>
        '''<returns>
        '''Returns the status code of this operation.  The status code  either indicates success or describes an error or warning condition.  You examine the status code from each call to an instrument driver function to determine if an error occurred.
        '''
        '''To obtain a text description of the status code, call the rsrtm_error_message function.  To obtain additional information about the error condition, call the rsrtm_GetError function.  To clear the error information from the driver, call the rsrtm_ClearError function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''
        '''Numeric Range (in Hex) Status Code Types
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF VISA Warnings
        '''3FFC0000 to 3FFCFFFF VXIPnP Driver Warnings
        '''
        '''BFFF0000 to BFFFFFFF VISA Errors
        '''BFFC0000 to BFFCFFFF VXIPnP Driver Errors
        '''</returns>
        Public Function ConfigureDiagramMode(ByVal Mode As Integer) As Integer
            Dim pInvokeResult As Integer = PInvoke.ConfigureDiagramMode(Me._handle, Mode)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function configures marker.
        '''
        '''Attribute(s):
        '''RSRTM_ATTR_MARKER_SET
        '''RSRTM_ATTR_MARKER_NEXT
        '''RSRTM_ATTR_MARKER_PREVIOUS
        '''RSRTM_ATTR_MARKER_CLEAR
        '''RSRTM_ATTR_MARKER_CLEAR_ALL
        '''
        '''Remote-control command(s):
        '''TSTamp:SET
        '''TSTamp:NEXT
        '''TSTamp:PREVious
        '''TSTemp:CLEar
        '''TSTamp:ACLear
        '''
        '''</summary>
        '''<param name="Marker_Action">
        '''This Control selects the marker action.
        '''
        '''Valid Values:
        '''RSRTM_VAL_MARKER_ACTION_SET    (0) - Set
        '''RSRTM_VAL_MARKER_ACTION_NEXT   (1) - Next
        '''RSRTM_VAL_MARKER_ACTION_PREV   (2) - Previous
        '''RSRTM_VAL_MARKER_ACTION_CLEAR  (3) - Clear
        '''RSRTM_VAL_MARKER_ACTION_ACLEAR (4) - Clear All
        '''
        '''Default Value: RSRTM_VAL_MARKER_ACTION_SET
        '''
        '''Attribute(s):
        '''RSRTM_ATTR_MARKER_SET
        '''RSRTM_ATTR_MARKER_NEXT
        '''RSRTM_ATTR_MARKER_PREVIOUS
        '''RSRTM_ATTR_MARKER_CLEAR
        '''RSRTM_ATTR_MARKER_CLEAR_ALL
        '''</param>
        '''<returns>
        '''Returns the status code of this operation.  The status code  either indicates success or describes an error or warning condition.  You examine the status code from each call to an instrument driver function to determine if an error occurred.
        '''
        '''To obtain a text description of the status code, call the rsrtm_error_message function.  To obtain additional information about the error condition, call the rsrtm_GetError function.  To clear the error information from the driver, call the rsrtm_ClearError function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''
        '''Numeric Range (in Hex) Status Code Types
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF VISA Warnings
        '''3FFC0000 to 3FFCFFFF VXIPnP Driver Warnings
        '''
        '''BFFF0000 to BFFFFFFF VISA Errors
        '''BFFC0000 to BFFCFFFF VXIPnP Driver Errors
        '''</returns>
        Public Function MarkerSearch(ByVal Marker_Action As Integer) As Integer
            Dim pInvokeResult As Integer = PInvoke.MarkerSearch(Me._handle, Marker_Action)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function configures persistence.
        '''
        '''Attribute(s):
        '''RSRTM_ATTR_PERSISTENCE_STATE
        '''RSRTM_ATTR_INFINITE_PERSISTENCE
        '''RSRTM_ATTR_PERSISTENCE_TIME
        '''
        '''Remote-control command(s):
        '''DISPlay:PERSistence[:STATe]
        '''DISPlay:PERSistence:INFinite
        '''DISPlay:PERSistence:TIME
        '''</summary>
        '''<param name="Enable">
        '''If enabled, each new data point in the diagram area remains on the screen for the defined duration. If disabled, the signal value is only displayed as long as it actually occurs.
        '''
        '''Valid Values:
        '''VI_FALSE (0) - Off
        '''VI_TRUE  (1) - On
        '''
        '''Default Value: VI_TRUE (1)
        '''
        '''Attribute(s):
        '''RSRTM_ATTR_PERSISTENCE_STATE
        '''</param>
        '''<param name="Infinite">
        '''If persistence is enabled, each new data point in the diagram area remains on the screen infinitely until is disabled.
        '''
        '''Valid Values:
        '''VI_FALSE (0) - Off
        '''VI_TRUE  (1) - On
        '''
        '''Default Value: VI_FALSE (0)
        '''
        '''Attribute(s):
        '''RSRTM_ATTR_INFINITE_PERSISTENCE
        '''</param>
        '''<param name="Time">
        '''If persistence is enabled, each new data point in the diagram area remains on the screen for the duration defined here.
        '''
        '''Valid Values:
        '''0.05 to infinite
        '''
        '''Default Value: 0.05
        '''
        '''Attribute:
        '''RSRTM_ATTR_PERSISTENCE_TIME
        '''</param>
        '''<returns>
        '''Returns the status code of this operation.  The status code  either indicates success or describes an error or warning condition.  You examine the status code from each call to an instrument driver function to determine if an error occurred.
        '''
        '''To obtain a text description of the status code, call the rsrtm_error_message function.  To obtain additional information about the error condition, call the rsrtm_GetError function.  To clear the error information from the driver, call the rsrtm_ClearError function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''
        '''Numeric Range (in Hex) Status Code Types
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF VISA Warnings
        '''3FFC0000 to 3FFCFFFF VXIPnP Driver Warnings
        '''
        '''BFFF0000 to BFFFFFFF VISA Errors
        '''BFFC0000 to BFFCFFFF VXIPnP Driver Errors
        '''</returns>
        Public Function ConfigurePersistence(ByVal Enable As Boolean, ByVal Infinite As Boolean, ByVal Time As Double) As Integer
            Dim pInvokeResult As Integer = PInvoke.ConfigurePersistence(Me._handle, System.Convert.ToUInt16(Enable), System.Convert.ToUInt16(Infinite), Time)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function removes the displayed persistent waveform from the screen.
        '''
        '''Attribute(s):
        '''RSRTM_ATTR_PERSISTENCE_CLEAR
        '''
        '''Remote-control command(s):
        '''DISPlay:PERSistence:CLEar
        '''</summary>
        '''<returns>
        '''Returns the status code of this operation.  The status code  either indicates success or describes an error or warning condition.  You examine the status code from each call to an instrument driver function to determine if an error occurred.
        '''
        '''To obtain a text description of the status code, call the rsrtm_error_message function.  To obtain additional information about the error condition, call the rsrtm_GetError function.  To clear the error information from the driver, call the rsrtm_ClearError function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''
        '''Numeric Range (in Hex) Status Code Types
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF VISA Warnings
        '''3FFC0000 to 3FFCFFFF VXIPnP Driver Warnings
        '''
        '''BFFF0000 to BFFFFFFF VISA Errors
        '''BFFC0000 to BFFCFFFF VXIPnP Driver Errors
        '''</returns>
        Public Function ClearPersistence() As Integer
            Dim pInvokeResult As Integer = PInvoke.ClearPersistence(Me._handle)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function configures optimal persistence time.
        '''
        '''Attribute(s):
        '''RSRTM_ATTR_PERSISTENCE_TIME_AUTO
        '''
        '''Remote-control command(s):
        '''DISPlay:PERSistence:TIME:AUTO &lt;Auto&gt;
        '''</summary>
        '''<param name="AutoPersist">
        '''If enabled, sets optimal persistence time.
        '''
        '''Valid Values:
        '''VI_FALSE (0) - Off
        '''VI_TRUE  (1) - On
        '''
        '''Default Value:
        '''VI_FALSE (0)
        '''
        '''Attribute(s):
        '''RSRTM_ATTR_PERSISTENCE_TIME_AUTO
        '''</param>
        '''<returns>
        '''Returns the status code of this operation.  The status code  either indicates success or describes an error or warning condition.  You examine the status code from each call to an instrument driver function to determine if an error occurred.
        '''
        '''To obtain a text description of the status code, call the rsrtm_error_message function.  To obtain additional information about the error condition, call the rsrtm_GetError function.  To clear the error information from the driver, call the rsrtm_ClearError function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''
        '''Numeric Range (in Hex) Status Code Types
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF VISA Warnings
        '''3FFC0000 to 3FFCFFFF VXIPnP Driver Warnings
        '''
        '''BFFF0000 to BFFFFFFF VISA Errors
        '''BFFC0000 to BFFCFFFF VXIPnP Driver Errors
        '''</returns>
        Public Function ConfigurePersistenceTimeAuto(ByVal AutoPersist As Boolean) As Integer
            Dim pInvokeResult As Integer = PInvoke.ConfigurePersistenceTimeAuto(Me._handle, System.Convert.ToUInt16(AutoPersist))
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function defines the source to be displayed in x direction in an XY-diagram, replacing the usual time base.
        '''
        '''Attribute(s):
        '''RSRTM_ATTR_XY_X_SOURCE
        '''
        '''Remote-control command(s):
        '''DISPlay:XY:XSOurce &lt;Source&gt;
        '''</summary>
        '''<param name="Source">
        '''Defines the source to be displayed.
        '''
        '''Valid Values:
        '''RSRTM_VAL_SOURCE_CH1 - (1) channel 1
        '''RSRTM_VAL_SOURCE_CH2 - (2) channel 2
        '''RSRTM_VAL_SOURCE_CH3 - (3) channel 3
        '''RSRTM_VAL_SOURCE_CH4 - (4) channel 4
        '''
        '''Default Value: RSRTM_VAL_SOURCE_CH1 (1)
        '''
        '''Attribute(s):
        '''RSRTM_ATTR_XY_X_SOURCE
        '''
        '''Note(s)
        '''(1) CH3 and CH4 are only available with 4-channel R&amp;S RTM oscilloscopes.
        '''</param>
        '''<returns>
        '''Returns the status code of this operation.  The status code  either indicates success or describes an error or warning condition.  You examine the status code from each call to an instrument driver function to determine if an error occurred.
        '''
        '''To obtain a text description of the status code, call the rsrtm_error_message function.  To obtain additional information about the error condition, call the rsrtm_GetError function.  To clear the error information from the driver, call the rsrtm_ClearError function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''
        '''Numeric Range (in Hex) Status Code Types
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF VISA Warnings
        '''3FFC0000 to 3FFCFFFF VXIPnP Driver Warnings
        '''
        '''BFFF0000 to BFFFFFFF VISA Errors
        '''BFFC0000 to BFFCFFFF VXIPnP Driver Errors
        '''</returns>
        Public Function ConfigureSourceX(ByVal Source As Integer) As Integer
            Dim pInvokeResult As Integer = PInvoke.ConfigureSourceX(Me._handle, Source)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function defines the (first) source to be displayed in y direction in an XY-diagram.
        '''
        '''Attribute(s):
        '''RSRTM_ATTR_XY_Y_SOURCE
        '''
        '''Remote-control command(s):
        '''DISPlay:XY:Y1Source &lt;Source&gt;
        '''</summary>
        '''<param name="Source">
        '''Defines the source to be displayed.
        '''
        '''Valid Values:
        '''RSRTM_VAL_SOURCE_CH1 - (1) channel 1
        '''RSRTM_VAL_SOURCE_CH2 - (2) channel 2
        '''RSRTM_VAL_SOURCE_CH3 - (3) channel 3
        '''RSRTM_VAL_SOURCE_CH4 - (4) channel 4
        '''
        '''Default Value: RSRTM_VAL_SOURCE_CH2 - (2)
        '''
        '''Attribute(s):
        '''RSRTM_ATTR_XY_Y_SOURCE
        '''
        '''Note(s)
        '''(1) CH3 and CH4 are only available with 4-channel R&amp;S RTM oscilloscopes.
        '''</param>
        '''<returns>
        '''Returns the status code of this operation.  The status code  either indicates success or describes an error or warning condition.  You examine the status code from each call to an instrument driver function to determine if an error occurred.
        '''
        '''To obtain a text description of the status code, call the rsrtm_error_message function.  To obtain additional information about the error condition, call the rsrtm_GetError function.  To clear the error information from the driver, call the rsrtm_ClearError function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''
        '''Numeric Range (in Hex) Status Code Types
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF VISA Warnings
        '''3FFC0000 to 3FFCFFFF VXIPnP Driver Warnings
        '''
        '''BFFF0000 to BFFFFFFF VISA Errors
        '''BFFC0000 to BFFCFFFF VXIPnP Driver Errors
        '''</returns>
        Public Function ConfigureSourceY1(ByVal Source As Integer) As Integer
            Dim pInvokeResult As Integer = PInvoke.ConfigureSourceY1(Me._handle, Source)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function defines an optional second source to be displayed in y direction in an XY-diagram. The command is only relevant for 4-channel R&amp;S RTM instruments.
        '''
        '''Attribute(s):
        '''RSRTM_ATTR_XY_Y2_SOURCE
        '''
        '''Remote-control command(s):
        '''DISPlay:XY:Y2Source &lt;Source&gt;
        '''</summary>
        '''<param name="Source">
        '''Defines the source to be displayed.
        '''
        '''Valid Values:
        '''RSRTM_VAL_SOURCE_NONE (0) - None
        '''RSRTM_VAL_SOURCE_CH1  (1) - channel 1
        '''RSRTM_VAL_SOURCE_CH2  (2) - channel 2
        '''RSRTM_VAL_SOURCE_CH3  (3) - channel 3
        '''RSRTM_VAL_SOURCE_CH4  (4) - channel 4
        '''
        '''Default Value: RSRTM_VAL_SOURCE_NONE (0)
        '''
        '''Attribute(s):
        '''RSRTM_ATTR_XY_Y2_SOURCE
        '''</param>
        '''<returns>
        '''Returns the status code of this operation.  The status code  either indicates success or describes an error or warning condition.  You examine the status code from each call to an instrument driver function to determine if an error occurred.
        '''
        '''To obtain a text description of the status code, call the rsrtm_error_message function.  To obtain additional information about the error condition, call the rsrtm_GetError function.  To clear the error information from the driver, call the rsrtm_ClearError function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''
        '''Numeric Range (in Hex) Status Code Types
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF VISA Warnings
        '''3FFC0000 to 3FFCFFFF VXIPnP Driver Warnings
        '''
        '''BFFF0000 to BFFFFFFF VISA Errors
        '''BFFC0000 to BFFCFFFF VXIPnP Driver Errors
        '''</returns>
        Public Function ConfigureSourceY2(ByVal Source As Integer) As Integer
            Dim pInvokeResult As Integer = PInvoke.ConfigureSourceY2(Me._handle, Source)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''Activates or deactivates the intensity control of the waveform via an additional signal source and sets the intensity mode.
        '''
        '''Attribute(s):
        '''RSRTM_ATTR_XY_INTENSITY_CONTROL
        '''
        '''Remote-control command(s):
        '''DISPlay:XY:ZMODe &lt;Mode&gt;
        '''</summary>
        '''<param name="Mode">
        '''Selects the mode of intensity control.
        '''
        '''Valid Values:
        '''RSRTM_VAL_ZMODE_ANALOG  (0) - Analog
        '''RSRTM_VAL_ZMODE_DIGITAL (1) - Digital
        '''RSRTM_VAL_ZMODE_OFF     (2) - Off
        '''
        '''Default Value: RSRTM_VAL_ZMODE_OFF (2)
        '''
        '''Attribute(s):
        '''RSRTM_ATTR_XY_INTENSITY_CONTROL
        '''</param>
        '''<returns>
        '''Returns the status code of this operation.  The status code  either indicates success or describes an error or warning condition.  You examine the status code from each call to an instrument driver function to determine if an error occurred.
        '''
        '''To obtain a text description of the status code, call the rsrtm_error_message function.  To obtain additional information about the error condition, call the rsrtm_GetError function.  To clear the error information from the driver, call the rsrtm_ClearError function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''
        '''Numeric Range (in Hex) Status Code Types
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF VISA Warnings
        '''3FFC0000 to 3FFCFFFF VXIPnP Driver Warnings
        '''
        '''BFFF0000 to BFFFFFFF VISA Errors
        '''BFFC0000 to BFFCFFFF VXIPnP Driver Errors
        '''</returns>
        Public Function ConfigureIntensityControl(ByVal Mode As Integer) As Integer
            Dim pInvokeResult As Integer = PInvoke.ConfigureIntensityControl(Me._handle, Mode)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function defines the source to be used to determine the intensity of the xy-waveform.
        '''
        '''Attribute(s):
        '''RSRTM_ATTR_XY_Z_SOURCE
        '''
        '''Remote-control command(s):
        '''DISPlay:XY:ZSOurce &lt;Source&gt;
        '''</summary>
        '''<param name="Source">
        '''Defines the source.
        '''
        '''Valid Values:
        '''RSRTM_VAL_SOURCE_CH1 (1) - channel 1
        '''RSRTM_VAL_SOURCE_CH2 (2) - channel 2
        '''RSRTM_VAL_SOURCE_CH3 (3) - channel 3
        '''RSRTM_VAL_SOURCE_CH4 (4) - channel 4
        '''
        '''Default Value: RSRTM_VAL_SOURCE_CH1 (1)
        '''
        '''Attribute(s):
        '''RSRTM_ATTR_XY_Z_SOURCE
        '''</param>
        '''<returns>
        '''Returns the status code of this operation.  The status code  either indicates success or describes an error or warning condition.  You examine the status code from each call to an instrument driver function to determine if an error occurred.
        '''
        '''To obtain a text description of the status code, call the rsrtm_error_message function.  To obtain additional information about the error condition, call the rsrtm_GetError function.  To clear the error information from the driver, call the rsrtm_ClearError function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''
        '''Numeric Range (in Hex) Status Code Types
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF VISA Warnings
        '''3FFC0000 to 3FFCFFFF VXIPnP Driver Warnings
        '''
        '''BFFF0000 to BFFFFFFF VISA Errors
        '''BFFC0000 to BFFCFFFF VXIPnP Driver Errors
        '''</returns>
        Public Function ConfigureSourceIntensity(ByVal Source As Integer) As Integer
            Dim pInvokeResult As Integer = PInvoke.ConfigureSourceIntensity(Me._handle, Source)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function defines the threshold for intensity with a two-state modulation, if DISPlay: XY: ZMODe is set to DIGital.
        '''
        '''Attribute(s):
        '''RSRTM_ATTR_XY_Z_TRESHOLD
        '''
        '''Remote-control command(s):
        '''DISPlay:XY:ZTHReshold &lt;Zthreshold&gt;
        '''</summary>
        '''<param name="Treshold">
        '''This Control defines the threshold.
        '''
        '''Valid Values:
        '''-10.0 to 10.0 V
        '''
        '''Default Value: 0.0
        '''
        '''Attribute:
        '''RSRTM_ATTR_XY_Z_TRESHOLD
        '''</param>
        '''<returns>
        '''Returns the status code of this operation.  The status code  either indicates success or describes an error or warning condition.  You examine the status code from each call to an instrument driver function to determine if an error occurred.
        '''
        '''To obtain a text description of the status code, call the rsrtm_error_message function.  To obtain additional information about the error condition, call the rsrtm_GetError function.  To clear the error information from the driver, call the rsrtm_ClearError function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''
        '''Numeric Range (in Hex) Status Code Types
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF VISA Warnings
        '''3FFC0000 to 3FFCFFFF VXIPnP Driver Warnings
        '''
        '''BFFF0000 to BFFFFFFF VISA Errors
        '''BFFC0000 to BFFCFFFF VXIPnP Driver Errors
        '''</returns>
        Public Function ConfigureIntensityTreshold(ByVal Treshold As Double) As Integer
            Dim pInvokeResult As Integer = PInvoke.ConfigureIntensityTreshold(Me._handle, Treshold)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function switches the zoom window on or off.
        '''
        '''Attribute(s):
        '''RSRTM_ATTR_ZOOM_WINDOW_STATE
        '''
        '''Remote-control command(s):
        '''TIMebase:ZOOM:STATe
        '''</summary>
        '''<param name="Zoom_Enabled">
        '''Switches the zoom window on or off.
        '''
        '''Valid Values:
        '''VI_FALSE (0) - OFF
        '''VI_TRUE  (1) - ON
        '''
        '''Default Value: VI_FALSE  (0)
        '''
        '''Attribute:
        '''RSRTM_ATTR_ZOOM_WINDOW_STATE
        '''</param>
        '''<returns>
        '''Returns the status code of this operation.  The status code  either indicates success or describes an error or warning condition.  You examine the status code from each call to an instrument driver function to determine if an error occurred.
        '''
        '''To obtain a text description of the status code, call the rsrtm_error_message function.  To obtain additional information about the error condition, call the rsrtm_GetError function.  To clear the error information from the driver, call the rsrtm_ClearError function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''
        '''Numeric Range (in Hex) Status Code Types
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF VISA Warnings
        '''3FFC0000 to 3FFCFFFF VXIPnP Driver Warnings
        '''
        '''BFFF0000 to BFFFFFFF VISA Errors
        '''BFFC0000 to BFFCFFFF VXIPnP Driver Errors
        '''</returns>
        Public Function ConfigureZoomWindowState(ByVal Zoom_Enabled As Boolean) As Integer
            Dim pInvokeResult As Integer = PInvoke.ConfigureZoomWindowState(Me._handle, System.Convert.ToUInt16(Zoom_Enabled))
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function defines the position of the zoom reference point (the reference point of the zoom window) in relation to the reference point of original time base.
        '''
        '''Attribute(s):
        '''RSRTM_ATTR_ZOOM_REFERENCE_POINT
        '''
        '''Remote-control command(s):
        '''TIMebase:ZOOM:POSition
        '''</summary>
        '''<param name="Position">
        '''Defines the zoom reference point.
        '''
        '''Valid Values:
        '''0 to 100
        '''
        '''Default Value: 50
        '''
        '''Attribute(s):
        '''RSRTM_ATTR_ZOOM_REFERENCE_POINT
        '''</param>
        '''<returns>
        '''Returns the status code of this operation.  The status code  either indicates success or describes an error or warning condition.  You examine the status code from each call to an instrument driver function to determine if an error occurred.
        '''
        '''To obtain a text description of the status code, call the rsrtm_error_message function.  To obtain additional information about the error condition, call the rsrtm_GetError function.  To clear the error information from the driver, call the rsrtm_ClearError function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''
        '''Numeric Range (in Hex) Status Code Types
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF VISA Warnings
        '''3FFC0000 to 3FFCFFFF VXIPnP Driver Warnings
        '''
        '''BFFF0000 to BFFFFFFF VISA Errors
        '''BFFC0000 to BFFCFFFF VXIPnP Driver Errors
        '''</returns>
        Public Function ConfigureZoomReferencePoint(ByVal Position As Double) As Integer
            Dim pInvokeResult As Integer = PInvoke.ConfigureZoomReferencePoint(Me._handle, Position)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function defines the time base in the zoom diagram in seconds per division.
        '''
        '''Attribute(s):
        '''RSRTM_ATTR_ZOOM_DIAGRAM_TIMEBASE
        '''
        '''Remote-control command(s):
        '''TIMebase:ZOOM:SCALe
        '''</summary>
        '''<param name="Scale">
        '''Scaling of the zoom time base.
        '''
        '''Valid Values:
        '''not checked
        '''
        '''Default Value: 50e-6
        '''
        '''Attribute(s):
        '''RSRTM_ATTR_ZOOM_DIAGRAM_TIMEBASE
        '''</param>
        '''<returns>
        '''Returns the status code of this operation.  The status code  either indicates success or describes an error or warning condition.  You examine the status code from each call to an instrument driver function to determine if an error occurred.
        '''
        '''To obtain a text description of the status code, call the rsrtm_error_message function.  To obtain additional information about the error condition, call the rsrtm_GetError function.  To clear the error information from the driver, call the rsrtm_ClearError function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''
        '''Numeric Range (in Hex) Status Code Types
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF VISA Warnings
        '''3FFC0000 to 3FFCFFFF VXIPnP Driver Warnings
        '''
        '''BFFF0000 to BFFFFFFF VISA Errors
        '''BFFC0000 to BFFCFFFF VXIPnP Driver Errors
        '''</returns>
        Public Function ConfigureZoomDiagramTimebase(ByVal Scale As Double) As Integer
            Dim pInvokeResult As Integer = PInvoke.ConfigureZoomDiagramTimebase(Me._handle, Scale)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function defines the offset of the trigger point to the reference point of the zoom diagram.
        '''
        '''Attribute(s):
        '''RSRTM_ATTR_ZOOM_OFFSET_OF_TRIGGER_POINT
        '''
        '''Remote-control command(s):
        '''TIMebase:ZOOM:TIME
        '''</summary>
        '''<param name="Time">
        '''Defines the offset of the trigger.
        '''
        '''Valid Values:
        '''not checked
        '''
        '''Default Value: 50.0E-6
        '''
        '''Attribute(s):
        '''RSRTM_ATTR_ZOOM_OFFSET_OF_TRIGGER_POINT
        '''</param>
        '''<returns>
        '''Returns the status code of this operation.  The status code  either indicates success or describes an error or warning condition.  You examine the status code from each call to an instrument driver function to determine if an error occurred.
        '''
        '''To obtain a text description of the status code, call the rsrtm_error_message function.  To obtain additional information about the error condition, call the rsrtm_GetError function.  To clear the error information from the driver, call the rsrtm_ClearError function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''
        '''Numeric Range (in Hex) Status Code Types
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF VISA Warnings
        '''3FFC0000 to 3FFCFFFF VXIPnP Driver Warnings
        '''
        '''BFFF0000 to BFFFFFFF VISA Errors
        '''BFFC0000 to BFFCFFFF VXIPnP Driver Errors
        '''</returns>
        Public Function ConfigureZoomOffsetOfTriggerPoint(ByVal Time As Double) As Integer
            Dim pInvokeResult As Integer = PInvoke.ConfigureZoomOffsetOfTriggerPoint(Me._handle, Time)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function configures indicated measurement.
        '''
        '''Attribute(s):
        '''RSRTM_ATTR_MEASUREMENT_ENABLED
        '''
        '''Remote-control command(s):
        '''MEASurement&lt;Measurement&gt;[:ENABle]
        '''</summary>
        '''<param name="Measurement">
        '''This control selects the measurement.
        '''
        '''Valid Values: 
        '''RSRTM_VAL_MEASUREMENT_1 (1) - 1
        '''RSRTM_VAL_MEASUREMENT_2 (2) - 2
        '''RSRTM_VAL_MEASUREMENT_3 (3) - 3
        '''RSRTM_VAL_MEASUREMENT_4 (4) - 4
        '''RSRTM_VAL_MEASUREMENT_5 (5) - 5
        '''RSRTM_VAL_MEASUREMENT_6 (6) - 6
        '''RSRTM_VAL_MEASUREMENT_7 (7) - 7
        '''RSRTM_VAL_MEASUREMENT_8 (8) - 8
        '''
        '''Default Value: RSRTM_VAL_MEASUREMENT_1 (1)
        '''
        '''Note:
        '''(1) For RTM values 1-4 are valid only.
        '''</param>
        '''<param name="Measurement_State">
        '''Switches the indicated measurement on or off.
        '''
        '''Valid Values:
        '''VI_FALSE (0) - OFF
        '''VI_TRUE  (1) - ON
        '''
        '''Default Value: VI_FALSE  (0)
        '''
        '''Attribute:
        '''RSRTM_ATTR_MEASUREMENT_ENABLED
        '''</param>
        '''<returns>
        '''Returns the status code of this operation.  The status code  either indicates success or describes an error or warning condition.  You examine the status code from each call to an instrument driver function to determine if an error occurred.
        '''
        '''To obtain a text description of the status code, call the rsrtm_error_message function.  To obtain additional information about the error condition, call the rsrtm_GetError function.  To clear the error information from the driver, call the rsrtm_ClearError function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''
        '''Numeric Range (in Hex) Status Code Types
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF VISA Warnings
        '''3FFC0000 to 3FFCFFFF VXIPnP Driver Warnings
        '''
        '''BFFF0000 to BFFFFFFF VISA Errors
        '''BFFC0000 to BFFCFFFF VXIPnP Driver Errors
        '''</returns>
        Public Function ConfigureMeasurement(ByVal Measurement As Integer, ByVal Measurement_State As Boolean) As Integer
            Dim pInvokeResult As Integer = PInvoke.ConfigureMeasurement(Me._handle, Measurement, System.Convert.ToUInt16(Measurement_State))
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''Selects one of the active signal, reference or math channels as the source of the selected measurement.
        '''
        '''Attribute(s):
        '''no attribute
        '''
        '''Remote-control command(s):
        '''MEASurement&lt;Measurement&gt;:SOURce
        '''</summary>
        '''<param name="Measurement">
        '''This control selects the measurement.
        '''
        '''Valid Values: 
        '''RSRTM_VAL_MEASUREMENT_1 (1) - 1
        '''RSRTM_VAL_MEASUREMENT_2 (2) - 2
        '''RSRTM_VAL_MEASUREMENT_3 (3) - 3
        '''RSRTM_VAL_MEASUREMENT_4 (4) - 4
        '''
        '''Default Value: RSRTM_VAL_MEASUREMENT_1 (1)
        '''</param>
        '''<param name="Signal_Source">
        '''Selects the source of the measurement.
        '''
        '''Valid Values:
        '''RSRTM_VAL_MEASUREMENT_SOURCE_NONE (0) - None
        '''RSRTM_VAL_MEASUREMENT_SOURCE_CH1  (1) - Channel 1
        '''RSRTM_VAL_MEASUREMENT_SOURCE_CH2  (2) - Channel 2
        '''RSRTM_VAL_MEASUREMENT_SOURCE_CH3  (3) - Channel 3
        '''RSRTM_VAL_MEASUREMENT_SOURCE_CH4  (4) - Channel 4
        '''RSRTM_VAL_MEASUREMENT_SOURCE_M1   (5) - Math Waveform 1
        '''RSRTM_VAL_MEASUREMENT_SOURCE_M2   (6) - Math Waveform 2
        '''RSRTM_VAL_MEASUREMENT_SOURCE_M3   (7) - Math Waveform 3
        '''RSRTM_VAL_MEASUREMENT_SOURCE_M4   (8) - Math Waveform 4
        '''RSRTM_VAL_MEASUREMENT_SOURCE_M5   (9) - Math Waveform 5
        '''RSRTM_VAL_MEASUREMENT_SOURCE_R1   (10) - Reference Waveform 1  
        '''RSRTM_VAL_MEASUREMENT_SOURCE_R2   (11) - Reference Waveform 2  
        '''RSRTM_VAL_MEASUREMENT_SOURCE_R3   (12) - Reference Waveform 3  
        '''RSRTM_VAL_MEASUREMENT_SOURCE_R4   (13) - Reference Waveform 4  
        '''
        '''Default Value: RSRTM_VAL_MEASUREMENT_SOURCE_CH1 (1)
        '''</param>
        '''<param name="Reference_Source">
        '''Selects the reference source of the measurement.
        '''
        '''Valid Values:
        '''RSRTM_VAL_MEASUREMENT_SOURCE_NONE (0) - None
        '''RSRTM_VAL_MEASUREMENT_SOURCE_CH1  (1) - Channel 1
        '''RSRTM_VAL_MEASUREMENT_SOURCE_CH2  (2) - Channel 2
        '''RSRTM_VAL_MEASUREMENT_SOURCE_CH3  (3) - Channel 3
        '''RSRTM_VAL_MEASUREMENT_SOURCE_CH4  (4) - Channel 4
        '''RSRTM_VAL_MEASUREMENT_SOURCE_M1   (5) - Math Waveform 1
        '''RSRTM_VAL_MEASUREMENT_SOURCE_M2   (6) - Math Waveform 2
        '''RSRTM_VAL_MEASUREMENT_SOURCE_M3   (7) - Math Waveform 3
        '''RSRTM_VAL_MEASUREMENT_SOURCE_M4   (8) - Math Waveform 4
        '''RSRTM_VAL_MEASUREMENT_SOURCE_M5   (9) - Math Waveform 5
        '''RSRTM_VAL_MEASUREMENT_SOURCE_R1   (17) - Reference Waveform 1  
        '''RSRTM_VAL_MEASUREMENT_SOURCE_R2   (18) - Reference Waveform 2  
        '''RSRTM_VAL_MEASUREMENT_SOURCE_R3   (19) - Reference Waveform 3  
        '''RSRTM_VAL_MEASUREMENT_SOURCE_R4   (20) - Reference Waveform 4  
        '''
        '''Default Value: RSRTM_VAL_MEASUREMENT_SOURCE_NONE (0)
        '''</param>
        '''<returns>
        '''Returns the status code of this operation.  The status code  either indicates success or describes an error or warning condition.  You examine the status code from each call to an instrument driver function to determine if an error occurred.
        '''
        '''To obtain a text description of the status code, call the rsrtm_error_message function.  To obtain additional information about the error condition, call the rsrtm_GetError function.  To clear the error information from the driver, call the rsrtm_ClearError function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''
        '''Numeric Range (in Hex) Status Code Types
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF VISA Warnings
        '''3FFC0000 to 3FFCFFFF VXIPnP Driver Warnings
        '''
        '''BFFF0000 to BFFFFFFF VISA Errors
        '''BFFC0000 to BFFCFFFF VXIPnP Driver Errors
        '''</returns>
        Public Function ConfigureMeasurementSource(ByVal Measurement As Integer, ByVal Signal_Source As Integer, ByVal Reference_Source As Integer) As Integer
            Dim pInvokeResult As Integer = PInvoke.ConfigureMeasurementSource(Me._handle, Measurement, Signal_Source, Reference_Source)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''Defines the main measurement. This measurement is the one referred to if the measurement waveform is used as a source for math calculations. The main measurement type must belong to the same category as the other types assigned to the same measurement waveform, if there are any.
        '''
        '''Attribute(s):
        '''RSRTM_ATTR_AMPT_MAIN_MEASUREMENT
        '''
        '''Remote-control command(s):
        '''MEASurement&lt;Measurement&gt;:MAIN
        '''</summary>
        '''<param name="Measurement">
        '''Selects waveform measurement.
        '''
        '''Valid Values:
        '''1 to 8
        '''
        '''Default Value: 1
        '''
        '''Note(s):
        '''(1) For RTM valid values from 1 to 4 only.
        '''</param>
        '''<param name="Measurement_Function">
        '''Defines or queries the main measurement. This measurement is the one referred to if the measurement waveform is used as a source for math calculations. The main measurement type must belong to the same category as the other types assigned to the same measurement waveform, if there are any.
        '''
        '''Valid Values:
        '''RSRTM_VAL_MEAS_FREQUENCY (1)  - Frequency
        '''RSRTM_VAL_MEAS_PERIOD    (2)  - Period
        '''RSRTM_VAL_MEAS_PEAK      (3)  - Peak Peak
        '''RSRTM_VAL_MEAS_UPEAK     (4)  - Peak Upper
        '''RSRTM_VAL_MEAS_LPEAK     (5)  - Peak Lower
        '''RSRTM_VAL_MEAS_PPC       (6)  - Positive Pulses Count
        '''RSRTM_VAL_MEAS_NPC       (7)  - Negative Pulses Count
        '''RSRTM_VAL_MEAS_REC       (8)  - Rising Edges Count
        '''RSRTM_VAL_MEAS_FEC       (9)  - Falling Edges Count
        '''RSRTM_VAL_MEAS_HIGH      (10)  - High
        '''RSRTM_VAL_MEAS_LOW       (11)  - Low
        '''RSRTM_VAL_MEAS_AMP       (12)  - Amplitude
        '''RSRTM_VAL_MEAS_MEAN      (13)  - Mean Value
        '''RSRTM_VAL_MEAS_RMS       (14)  - RMS Value
        '''RSRTM_VAL_MEAS_RTM       (15)  - Rise Time
        '''RSRTM_VAL_MEAS_FTIM      (16)  - Falling Time
        '''RSRTM_VAL_MEAS_PDCY      (17)  - Duty Cycle Positive
        '''RSRTM_VAL_MEAS_NDCY      (18)  - Duty Cycle Negative
        '''RSRTM_VAL_MEAS_PPW       (19)  - Pulse Width Positive
        '''RSRTM_VAL_MEAS_NPW       (20)  - Pulse Width Negative
        '''RSRTM_VAL_MEAS_CYCM      (21)  - Cycle Mean
        '''RSRTM_VAL_MEAS_CYCR      (22)  - Cycle RMS
        '''RSRTM_VAL_MEAS_SSTDD     (23)  - Standard Deviation
        '''RSRTM_VAL_MEAS_TFR       (24)  - Trigger Frequency
        '''RSRTM_VAL_MEAS_TPER      (25)  - Trigger Period
        '''
        '''Default Value: RSRTM_VAL_MEAS_FREQUENCY (1)
        '''
        '''Attribute(s):
        '''RSRTM_ATTR_AMPT_MAIN_MEASUREMENT
        '''</param>
        '''<returns>
        '''Returns the status code of this operation.  The status code  either indicates success or describes an error or warning condition.  You examine the status code from each call to an instrument driver function to determine if an error occurred.
        '''
        '''To obtain a text description of the status code, call the rsrtm_error_message function.  To obtain additional information about the error condition, call the rsrtm_GetError function.  To clear the error information from the driver, call the rsrtm_ClearError function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''
        '''Numeric Range (in Hex) Status Code Types
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF VISA Warnings
        '''3FFC0000 to 3FFCFFFF VXIPnP Driver Warnings
        '''
        '''BFFF0000 to BFFFFFFF VISA Errors
        '''BFFC0000 to BFFCFFFF VXIPnP Driver Errors
        '''</returns>
        Public Function ConfigureAmplitudeTimeMainMeasurement(ByVal Measurement As Integer, ByVal Measurement_Function As Integer) As Integer
            Dim pInvokeResult As Integer = PInvoke.ConfigureAmplitudeTimeMainMeasurement(Me._handle, Measurement, Measurement_Function)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''Sets the edges to be used for delay measurement. The associated waveforms are defined with rsrtm_ConfigureMeasurementSource function.
        '''
        '''Attribute(s):
        '''RSRTM_ATTR_MEAS_DELAY_SLOPE
        '''
        '''Remote-control command(s):
        '''MEASurement&lt;measurement&gt;:DELay:SLOPe
        '''</summary>
        '''<param name="Measurement">
        '''Selects waveform measurement.
        '''
        '''Valid Values:
        '''1 to 8
        '''
        '''Default Value: 1
        '''
        '''Note(s):
        '''(1) For RTM valid values from 1 to 4 only.
        '''</param>
        '''<param name="Source_1_Slope">
        '''Slope of source 1 (first waveform).
        '''
        '''Valid Values:
        '''RSRTM_VAL_MEAS_SLOPE_POS (0)  - Positive
        '''RSRTM_VAL_MEAS_SLOPE_NEG (1)  - Negative
        '''
        '''
        '''Default Value: RSRTM_VAL_MEAS_SLOPE_POS (0)
        '''
        '''Attribute(s):
        '''RSRTM_ATTR_MEAS_DELAY_SLOPE
        '''</param>
        '''<param name="Source_2_Slope">
        '''Slope of source 2 (second waveform).
        '''
        '''Valid Values:
        '''RSRTM_VAL_MEAS_SLOPE_POS (0)  - Positive
        '''RSRTM_VAL_MEAS_SLOPE_NEG (1)  - Negative
        '''
        '''
        '''Default Value: RSRTM_VAL_MEAS_SLOPE_POS (0)
        '''
        '''Attribute(s):
        '''RSRTM_ATTR_MEAS_DELAY_SLOPE
        '''</param>
        '''<returns>
        '''Returns the status code of this operation.  The status code  either indicates success or describes an error or warning condition.  You examine the status code from each call to an instrument driver function to determine if an error occurred.
        '''
        '''To obtain a text description of the status code, call the rsrtm_error_message function.  To obtain additional information about the error condition, call the rsrtm_GetError function.  To clear the error information from the driver, call the rsrtm_ClearError function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''
        '''Numeric Range (in Hex) Status Code Types
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF VISA Warnings
        '''3FFC0000 to 3FFCFFFF VXIPnP Driver Warnings
        '''
        '''BFFF0000 to BFFFFFFF VISA Errors
        '''BFFC0000 to BFFCFFFF VXIPnP Driver Errors
        '''</returns>
        Public Function ConfigureDelayMeasuremenSlope(ByVal Measurement As Integer, ByVal Source_1_Slope As Integer, ByVal Source_2_Slope As Integer) As Integer
            Dim pInvokeResult As Integer = PInvoke.ConfigureDelayMeasuremenSlope(Me._handle, Measurement, Source_1_Slope, Source_2_Slope)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function returns the measurement category. Currently, the instrument supports only yt-measurements.
        '''
        '''Attribute(s):
        '''RSRTM_ATTR_MEAS_CATEGORY
        '''
        '''Remote-control command(s):
        '''MEASurement&lt;Measurement&gt;:CATegory?
        '''</summary>
        '''<param name="Measurement">
        '''This control selects the measurement.
        '''
        '''Valid Values: 
        '''RSRTM_VAL_MEASUREMENT_1 (1) - 1
        '''RSRTM_VAL_MEASUREMENT_2 (2) - 2
        '''RSRTM_VAL_MEASUREMENT_3 (3) - 3
        '''RSRTM_VAL_MEASUREMENT_4 (4) - 4
        '''RSRTM_VAL_MEASUREMENT_5 (5) - 5
        '''RSRTM_VAL_MEASUREMENT_6 (6) - 6
        '''RSRTM_VAL_MEASUREMENT_7 (7) - 7
        '''RSRTM_VAL_MEASUREMENT_8 (8) - 8
        '''
        '''Default Value: RSRTM_VAL_MEASUREMENT_1 (1)
        '''</param>
        '''<param name="Category">
        '''Returns the measurement category. Currently, the instrument supports only yt-measurements.
        '''
        '''Valid Values:
        '''RSRTM_VAL_MEAS_AMPT (0)  - AMP Time
        '''
        '''Attribute(s):
        '''RSRTM_ATTR_MEAS_CATEGORY
        '''</param>
        '''<returns>
        '''Returns the status code of this operation.  The status code  either indicates success or describes an error or warning condition.  You examine the status code from each call to an instrument driver function to determine if an error occurred.
        '''
        '''To obtain a text description of the status code, call the rsrtm_error_message function.  To obtain additional information about the error condition, call the rsrtm_GetError function.  To clear the error information from the driver, call the rsrtm_ClearError function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''
        '''Numeric Range (in Hex) Status Code Types
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF VISA Warnings
        '''3FFC0000 to 3FFCFFFF VXIPnP Driver Warnings
        '''
        '''BFFF0000 to BFFFFFFF VISA Errors
        '''BFFC0000 to BFFCFFFF VXIPnP Driver Errors
        '''</returns>
        Public Function QueryMeasurementCategory(ByVal Measurement As Integer, ByRef Category As Integer) As Integer
            Dim pInvokeResult As Integer = PInvoke.QueryMeasurementCategory(Me._handle, Measurement, Category)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function sets the lower and upper reference levels for rise and fall time mesurements (cursor and automatic mesurements) as well as the middle reference level for phase and delay measurements. The levels are defined as percentages of the high signal level. The setting is valid for all measurement places.
        '''
        '''Attribute(s):
        '''RSRTM_ATTR_MEAS_RELATIVE_MODE
        '''
        '''Remote-control command(s):
        '''REFLevel:RELative:MODE
        '''</summary>
        '''<param name="Relative_Mode">
        '''Selects the reference level.
        '''
        '''Valid Values:
        '''RSRTM_VAL_MEAS_RELATIVE_TEN    (0)  - Ten
        '''RSRTM_VAL_MEAS_RELATIVE_TWENTY (1)  - Twenty
        '''RSRTM_VAL_MEAS_RELATIVE_FIVE   (2)  - Five
        '''RSRTM_VAL_MEAS_RELATIVE_USER   (3)  - User
        '''
        '''Default Value: RSRTM_VAL_MEAS_RELATIVE_TEN (0)
        '''
        '''Attribute:
        '''RSRTM_ATTR_MEAS_RELATIVE_MODE
        '''
        '''Note(s):
        '''
        '''(1) TEN: 10, 50 and 90%
        '''
        '''(2) TWENty: 20, 50 and 80%
        '''
        '''(3) FIVE: 5, 50 and 95 %
        '''
        '''(4) USER: Defined by user
        '''</param>
        '''<returns>
        '''Returns the status code of this operation.  The status code  either indicates success or describes an error or warning condition.  You examine the status code from each call to an instrument driver function to determine if an error occurred.
        '''
        '''To obtain a text description of the status code, call the rsrtm_error_message function.  To obtain additional information about the error condition, call the rsrtm_GetError function.  To clear the error information from the driver, call the rsrtm_ClearError function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''
        '''Numeric Range (in Hex) Status Code Types
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF VISA Warnings
        '''3FFC0000 to 3FFCFFFF VXIPnP Driver Warnings
        '''
        '''BFFF0000 to BFFFFFFF VISA Errors
        '''BFFC0000 to BFFCFFFF VXIPnP Driver Errors
        '''</returns>
        Public Function ConfigureReferenceLevelMode(ByVal Relative_Mode As Integer) As Integer
            Dim pInvokeResult As Integer = PInvoke.ConfigureReferenceLevelMode(Me._handle, Relative_Mode)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''Set the lower and upper reference levels for rise and fall time mesurements, and the middle reference level used for phase and delay measurements.
        '''
        '''Attribute(s):
        '''RSRTM_ATTR_MEAS_RELATIVE_LOWER_LEVEL
        '''RSRTM_ATTR_MEAS_RELATIVE_UPPER_LEVEL
        '''RSRTM_ATTR_MEAS_RELATIVE_MIDDLE_LEVEL
        '''
        '''Remote-control command(s):
        '''REFLevel:RELative:LOWer
        '''REFLevel:RELative:UPPer
        '''REFLevel:RELative:MIDDle
        '''</summary>
        '''<param name="Lower_Level">
        '''Set the lower reference level for rise and fall time mesurements.
        '''
        '''Valid Values:
        '''0 to 100
        '''
        '''Default Value: 10
        '''
        '''Attribute:
        '''RSRTM_ATTR_MEAS_RELATIVE_LOWER_LEVEL
        '''</param>
        '''<param name="Upper_Level">
        '''Set the upper reference level for rise and fall time mesurements.
        '''
        '''Valid Values:
        '''0 to 100
        '''
        '''Default Value: 90
        '''
        '''Attribute:
        '''RSRTM_ATTR_MEAS_RELATIVE_LOWER_LEVEL
        '''</param>
        '''<param name="Middle_Level">
        '''Set the middle reference level used for phase and delay measurements.
        '''
        '''Valid Values:
        '''0 to 100
        '''
        '''Default Value: 50
        '''
        '''Attribute:
        '''RSRTM_ATTR_MEAS_RELATIVE_MIDDLE_LEVEL
        '''</param>
        '''<returns>
        '''Returns the status code of this operation.  The status code  either indicates success or describes an error or warning condition.  You examine the status code from each call to an instrument driver function to determine if an error occurred.
        '''
        '''To obtain a text description of the status code, call the rsrtm_error_message function.  To obtain additional information about the error condition, call the rsrtm_GetError function.  To clear the error information from the driver, call the rsrtm_ClearError function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''
        '''Numeric Range (in Hex) Status Code Types
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF VISA Warnings
        '''3FFC0000 to 3FFCFFFF VXIPnP Driver Warnings
        '''
        '''BFFF0000 to BFFFFFFF VISA Errors
        '''BFFC0000 to BFFCFFFF VXIPnP Driver Errors
        '''</returns>
        Public Function ConfigureUserReferenceLevel(ByVal Lower_Level As Double, ByVal Upper_Level As Double, ByVal Middle_Level As Double) As Integer
            Dim pInvokeResult As Integer = PInvoke.ConfigureUserReferenceLevel(Me._handle, Lower_Level, Upper_Level, Middle_Level)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function configures the cursor settings.
        '''
        '''Attribute(s):
        '''RSRTM_ATTR_CURSOR_ENABLED
        '''RSRTM_ATTR_CURSOR_SOURCE
        '''RSRTM_ATTR_CURSOR_MEASUREMENT_TYPE
        '''
        '''Remote-control command(s):
        '''CURSor&lt;Cursor&gt;:STATe
        '''CURSor&lt;Cursor&gt;:SOURce
        '''CURSor&lt;Cursor&gt;:FUNCtion
        '''</summary>
        '''<param name="Cursor_State">
        '''Switches the indicated cursor on or off.
        '''
        '''Valid Values:
        '''VI_FALSE (0) - OFF
        '''VI_TRUE  (1) - ON
        '''
        '''Default Value: VI_FALSE  (0)
        '''
        '''Attribute:
        '''RSRTM_ATTR_CURSOR_ENABLED
        '''</param>
        '''<param name="Source">
        '''Defines the source of the cursor measurement.
        '''
        '''Valid Values:
        '''Defines the source of the cursor measurement.
        '''
        '''Valid Values:
        '''RSRTM_VAL_WAV_CH1 (1) - Channel 1
        '''RSRTM_VAL_WAV_CH2 (2) - Channel2
        '''RSRTM_VAL_WAV_CH3 (3) - Channel 3
        '''RSRTM_VAL_WAV_CH4 (4) - Channel 4
        '''RSRTM_VAL_WAV_M1  (5) - Math Waveform 1
        '''RSRTM_VAL_WAV_M2  (6) - Math Waveform 2
        '''RSRTM_VAL_WAV_M3  (7) - Math Waveform 3
        '''RSRTM_VAL_WAV_M4  (8) - Math Waveform 4
        '''RSRTM_VAL_WAV_M5  (9) - Math Waveform 4
        '''RSRTM_VAL_WAV_R1  (10) - Reference Waveform 1
        '''RSRTM_VAL_WAV_R2  (11) - Reference Waveform 2
        '''RSRTM_VAL_WAV_R3  (12) - Reference Waveform 3
        '''RSRTM_VAL_WAV_R4  (13) - Reference Waveform 4
        '''
        '''Default Value: RSRTM_VAL_WAV_CH1 (1)
        '''
        '''Attribute:
        '''RSRTM_ATTR_CURSOR_SOURCE
        '''</param>
        '''<param name="Type">
        '''Defines the cursor measurement type.
        '''
        '''Valid Values:
        '''RSRTM_VAL_CURSOR_HORIZONTAL (0) - Horizontal
        '''RSRTM_VAL_CURSOR_VERTICAL   (1) - Vertical
        '''RSRTM_VAL_CURSOR_PAIRED     (2) - Paired
        '''RSRTM_VAL_CURSOR_HRAT       (3) - H Ratio
        '''RSRTM_VAL_CURSOR_VRAT       (4) - V Ratio
        '''RSRTM_VAL_CURSOR_PPC        (5) - Count positive pulses
        '''RSRTM_VAL_CURSOR_NPC        (6) - Count negative pulses
        '''RSRTM_VAL_CURSOR_REC        (7) - Count rising edges
        '''RSRTM_VAL_CURSOR_FEC        (8) - Count falling edges
        '''RSRTM_VAL_CURSOR_MEAN       (9) - Mean value
        '''RSRTM_VAL_CURSOR_RMS        (10) - Root mean square
        '''RSRTM_VAL_CURSOR_RTIM       (11) - Rise time
        '''RSRTM_VAL_CURSOR_FTIM       (12) - Fall time
        '''RSRTM_VAL_CURSOR_PEAK       (13) - Peak value
        '''RSRTM_VAL_CURSOR_UPE        (14) - Upper peak value
        '''RSRTM_VAL_CURSOR_LPE        (15) - Lower peak value
        '''
        '''Default Value: RSRTM_VAL_CURSOR_VERTICAL (1)
        '''
        '''Attribute:
        '''RSRTM_ATTR_CURSOR_MEASUREMENT_TYPE
        '''</param>
        '''<returns>
        '''Returns the status code of this operation.  The status code  either indicates success or describes an error or warning condition.  You examine the status code from each call to an instrument driver function to determine if an error occurred.
        '''
        '''To obtain a text description of the status code, call the rsrtm_error_message function.  To obtain additional information about the error condition, call the rsrtm_GetError function.  To clear the error information from the driver, call the rsrtm_ClearError function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''
        '''Numeric Range (in Hex) Status Code Types
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF VISA Warnings
        '''3FFC0000 to 3FFCFFFF VXIPnP Driver Warnings
        '''
        '''BFFF0000 to BFFFFFFF VISA Errors
        '''BFFC0000 to BFFCFFFF VXIPnP Driver Errors
        '''</returns>
        Public Function ConfigureCursor(ByVal Cursor_State As Boolean, ByVal Source As Integer, ByVal Type As Integer) As Integer
            Dim pInvokeResult As Integer = PInvoke.ConfigureCursor(Me._handle, System.Convert.ToUInt16(Cursor_State), Source, Type)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function switches all cursors off.
        '''
        '''Attribute(s):
        '''RSRTM_ATTR_ALL_CURSORS_OFF
        '''
        '''Remote-control command(s):
        '''CURSor&lt;Cursor&gt;:AOFF
        '''</summary>
        '''<returns>
        '''Returns the status code of this operation.  The status code  either indicates success or describes an error or warning condition.  You examine the status code from each call to an instrument driver function to determine if an error occurred.
        '''
        '''To obtain a text description of the status code, call the rsrtm_error_message function.  To obtain additional information about the error condition, call the rsrtm_GetError function.  To clear the error information from the driver, call the rsrtm_ClearError function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''
        '''Numeric Range (in Hex) Status Code Types
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF VISA Warnings
        '''3FFC0000 to 3FFCFFFF VXIPnP Driver Warnings
        '''
        '''BFFF0000 to BFFFFFFF VISA Errors
        '''BFFC0000 to BFFCFFFF VXIPnP Driver Errors
        '''</returns>
        Public Function AllCursorsOff() As Integer
            Dim pInvokeResult As Integer = PInvoke.AllCursorsOff(Me._handle)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function configures the horizontal and vertical position of selected cursor.
        '''
        '''Attribute(s):
        '''RSRTM_ATTR_CURSOR_X_POSITION
        '''RSRTM_ATTR_CURSOR_Y_POSITION
        '''
        '''Remote-control command(s):
        '''CURSor&lt;Cursor&gt;:X&lt;CPosition&gt;Position
        '''CURSor&lt;Cursor&gt;:Y&lt;CPosition&gt;Position
        '''</summary>
        '''<param name="Cursor">
        '''This control selects the cursor.
        '''
        '''Valid Values: 
        '''RSRTM_VAL_CURSOR_1 (1) - 1
        '''RSRTM_VAL_CURSOR_2 (2) - 2
        '''RSRTM_VAL_CURSOR_3 (3) - 3
        '''
        '''Default Value: RSRTM_VAL_CURSOR_1 (1)
        '''</param>
        '''<param name="X_Position">
        '''Defines the X position of selected cursor.
        '''
        '''Valid Values: 0.0 to 500.0
        '''
        '''Default Value: 0.0
        '''
        '''Attribute:
        '''RSRTM_ATTR_CURSOR_X_POSITION
        '''</param>
        '''<param name="Y_Position">
        '''Defines the Y position of selected cursor.
        '''
        '''Valid Values: -50.0 to 50.0
        '''
        '''Default Value: 0.0
        '''
        '''Attribute:
        '''RSRTM_ATTR_CURSOR_Y_POSITION
        '''</param>
        '''<returns>
        '''Returns the status code of this operation.  The status code  either indicates success or describes an error or warning condition.  You examine the status code from each call to an instrument driver function to determine if an error occurred.
        '''
        '''To obtain a text description of the status code, call the rsrtm_error_message function.  To obtain additional information about the error condition, call the rsrtm_GetError function.  To clear the error information from the driver, call the rsrtm_ClearError function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''
        '''Numeric Range (in Hex) Status Code Types
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF VISA Warnings
        '''3FFC0000 to 3FFCFFFF VXIPnP Driver Warnings
        '''
        '''BFFF0000 to BFFFFFFF VISA Errors
        '''BFFC0000 to BFFCFFFF VXIPnP Driver Errors
        '''</returns>
        Public Function ConfigureCursorPosition(ByVal Cursor As Integer, ByVal X_Position As Double, ByVal Y_Position As Double) As Integer
            Dim pInvokeResult As Integer = PInvoke.ConfigureCursorPosition(Me._handle, Cursor, X_Position, Y_Position)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function configures the positioning mode of the horizontal and vertical cursors.
        '''
        '''Attribute(s):
        '''RSRTM_ATTR_CURSOR_X_POSITION_COUPLING
        '''RSRTM_ATTR_CURSOR_Y_POSITION_COUPLING
        '''
        '''Remote-control command(s):
        '''CURSor&lt;Cursor&gt;:XCOupling
        '''CURSor&lt;Cursor&gt;:YCOupling
        '''</summary>
        '''<param name="X_Coupling">
        '''Defines the positioning mode of the vertical cursor.
        '''
        '''Valid Values:
        '''VI_FALSE (0) - OFF
        '''VI_TRUE  (1) - ON
        '''
        '''Default Value: VI_FALSE  (0)
        '''
        '''Attribute:
        '''RSRTM_ATTR_CURSOR_X_POSITION_COUPLING
        '''
        '''Note(s):
        '''
        '''(1) ON: Moving one cursor line moves the other cursor line too. The cursor lines always remain a fixed distance.
        '''
        '''(2) OFF: Each cursor line is positioned independently.
        '''</param>
        '''<param name="Y_Coupling">
        '''Defines the positioning mode of the horizontal cursor.
        '''
        '''Valid Values:
        '''VI_FALSE (0) - OFF
        '''VI_TRUE  (1) - ON
        '''
        '''Default Value: VI_FALSE  (0)
        '''
        '''Attribute:
        '''RSRTM_ATTR_CURSOR_Y_POSITION_COUPLING
        '''
        '''Note(s):
        '''
        '''(1) ON: Moving one cursor line moves the other cursor line too. The cursor lines always remain a fixed distance.
        '''
        '''(2) OFF: Each cursor line is positioned independently.
        '''</param>
        '''<returns>
        '''Returns the status code of this operation.  The status code  either indicates success or describes an error or warning condition.  You examine the status code from each call to an instrument driver function to determine if an error occurred.
        '''
        '''To obtain a text description of the status code, call the rsrtm_error_message function.  To obtain additional information about the error condition, call the rsrtm_GetError function.  To clear the error information from the driver, call the rsrtm_ClearError function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''
        '''Numeric Range (in Hex) Status Code Types
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF VISA Warnings
        '''3FFC0000 to 3FFCFFFF VXIPnP Driver Warnings
        '''
        '''BFFF0000 to BFFFFFFF VISA Errors
        '''BFFC0000 to BFFCFFFF VXIPnP Driver Errors
        '''</returns>
        Public Function ConfigureCursorCoupling(ByVal X_Coupling As Boolean, ByVal Y_Coupling As Boolean) As Integer
            Dim pInvokeResult As Integer = PInvoke.ConfigureCursorCoupling(Me._handle, System.Convert.ToUInt16(X_Coupling), System.Convert.ToUInt16(Y_Coupling))
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function resets the cursor to the initial position or sets the cursor lines to typical points of the waveform depending
        '''on the selected measurement type.
        '''
        '''Attribute(s):
        '''RSRTM_ATTR_CURSOR_AUTOSET
        '''RSRTM_ATTR_CURSOR_RESET
        '''
        '''Remote-control command(s):
        '''CURSor&lt;Cursor&gt;:SWAVe
        '''CURSor&lt;Cursor&gt;:SSCReen
        '''</summary>
        '''<param name="Cursor">
        '''This control selects the cursor.
        '''
        '''Valid Values: 
        '''RSRTM_VAL_CURSOR_1 (1) - 1
        '''RSRTM_VAL_CURSOR_2 (2) - 2
        '''RSRTM_VAL_CURSOR_3 (3) - 3
        '''
        '''Default Value: RSRTM_VAL_CURSOR_1 (1)
        '''</param>
        '''<param name="Position">
        '''Selects if the cursor position resets or autosets.
        '''
        '''Valid Values: 
        '''RSRTM_VAL_CURSOR_POSITION_AUTOSET (0) - Autoset
        '''RSRTM_VAL_CURSOR_POSITION_RESET   (1) - Reset
        '''
        '''
        '''Default Value: RSRTM_VAL_CURSOR_POSITION_AUTOSET (0)
        '''
        '''Note(s):
        '''(1) Autoset: Sets the cursor lines to typical points of the waveform depending on the selected measurement type.
        '''(2) Reset: Resets the cursors to their initial positions.
        '''</param>
        '''<returns>
        '''Returns the status code of this operation.  The status code  either indicates success or describes an error or warning condition.  You examine the status code from each call to an instrument driver function to determine if an error occurred.
        '''
        '''To obtain a text description of the status code, call the rsrtm_error_message function.  To obtain additional information about the error condition, call the rsrtm_GetError function.  To clear the error information from the driver, call the rsrtm_ClearError function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''
        '''Numeric Range (in Hex) Status Code Types
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF VISA Warnings
        '''3FFC0000 to 3FFCFFFF VXIPnP Driver Warnings
        '''
        '''BFFF0000 to BFFFFFFF VISA Errors
        '''BFFC0000 to BFFCFFFF VXIPnP Driver Errors
        '''</returns>
        Public Function SetCursorPosition(ByVal Cursor As Integer, ByVal Position As Integer) As Integer
            Dim pInvokeResult As Integer = PInvoke.SetCursorPosition(Me._handle, Cursor, Position)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function sets the cursor to the next or the previous peak.
        '''
        '''Attribute(s):
        '''RSRTM_ATTR_CURSOR_PEAK_NEXT
        '''RSRTM_ATTR_CURSOR_PEAK_PREVIOUS
        '''
        '''Remote-control command(s):
        '''CURSor&lt;Cursor&gt;:SNPeak
        '''CURSor&lt;Cursor&gt;:SPPeak
        '''
        '''Note(s):
        '''(1) For FFT analysis only
        '''</summary>
        '''<param name="Cursor">
        '''This control selects the cursor.
        '''
        '''Valid Values: 
        '''RSRTM_VAL_CURSOR_1 (1) - 1
        '''RSRTM_VAL_CURSOR_2 (2) - 2
        '''RSRTM_VAL_CURSOR_3 (3) - 3
        '''
        '''Default Value: RSRTM_VAL_CURSOR_1 (1)
        '''</param>
        '''<param name="Peak">
        '''This control selects if the cursor is set to the next or the previous peak.
        '''
        '''Valid Values: 
        '''RSRTM_VAL_CURSOR_PEAK_NEXT     (0) - Next Peak
        '''RSRTM_VAL_CURSOR_PEAK_PREVIOUS (1) - Previous Peak
        '''
        '''
        '''Default Value: RSRTM_VAL_CURSOR_PEAK_NEXT (0)
        '''</param>
        '''<returns>
        '''Returns the status code of this operation.  The status code  either indicates success or describes an error or warning condition.  You examine the status code from each call to an instrument driver function to determine if an error occurred.
        '''
        '''To obtain a text description of the status code, call the rsrtm_error_message function.  To obtain additional information about the error condition, call the rsrtm_GetError function.  To clear the error information from the driver, call the rsrtm_ClearError function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''
        '''Numeric Range (in Hex) Status Code Types
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF VISA Warnings
        '''3FFC0000 to 3FFCFFFF VXIPnP Driver Warnings
        '''
        '''BFFF0000 to BFFFFFFF VISA Errors
        '''BFFC0000 to BFFCFFFF VXIPnP Driver Errors
        '''</returns>
        Public Function SetFFTAnalysisCursorToPeak(ByVal Cursor As Integer, ByVal Peak As Integer) As Integer
            Dim pInvokeResult As Integer = PInvoke.SetFFTAnalysisCursorToPeak(Me._handle, Cursor, Peak)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function configures the cursor waveform tracking
        '''
        '''Attribute(s):
        '''RSRTM_ATTR_CURSOR_TRACKING
        '''
        '''Remote-control command(s):
        '''CURSor&lt;Cursor&gt;:TRACking[:STATe]
        '''</summary>
        '''<param name="Tracking">
        '''Switches the cursor waveform tracking.
        '''
        '''Valid Values:
        '''VI_FALSE (0) - OFF
        '''VI_TRUE  (1) - ON
        '''
        '''Default Value: VI_FALSE  (0)
        '''
        '''Attribute:
        '''RSRTM_ATTR_CURSOR_TRACKING
        '''</param>
        '''<returns>
        '''Returns the status code of this operation.  The status code  either indicates success or describes an error or warning condition.  You examine the status code from each call to an instrument driver function to determine if an error occurred.
        '''
        '''To obtain a text description of the status code, call the rsrtm_error_message function.  To obtain additional information about the error condition, call the rsrtm_GetError function.  To clear the error information from the driver, call the rsrtm_ClearError function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''
        '''Numeric Range (in Hex) Status Code Types
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF VISA Warnings
        '''3FFC0000 to 3FFCFFFF VXIPnP Driver Warnings
        '''
        '''BFFF0000 to BFFFFFFF VISA Errors
        '''BFFC0000 to BFFCFFFF VXIPnP Driver Errors
        '''</returns>
        Public Function ConfigureCursorWaveformTracking(ByVal Tracking As Boolean) As Integer
            Dim pInvokeResult As Integer = PInvoke.ConfigureCursorWaveformTracking(Me._handle, System.Convert.ToUInt16(Tracking))
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function configures the adjustment of cursor lines if the vertical or horizontal scales are changed.
        '''
        '''Attribute(s):
        '''RSRTM_ATTR_CURSOR_ADJUSTMENT
        '''
        '''Remote-control command(s):
        '''CURSor&lt;Cursor&gt;:TRACking:SCALe[:STATe]
        '''</summary>
        '''<param name="Adjustment">
        '''Switches the adjustment of cursor lines if the vertical or horizontal scales are changed.
        '''
        '''Valid Values:
        '''VI_FALSE (0) - OFF
        '''VI_TRUE  (1) - ON
        '''
        '''Default Value: VI_FALSE  (0)
        '''
        '''Attribute:
        '''RSRTM_ATTR_CURSOR_ADJUSTMENT
        '''</param>
        '''<returns>
        '''Returns the status code of this operation.  The status code  either indicates success or describes an error or warning condition.  You examine the status code from each call to an instrument driver function to determine if an error occurred.
        '''
        '''To obtain a text description of the status code, call the rsrtm_error_message function.  To obtain additional information about the error condition, call the rsrtm_GetError function.  To clear the error information from the driver, call the rsrtm_ClearError function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''
        '''Numeric Range (in Hex) Status Code Types
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF VISA Warnings
        '''3FFC0000 to 3FFCFFFF VXIPnP Driver Warnings
        '''
        '''BFFF0000 to BFFFFFFF VISA Errors
        '''BFFC0000 to BFFCFFFF VXIPnP Driver Errors
        '''</returns>
        Public Function ConfigureCursorAdjustment(ByVal Adjustment As Boolean) As Integer
            Dim pInvokeResult As Integer = PInvoke.ConfigureCursorAdjustment(Me._handle, System.Convert.ToUInt16(Adjustment))
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function sets the unit for horizontal or vertical ratio measurements.
        '''
        '''Attribute(s):
        '''RSRTM_ATTR_CURSOR_X_RATIO_MEASUREMENT_UNIT
        '''RSRTM_ATTR_CURSOR_Y_RATIO_MEASUREMENT_UNIT
        '''
        '''Remote-control command(s):
        '''CURSor1:XRATio:UNIT
        '''CURSor1:YRATio:UNIT
        '''</summary>
        '''<param name="Direction">
        '''Selects the distance direction.
        '''
        '''Valid Values:
        '''RSRTM_VAL_CURSOR_HORIZONTAL (0) - Horizontal
        '''RSRTM_VAL_CURSOR_VERTICAL   (1) - Vertical
        '''
        '''Default Value: RSRTM_VAL_CURSOR_HORIZONTAL (0)
        '''
        '''Attribute:
        '''-
        '''</param>
        '''<param name="Measurement_Unit">
        '''Defines the measurement unit.
        '''
        '''Note(s):
        '''For Y ratio only 0 or 1 is valid.
        '''
        '''Valid Values:
        '''RSRTM_VAL_UNIT_RATIO  (0) - Floating Value
        '''RSRTM_VAL_UNIT_PCT    (1) - Percent
        '''RSRTM_VAL_UNIT_DEGREE (2) - Degree
        '''RSRTM_VAL_UNIT_RAD    (3) - Radian
        '''
        '''Default Value: RSRTM_VAL_UNIT_RATIO (1)
        '''
        '''Attribute:
        '''RSRTM_ATTR_CURSOR_X_RATIO_MEASUREMENT_UNIT
        '''RSRTM_ATTR_CURSOR_Y_RATIO_MEASUREMENT_UNIT
        '''</param>
        '''<returns>
        '''Returns the status code of this operation.  The status code  either indicates success or describes an error or warning condition.  You examine the status code from each call to an instrument driver function to determine if an error occurred.
        '''
        '''To obtain a text description of the status code, call the rsrtm_error_message function.  To obtain additional information about the error condition, call the rsrtm_GetError function.  To clear the error information from the driver, call the rsrtm_ClearError function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''
        '''Numeric Range (in Hex) Status Code Types
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF VISA Warnings
        '''3FFC0000 to 3FFCFFFF VXIPnP Driver Warnings
        '''
        '''BFFF0000 to BFFFFFFF VISA Errors
        '''BFFC0000 to BFFCFFFF VXIPnP Driver Errors
        '''</returns>
        Public Function ConfigureCursorRatioMeasurementUnit(ByVal Direction As Integer, ByVal Measurement_Unit As Integer) As Integer
            Dim pInvokeResult As Integer = PInvoke.ConfigureCursorRatioMeasurementUnit(Me._handle, Direction, Measurement_Unit)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function returns the ratio of the x-values (e.g. a duty cycle) between the first and second cursors and the first and third cursors: (x2-x1)/(x3-x1) or provides three cursors and measures the ratio of the y-values (e.g. overshooting) between the first and second cursors and the first and third cursors: (y2-y1)/(y3-y1).
        '''
        '''Attribute(s):
        '''RSRTM_ATTR_CURSOR_X_RATIO_MEASUREMENT
        '''RSRTM_ATTR_CURSOR_Y_RATIO_MEASUREMENT
        '''
        '''Remote-control command(s):
        '''CURSor&lt;Cursor&gt;:XRATio[:VALue]?
        '''CURSor&lt;Cursor&gt;:YRATio[:VALue]?
        '''</summary>
        '''<param name="Direction">
        '''Selects the distance direction.
        '''
        '''Valid Values:
        '''RSRTM_VAL_CURSOR_HORIZONTAL (0) - Horizontal
        '''RSRTM_VAL_CURSOR_VERTICAL   (1) - Vertical
        '''
        '''Default Value: RSRTM_VAL_CURSOR_HORIZONTAL (0)
        '''</param>
        '''<param name="Ratio_Measurement">
        '''Returns the ratio.
        '''
        '''Attribute(s):
        '''RSRTM_ATTR_CURSOR_X_RATIO_MEASUREMENT
        '''RSRTM_ATTR_CURSOR_Y_RATIO_MEASUREMENT
        '''</param>
        '''<returns>
        '''Returns the status code of this operation.  The status code  either indicates success or describes an error or warning condition.  You examine the status code from each call to an instrument driver function to determine if an error occurred.
        '''
        '''To obtain a text description of the status code, call the rsrtm_error_message function.  To obtain additional information about the error condition, call the rsrtm_GetError function.  To clear the error information from the driver, call the rsrtm_ClearError function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''
        '''Numeric Range (in Hex) Status Code Types
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF VISA Warnings
        '''3FFC0000 to 3FFCFFFF VXIPnP Driver Warnings
        '''
        '''BFFF0000 to BFFFFFFF VISA Errors
        '''BFFC0000 to BFFCFFFF VXIPnP Driver Errors
        '''</returns>
        Public Function QueryCursorRatioMeasurement(ByVal Direction As Integer, ByRef Ratio_Measurement As Double) As Integer
            Dim pInvokeResult As Integer = PInvoke.QueryCursorRatioMeasurement(Me._handle, Direction, Ratio_Measurement)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function queries the delta value (distance) of two horizontal or vertical cursors.
        '''
        '''Attribute(s):
        '''RSRTM_ATTR_CURSOR_DISTANCE
        '''
        '''Remote-control command(s):
        '''CURSor1:&lt;CursorDirection&gt;[:VALue]?
        '''</summary>
        '''<param name="Direction">
        '''Selects the distance direction.
        '''
        '''Valid Values:
        '''RSRTM_VAL_CURSOR_HORIZONTAL (0) - Horizontal
        '''RSRTM_VAL_CURSOR_VERTICAL   (1) - Vertical
        '''
        '''Default Value: RSRTM_VAL_CURSOR_HORIZONTAL (0)
        '''
        '''</param>
        '''<param name="Cursor_Distance">
        '''Returns the delta value (distance) of two horizontal or vertical cursors (RTM) / cursor lines (RTO).
        '''
        '''Attribute:
        '''RSRTM_ATTR_CURSOR_DISTANCE
        '''</param>
        '''<returns>
        '''Returns the status code of this operation.  The status code  either indicates success or describes an error or warning condition.  You examine the status code from each call to an instrument driver function to determine if an error occurred.
        '''
        '''To obtain a text description of the status code, call the rsrtm_error_message function.  To obtain additional information about the error condition, call the rsrtm_GetError function.  To clear the error information from the driver, call the rsrtm_ClearError function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''
        '''Numeric Range (in Hex) Status Code Types
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF VISA Warnings
        '''3FFC0000 to 3FFCFFFF VXIPnP Driver Warnings
        '''
        '''BFFF0000 to BFFFFFFF VISA Errors
        '''BFFC0000 to BFFCFFFF VXIPnP Driver Errors
        '''</returns>
        Public Function QueryCursorDistance(ByVal Direction As Integer, ByRef Cursor_Distance As Double) As Integer
            Dim pInvokeResult As Integer = PInvoke.QueryCursorDistance(Me._handle, Direction, Cursor_Distance)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function queries the inverse value of the delta value (distance) of the two vertical or horizontal cursors.
        '''
        '''Attribute(s):
        '''RSRTM_ATTR_CURSOR_INVERSE_DISTANCE
        '''
        '''Remote-control command(s):
        '''CURSor&lt;Cursor&gt;:XDELta:INVerse?
        '''</summary>
        '''<param name="Cursor_Distance">
        '''Returns the inverse value of the delta value (distance) of the two vertical or horizontal cursors (RTM) / cursor lines (RTO).
        '''
        '''Attribute:
        '''RSRTM_ATTR_CURSOR_INVERSE_DISTANCE
        '''</param>
        '''<returns>
        '''Returns the status code of this operation.  The status code  either indicates success or describes an error or warning condition.  You examine the status code from each call to an instrument driver function to determine if an error occurred.
        '''
        '''To obtain a text description of the status code, call the rsrtm_error_message function.  To obtain additional information about the error condition, call the rsrtm_GetError function.  To clear the error information from the driver, call the rsrtm_ClearError function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''
        '''Numeric Range (in Hex) Status Code Types
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF VISA Warnings
        '''3FFC0000 to 3FFCFFFF VXIPnP Driver Warnings
        '''
        '''BFFF0000 to BFFFFFFF VISA Errors
        '''BFFC0000 to BFFCFFFF VXIPnP Driver Errors
        '''</returns>
        Public Function QueryCursorInverseDistance(ByRef Cursor_Distance As Double) As Integer
            Dim pInvokeResult As Integer = PInvoke.QueryCursorInverseDistance(Me._handle, Cursor_Distance)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function queries the inverse value of the voltage difference - the reciprocal of the vertical distance of two horizontal cursor lines: 1/?V.
        '''
        '''Note(s):
        '''(1) Only for horizontal direction.
        '''
        '''Attribute(s):
        '''RSRTM_ATTR_CURSOR_VOLTAGE_INVERSE_DISTANCE
        '''
        '''Remote-control command(s):
        '''CURSor1:&lt;CursorDirection&gt;:SLOPe?
        '''</summary>
        '''<param name="Cursor_Distance">
        '''Returns the inverse value of the voltage difference - the reciprocal of the vertical distance
        '''of two horizontal cursor lines: 1/deltaV.
        '''
        '''Attribute:
        '''RSRTM_ATTR_CURSOR_VOLTAGE_INVERSE_DISTANCE
        '''</param>
        '''<returns>
        '''Returns the status code of this operation.  The status code  either indicates success or describes an error or warning condition.  You examine the status code from each call to an instrument driver function to determine if an error occurred.
        '''
        '''To obtain a text description of the status code, call the rsrtm_error_message function.  To obtain additional information about the error condition, call the rsrtm_GetError function.  To clear the error information from the driver, call the rsrtm_ClearError function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''
        '''Numeric Range (in Hex) Status Code Types
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF VISA Warnings
        '''3FFC0000 to 3FFCFFFF VXIPnP Driver Warnings
        '''
        '''BFFF0000 to BFFFFFFF VISA Errors
        '''BFFC0000 to BFFCFFFF VXIPnP Driver Errors
        '''</returns>
        Public Function QueryCursorVoltageInverseDistance(ByRef Cursor_Distance As Double) As Integer
            Dim pInvokeResult As Integer = PInvoke.QueryCursorVoltageInverseDistance(Me._handle, Cursor_Distance)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function queries the cursor result.
        '''
        '''Attribute(s):
        '''RSRTM_ATTR_CURSOR_POSITION
        '''
        '''Remote-control command(s):
        '''CURSor&lt;Cursor&gt;:RESult?
        '''</summary>
        '''<param name="Data">
        '''Returns the cursor measurement result.
        '''
        '''Attribute(s):
        '''RSRTM_ATTR_CURSOR_POSITION
        '''</param>
        '''<returns>
        '''Returns the status code of this operation.  The status code  either indicates success or describes an error or warning condition.  You examine the status code from each call to an instrument driver function to determine if an error occurred.
        '''
        '''To obtain a text description of the status code, call the rsrtm_error_message function.  To obtain additional information about the error condition, call the rsrtm_GetError function.  To clear the error information from the driver, call the rsrtm_ClearError function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''
        '''Numeric Range (in Hex) Status Code Types
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF VISA Warnings
        '''3FFC0000 to 3FFCFFFF VXIPnP Driver Warnings
        '''
        '''BFFF0000 to BFFFFFFF VISA Errors
        '''BFFC0000 to BFFCFFFF VXIPnP Driver Errors
        '''</returns>
        Public Function QueryCursorPosition(ByRef Data As Double) As Integer
            Dim pInvokeResult As Integer = PInvoke.QueryCursorPosition(Me._handle, Data)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function configures the minimum level by which the waveform must rise or fall so that it will be identified as a maximum or a minimum by the search functions.
        '''
        '''Attribute(s):
        '''RSRTM_ATTR_CURSOR_PEAK_EXCURSION
        '''
        '''Remote-control command(s):
        '''CURSor&lt;Cursor&gt;:PEXCursion
        '''</summary>
        '''<param name="Peak_Excursion">
        '''Defines the minimum level by which the waveform must rise or fall so that it will be identified as a maximum or a minimum by the search functions.
        '''
        '''Valid Values: 0 to 100 dB
        '''
        '''Default Value: 5 dB
        '''
        '''Attribute:
        '''RSRTM_ATTR_CURSOR_PEAK_EXCURSION
        '''</param>
        '''<returns>
        '''Returns the status code of this operation.  The status code  either indicates success or describes an error or warning condition.  You examine the status code from each call to an instrument driver function to determine if an error occurred.
        '''
        '''To obtain a text description of the status code, call the rsrtm_error_message function.  To obtain additional information about the error condition, call the rsrtm_GetError function.  To clear the error information from the driver, call the rsrtm_ClearError function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''
        '''Numeric Range (in Hex) Status Code Types
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF VISA Warnings
        '''3FFC0000 to 3FFCFFFF VXIPnP Driver Warnings
        '''
        '''BFFF0000 to BFFFFFFF VISA Errors
        '''BFFC0000 to BFFCFFFF VXIPnP Driver Errors
        '''</returns>
        Public Function ConfigureCursorPeakExcursion(ByVal Peak_Excursion As Integer) As Integer
            Dim pInvokeResult As Integer = PInvoke.ConfigureCursorPeakExcursion(Me._handle, Peak_Excursion)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function enables and disables all quick measurements of the indicated measurement.
        '''
        '''Attribute(s):
        '''RSRTM_ATTR_QUICK_MEASUREMENTS_ENABLE
        '''RSRTM_ATTR_QUICK_MEASUREMENTS_DISABLE
        '''
        '''Remote-control command(s):
        '''MEASurement&lt;Measurement&gt;:AON
        '''MEASurement&lt;Measurement&gt;:AOFF
        '''</summary>
        '''<param name="Measurement">
        '''This control selects the measurement.
        '''
        '''Valid Values: 
        '''RSRTM_VAL_MEASUREMENT_1 (1) - 1
        '''RSRTM_VAL_MEASUREMENT_2 (2) - 2
        '''RSRTM_VAL_MEASUREMENT_3 (3) - 3
        '''RSRTM_VAL_MEASUREMENT_4 (4) - 4
        '''
        '''Default Value: RSRTM_VAL_MEASUREMENT_1 (1)
        '''</param>
        '''<param name="Quick_Measurements_Enabled">
        '''This function enables and disables all quick measurements of the indicated measurement.
        '''
        '''Valid Values:
        '''VI_FALSE (0) - Off
        '''VI_TRUE  (1) - On
        '''
        '''Default Value: VI_FALSE (0)
        '''
        '''Attribute(s):
        '''RSRTM_ATTR_QUICK_MEASUREMENTS_ENABLE
        '''RSRTM_ATTR_QUICK_MEASUREMENTS_DISABLE
        '''</param>
        '''<returns>
        '''Returns the status code of this operation.  The status code  either indicates success or describes an error or warning condition.  You examine the status code from each call to an instrument driver function to determine if an error occurred.
        '''
        '''To obtain a text description of the status code, call the rsrtm_error_message function.  To obtain additional information about the error condition, call the rsrtm_GetError function.  To clear the error information from the driver, call the rsrtm_ClearError function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''
        '''Numeric Range (in Hex) Status Code Types
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF VISA Warnings
        '''3FFC0000 to 3FFCFFFF VXIPnP Driver Warnings
        '''
        '''BFFF0000 to BFFFFFFF VISA Errors
        '''BFFC0000 to BFFCFFFF VXIPnP Driver Errors
        '''</returns>
        Public Function ConfigureQuickMeasurements(ByVal Measurement As Integer, ByVal Quick_Measurements_Enabled As Boolean) As Integer
            Dim pInvokeResult As Integer = PInvoke.ConfigureQuickMeasurements(Me._handle, Measurement, System.Convert.ToUInt16(Quick_Measurements_Enabled))
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function returns the results of the quick measurement.
        '''
        '''Attribute(s):
        '''-
        '''
        '''Remote-control command(s):
        '''MEASurement&lt;Measurement&gt;:ARESult?
        '''</summary>
        '''<param name="Measurement">
        '''This control selects the measurement.
        '''
        '''Valid Values: 
        '''RSRTM_VAL_MEASUREMENT_1 (1) - 1
        '''RSRTM_VAL_MEASUREMENT_2 (2) - 2
        '''RSRTM_VAL_MEASUREMENT_3 (3) - 3
        '''RSRTM_VAL_MEASUREMENT_4 (4) - 4
        '''RSRTM_VAL_MEASUREMENT_5 (5) - 5
        '''RSRTM_VAL_MEASUREMENT_6 (6) - 6
        '''RSRTM_VAL_MEASUREMENT_7 (7) - 7
        '''RSRTM_VAL_MEASUREMENT_8 (8) - 8
        '''
        '''Default Value: RSRTM_VAL_MEASUREMENT_1 (1)
        '''</param>
        '''<param name="Array_Size">
        '''Indicates size of array passed to 'Results' argument.
        '''
        '''Valid Values:
        '''not checked
        '''
        '''Default Value: 9
        '''</param>
        '''<param name="Results">
        '''Returns the list of values.
        '''Quick measurement results are listed in the following order: PEAK, UPE, LPE, CYCR, CYCM, PER, FREQ, RTIM , FTIM
        '''
        '''Valid Values:
        '''Not Checked
        '''
        '''Attribute(s):
        '''RSRTM_ATTR_QUICK_MEASUREMENT
        '''</param>
        '''<returns>
        '''Returns the status code of this operation.  The status code  either indicates success or describes an error or warning condition.  You examine the status code from each call to an instrument driver function to determine if an error occurred.
        '''
        '''To obtain a text description of the status code, call the rsrtm_error_message function.  To obtain additional information about the error condition, call the rsrtm_GetError function.  To clear the error information from the driver, call the rsrtm_ClearError function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''
        '''Numeric Range (in Hex) Status Code Types
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF VISA Warnings
        '''3FFC0000 to 3FFCFFFF VXIPnP Driver Warnings
        '''
        '''BFFF0000 to BFFFFFFF VISA Errors
        '''BFFC0000 to BFFCFFFF VXIPnP Driver Errors
        '''</returns>
        Public Function QueryQuickMeasurementResults(ByVal Measurement As Integer, ByVal Array_Size As Integer, ByVal Results() As Double) As Integer
            Dim pInvokeResult As Integer = PInvoke.QueryQuickMeasurementResults(Me._handle, Measurement, Array_Size, Results)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function configures automatic measurement.
        '''
        '''Attribute(s):
        '''RSRTM_ATTR_AUTOMATIC_MEASUREMENT_STATE
        '''RSRTM_ATTR_AUTOMATIC_MEASUREMENT_NUMBER_OF_WAVEFORMS
        '''
        '''Remote-control command(s):
        '''MEASurement&lt;Measurement&gt;:STATistics[:ENABle]
        '''MEASurement&lt;Measurement&gt;:STATistics:WEIGth
        '''
        '''</summary>
        '''<param name="Measurement">
        '''This control selects the measurement.
        '''
        '''Valid Values: 
        '''RSRTM_VAL_MEASUREMENT_1 (1) - 1
        '''RSRTM_VAL_MEASUREMENT_2 (2) - 2
        '''RSRTM_VAL_MEASUREMENT_3 (3) - 3
        '''RSRTM_VAL_MEASUREMENT_4 (4) - 4
        '''
        '''Default Value: RSRTM_VAL_MEASUREMENT_1 (1)
        '''</param>
        '''<param name="State">
        '''Activates or deactivates the statistical evaluation for the selected measurement.
        '''
        '''Valid Values:
        '''VI_FALSE (0) - Off
        '''VI_TRUE  (1) - On
        '''
        '''Default Value: VI_FALSE (0)
        '''
        '''Attribute(s):
        '''RSRTM_ATTR_AUTOMATIC_MEASUREMENT_STATE
        '''</param>
        '''<param name="Number_Of_Waveforms">
        '''Sets the number of measured waveforms.
        '''
        '''Valid Values: 2 to 1000
        '''
        '''Default Value: 1000
        '''
        '''Attribute:
        '''RSRTM_ATTR_AUTOMATIC_MEASUREMENT_NUMBER_OF_WAVEFORMS
        '''</param>
        '''<returns>
        '''Returns the status code of this operation.  The status code  either indicates success or describes an error or warning condition.  You examine the status code from each call to an instrument driver function to determine if an error occurred.
        '''
        '''To obtain a text description of the status code, call the rsrtm_error_message function.  To obtain additional information about the error condition, call the rsrtm_GetError function.  To clear the error information from the driver, call the rsrtm_ClearError function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''
        '''Numeric Range (in Hex) Status Code Types
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF VISA Warnings
        '''3FFC0000 to 3FFCFFFF VXIPnP Driver Warnings
        '''
        '''BFFF0000 to BFFFFFFF VISA Errors
        '''BFFC0000 to BFFCFFFF VXIPnP Driver Errors
        '''</returns>
        Public Function ConfigureAutomaticMeasurement(ByVal Measurement As Integer, ByVal State As Boolean, ByVal Number_Of_Waveforms As Integer) As Integer
            Dim pInvokeResult As Integer = PInvoke.ConfigureAutomaticMeasurement(Me._handle, Measurement, System.Convert.ToUInt16(State), Number_Of_Waveforms)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function deletes the statistical results for the selected measurement, and starts a new statistical evaluation if the acquisition is running. The waveform count is set to 0 and all measurement values are set to NAN.
        '''
        '''Attribute(s):
        '''RSRTM_ATTR_RESET_AUTOMATIC_MEASUREMENT
        '''
        '''Remote-control command(s):
        '''MEASurement&lt;Measurement&gt;:STATistics:RESet
        '''</summary>
        '''<param name="Measurement">
        '''This control selects the measurement.
        '''
        '''Valid Values: 
        '''RSRTM_VAL_MEASUREMENT_1 (1) - 1
        '''RSRTM_VAL_MEASUREMENT_2 (2) - 2
        '''RSRTM_VAL_MEASUREMENT_3 (3) - 3
        '''RSRTM_VAL_MEASUREMENT_4 (4) - 4
        '''RSRTM_VAL_MEASUREMENT_5 (5) - 5
        '''RSRTM_VAL_MEASUREMENT_6 (6) - 6
        '''RSRTM_VAL_MEASUREMENT_7 (7) - 7
        '''RSRTM_VAL_MEASUREMENT_8 (8) - 8
        '''
        '''Default Value: RSRTM_VAL_MEASUREMENT_1 (1)
        '''</param>
        '''<returns>
        '''Returns the status code of this operation.  The status code  either indicates success or describes an error or warning condition.  You examine the status code from each call to an instrument driver function to determine if an error occurred.
        '''
        '''To obtain a text description of the status code, call the rsrtm_error_message function.  To obtain additional information about the error condition, call the rsrtm_GetError function.  To clear the error information from the driver, call the rsrtm_ClearError function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''
        '''Numeric Range (in Hex) Status Code Types
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF VISA Warnings
        '''3FFC0000 to 3FFCFFFF VXIPnP Driver Warnings
        '''
        '''BFFF0000 to BFFFFFFF VISA Errors
        '''BFFC0000 to BFFCFFFF VXIPnP Driver Errors
        '''</returns>
        Public Function ResetAutomaticMeasurement(ByVal Measurement As Integer) As Integer
            Dim pInvokeResult As Integer = PInvoke.ResetAutomaticMeasurement(Me._handle, Measurement)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function returns the result of the automatic measurement.
        '''
        '''Attribute(s):
        '''RSRTM_ATTR_AUTOMATIC_MEASUREMENT_NUMBER_OF_MEASURED_WAVEFORMS
        '''
        '''Remote-control command(s):
        '''MEASurement&lt;Measurement&gt;:RESult:WFMCount?
        '''</summary>
        '''<param name="Measurement">
        '''This control selects the measurement.
        '''
        '''Valid Values: 
        '''RSRTM_VAL_MEASUREMENT_1 (1) - 1
        '''RSRTM_VAL_MEASUREMENT_2 (2) - 2
        '''RSRTM_VAL_MEASUREMENT_3 (3) - 3
        '''RSRTM_VAL_MEASUREMENT_4 (4) - 4
        '''RSRTM_VAL_MEASUREMENT_5 (5) - 5
        '''RSRTM_VAL_MEASUREMENT_6 (6) - 6
        '''RSRTM_VAL_MEASUREMENT_7 (7) - 7
        '''RSRTM_VAL_MEASUREMENT_8 (8) - 8
        '''
        '''Default Value: RSRTM_VAL_MEASUREMENT_1 (1)
        '''</param>
        '''<param name="Number_Of_Waveforms">
        '''Returns the current number of measured waveforms.
        '''
        '''Attribute(s):
        '''RSRTM_ATTR_AUTOMATIC_MEASUREMENT_NUMBER_OF_MEASURED_WAVEFORMS
        '''</param>
        '''<returns>
        '''Returns the status code of this operation.  The status code  either indicates success or describes an error or warning condition.  You examine the status code from each call to an instrument driver function to determine if an error occurred.
        '''
        '''To obtain a text description of the status code, call the rsrtm_error_message function.  To obtain additional information about the error condition, call the rsrtm_GetError function.  To clear the error information from the driver, call the rsrtm_ClearError function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''
        '''Numeric Range (in Hex) Status Code Types
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF VISA Warnings
        '''3FFC0000 to 3FFCFFFF VXIPnP Driver Warnings
        '''
        '''BFFF0000 to BFFFFFFF VISA Errors
        '''BFFC0000 to BFFCFFFF VXIPnP Driver Errors
        '''</returns>
        Public Function QueryAutomaticMeasurementNumberOfWaveforms(ByVal Measurement As Integer, ByRef Number_Of_Waveforms As Integer) As Integer
            Dim pInvokeResult As Integer = PInvoke.QueryAutomaticMeasurementNumberOfWaveforms(Me._handle, Measurement, Number_Of_Waveforms)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function returns the result of the automatic measurement.
        '''
        '''Attribute(s):
        '''RSRTM_ATTR_AUTOMATIC_MEASUREMENT_RESULT
        '''
        '''Remote-control command(s):
        '''MEASurement&lt;Measurement&gt;:RESult:AVG?
        '''MEASurement&lt;Measurement&gt;:RESult:STDDev?
        '''MEASurement&lt;Measurement&gt;:RESult:NPEak?
        '''MEASurement&lt;Measurement&gt;:RESult:PPEak?
        '''</summary>
        '''<param name="Measurement">
        '''This control selects the measurement.
        '''
        '''Valid Values: 
        '''RSRTM_VAL_MEASUREMENT_1 (1) - 1
        '''RSRTM_VAL_MEASUREMENT_2 (2) - 2
        '''RSRTM_VAL_MEASUREMENT_3 (3) - 3
        '''RSRTM_VAL_MEASUREMENT_4 (4) - 4
        '''RSRTM_VAL_MEASUREMENT_5 (5) - 5
        '''RSRTM_VAL_MEASUREMENT_6 (6) - 6
        '''RSRTM_VAL_MEASUREMENT_7 (7) - 7
        '''RSRTM_VAL_MEASUREMENT_8 (8) - 8
        '''
        '''Default Value: RSRTM_VAL_MEASUREMENT_1 (1)
        '''</param>
        '''<param name="Result_Type">
        '''This control selects the result type.
        '''
        '''Valid Values: 
        '''RSRTM_VAL_AUTOMATIC_MEASUREMENT_AVERAGE   (0) - Average
        '''RSRTM_VAL_AUTOMATIC_MEASUREMENT_DEVIATION (1) - Standard Deviation
        '''RSRTM_VAL_AUTOMATIC_MEASUREMENT_MINIMUM   (2) - Minimum
        '''RSRTM_VAL_AUTOMATIC_MEASUREMENT_MAXIMUM   (3) - Maximum
        '''
        '''
        '''Default Value: RSRTM_VAL_AUTOMATIC_MEASUREMENT_AVERAGE (0)
        '''</param>
        '''<param name="Result">
        '''Returns the automatic measuremnt result.
        '''
        '''Attribute(s):
        '''RSRTM_ATTR_AUTOMATIC_MEASUREMENT_RESULT
        '''</param>
        '''<returns>
        '''Returns the status code of this operation.  The status code  either indicates success or describes an error or warning condition.  You examine the status code from each call to an instrument driver function to determine if an error occurred.
        '''
        '''To obtain a text description of the status code, call the rsrtm_error_message function.  To obtain additional information about the error condition, call the rsrtm_GetError function.  To clear the error information from the driver, call the rsrtm_ClearError function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''
        '''Numeric Range (in Hex) Status Code Types
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF VISA Warnings
        '''3FFC0000 to 3FFCFFFF VXIPnP Driver Warnings
        '''
        '''BFFF0000 to BFFFFFFF VISA Errors
        '''BFFC0000 to BFFCFFFF VXIPnP Driver Errors
        '''</returns>
        Public Function QueryAutomaticMeasurementResult(ByVal Measurement As Integer, ByVal Result_Type As Integer, ByRef Result As Double) As Integer
            Dim pInvokeResult As Integer = PInvoke.QueryAutomaticMeasurementResult(Me._handle, Measurement, Result_Type, Result)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function returns the sample mode the oscilloscope is currently using.
        '''
        '''Attribute(s):
        '''RSRTM_ATTR_SAMPLE_MODE
        '''
        '''Remote-control command(s):
        '''ACQuire:MODE?
        '''</summary>
        '''<param name="Sample_Mode">
        '''Returns the method of adding waveform points to the samples of the ADC in order to fill the record length.
        '''
        '''Valid Values:
        '''RSRTM_VAL_REAL_TIME         (0) - Real Time Mode
        '''RSRTM_VAL_EQUIVALENT_TIME   (1) - Equivalent time
        '''RSRTM_VAL_INTERPOLATED_TIME (2) - Interpolated time
        '''
        '''Attribute:
        '''RSRTM_ATTR_SAMPLE_MODE
        '''
        '''Note(s):
        '''
        '''(1) Real Time Mode: At slow time base settings the sampled points of the input signal are used to build the waveform, no waveform points are added. With fast time base settings, the sample rate is higher than the ADC sample rate. Waveform samples are added to the ADC samples with sin(x)/x interpolation.
        '''
        '''(2) Equivalent time: The waveform points are taken from several acquisitions of a repetive signal at a different time in relation to the trigger point.
        '''
        '''(3) Interpolated time: Interpolation of waveform points with the method set by the interpolation mode
        '''</param>
        '''<returns>
        '''Returns the status code of this operation.  The status code  either indicates success or describes an error or warning condition.  You examine the status code from each call to an instrument driver function to determine if an error occurred.
        '''
        '''To obtain a text description of the status code, call the rsrtm_error_message function.  To obtain additional information about the error condition, call the rsrtm_GetError function.  To clear the error information from the driver, call the rsrtm_ClearError function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''
        '''Numeric Range (in Hex) Status Code Types
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF VISA Warnings
        '''3FFC0000 to 3FFCFFFF VXIPnP Driver Warnings
        '''
        '''BFFF0000 to BFFFFFFF VISA Errors
        '''BFFC0000 to BFFCFFFF VXIPnP Driver Errors
        '''</returns>
        Public Function SampleMode(ByRef Sample_Mode As Integer) As Integer
            Dim pInvokeResult As Integer = PInvoke.SampleMode(Me._handle, Sample_Mode)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function returns the effective sample rate of the acquired waveform using the current configuration in samples per second.
        '''
        '''Attribute(s):
        '''RSRTM_ATTR_HORZ_SAMPLE_RATE
        '''
        '''Remote-control command(s):
        '''ACQuire:POINts:SRATe?
        '''</summary>
        '''<param name="Sample_Rate">
        '''Return the sample rate, that is the number of recorded waveform samples per second.
        '''
        '''Valid Values:
        '''2.0E+000 to 2.0E+013
        '''
        '''Attribute:
        '''RSRTM_ATTR_HORZ_SAMPLE_RATE
        '''</param>
        '''<returns>
        '''Returns the status code of this operation.  The status code  either indicates success or describes an error or warning condition.  You examine the status code from each call to an instrument driver function to determine if an error occurred.
        '''
        '''To obtain a text description of the status code, call the rsrtm_error_message function.  To obtain additional information about the error condition, call the rsrtm_GetError function.  To clear the error information from the driver, call the rsrtm_ClearError function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''
        '''Numeric Range (in Hex) Status Code Types
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF VISA Warnings
        '''3FFC0000 to 3FFCFFFF VXIPnP Driver Warnings
        '''
        '''BFFF0000 to BFFFFFFF VISA Errors
        '''BFFC0000 to BFFCFFFF VXIPnP Driver Errors
        '''</returns>
        Public Function ActualSampleRate(ByRef Sample_Rate As Double) As Integer
            Dim pInvokeResult As Integer = PInvoke.ActualSampleRate(Me._handle, Sample_Rate)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''Queries the attenuation of the probe.
        '''
        '''Attribute(s):
        '''RSRTM_ATTR_PROBE_ATTENUATION
        '''
        '''Remote-control command(s):
        '''PROBe&lt;Channel&gt;:SETup:ATTenuation?
        '''</summary>
        '''<param name="Channel">
        '''This control selects the channel.
        '''
        '''Valid Values: 
        '''RSRTM_VAL_CHANNEL_1   (1) - 1
        '''RSRTM_VAL_CHANNEL_2   (2) - 2
        '''RSRTM_VAL_CHANNEL_3   (3) - 3
        '''RSRTM_VAL_CHANNEL_4   (4) - 4
        '''RSRTM_VAL_CHANNEL_EXT (5) - External
        '''
        '''Default Value: RSRTM_VAL_CHANNEL_1 (1)
        '''</param>
        '''<param name="Buffer_Size">
        '''Pass the number of bytes in the ViChar array you specify for the Auto Probe Sense Value.
        '''
        '''Valid Values:
        '''not checked
        '''
        '''Default Value: 15
        '''</param>
        '''<param name="Auto_Probe_Sense_Value">
        '''Queries the attenuation of the probe.
        '''
        '''Attribute:
        '''RSRTM_ATTR_PROBE_ATTENUATION
        '''</param>
        '''<returns>
        '''Returns the status code of this operation.  The status code  either indicates success or describes an error or warning condition.  You examine the status code from each call to an instrument driver function to determine if an error occurred.
        '''
        '''To obtain a text description of the status code, call the rsrtm_error_message function.  To obtain additional information about the error condition, call the rsrtm_GetError function.  To clear the error information from the driver, call the rsrtm_ClearError function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''
        '''Numeric Range (in Hex) Status Code Types
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF VISA Warnings
        '''3FFC0000 to 3FFCFFFF VXIPnP Driver Warnings
        '''
        '''BFFF0000 to BFFFFFFF VISA Errors
        '''BFFC0000 to BFFCFFFF VXIPnP Driver Errors
        '''</returns>
        Public Function AutoProbeSenseValue(ByVal Channel As Integer, ByVal Buffer_Size As Integer, ByVal Auto_Probe_Sense_Value As System.Text.StringBuilder) As Integer
            Dim pInvokeResult As Integer = PInvoke.AutoProbeSenseValue(Me._handle, Channel, Buffer_Size, Auto_Probe_Sense_Value)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function turns the mask test mode on or off. When turning off, any temporarily stored new masks are deleted.
        '''
        '''Attribute(s):
        '''RSRTM_ATTR_MASK_ENABLED
        '''
        '''Remote-control command(s):
        '''MASK:STATe &lt;State&gt;
        '''</summary>
        '''<param name="State">
        '''This Control Turns the mask test mode on or off.
        '''
        '''Valid Values:
        '''VI_FALSE (0) - OFF
        '''VI_TRUE  (1) - ON
        '''
        '''Default Value: VI_FALSE (0)
        '''
        '''Attribute(s):
        '''RSRTM_ATTR_MASK_ENABLED
        '''</param>
        '''<returns>
        '''Returns the status code of this operation.  The status code  either indicates success or describes an error or warning condition.  You examine the status code from each call to an instrument driver function to determine if an error occurred.
        '''
        '''To obtain a text description of the status code, call the rsrtm_error_message function.  To obtain additional information about the error condition, call the rsrtm_GetError function.  To clear the error information from the driver, call the rsrtm_ClearError function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''
        '''Numeric Range (in Hex) Status Code Types
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF VISA Warnings
        '''3FFC0000 to 3FFCFFFF VXIPnP Driver Warnings
        '''
        '''BFFF0000 to BFFFFFFF VISA Errors
        '''BFFC0000 to BFFCFFFF VXIPnP Driver Errors
        '''</returns>
        Public Function ConfigureMaskTestEnable(ByVal State As Boolean) As Integer
            Dim pInvokeResult As Integer = PInvoke.ConfigureMaskTestEnable(Me._handle, System.Convert.ToUInt16(State))
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''Defines the channel to be compared with the mask.
        '''
        '''Attribute(s):
        '''RSRTM_ATTR_MASK_SOURCE
        '''RSRTM_ATTR_MASK_TEST
        '''
        '''Remote-control command(s):
        '''MASK:SOURce &lt;Source&gt;
        '''MASK:TEST
        '''</summary>
        '''<param name="Source">
        '''Defines the channel to be compared with the mask.
        '''
        '''Valid Values:
        '''RSRTM_VAL_SOURCE_CH1 (1) - Channel 1
        '''RSRTM_VAL_SOURCE_CH2 (2) - Channel 2
        '''RSRTM_VAL_SOURCE_CH3 (3) - Channel 3
        '''RSRTM_VAL_SOURCE_CH4 (4) - Channel 4
        '''
        '''Default Value: RSRTM_VAL_SOURCE_CH1 (1)
        '''
        '''Attribute:
        '''RSRTM_ATTR_MASK_SOURCE
        '''</param>
        '''<param name="Action">
        '''Selects the action.
        '''
        '''Valid Values:
        '''RSRTM_VAL_MASKCOND_RUN   (0) - Run
        '''RSRTM_VAL_MASKCOND_STOP  (1) - Stop
        '''RSRTM_VAL_MASKCOND_PAUSE (2) - Pause
        '''
        '''Default Value:
        '''RSRTM_VAL_MASKCOND_STOP  (1)
        '''
        '''Attribute(s):
        '''RSRTM_ATTR_MASK_TEST
        '''</param>
        '''<returns>
        '''Returns the status code of this operation.  The status code  either indicates success or describes an error or warning condition.  You examine the status code from each call to an instrument driver function to determine if an error occurred.
        '''
        '''To obtain a text description of the status code, call the rsrtm_error_message function.  To obtain additional information about the error condition, call the rsrtm_GetError function.  To clear the error information from the driver, call the rsrtm_ClearError function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''
        '''Numeric Range (in Hex) Status Code Types
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF VISA Warnings
        '''3FFC0000 to 3FFCFFFF VXIPnP Driver Warnings
        '''
        '''BFFF0000 to BFFFFFFF VISA Errors
        '''BFFC0000 to BFFCFFFF VXIPnP Driver Errors
        '''</returns>
        Public Function ConfigureMaskTest(ByVal Source As Integer, ByVal Action As Integer) As Integer
            Dim pInvokeResult As Integer = PInvoke.ConfigureMaskTest(Me._handle, Source, Action)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''Creates a mask from the envelope waveform of the test source set with MASK: SOURce.
        '''
        '''Attribute(s):
        '''RSRTM_ATTR_MASK_COPY_CHANNEL
        '''
        '''Remote-control command(s):
        '''MASK:CHCopy
        '''</summary>
        '''<returns>
        '''Returns the status code of this operation.  The status code  either indicates success or describes an error or warning condition.  You examine the status code from each call to an instrument driver function to determine if an error occurred.
        '''
        '''To obtain a text description of the status code, call the rsrtm_error_message function.  To obtain additional information about the error condition, call the rsrtm_GetError function.  To clear the error information from the driver, call the rsrtm_ClearError function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''
        '''Numeric Range (in Hex) Status Code Types
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF VISA Warnings
        '''3FFC0000 to 3FFCFFFF VXIPnP Driver Warnings
        '''
        '''BFFF0000 to BFFFFFFF VISA Errors
        '''BFFC0000 to BFFCFFFF VXIPnP Driver Errors
        '''</returns>
        Public Function MaskCopyChannel() As Integer
            Dim pInvokeResult As Integer = PInvoke.MaskCopyChannel(Me._handle)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function loads a stored mask from the specified file.
        '''
        '''Attribute(s):
        '''RSRTM_ATTR_MASK_LOAD
        '''
        '''Remote-control command(s):
        '''MASK:LOAD &lt;FileName&gt;
        '''</summary>
        '''<param name="Name">
        '''Defines the file with stored mask.
        '''
        '''Valid Values:
        '''not checked
        '''
        '''Default Value:
        '''""
        '''
        '''Attribute(s):
        '''RSRTM_ATTR_MASK_LOAD
        '''</param>
        '''<returns>
        '''Returns the status code of this operation.  The status code  either indicates success or describes an error or warning condition.  You examine the status code from each call to an instrument driver function to determine if an error occurred.
        '''
        '''To obtain a text description of the status code, call the rsrtm_error_message function.  To obtain additional information about the error condition, call the rsrtm_GetError function.  To clear the error information from the driver, call the rsrtm_ClearError function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''
        '''Numeric Range (in Hex) Status Code Types
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF VISA Warnings
        '''3FFC0000 to 3FFCFFFF VXIPnP Driver Warnings
        '''
        '''BFFF0000 to BFFFFFFF VISA Errors
        '''BFFC0000 to BFFCFFFF VXIPnP Driver Errors
        '''</returns>
        Public Function MaskLoad(ByVal Name As String) As Integer
            Dim pInvokeResult As Integer = PInvoke.MaskLoad(Me._handle, Name)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function saves the current mask in the specified file.
        '''
        '''Attribute(s):
        '''RSRTM_ATTR_MASK_STORE
        '''
        '''Remote-control command(s):
        '''MASK:SAVE &lt;FileName&gt;
        '''</summary>
        '''<param name="Name">
        '''Defines the file.
        '''
        '''Valid Values:
        '''not checked
        '''
        '''Default Value:
        '''""
        '''
        '''Attribute(s):
        '''RSRTM_ATTR_MASK_STORE
        '''</param>
        '''<returns>
        '''Returns the status code of this operation.  The status code  either indicates success or describes an error or warning condition.  You examine the status code from each call to an instrument driver function to determine if an error occurred.
        '''
        '''To obtain a text description of the status code, call the rsrtm_error_message function.  To obtain additional information about the error condition, call the rsrtm_GetError function.  To clear the error information from the driver, call the rsrtm_ClearError function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''
        '''Numeric Range (in Hex) Status Code Types
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF VISA Warnings
        '''3FFC0000 to 3FFCFFFF VXIPnP Driver Warnings
        '''
        '''BFFF0000 to BFFFFFFF VISA Errors
        '''BFFC0000 to BFFCFFFF VXIPnP Driver Errors
        '''</returns>
        Public Function MaskStore(ByVal Name As String) As Integer
            Dim pInvokeResult As Integer = PInvoke.MaskStore(Me._handle, Name)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function defines the vertical offset.
        '''
        '''Attribute(s):
        '''RSRTM_ATTR_MASK_VERTICAL_OFFSET
        '''
        '''Remote-control command(s):
        '''MASK:YPOSition
        '''</summary>
        '''<param name="Y_Position">
        '''This control defines the offset.
        '''
        '''Valid Values: 
        '''-200.0 to 200.0
        '''
        '''Default Value: 0.0
        '''
        '''Attribute(s):
        '''RSRTM_ATTR_MASK_VERTICAL_OFFSET
        '''</param>
        '''<returns>
        '''Returns the status code of this operation.  The status code  either indicates success or describes an error or warning condition.  You examine the status code from each call to an instrument driver function to determine if an error occurred.
        '''
        '''To obtain a text description of the status code, call the rsrtm_error_message function.  To obtain additional information about the error condition, call the rsrtm_GetError function.  To clear the error information from the driver, call the rsrtm_ClearError function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''
        '''Numeric Range (in Hex) Status Code Types
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF VISA Warnings
        '''3FFC0000 to 3FFCFFFF VXIPnP Driver Warnings
        '''
        '''BFFF0000 to BFFFFFFF VISA Errors
        '''BFFC0000 to BFFCFFFF VXIPnP Driver Errors
        '''</returns>
        Public Function ConfigureMaskVerticalOffset(ByVal Y_Position As Double) As Integer
            Dim pInvokeResult As Integer = PInvoke.ConfigureMaskVerticalOffset(Me._handle, Y_Position)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function defines vertical stretch or compress.
        '''
        '''Attribute(s):
        '''RSRTM_ATTR_MASK_VERTICAL_SCALING
        '''
        '''Remote-control command(s):
        '''MASK:YSCALe
        '''</summary>
        '''<param name="Y_Stretch">
        '''This control defines vertical stretch or compress.
        '''
        '''Valid Values: 
        '''10 to 1000
        '''
        '''Default Value: 100
        '''
        '''Attribute(s):
        '''RSRTM_ATTR_MASK_VERTICAL_SCALING
        '''</param>
        '''<returns>
        '''Returns the status code of this operation.  The status code  either indicates success or describes an error or warning condition.  You examine the status code from each call to an instrument driver function to determine if an error occurred.
        '''
        '''To obtain a text description of the status code, call the rsrtm_error_message function.  To obtain additional information about the error condition, call the rsrtm_GetError function.  To clear the error information from the driver, call the rsrtm_ClearError function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''
        '''Numeric Range (in Hex) Status Code Types
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF VISA Warnings
        '''3FFC0000 to 3FFCFFFF VXIPnP Driver Warnings
        '''
        '''BFFF0000 to BFFFFFFF VISA Errors
        '''BFFC0000 to BFFCFFFF VXIPnP Driver Errors
        '''</returns>
        Public Function ConfigureMaskVerticalScaling(ByVal Y_Stretch As Double) As Integer
            Dim pInvokeResult As Integer = PInvoke.ConfigureMaskVerticalScaling(Me._handle, Y_Stretch)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function defines the shift.
        '''
        '''Attribute(s):
        '''RSRTM_ATTR_MASK_VERTICAL_WIDTH
        '''
        '''Remote-control command(s):
        '''MASK:YWIDth &lt;Yaddition&gt;
        '''</summary>
        '''<param name="Y_Width">
        '''This control defines the width of mask.
        '''
        '''Valid Values: 
        '''0.0 to 512.0
        '''
        '''Default Value: 0.0
        '''
        '''Attribute(s):
        '''RSRTM_ATTR_MASK_VERTICAL_WIDTH
        '''</param>
        '''<returns>
        '''Returns the status code of this operation.  The status code  either indicates success or describes an error or warning condition.  You examine the status code from each call to an instrument driver function to determine if an error occurred.
        '''
        '''To obtain a text description of the status code, call the rsrtm_error_message function.  To obtain additional information about the error condition, call the rsrtm_GetError function.  To clear the error information from the driver, call the rsrtm_ClearError function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''
        '''Numeric Range (in Hex) Status Code Types
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF VISA Warnings
        '''3FFC0000 to 3FFCFFFF VXIPnP Driver Warnings
        '''
        '''BFFF0000 to BFFFFFFF VISA Errors
        '''BFFC0000 to BFFCFFFF VXIPnP Driver Errors
        '''</returns>
        Public Function ConfigureMaskVerticalWidth(ByVal Y_Width As Double) As Integer
            Dim pInvokeResult As Integer = PInvoke.ConfigureMaskVerticalWidth(Me._handle, Y_Width)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function changes the horizontal width of the mask.
        '''
        '''Attribute(s):
        '''RSRTM_ATTR_MASK_HORIZONTAL_WIDTH
        '''
        '''Remote-control command(s):
        '''MASK:XWIDth &lt;Xaddition&gt;
        '''</summary>
        '''<param name="X_Width">
        '''This control defines the width.
        '''
        '''Valid Values: 
        '''0.0 to 10.0
        '''
        '''Default Value: 0.0
        '''
        '''Atttribute(s):
        '''RSRTM_ATTR_MASK_HORIZONTAL_WIDTH
        '''</param>
        '''<returns>
        '''Returns the status code of this operation.  The status code  either indicates success or describes an error or warning condition.  You examine the status code from each call to an instrument driver function to determine if an error occurred.
        '''
        '''To obtain a text description of the status code, call the rsrtm_error_message function.  To obtain additional information about the error condition, call the rsrtm_GetError function.  To clear the error information from the driver, call the rsrtm_ClearError function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''
        '''Numeric Range (in Hex) Status Code Types
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF VISA Warnings
        '''3FFC0000 to 3FFCFFFF VXIPnP Driver Warnings
        '''
        '''BFFF0000 to BFFFFFFF VISA Errors
        '''BFFC0000 to BFFCFFFF VXIPnP Driver Errors
        '''</returns>
        Public Function ConfigureMaskHorizontalWidth(ByVal X_Width As Double) As Integer
            Dim pInvokeResult As Integer = PInvoke.ConfigureMaskHorizontalWidth(Me._handle, X_Width)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function returns the number of tested acquisitions.
        '''
        '''Attribute(s):
        '''RSRTM_ATTR_MASK_COUNT
        '''
        '''Remote-control command(s):
        '''MASK:COUNt?
        '''</summary>
        '''<param name="Total_Count">
        '''This Output shows the number of tested acquisitions.
        '''
        '''Attribute(s):
        '''RSRTM_ATTR_MASK_COUNT
        '''</param>
        '''<returns>
        '''Returns the status code of this operation.  The status code  either indicates success or describes an error or warning condition.  You examine the status code from each call to an instrument driver function to determine if an error occurred.
        '''
        '''To obtain a text description of the status code, call the rsrtm_error_message function.  To obtain additional information about the error condition, call the rsrtm_GetError function.  To clear the error information from the driver, call the rsrtm_ClearError function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''
        '''Numeric Range (in Hex) Status Code Types
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF VISA Warnings
        '''3FFC0000 to 3FFCFFFF VXIPnP Driver Warnings
        '''
        '''BFFF0000 to BFFFFFFF VISA Errors
        '''BFFC0000 to BFFCFFFF VXIPnP Driver Errors
        '''</returns>
        Public Function QueryMaskAcquisitions(ByRef Total_Count As Integer) As Integer
            Dim pInvokeResult As Integer = PInvoke.QueryMaskAcquisitions(Me._handle, Total_Count)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function returns the number of acquistions that hit the mask.
        '''
        '''Attribute(s):
        '''RSRTM_ATTR_MASK_HIT_COUNT
        '''
        '''Remote-control command(s):
        '''MASK:VCOunt?
        '''</summary>
        '''<param name="Acquistions">
        '''This Control shows the number of acquistions that hit the mask.
        '''
        '''Valid Values: 
        '''Not Checked
        '''
        '''Default Value: 0
        '''
        '''Attribute(s):
        '''RSRTM_ATTR_MASK_HIT_COUNT
        '''</param>
        '''<returns>
        '''Returns the status code of this operation.  The status code  either indicates success or describes an error or warning condition.  You examine the status code from each call to an instrument driver function to determine if an error occurred.
        '''
        '''To obtain a text description of the status code, call the rsrtm_error_message function.  To obtain additional information about the error condition, call the rsrtm_GetError function.  To clear the error information from the driver, call the rsrtm_ClearError function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''
        '''Numeric Range (in Hex) Status Code Types
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF VISA Warnings
        '''3FFC0000 to 3FFCFFFF VXIPnP Driver Warnings
        '''
        '''BFFF0000 to BFFFFFFF VISA Errors
        '''BFFC0000 to BFFCFFFF VXIPnP Driver Errors
        '''</returns>
        Public Function QueryMaskHitCount(ByRef Acquistions As Integer) As Integer
            Dim pInvokeResult As Integer = PInvoke.QueryMaskHitCount(Me._handle, Acquistions)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function enables and disables the search mode.
        '''
        '''Attribute(s):
        '''RSRTM_ATTR_SEARCH_STATE
        '''
        '''Remote-control command(s):
        '''SEARch:STATe
        '''</summary>
        '''<param name="State">
        '''Enables and disables the search mode.
        '''
        '''Valid Values:
        '''VI_FALSE (0) - OFF
        '''VI_TRUE  (1) - ON
        '''
        '''Default Value: VI_FALSE (0)
        '''
        '''Attribute(s):
        '''RSRTM_ATTR_SEARCH_STATE
        '''</param>
        '''<returns>
        '''Returns the status code of this operation.  The status code  either indicates success or describes an error or warning condition.  You examine the status code from each call to an instrument driver function to determine if an error occurred.
        '''
        '''To obtain a text description of the status code, call the rsrtm_error_message function.  To obtain additional information about the error condition, call the rsrtm_GetError function.  To clear the error information from the driver, call the rsrtm_ClearError function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''
        '''Numeric Range (in Hex) Status Code Types
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF VISA Warnings
        '''3FFC0000 to 3FFCFFFF VXIPnP Driver Warnings
        '''
        '''BFFF0000 to BFFFFFFF VISA Errors
        '''BFFC0000 to BFFCFFFF VXIPnP Driver Errors
        '''</returns>
        Public Function ConfigureSearchState(ByVal State As Boolean) As Integer
            Dim pInvokeResult As Integer = PInvoke.ConfigureSearchState(Me._handle, System.Convert.ToUInt16(State))
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''Selects the symptom you want to search for.
        '''
        '''Attribute(s):
        '''RSRTM_ATTR_SEARCH_CONDITION
        '''
        '''Remote-control command(s):
        '''SEARch:CONDition
        '''</summary>
        '''<param name="Action">
        '''Selects the symptom.
        '''
        '''Valid Values:
        '''RSRTM_VAL_SEARCHCOND_EDGE   (0) - Edge
        '''RSRTM_VAL_SEARCHCOND_WIDTH  (1) - Width
        '''RSRTM_VAL_SEARCHCOND_PEAK   (2) - Peak
        '''RSRTM_VAL_SEARCHCOND_RUNT   (3) - Runt
        '''RSRTM_VAL_SEARCHCOND_RTIME  (4) - Rise Time
        '''
        '''Default Value:
        '''RSRTM_VAL_SEARCHCOND_EDGE   (0)
        '''
        '''Attribute(s):
        '''RSRTM_ATTR_SEARCH_CONDITION
        '''
        '''Note(s):
        '''(1) Edge: An edge search result is found when the waveform passes the given level in the specified direction.
        '''(2) Width: A width search finds pulses with an exact pulse width, or pulses shorter or longer than a given time, or pulses inside or outside the allowable time range.
        '''(3) Peak: The peak search finds pulses exceeding a given amplitude.
        '''(4) Runt: The runt search finds pulses lower than normal in amplitude. The amplitude crosses the first threshold twice without crossing the second one. In addition to the threshold amplitudes, you can define a time limit for the runt in the same way as for width search: runts with exact width, shorter or longer than a given time, or runts inside or outside the allowable time range.
        '''(5) Rise Time: The rise or fall time search finds slopes with an exact rise or fall time, or rise/fall times shorter or longer than a given limit, or rise/fall times inside or outside the allowable time range.
        '''</param>
        '''<returns>
        '''Returns the status code of this operation.  The status code  either indicates success or describes an error or warning condition.  You examine the status code from each call to an instrument driver function to determine if an error occurred.
        '''
        '''To obtain a text description of the status code, call the rsrtm_error_message function.  To obtain additional information about the error condition, call the rsrtm_GetError function.  To clear the error information from the driver, call the rsrtm_ClearError function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''
        '''Numeric Range (in Hex) Status Code Types
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF VISA Warnings
        '''3FFC0000 to 3FFCFFFF VXIPnP Driver Warnings
        '''
        '''BFFF0000 to BFFFFFFF VISA Errors
        '''BFFC0000 to BFFCFFFF VXIPnP Driver Errors
        '''</returns>
        Public Function ConfigureSearchCondition(ByVal Action As Integer) As Integer
            Dim pInvokeResult As Integer = PInvoke.ConfigureSearchCondition(Me._handle, Action)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''Selects the waveform to be analyzed. One of the active channel, math, and reference waveforms can be searched.
        '''
        '''Attribute(s):
        '''RSRTM_ATTR_SEARCH_SOURCE
        '''
        '''Remote-control command(s):
        '''SEARch:SOURce
        '''</summary>
        '''<param name="Search_Source">
        '''Selects the waveform to be analyzed. One of the active channel, math, and reference waveforms can be searched.
        '''
        '''Valid Values:
        '''RSRTM_VAL_MEASUREMENT_SOURCE_C1   (0)  - Channel Waveform 1
        '''RSRTM_VAL_MEASUREMENT_SOURCE_C2   (1)  - Channel Waveform 2
        '''RSRTM_VAL_MEASUREMENT_SOURCE_C3   (2)  - Channel Waveform 3
        '''RSRTM_VAL_MEASUREMENT_SOURCE_C4   (3)  - Channel Waveform 4
        '''RSRTM_VAL_MEASUREMENT_SOURCE_MA1   (4)  - Math Waveform 1  
        '''RSRTM_VAL_MEASUREMENT_SOURCE_MA2   (5)  - Math Waveform 2  
        '''RSRTM_VAL_MEASUREMENT_SOURCE_MA3   (6)  - Math Waveform 3  
        '''RSRTM_VAL_MEASUREMENT_SOURCE_MA4   (7)  - Math Waveform 4  
        '''RSRTM_VAL_MEASUREMENT_SOURCE_RE1   (8)  - Reference Waveform 1  
        '''RSRTM_VAL_MEASUREMENT_SOURCE_RE2   (9)  - Reference Waveform 2  
        '''RSRTM_VAL_MEASUREMENT_SOURCE_RE3   (10) - Reference Waveform 3  
        '''RSRTM_VAL_MEASUREMENT_SOURCE_RE4   (11) - Reference Waveform 4  
        '''
        '''Default Value: RSSCOPE_VAL_MEASUREMENT_SOURCE_C1 (0)
        '''
        '''Attribute(s):
        '''RSRTM_ATTR_SEARCH_SOURCE
        '''</param>
        '''<returns>
        '''Returns the status code of this operation.  The status code  either indicates success or describes an error or warning condition.  You examine the status code from each call to an instrument driver function to determine if an error occurred.
        '''
        '''To obtain a text description of the status code, call the rsscope_error_message function.  To obtain additional information about the error condition, call the rsscope_GetError function.  To clear the error information from the driver, call the rsscope_ClearError function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''
        '''Numeric Range (in Hex) Status Code Types
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF VISA Warnings
        '''3FFC0000 to 3FFCFFFF VXIPnP Driver Warnings
        '''
        '''BFFF0000 to BFFFFFFF VISA Errors
        '''BFFC0000 to BFFCFFFF VXIPnP Driver Errors
        '''</returns>
        Public Function ConfigureSearchSource(ByVal Search_Source As Integer) As Integer
            Dim pInvokeResult As Integer = PInvoke.ConfigureSearchSource(Me._handle, Search_Source)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function configures the conditions for the edge trigger search.  An edge trigger occurs when the trigger signal passes through the voltage threshold that you specify with the Trigger Level parameter and has the slope that you specify with the Trigger Slope parameter.  
        '''
        '''Attribute(s):
        '''RSRTM_ATTR_SEARCH_TRIGGER_EDGE_SLOPE
        '''RSRTM_ATTR_SEARCH_TRIGGER_EDGE_LEVEL
        '''RSRTM_ATTR_SEARCH_TRIGGER_EDGE_HYSTERSIS
        '''
        '''Remote-control command(s):
        '''SEARch:TRIGger:EDGE:SLOPe
        '''SEARch:TRIGger:EDGE:LEVel
        '''SEARch:TRIGger:EDGE:LEVel:DELTa
        '''</summary>
        '''<param name="Trigger_Slope">
        '''Sets the slope to be found.
        '''
        '''Valid Values:
        '''RSRTM_VAL_POSITIVE (0) - Positive
        '''RSRTM_VAL_NEGATIVE (1) - Negative
        '''RSRTM_VAL_EITHER   (2) - Either
        '''
        '''Default Value: RSSCOPE_VAL_POSITIVE (0)
        '''
        '''Attribute(s):
        '''RSRTM_ATTR_SEARCH_TRIGGER_EDGE_SLOPE
        '''
        '''Note(s):
        '''
        '''(1) Positive: Rising Edge, a positive voltage change
        '''
        '''(2) Negative: Falling Edge, a negative voltage change
        '''
        '''(3) Either: Rising as well as the falling edge.
        '''</param>
        '''<param name="Trigger_Level">
        '''Sets the voltage level for the edge search.
        '''
        '''Valid Values: not checked
        '''
        '''Default Value: 0.1
        '''
        '''Attribute(s):
        '''RSRTM_ATTR_SEARCH_TRIGGER_EDGE_LEVEL
        '''
        '''
        '''</param>
        '''<param name="Trigger_Hystersis">
        '''Sets a hysteresis range above and below the search level to avoid unwanted search results caused by noise oscillation around the level.
        '''
        '''Valid Values: not checked
        '''
        '''Default Value: 0.05
        '''
        '''Attribute(s):
        '''RSRTM_ATTR_SEARCH_TRIGGER_EDGE_HYSTERSIS
        '''</param>
        '''<returns>
        '''Returns the status code of this operation.  The status code  either indicates success or describes an error or warning condition.  You examine the status code from each call to an instrument driver function to determine if an error occurred.
        '''
        '''To obtain a text description of the status code, call the rsscope_error_message function.  To obtain additional information about the error condition, call the rsscope_GetError function.  To clear the error information from the driver, call the rsscope_ClearError function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''
        '''Numeric Range (in Hex) Status Code Types
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF VISA Warnings
        '''3FFC0000 to 3FFCFFFF VXIPnP Driver Warnings
        '''
        '''BFFF0000 to BFFFFFFF VISA Errors
        '''BFFC0000 to BFFCFFFF VXIPnP Driver Errors
        '''</returns>
        Public Function ConfigureEdgeTriggerSearch(ByVal Trigger_Slope As Integer, ByVal Trigger_Level As Double, ByVal Trigger_Hystersis As Double) As Integer
            Dim pInvokeResult As Integer = PInvoke.ConfigureEdgeTriggerSearch(Me._handle, Trigger_Slope, Trigger_Level, Trigger_Hystersis)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function configures the conditions for the width trigger search.  A width trigger occurs when the oscilloscope detects a positive or negative pulse with a width between, or optionally outside, the width thresholds.  You specify the width thresholds with the Width Low Threshold and Width High Threshold parameters.  You specify whether the oscilloscope triggers on pulse widths that are within or outside the width thresholds with the Width Condition parameter.  You specify the polarity of the pulse with the Width Polarity parameter.  The trigger does not actually occur until the edge of a pulse that corresponds to the Width Low Threshold, Width High Threshold, Width Condition, and Width Polarity crosses the threshold you specify in the Trigger Level parameter.
        '''
        '''Attribute(s):
        '''RSRTM_ATTR_SEARCH_TRIGGER_WIDTH_LEVEL
        '''RSRTM_ATTR_SEARCH_TRIGGER_WIDTH_HYSTERSIS
        '''RSRTM_ATTR_SEARCH_TRIGGER_WIDTH_WIDTH
        '''RSRTM_ATTR_SEARCH_TRIGGER_WIDTH_DELTA
        '''RSRTM_ATTR_SEARCH_TRIGGER_WIDTH_POLARITY
        '''RSRTM_ATTR_SEARCH_TRIGGER_WIDTH_RANGE
        '''
        '''Remote-control command(s):
        '''SEARch:TRIGger:WIDTh:LEVel
        '''SEARch:TRIGger:WIDTh:LEVel:DELTa
        '''SEARch:TRIGger:WIDTh:WIDTh
        '''SEARch:TRIGger:WIDTh:DELTa
        '''SEARch:TRIGger:WIDTh:POLarity
        '''SEARch:TRIGger:WIDTh:RANGe
        '''</summary>
        '''<param name="Level">
        '''Sets the voltage level on which the pulse width is measured.
        '''
        '''Valid Values: not checked
        '''
        '''Default Value: 0.1
        '''
        '''Attribute(s):
        '''RSRTM_ATTR_SEARCH_TRIGGER_WIDTH_LEVEL
        '''
        '''</param>
        '''<param name="Level_Delta">
        '''Defines a range around the width value.
        '''
        '''Valid Values: not checked
        '''
        '''Default Value: 0.05 
        '''
        '''Attribute(s):
        '''RSRTM_ATTR_SEARCH_TRIGGER_WIDTH_HYSTERSIS
        '''
        '''</param>
        '''<param name="Width">
        '''Sets the reference pulse width, the nominal value for comparisons.
        '''
        '''Valid Values: not checked
        '''
        '''Default Value: not checked
        '''
        '''Attribute(s):
        '''RSRTM_ATTR_SEARCH_TRIGGER_WIDTH_WIDTH
        '''
        '''</param>
        '''<param name="Width_Delta">
        '''Sets a range delta t to the reference pulse width set with "Width" if "Range" is set to Within or Outside
        '''
        '''Valid Values: not checked
        '''
        '''Default Value: not checked 
        '''
        '''Attribute(s):
        '''RSRTM_ATTR_SEARCH_TRIGGER_WIDTH_DELTA
        '''
        '''</param>
        '''<param name="Polarity">
        '''Sets the polarity of the pulse.
        '''
        '''Valid Values:
        '''RSRTM_VAL_POSITIVE (0) - Positive
        '''RSRTM_VAL_NEGATIVE (1) - Negative
        '''
        '''Default Value: RSRTM_VAL_POSITIVE (0)
        '''
        '''Attribute(s):
        '''RSRTM_ATTR_SEARCH_TRIGGER_WIDTH_POLARITY
        '''
        '''
        '''Note(s):
        '''
        '''(1) Positive: Rising Edge, a positive voltage change
        '''
        '''(2) Negative: Falling Edge, a negative voltage change
        '''
        '''</param>
        '''<param name="Range">
        '''Sets how the measured pulse width is compared with the given limit(s).
        '''
        '''Valid Values:
        '''RSRTM_VAL_SHORTER (0) - Shorter
        '''RSRTM_VAL_LONGER  (1) - Longer
        '''RSRTM_VAL_WITHIN  (2) - Within
        '''RSRTM_VAL_OUTSIDE (3) - Outside
        '''
        '''Default Value: RSRSRTM_VAL_WITHIN (2)
        '''
        '''Attribute(s):
        '''RSRTM_ATTR_SEARCH_TRIGGER_WIDTH_RANGE
        '''
        '''Note(s):
        '''
        '''(1) Shorter: Triggers on pulses shorter than the given "Width".
        '''
        '''(2) Longer: Triggers on pulses longer than the given "Width".
        '''
        '''(3) Within: Triggers on pulses inside a given range. The range of the pulse width is defined by "Width" and "+/-Delta".
        '''
        '''(4) Outside: Triggers on pulses outside a given range. The range definition is the same as for "Within" range.
        '''</param>
        '''<returns>
        '''Returns the status code of this operation.  The status code  either indicates success or describes an error or warning condition.  You examine the status code from each call to an instrument driver function to determine if an error occurred.
        '''
        '''To obtain a text description of the status code, call the rsscope_error_message function.  To obtain additional information about the error condition, call the rsscope_GetError function.  To clear the error information from the driver, call the rsscope_ClearError function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''
        '''Numeric Range (in Hex) Status Code Types
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF VISA Warnings
        '''3FFC0000 to 3FFCFFFF VXIPnP Driver Warnings
        '''
        '''BFFF0000 to BFFFFFFF VISA Errors
        '''BFFC0000 to BFFCFFFF VXIPnP Driver Errors
        '''</returns>
        Public Function ConfigureWidthTriggerSearch(ByVal Level As Double, ByVal Level_Delta As Double, ByVal Width As Double, ByVal Width_Delta As Double, ByVal Polarity As Integer, ByVal Range As Integer) As Integer
            Dim pInvokeResult As Integer = PInvoke.ConfigureWidthTriggerSearch(Me._handle, Level, Level_Delta, Width, Width_Delta, Polarity, Range)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function configures the conditions for the peak trigger search.
        '''
        '''Attribute(s):
        '''RSRTM_ATTR_SEARCH_TRIGGER_PEAK_POLARITY
        '''RSRTM_ATTR_SEARCH_TRIGGER_PEAK_LIMIT
        '''
        '''Remote-control command(s):
        '''SEARch:MEASure:PEAK:POLarity
        '''SEARch:MEASure:LEVel:PEAK:MAGNitude
        '''
        '''</summary>
        '''<param name="Polarity">
        '''Indicates the polarity of the pulse to be searched for a peak.
        '''
        '''Valid Values:
        '''RSRTM_VAL_POSITIVE (0) - Positive
        '''RSRTM_VAL_NEGATIVE (1) - Negative
        '''RSRTM_VAL_EITHER   (2) - Either
        '''
        '''Default Value: RSSCOPE_VAL_POSITIVE (0)
        '''
        '''Attribute(s):
        '''RSRTM_ATTR_SEARCH_TRIGGER_PEAK_POLARITY
        '''
        '''Note(s):
        '''
        '''(1) Positive: Rising Edge, a positive voltage change
        '''
        '''(2) Negative: Falling Edge, a negative voltage change
        '''
        '''(3) Either: Rising as well as the falling edge.
        '''</param>
        '''<param name="Limit">
        '''Sets the amplitude limit.
        '''
        '''Valid Values: not checked
        '''
        '''Default Value: 0.1
        '''
        '''Attribute(s):
        '''RSRTM_ATTR_SEARCH_TRIGGER_PEAK_LIMIT
        '''
        '''
        '''</param>
        '''<returns>
        '''Returns the status code of this operation.  The status code  either indicates success or describes an error or warning condition.  You examine the status code from each call to an instrument driver function to determine if an error occurred.
        '''
        '''To obtain a text description of the status code, call the rsscope_error_message function.  To obtain additional information about the error condition, call the rsscope_GetError function.  To clear the error information from the driver, call the rsscope_ClearError function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''
        '''Numeric Range (in Hex) Status Code Types
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF VISA Warnings
        '''3FFC0000 to 3FFCFFFF VXIPnP Driver Warnings
        '''
        '''BFFF0000 to BFFFFFFF VISA Errors
        '''BFFC0000 to BFFCFFFF VXIPnP Driver Errors
        '''</returns>
        Public Function ConfigurePeakTriggerSearch(ByVal Polarity As Integer, ByVal Limit As Double) As Integer
            Dim pInvokeResult As Integer = PInvoke.ConfigurePeakTriggerSearch(Me._handle, Polarity, Limit)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function configures the conditions for the rise time trigger search.
        '''
        '''Attribute(s):
        '''RSRTM_ATTR_SEARCH_TRIGGER_RISE_TIME_POLARITY
        '''RSRTM_ATTR_SEARCH_TRIGGER_RISE_TIME_LEVEL
        '''RSRTM_ATTR_SEARCH_TRIGGER_RISE_TIME_RANGE
        '''RSRTM_ATTR_SEARCH_TRIGGER_RISE_TIME_REFERENCE_TIME
        '''RSRTM_ATTR_SEARCH_TRIGGER_RISE_TIME_DELTA_TIME
        '''
        '''Remote-control command(s):
        '''SEARch:TRIGger:RISetime:SLOPe
        '''SEARch:TRIGger:LEVel:RISetime:LOWer
        '''SEARch:TRIGger:LEVel:RISetime:UPPer
        '''SEARch:TRIGger:RISetime:RANGe
        '''SEARch:TRIGger:RISetime:TIME
        '''SEARch:TRIGger:RISetime:DELTa
        '''</summary>
        '''<param name="Polarity">
        '''Sets the slope to be found.
        '''
        '''Valid Values:
        '''RSRTM_VAL_POSITIVE (0) - Positive
        '''RSRTM_VAL_NEGATIVE (1) - Negative
        '''RSRTM_VAL_EITHER   (2) - Either
        '''
        '''Default Value: RSSCOPE_VAL_POSITIVE (0)
        '''
        '''Attribute(s):
        '''RSRTM_ATTR_SEARCH_TRIGGER_RISE_TIME_POLARITY
        '''
        '''Note(s):
        '''(1) Positive: Rising Edge, a positive voltage change
        '''
        '''(2) Negative: Falling Edge, a negative voltage change
        '''
        '''(3) Either: Rising as well as the falling edge.
        '''</param>
        '''<param name="Upper_Level">
        '''Sets the upper voltage threshold. When the signal crosses this level, the rise time measurement starts or stops depending on the selected slope.
        '''
        '''Valid Values: not checked
        '''
        '''Default Value: 600E-3 V
        '''
        '''Attribute(s):
        '''RSRTM_ATTR_SEARCH_TRIGGER_RISE_TIME_LEVEL
        '''
        '''</param>
        '''<param name="Lower_Level">
        '''Sets the lower voltage threshold. When the signal crosses this level, the rise/fall time measurement starts or stops depending on the selected slope.
        '''
        '''Valid Values: not checked
        '''
        '''Default Value: 400e-3 V
        '''
        '''Attribute(s):
        '''RSRTM_ATTR_SEARCH_TRIGGER_RISE_TIME_LEVEL
        '''
        '''</param>
        '''<param name="Range">
        '''Sets how the measured rise or fall time is compared with the given limit(s).
        '''
        '''Valid Values:
        '''RSRTM_VAL_SHORTER (0) - Shorter
        '''RSRTM_VAL_LONGER  (1) - Longer
        '''RSRTM_VAL_WITHIN  (2) - Within
        '''RSRTM_VAL_OUTSIDE (3) - Outside
        '''
        '''Default Value: RSRTM_VAL_LONGER (1)
        '''
        '''Attribute(s):
        '''RSRTM_ATTR_SEARCH_TRIGGER_RISE_TIME_RANGE
        '''
        '''Note(s):
        '''
        '''(1) Shorter: Triggers on pulses shorter than the given "Time".
        '''
        '''(2) Longer: Triggers on pulses longer than the given "Time".
        '''
        '''(3) Within: Triggers on pulses inside a given range. The range of the pulse width is defined by "Time" and "+/-Delta Time".
        '''
        '''(4) Outside: Triggers on pulses outside a given range. The range definition is the same as for "Within" range.
        '''</param>
        '''<param name="Time">
        '''Sets the reference rise or fall time, the nominal value for comparisons.
        '''
        '''Valid Values: not checked
        '''
        '''Default Value: 200e-6 s
        '''
        '''Attribute(s):
        '''RSRTM_ATTR_SEARCH_TRIGGER_RISE_TIME_REFERENCE_TIME
        '''
        '''</param>
        '''<param name="Delta_Time">
        '''Sets a range delta t to the reference rise/fall time set with "Time" if "Range" is set to Within or Outside.
        '''
        '''Valid Values: not checked
        '''
        '''Default Value: 50e-6 s 
        '''
        '''Attribute(s):
        '''RSRTM_ATTR_SEARCH_TRIGGER_RISE_TIME_DELTA_TIME
        '''
        '''</param>
        '''<returns>
        '''Returns the status code of this operation.  The status code  either indicates success or describes an error or warning condition.  You examine the status code from each call to an instrument driver function to determine if an error occurred.
        '''
        '''To obtain a text description of the status code, call the rsscope_error_message function.  To obtain additional information about the error condition, call the rsscope_GetError function.  To clear the error information from the driver, call the rsscope_ClearError function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''
        '''Numeric Range (in Hex) Status Code Types
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF VISA Warnings
        '''3FFC0000 to 3FFCFFFF VXIPnP Driver Warnings
        '''
        '''BFFF0000 to BFFFFFFF VISA Errors
        '''BFFC0000 to BFFCFFFF VXIPnP Driver Errors
        '''</returns>
        Public Function ConfigureRiseTimeTriggerSearch(ByVal Polarity As Integer, ByVal Upper_Level As Double, ByVal Lower_Level As Double, ByVal Range As Integer, ByVal Time As Double, ByVal Delta_Time As Double) As Integer
            Dim pInvokeResult As Integer = PInvoke.ConfigureRiseTimeTriggerSearch(Me._handle, Polarity, Upper_Level, Lower_Level, Range, Time, Delta_Time)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function configures the conditions for the runt trigger search.
        '''
        '''Attribute(s):
        '''RSRTM_ATTR_SEARCH_TRIGGER_RUNT_POLARITY
        '''RSRTM_ATTR_SEARCH_TRIGGER_RUNT_LEVEL
        '''RSRTM_ATTR_SEARCH_TRIGGER_RUNT_RANGE
        '''RSRTM_ATTR_SEARCH_TRIGGER_RUNT_WIDTH
        '''RSRTM_ATTR_SEARCH_TRIGGER_RUNT_DELTA_WIDTH
        '''
        '''Remote-control command(s):
        '''SEARch:TRIGger:RUNT:POLarity
        '''SEARch:TRIGger:LEVel:RUNT:LOWer
        '''SEARch:TRIGger:LEVel:RUNT:UPPer
        '''SEARch:TRIGger:RUNT:RANGe
        '''SEARch:TRIGger:RUNT:WIDTh
        '''SEARch:TRIGger:RUNT:DELTa
        '''</summary>
        '''<param name="Polarity">
        '''Indicates the polarity of a the runt to be searched for.
        '''
        '''Valid Values:
        '''RSRTM_VAL_POSITIVE (0) - Positive
        '''RSRTM_VAL_NEGATIVE (1) - Negative
        '''RSRTM_VAL_EITHER   (2) - Either
        '''
        '''Default Value: RSSCOPE_VAL_POSITIVE (0)
        '''
        '''Attribute(s):
        '''RSRTM_ATTR_SEARCH_TRIGGER_RUNT_POLARITY
        '''
        '''Note(s):
        '''(1) Positive: Rising Edge, a positive voltage change
        '''
        '''(2) Negative: Falling Edge, a negative voltage change
        '''
        '''(3) Either: Rising as well as the falling edge.
        '''</param>
        '''<param name="Upper_Level">
        '''Sets the upper voltage threshold for runt detection. A positive runt crosses the lower level twice without crossing the upper level.
        '''
        '''Valid Values: not checked
        '''
        '''Default Value: 600e-3 V
        '''
        '''Attribute(s):
        '''RSRTM_ATTR_SEARCH_TRIGGER_RUNT_LEVEL
        '''
        '''</param>
        '''<param name="Lower_Level">
        '''Sets the lower voltage threshold for runt detection. A negative runt crosses the upper level twice without crossing the lower level.
        '''
        '''Valid Values: not checked
        '''
        '''Default Value: 400e-3 V
        '''
        '''Attribute(s):
        '''RSRTM_ATTR_SEARCH_TRIGGER_RUNT_LEVEL
        '''
        '''</param>
        '''<param name="Range">
        '''Sets how the measured pulse width is compared with the given limit(s).
        '''
        '''Valid Values:
        '''RSRTM_VAL_SHORTER (0) - Shorter
        '''RSRTM_VAL_LONGER  (1) - Longer
        '''RSRTM_VAL_WITHIN  (2) - Within
        '''RSRTM_VAL_OUTSIDE (3) - Outside
        '''
        '''Default Value: RSRTM_VAL_LONGER (1)
        '''
        '''Attribute(s):
        '''RSRTM_ATTR_SEARCH_TRIGGER_RUNT_RANGE
        '''
        '''Note(s):
        '''
        '''(1) Shorter: Triggers on pulses shorter than the given "Width".
        '''
        '''(2) Longer: Triggers on pulses longer than the given "Width".
        '''
        '''(3) Within: Triggers on pulses inside a given range. The range of the pulse width is defined by "Width" and "+/-Delta Time".
        '''
        '''(4) Outside: Triggers on pulses outside a given range. The range definition is the same as for "Within" range.
        '''</param>
        '''<param name="Width">
        '''Sets the reference runt pulse width, the nominal value for comparisons.
        '''
        '''Valid Values: not checked
        '''
        '''Default Value: 200e-6 s
        '''
        '''Attribute(s):
        '''RSRTM_ATTR_SEARCH_TRIGGER_RUNT_WIDTH
        '''
        '''</param>
        '''<param name="Delta_Width">
        '''Sets a range delta t to the reference pulse width set with "Width" if "Range" is set to Within or Outside.
        '''
        '''Valid Values: not checked
        '''
        '''Default Value: 50e-6 s 
        '''
        '''Attribute(s):
        '''RSRTM_ATTR_SEARCH_TRIGGER_RUNT_DELTA_WIDTH
        '''
        '''</param>
        '''<returns>
        '''Returns the status code of this operation.  The status code  either indicates success or describes an error or warning condition.  You examine the status code from each call to an instrument driver function to determine if an error occurred.
        '''
        '''To obtain a text description of the status code, call the rsscope_error_message function.  To obtain additional information about the error condition, call the rsscope_GetError function.  To clear the error information from the driver, call the rsscope_ClearError function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''
        '''Numeric Range (in Hex) Status Code Types
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF VISA Warnings
        '''3FFC0000 to 3FFCFFFF VXIPnP Driver Warnings
        '''
        '''BFFF0000 to BFFFFFFF VISA Errors
        '''BFFC0000 to BFFCFFFF VXIPnP Driver Errors
        '''</returns>
        Public Function ConfigureRuntTriggerSearch(ByVal Polarity As Integer, ByVal Upper_Level As Double, ByVal Lower_Level As Double, ByVal Range As Integer, ByVal Width As Double, ByVal Delta_Width As Double) As Integer
            Dim pInvokeResult As Integer = PInvoke.ConfigureRuntTriggerSearch(Me._handle, Polarity, Upper_Level, Lower_Level, Range, Width, Delta_Width)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function shows or hides the table of search results.
        '''
        '''Attribute(s):
        '''RSRTM_ATTR_SEARCH_SHOW_RESULT
        '''
        '''Remote-control command(s):
        '''SEARch:RESDiagram:SHOW
        '''</summary>
        '''<param name="Show_Result">
        '''Shows or hides the table of search results.
        '''
        '''Valid Values:
        '''VI_FALSE (0) - OFF
        '''VI_TRUE  (1) - ON
        '''
        '''Default Value: VI_FALSE (0)
        '''
        '''Attribute(s):
        '''RSRTM_ATTR_SEARCH_SHOW_RESULT
        '''</param>
        '''<returns>
        '''Returns the status code of this operation.  The status code  either indicates success or describes an error or warning condition.  You examine the status code from each call to an instrument driver function to determine if an error occurred.
        '''
        '''To obtain a text description of the status code, call the rsrtm_error_message function.  To obtain additional information about the error condition, call the rsrtm_GetError function.  To clear the error information from the driver, call the rsrtm_ClearError function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''
        '''Numeric Range (in Hex) Status Code Types
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF VISA Warnings
        '''3FFC0000 to 3FFCFFFF VXIPnP Driver Warnings
        '''
        '''BFFF0000 to BFFFFFFF VISA Errors
        '''BFFC0000 to BFFCFFFF VXIPnP Driver Errors
        '''</returns>
        Public Function ConfigureShowResultDiagram(ByVal Show_Result As Boolean) As Integer
            Dim pInvokeResult As Integer = PInvoke.ConfigureShowResultDiagram(Me._handle, System.Convert.ToUInt16(Show_Result))
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function returns the number of search results.
        '''
        '''Attribute(s):
        '''RSRTM_ATTR_SEARCH_NUMBER_OF_RESULTS
        '''
        '''Remote-control command(s):
        '''SEARch:RCOunt?
        '''</summary>
        '''<param name="Number_Of_Results">
        '''Returns the number of search results.
        '''
        '''</param>
        '''<returns>
        '''Returns the status code of this operation.  The status code  either indicates success or describes an error or warning condition.  You examine the status code from each call to an instrument driver function to determine if an error occurred.
        '''
        '''To obtain a text description of the status code, call the rsrtm_error_message function.  To obtain additional information about the error condition, call the rsrtm_GetError function.  To clear the error information from the driver, call the rsrtm_ClearError function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''
        '''Numeric Range (in Hex) Status Code Types
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF VISA Warnings
        '''3FFC0000 to 3FFCFFFF VXIPnP Driver Warnings
        '''
        '''BFFF0000 to BFFFFFFF VISA Errors
        '''BFFC0000 to BFFCFFFF VXIPnP Driver Errors
        '''</returns>
        Public Function QueryNumberOfResults(ByRef Number_Of_Results As Integer) As Integer
            Dim pInvokeResult As Integer = PInvoke.QueryNumberOfResults(Me._handle, Number_Of_Results)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function returns the result values of the specified search result.
        '''
        '''Attribute(s):
        '''no attribute
        '''
        '''Remote-control command(s):
        '''SEARch:RESult&lt;n&gt;?
        '''</summary>
        '''<param name="Result_Number">
        '''Number of result to be read.
        '''
        '''Valid Values: not checked
        '''
        '''Default Value: 1
        '''
        '''
        '''
        '''
        '''</param>
        '''<param name="X_Position">
        '''Returns the X-position (time) of the search result  
        '''
        '''</param>
        '''<param name="Y_Position">
        '''Returns the Y-position of the search result, currently not relevant.  
        '''
        '''</param>
        '''<param name="Result_Type">
        '''Returns the type of the search result (Edge, Peak, Width).
        '''
        '''Valid Values:
        '''0 - Edge
        '''1 - Width
        '''2 - Peak  
        '''
        '''</param>
        '''<param name="Polarity">
        '''Returns the slope or polarity of the search result.
        '''
        '''Valid Values:
        '''0 - Positive
        '''1 - Negative
        '''2 - Either
        '''</param>
        '''<param name="Voltage_Width">
        '''For peak searches, the value contains the peak voltage. For
        '''width searches, it contains the pulse width. For edge searches,
        '''the value is not relevant.
        '''</param>
        '''<returns>
        '''Returns the status code of this operation.  The status code  either indicates success or describes an error or warning condition.  You examine the status code from each call to an instrument driver function to determine if an error occurred.
        '''
        '''To obtain a text description of the status code, call the rsrtm_error_message function.  To obtain additional information about the error condition, call the rsrtm_GetError function.  To clear the error information from the driver, call the rsrtm_ClearError function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''
        '''Numeric Range (in Hex) Status Code Types
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF VISA Warnings
        '''3FFC0000 to 3FFCFFFF VXIPnP Driver Warnings
        '''
        '''BFFF0000 to BFFFFFFF VISA Errors
        '''BFFC0000 to BFFCFFFF VXIPnP Driver Errors
        '''</returns>
        Public Function QuerySearchResult(ByVal Result_Number As Integer, ByRef X_Position As Double, ByRef Y_Position As Double, ByRef Result_Type As Integer, ByRef Polarity As Integer, ByRef Voltage_Width As Double) As Integer
            Dim pInvokeResult As Integer = PInvoke.QuerySearchResult(Me._handle, Result_Number, X_Position, Y_Position, Result_Type, Polarity, Voltage_Width)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function returns all result values of the search.  
        '''
        '''Attribute(s):
        '''no attribute
        '''
        '''Remote-control command(s):
        '''SEARch:RESult:ALL?
        '''</summary>
        '''<param name="Array_Size">
        '''Pass the number of elements in the array parameters.
        '''
        '''Default Value: None
        '''
        '''
        '''</param>
        '''<param name="X_Position">
        '''Returns the X-position (time) of the search result  
        '''
        '''</param>
        '''<param name="Y_Position">
        '''Returns the Y-position of the search result, currently not relevant.  
        '''
        '''</param>
        '''<param name="Result_Type">
        '''Returns the type of the search result (Edge, Peak, Width).
        '''
        '''Valid Values:
        '''0 - Edge
        '''1 - Width
        '''2 - Peak  
        '''
        '''</param>
        '''<param name="Polarity">
        '''Returns the slope or polarity of the search result.
        '''
        '''Valid Values:
        '''0 - Positive
        '''1 - Negative
        '''2 - Either
        '''</param>
        '''<param name="Voltage_Width">
        '''For peak searches, the value contains the peak voltage. For
        '''width searches, it contains the pulse width. For edge searches,
        '''the value is not relevant.
        '''</param>
        '''<param name="Number_Of_Results">
        '''Number of returned results.
        '''
        '''</param>
        '''<returns>
        '''Returns the status code of this operation.  The status code  either indicates success or describes an error or warning condition.  You examine the status code from each call to an instrument driver function to determine if an error occurred.
        '''
        '''To obtain a text description of the status code, call the rsrtm_error_message function.  To obtain additional information about the error condition, call the rsrtm_GetError function.  To clear the error information from the driver, call the rsrtm_ClearError function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''
        '''Numeric Range (in Hex) Status Code Types
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF VISA Warnings
        '''3FFC0000 to 3FFCFFFF VXIPnP Driver Warnings
        '''
        '''BFFF0000 to BFFFFFFF VISA Errors
        '''BFFC0000 to BFFCFFFF VXIPnP Driver Errors
        '''</returns>
        Public Function QueryAllSearchResults(ByVal Array_Size As Integer, ByVal X_Position() As Double, ByVal Y_Position() As Double, ByVal Result_Type() As Integer, ByVal Polarity() As Integer, ByVal Voltage_Width() As Double, ByRef Number_Of_Results As Integer) As Integer
            Dim pInvokeResult As Integer = PInvoke.QueryAllSearchResults(Me._handle, Array_Size, X_Position, Y_Position, Result_Type, Polarity, Voltage_Width, Number_Of_Results)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function enables the decoding of the selected bus.
        '''
        '''Note(s):
        '''(1) This function is only available if at least one protocol option is installed.
        '''
        '''Attribute(s):
        '''RSRTM_ATTR_PROTOCOL_STATE
        '''
        '''Remote-control command(s):
        '''BUS:STATe
        '''</summary>
        '''<param name="State">
        '''Enables the decoding of the selected bus.
        '''
        '''Valid Values:
        '''VI_FALSE (0) - OFF
        '''VI_TRUE  (1) - ON
        '''
        '''Default Value: VI_FALSE  (0)
        '''
        '''Attribute:
        '''RSRTM_ATTR_PROTOCOL_STATE
        '''</param>
        '''<returns>
        '''Returns the status code of this operation.  The status code  either indicates success or describes an error or warning condition.  You examine the status code from each call to an instrument driver function to determine if an error occurred.
        '''
        '''To obtain a text description of the status code, call the rsrtm_error_message function.  To obtain additional information about the error condition, call the rsrtm_GetError function.  To clear the error information from the driver, call the rsrtm_ClearError function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''
        '''Numeric Range (in Hex) Status Code Types
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF VISA Warnings
        '''3FFC0000 to 3FFCFFFF VXIPnP Driver Warnings
        '''
        '''BFFF0000 to BFFFFFFF VISA Errors
        '''BFFC0000 to BFFCFFFF VXIPnP Driver Errors
        '''</returns>
        Public Function ConfigureDecodeState(ByVal State As Boolean) As Integer
            Dim pInvokeResult As Integer = PInvoke.ConfigureDecodeState(Me._handle, System.Convert.ToUInt16(State))
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''Selects protocol type.
        '''
        '''Attribute(s):
        '''RSRTM_ATTR_PROTOCOL_TYPE
        '''
        '''Remote-control command(s):
        '''BUS:TYPE
        '''</summary>
        '''<param name="Protocol">
        '''This control selects protocol type.
        '''
        '''Valid Values: 
        '''RSRTM_VAL_PTYPE_RTM_PARALLEL   (0) - Parallel
        '''RSRTM_VAL_PTYPE_RTM_CPARALLEL  (1) - C Parallel
        '''RSRTM_VAL_PTYPE_RTM_I2C        (2) - I2C
        '''RSRTM_VAL_PTYPE_RTM_SPI        (3) - SPI
        '''RSRTM_VAL_PTYPE_RTM_SSPI       (4) - SSPI
        '''RSRTM_VAL_PTYPE_RTM_UART       (5) - UART
        '''
        '''Default Value: RSRTM_VAL_PTYPE_RTM_PARALLEL (0)
        '''
        '''Attribute:
        '''RSRTM_ATTR_PROTOCOL_TYPE
        '''</param>
        '''<returns>
        '''Returns the status code of this operation.  The status code  either indicates success or describes an error or warning condition.  You examine the status code from each call to an instrument driver function to determine if an error occurred.
        '''
        '''To obtain a text description of the status code, call the rsrtm_error_message function.  To obtain additional information about the error condition, call the rsrtm_GetError function.  To clear the error information from the driver, call the rsrtm_ClearError function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''
        '''Numeric Range (in Hex) Status Code Types
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF VISA Warnings
        '''3FFC0000 to 3FFCFFFF VXIPnP Driver Warnings
        '''
        '''BFFF0000 to BFFFFFFF VISA Errors
        '''BFFC0000 to BFFCFFFF VXIPnP Driver Errors
        '''</returns>
        Public Function ConfigureBusProtocol(ByVal Protocol As Integer) As Integer
            Dim pInvokeResult As Integer = PInvoke.ConfigureBusProtocol(Me._handle, Protocol)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''Configuration of the protocol display.
        '''
        '''Attribute(s):
        '''RSRTM_ATTR_PROTOCOL_DISPLAY_FORMAT
        '''RSRTM_ATTR_PROTOCOL_DISPLAY_HEIGHT
        '''RSRTM_ATTR_PROTOCOL_DISPLAY_LINES
        '''RSRTM_ATTR_PROTOCOL_DISPLAY_VERTICAL
        '''
        '''Remote-control command(s):
        '''BUS:FORMat
        '''BUS:DSIZe
        '''BUS:DSIGnals
        '''BUS:POSition
        '''</summary>
        '''<param name="Format">
        '''This control sets the decoding format for the display on the screen.
        '''
        '''Valid Values: 
        '''RSRTM_VAL_PFORMAT_ASCI (0) - Asci
        '''RSRTM_VAL_PFORMAT_HEX  (1) - Hexadecimal
        '''RSRTM_VAL_PFORMAT_BIN  (2) - Binary
        '''RSRTM_VAL_PFORMAT_DEC  (3) - Decimal
        '''
        '''Default Value: RSRTM_VAL_PFORMAT_HEX (1)
        '''
        '''Attribute:
        '''RSRTM_ATTR_PROTOCOL_DISPLAY_FORMAT
        '''</param>
        '''<param name="Height">
        '''This control sets the height of the display on the screen.
        '''
        '''Valid Values: 
        '''RSRTM_VAL_PHEIGHT_SMALL  (0) - Small
        '''RSRTM_VAL_PHEIGHT_MEDIUM (1) - Medium
        '''RSRTM_VAL_PHEIGHT_LARGE  (2) - Large
        '''
        '''Default Value: RSRTM_VAL_PHEIGHT_MEDIUM (1)
        '''
        '''Attribute:
        '''RSRTM_ATTR_PROTOCOL_DISPLAY_HEIGHT
        '''</param>
        '''<param name="Display_Lines">
        '''Displays the individual bit lines above the decoded bus line.
        '''
        '''Valid Values:
        '''VI_FALSE (0) - OFF
        '''VI_TRUE  (1) - ON
        '''
        '''Default Value: VI_TRUE  (1)
        '''
        '''Attribute:
        '''RSRTM_ATTR_PROTOCOL_DISPLAY_LINES
        '''</param>
        '''<param name="Vertical_Position">
        '''This control selects the vertical position of the decoded bus signal in divisions on the sreen.
        '''
        '''Valid Values: 
        '''-4.0 to 4.0
        '''
        '''Default Value: 3.50
        '''
        '''Attribute:
        '''RSRTM_ATTR_PROTOCOL_DISPLAY_VERTICAL
        '''</param>
        '''<returns>
        '''Returns the status code of this operation.  The status code  either indicates success or describes an error or warning condition.  You examine the status code from each call to an instrument driver function to determine if an error occurred.
        '''
        '''To obtain a text description of the status code, call the rsrtm_error_message function.  To obtain additional information about the error condition, call the rsrtm_GetError function.  To clear the error information from the driver, call the rsrtm_ClearError function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''
        '''Numeric Range (in Hex) Status Code Types
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF VISA Warnings
        '''3FFC0000 to 3FFCFFFF VXIPnP Driver Warnings
        '''
        '''BFFF0000 to BFFFFFFF VISA Errors
        '''BFFC0000 to BFFCFFFF VXIPnP Driver Errors
        '''</returns>
        Public Function ConfigureProtocolDisplay(ByVal Format As Integer, ByVal Height As Integer, ByVal Display_Lines As Boolean, ByVal Vertical_Position As Double) As Integer
            Dim pInvokeResult As Integer = PInvoke.ConfigureProtocolDisplay(Me._handle, Format, Height, System.Convert.ToUInt16(Display_Lines), Vertical_Position)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function configures source waveform of the data line (SDA) and clock line (SCL).
        '''
        '''Attribute(s):
        '''RSRTM_ATTR_PROTOCOL_I2C_SOURCE
        '''
        '''Remote-control command(s):
        '''BUS:I2C:&lt;I2CLine&gt;:SOURce
        '''</summary>
        '''<param name="Line">
        '''This control select I2C line.
        '''
        '''Valid Values: 
        '''RSRTM_VAL_I2C_SCL  (0) - Clock line
        '''RSRTM_VAL_I2C_SDA  (1) - Data line
        '''
        '''Default Value: RSRTM_VAL_I2C_SCL (0)
        '''</param>
        '''<param name="Waveform_Source">
        '''Sets the waveform of the clock or data line.
        '''
        '''Valid Values:
        '''RSRTM_VAL_SOURCE_CH1 (1) - Channel 1
        '''RSRTM_VAL_SOURCE_CH2 (2) - Channel 2
        '''RSRTM_VAL_SOURCE_CH3 (3) - Channel 3
        '''RSRTM_VAL_SOURCE_CH4 (4) - Channel 4
        '''
        '''Default Value: RSRTM_VAL_SOURCE_CH1 (1)
        '''
        '''Attribute:
        '''RSRTM_ATTR_PROTOCOL_I2C_SOURCE
        '''</param>
        '''<returns>
        '''Returns the status code of this operation.  The status code  either indicates success or describes an error or warning condition.  You examine the status code from each call to an instrument driver function to determine if an error occurred.
        '''
        '''To obtain a text description of the status code, call the rsrtm_error_message function.  To obtain additional information about the error condition, call the rsrtm_GetError function.  To clear the error information from the driver, call the rsrtm_ClearError function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''
        '''Numeric Range (in Hex) Status Code Types
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF VISA Warnings
        '''3FFC0000 to 3FFCFFFF VXIPnP Driver Warnings
        '''
        '''BFFF0000 to BFFFFFFF VISA Errors
        '''BFFC0000 to BFFCFFFF VXIPnP Driver Errors
        '''</returns>
        Public Function ConfigureI2CSource(ByVal Line As Integer, ByVal Waveform_Source As Integer) As Integer
            Dim pInvokeResult As Integer = PInvoke.ConfigureI2CSource(Me._handle, Line, Waveform_Source)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function:
        '''Toggles the trigger condition between Read and Write access of the master.
        '''Sets the lenght of the slave address.
        '''Sets the address of the slave device. The address can have 7 bits or 10 bits.
        '''Specifies the trigger mode for I2C.
        '''Defines how many bytes are considered in the trigger condition.
        '''Defines the bit pattern as trigger condition.
        '''Sets the number of bytes before the first byte of interest.
        '''
        '''Attribute(s):
        '''RSRTM_ATTR_PROTOCOL_I2C_TRIGGER_ACCESS
        '''RSRTM_ATTR_PROTOCOL_I2C_TRIGGER_ADDRESS_TYPE
        '''RSRTM_ATTR_PROTOCOL_I2C_TRIGGER_ADDRESS
        '''RSRTM_ATTR_PROTOCOL_I2C_TRIGGER_MODE
        '''RSRTM_ATTR_PROTOCOL_I2C_TRIGGER_CONDITION_LENGTH
        '''RSRTM_ATTR_PROTOCOL_I2C_TRIGGER_BIT_PATTERN
        '''RSRTM_ATTR_PROTOCOL_I2C_TRIGGER_FIRST_BYTE_OFFSET
        '''
        '''Remote-control command(s):
        '''TRIGger:A:I2C:ACCess
        '''TRIGger:A:I2C:AMODe
        '''TRIGger:A:I2C:ADDRess
        '''TRIGger:A:I2C:MODE
        '''TRIGger:A:I2C:PLENgth
        '''TRIGger:A:I2C:PATTern
        '''TRIGger:A:I2C:POFFset
        '''</summary>
        '''<param name="Access">
        '''Selects access mode.
        '''
        '''Valid Values:
        '''RSRTM_VAL_I2C_TRIGGER_READ  (0) - Read
        '''RSRTM_VAL_I2C_TRIGGER_WRITE (1) - Write
        '''
        '''Default Value: RSRTM_VAL_I2C_TRIGGER_READ (0)
        '''
        '''Attribute:
        '''RSRTM_ATTR_PROTOCOL_I2C_TRIGGER_ACCESS
        '''</param>
        '''<param name="Address_length">
        '''Sets the length of the slave address.
        '''
        '''Valid Values:
        '''RSRTM_VAL_LENGTH_NORMAL   (0) - Normal
        '''RSRTM_VAL_LENGTH_EXTENDED (1) - Extended
        '''
        '''Default Value: RSRTM_VAL_LENGTH_NORMAL (0)
        '''
        '''Attribute:
        '''RSRTM_ATTR_PROTOCOL_I2C_TRIGGER_ADDRESS_TYPE
        '''</param>
        '''<param name="Device_Address">
        '''This control sets the address of the slave device.
        '''
        '''Valid Values:
        '''not checked
        '''
        '''Default Value:
        '''""
        '''
        '''Attribute:
        '''RSRTM_ATTR_PROTOCOL_I2C_TRIGGER_ADDRESS
        '''
        '''Note:
        '''(1) Characters 0, 1, and X are allowed.
        '''</param>
        '''<param name="Trigger_Mode">
        '''Sets the trigger mode for I2C.
        '''
        '''Valid Values:
        '''RSRTM_VAL_TRIGGER_MODE_START   (0) - Start
        '''RSRTM_VAL_TRIGGER_MODE_RESTART (1) - Restart
        '''RSRTM_VAL_TRIGGER_MODE_STOP    (2) - Stop
        '''RSRTM_VAL_TRIGGER_MODE_MISSING (3) - Missing ACK
        '''RSRTM_VAL_TRIGGER_MODE_PATT    (4) - Pattern
        '''
        '''Default Value: RSRTM_VAL_TRIGGER_MODE_START (0)
        '''
        '''Attribute:
        '''RSRTM_ATTR_PROTOCOL_I2C_TRIGGER_MODE
        '''</param>
        '''<param name="Pattern_Length">
        '''This Control defines how many bytes are considered in the trigger condition.
        '''
        '''Valid Values: 1 to 3
        '''
        '''Default Value: 1
        '''
        '''Attribute:
        '''RSRTM_ATTR_PROTOCOL_I2C_TRIGGER_CONDITION_LENGTH
        '''</param>
        '''<param name="Pattern">
        '''This control defines the bit pattern as trigger condition.
        '''
        '''Valid Values:
        '''not checked
        '''
        '''Default Value:
        '''""
        '''
        '''Attribute:
        '''RSRTM_ATTR_PROTOCOL_I2C_TRIGGER_BIT_PATTERN
        '''
        '''Note:
        '''(1) Characters 0, 1, and X are allowed.
        '''</param>
        '''<param name="Pattern_Offset">
        '''Sets the number of bytes before the first byte of interest, relating to the end of the address bytes.
        '''
        '''Valid Values: 0 to 4095
        '''
        '''Default Value: 0
        '''
        '''Attribute: 
        '''RSRTM_ATTR_PROTOCOL_I2C_TRIGGER_FIRST_BYTE_OFFSET
        '''</param>
        '''<returns>
        '''Returns the status code of this operation.  The status code  either indicates success or describes an error or warning condition.  You examine the status code from each call to an instrument driver function to determine if an error occurred.
        '''
        '''To obtain a text description of the status code, call the rsrtm_error_message function.  To obtain additional information about the error condition, call the rsrtm_GetError function.  To clear the error information from the driver, call the rsrtm_ClearError function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''
        '''Numeric Range (in Hex) Status Code Types
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF VISA Warnings
        '''3FFC0000 to 3FFCFFFF VXIPnP Driver Warnings
        '''
        '''BFFF0000 to BFFFFFFF VISA Errors
        '''BFFC0000 to BFFCFFFF VXIPnP Driver Errors
        '''</returns>
        Public Function ConfigureI2CTriggerSetting(ByVal Access As Integer, ByVal Address_length As Integer, ByVal Device_Address As String, ByVal Trigger_Mode As Integer, ByVal Pattern_Length As Integer, ByVal Pattern As String, ByVal Pattern_Offset As Integer) As Integer
            Dim pInvokeResult As Integer = PInvoke.ConfigureI2CTriggerSetting(Me._handle, Access, Address_length, Device_Address, Trigger_Mode, Pattern_Length, Pattern, Pattern_Offset)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function configures input channel of the selected line.
        '''
        '''Attribute(s):
        '''RSRTM_ATTR_PROTOCOL_SPI_SOURCE
        '''
        '''Remote-control command(s):
        '''BUS:SPI:&lt;SPILine&gt;:SOURce
        '''</summary>
        '''<param name="Line">
        '''This control select configured SPI line.
        '''
        '''Valid Values: 
        '''RSRTM_VAL_SPI_CLOCK (0) - Clock
        '''RSRTM_VAL_SPI_DATA  (1) - Data
        '''RSRTM_VAL_SPI_CSEL  (2) - Chip Select
        '''
        '''Default Value: RSRTM_VAL_SPI_CLOCK (0)
        '''</param>
        '''<param name="Waveform_Source">
        '''Sets the waveform of the selected line.
        '''
        '''Valid Values:
        '''RSRTM_VAL_SOURCE_CH1 (1) - Channel 1
        '''RSRTM_VAL_SOURCE_CH2 (2) - Channel 2
        '''RSRTM_VAL_SOURCE_CH3 (3) - Channel 3
        '''RSRTM_VAL_SOURCE_CH4 (4) - Channel 4
        '''
        '''Default Value: RSRTM_VAL_SOURCE_CH1 (1)
        '''
        '''Attribute:
        '''RSRTM_ATTR_PROTOCOL_SPI_SOURCE
        '''</param>
        '''<returns>
        '''Returns the status code of this operation.  The status code  either indicates success or describes an error or warning condition.  You examine the status code from each call to an instrument driver function to determine if an error occurred.
        '''
        '''To obtain a text description of the status code, call the rsrtm_error_message function.  To obtain additional information about the error condition, call the rsrtm_GetError function.  To clear the error information from the driver, call the rsrtm_ClearError function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''
        '''Numeric Range (in Hex) Status Code Types
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF VISA Warnings
        '''3FFC0000 to 3FFCFFFF VXIPnP Driver Warnings
        '''
        '''BFFF0000 to BFFFFFFF VISA Errors
        '''BFFC0000 to BFFCFFFF VXIPnP Driver Errors
        '''</returns>
        Public Function ConfigureSPISource(ByVal Line As Integer, ByVal Waveform_Source As Integer) As Integer
            Dim pInvokeResult As Integer = PInvoke.ConfigureSPISource(Me._handle, Line, Waveform_Source)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function configures whether transmitted data or the slave select signal is high active (high = 1) or low
        '''active (low = 1).
        '''
        '''Note(s):
        '''
        '''Attribute(s):
        '''RSRTM_ATTR_PROTOCOL_SPI_POLARITY
        '''
        '''Remote-control command(s):
        '''BUS:SPI:&lt;SPILine&gt;:POLarity
        '''</summary>
        '''<param name="Line">
        '''This control select configured SPI line.
        '''
        '''Valid Values: 
        '''RSRTM_VAL_SPI_CLOCK (0) - Clock
        '''RSRTM_VAL_SPI_CSEL  (1) - Chip Select
        '''RSRTM_VAL_SPI_DATA  (2) - Data
        '''
        '''Default Value: RSRTM_VAL_SPI_CLOCK (0)
        '''</param>
        '''<param name="Polarity">
        '''Selects line polarity.
        '''
        '''Valid Values:
        '''RSRTM_VAL_ACTLOW  (0) - Low active (low = 0)
        '''RSRTM_VAL_ACTHIGH (1) - High active (high = 1)
        '''
        '''Default Value: RSRTM_VAL_ACTLOW (0)
        '''
        '''Attribute:
        '''RSRTM_ATTR_PROTOCOL_SPI_POLARITY
        '''</param>
        '''<returns>
        '''Returns the status code of this operation.  The status code  either indicates success or describes an error or warning condition.  You examine the status code from each call to an instrument driver function to determine if an error occurred.
        '''
        '''To obtain a text description of the status code, call the rsrtm_error_message function.  To obtain additional information about the error condition, call the rsrtm_GetError function.  To clear the error information from the driver, call the rsrtm_ClearError function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''
        '''Numeric Range (in Hex) Status Code Types
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF VISA Warnings
        '''3FFC0000 to 3FFCFFFF VXIPnP Driver Warnings
        '''
        '''BFFF0000 to BFFFFFFF VISA Errors
        '''BFFC0000 to BFFCFFFF VXIPnP Driver Errors
        '''</returns>
        Public Function ConfigureSPIPolarity(ByVal Line As Integer, ByVal Polarity As Integer) As Integer
            Dim pInvokeResult As Integer = PInvoke.ConfigureSPIPolarity(Me._handle, Line, Polarity)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function configures bit count and it's order in message. The display of the decoded signal considers this setting.
        '''
        '''Attribute(s):
        '''RSRTM_ATTR_PROTOCOL_SPI_BIT_ORDER
        '''RSRTM_ATTR_PROTOCOL_SPI_WORD_LENGTH
        '''
        '''Remote-control command(s):
        '''BUS:SPI:BORDer
        '''BUS:SPI:SSIZe
        '''</summary>
        '''<param name="Bit_Order">
        '''Select if the data of the messages starts with msb or lsb.
        '''
        '''Valid Values: 
        '''RSRTM_VAL_SPI_MSBF (0) - Most significant bit
        '''RSRTM_VAL_SPI_LSBF (1) - Least significant bit
        '''
        '''Default Value: RSRTM_VAL_SPI_MSBF (0)
        '''
        '''Attribute:
        '''RSRTM_ATTR_PROTOCOL_SPI_BIT_ORDER
        '''</param>
        '''<param name="Word_Length">
        '''Sets the number of bits in a word.
        '''
        '''Valid Values:  4 to 32
        '''
        '''Default Value: 8
        '''
        '''Attribute:
        '''RSRTM_ATTR_PROTOCOL_SPI_WORD_LENGTH
        '''</param>
        '''<returns>
        '''Returns the status code of this operation.  The status code  either indicates success or describes an error or warning condition.  You examine the status code from each call to an instrument driver function to determine if an error occurred.
        '''
        '''To obtain a text description of the status code, call the rsrtm_error_message function.  To obtain additional information about the error condition, call the rsrtm_GetError function.  To clear the error information from the driver, call the rsrtm_ClearError function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''
        '''Numeric Range (in Hex) Status Code Types
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF VISA Warnings
        '''3FFC0000 to 3FFCFFFF VXIPnP Driver Warnings
        '''
        '''BFFF0000 to BFFFFFFF VISA Errors
        '''BFFC0000 to BFFCFFFF VXIPnP Driver Errors
        '''</returns>
        Public Function ConfigureSPIWord(ByVal Bit_Order As Integer, ByVal Word_Length As Integer) As Integer
            Dim pInvokeResult As Integer = PInvoke.ConfigureSPIWord(Me._handle, Bit_Order, Word_Length)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''Specifies the trigger mode for SPI/SSPI protocols.
        '''
        '''Attribute(s):
        '''RSRTM_ATTR_PROTOCOL_SPI_TRIGGER_MODE
        '''
        '''Remote-control command(s):
        '''TRIGger:A:SPI:MODE
        '''</summary>
        '''<param name="Mode">
        '''This control specifies the trigger mode.
        '''
        '''Valid Values:
        '''RSRTM_VAL_SPI_MODE_BURSTSTART (0) - Burst Start
        '''RSRTM_VAL_SPI_MODE_BURSTEND   (1) - Burst End
        '''RSRTM_VAL_SPI_MODE_BIT        (2) - NTH Bit
        '''RSRTM_VAL_SPI_MODE_PATTERN    (3) - Pattern
        '''
        '''Default Value: RSRTM_VAL_SPI_MODE_BURSTSTART (0)
        '''
        '''Attribute(s): 
        '''RSRTM_ATTR_PROTOCOL_SPI_TRIGGER_MODE
        '''</param>
        '''<returns>
        '''Returns the status code of this operation.  The status code  either indicates success or describes an error or warning condition.  You examine the status code from each call to an instrument driver function to determine if an error occurred.
        '''
        '''To obtain a text description of the status code, call the rsrtm_error_message function.  To obtain additional information about the error condition, call the rsrtm_GetError function.  To clear the error information from the driver, call the rsrtm_ClearError function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''
        '''Numeric Range (in Hex) Status Code Types
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF VISA Warnings
        '''3FFC0000 to 3FFCFFFF VXIPnP Driver Warnings
        '''
        '''BFFF0000 to BFFFFFFF VISA Errors
        '''BFFC0000 to BFFCFFFF VXIPnP Driver Errors
        '''</returns>
        Public Function ConfigureSPITriggerType(ByVal Mode As Integer) As Integer
            Dim pInvokeResult As Integer = PInvoke.ConfigureSPITriggerType(Me._handle, Mode)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function configure trigger conditions.
        '''
        '''Note(s):
        '''(1) This function has effect only, when trigger type is set to MOSI, MISO or MISO/MOSI.
        '''
        '''Attribute(s):
        '''RSRTM_ATTR_PROTOCOL_SPI_TRIGGER_OFFSET
        '''RSRTM_ATTR_PROTOCOL_SPI_TRIGGER_PATTERN
        '''RSRTM_ATTR_PROTOCOL_SPI_BIT_PATTERN_LENGTH
        '''
        '''Remote-control command(s):
        '''TRIGger:A:SPI:POFFset
        '''TRIGger:A:SPI:&lt;SPIPattern&gt;
        '''TRIGger:A:SPI:PLENgth
        '''
        '''</summary>
        '''<param name="Offset">
        '''Sets the number of bits or words before the first byte of interest.
        '''
        '''Valid Values: 0 to 4095
        '''
        '''Default Value: 0
        '''</param>
        '''<param name="Bit_Pattern_Length">
        '''Defines how many bits build up the serial pattern.
        '''
        '''Valid Values:
        '''1 to 32
        '''
        '''Default Value: 4
        '''
        '''Attribute:
        '''RSRTM_ATTR_PROTOCOL_SPI_BIT_PATTERN_LENGTH
        '''</param>
        '''<param name="Bit_Pattern">
        '''Specifies the trigger bit pattern.
        '''
        '''Valid Values:
        '''not checked
        '''
        '''Default Value: ""
        '''
        '''Attribute(s):
        '''RSRTM_ATTR_PROTOCOL_SPI_BIT_PATTERN
        '''</param>
        '''<returns>
        '''Returns the status code of this operation.  The status code  either indicates success or describes an error or warning condition.  You examine the status code from each call to an instrument driver function to determine if an error occurred.
        '''
        '''To obtain a text description of the status code, call the rsrtm_error_message function.  To obtain additional information about the error condition, call the rsrtm_GetError function.  To clear the error information from the driver, call the rsrtm_ClearError function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''
        '''Numeric Range (in Hex) Status Code Types
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF VISA Warnings
        '''3FFC0000 to 3FFCFFFF VXIPnP Driver Warnings
        '''
        '''BFFF0000 to BFFFFFFF VISA Errors
        '''BFFC0000 to BFFCFFFF VXIPnP Driver Errors
        '''</returns>
        Public Function ConfigureSPITriggerData(ByVal Offset As Integer, ByVal Bit_Pattern_Length As Integer, ByVal Bit_Pattern As String) As Integer
            Dim pInvokeResult As Integer = PInvoke.ConfigureSPITriggerData(Me._handle, Offset, Bit_Pattern_Length, Bit_Pattern)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function configures input channel of the selected line.
        '''
        '''Attribute(s):
        '''RSRTM_ATTR_PROTOCOL_SSPI_SOURCE
        '''
        '''Remote-control command(s):
        '''BUS:SSPI:&lt;SSPILine&gt;:SOURce
        '''</summary>
        '''<param name="Line">
        '''This control selects configured SSPI line.
        '''
        '''Valid Values: 
        '''RSRTM_VAL_SPI_CLOCK (0) - Clock
        '''RSRTM_VAL_SPI_DATA  (1) - Data
        '''
        '''Default Value: RSRTM_VAL_SPI_CLOCK (0)
        '''</param>
        '''<param name="Waveform_Source">
        '''Sets the waveform of the selected line.
        '''
        '''Valid Values:
        '''RSRTM_VAL_SOURCE_CH1 (1) - Channel 1
        '''RSRTM_VAL_SOURCE_CH2 (2) - Channel 2
        '''RSRTM_VAL_SOURCE_CH3 (3) - Channel 3
        '''RSRTM_VAL_SOURCE_CH4 (4) - Channel 4
        '''
        '''Default Value: RSRTM_VAL_SOURCE_CH1 (1)
        '''
        '''Attribute:
        '''RSRTM_ATTR_PROTOCOL_SSPI_SOURCE
        '''</param>
        '''<returns>
        '''Returns the status code of this operation.  The status code  either indicates success or describes an error or warning condition.  You examine the status code from each call to an instrument driver function to determine if an error occurred.
        '''
        '''To obtain a text description of the status code, call the rsrtm_error_message function.  To obtain additional information about the error condition, call the rsrtm_GetError function.  To clear the error information from the driver, call the rsrtm_ClearError function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''
        '''Numeric Range (in Hex) Status Code Types
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF VISA Warnings
        '''3FFC0000 to 3FFCFFFF VXIPnP Driver Warnings
        '''
        '''BFFF0000 to BFFFFFFF VISA Errors
        '''BFFC0000 to BFFCFFFF VXIPnP Driver Errors
        '''</returns>
        Public Function ConfigureSSPISource(ByVal Line As Integer, ByVal Waveform_Source As Integer) As Integer
            Dim pInvokeResult As Integer = PInvoke.ConfigureSSPISource(Me._handle, Line, Waveform_Source)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function configures whether transmitted data or the slave select signal is high active (high = 1) or low active (low = 1).
        '''
        '''Note(s):
        '''
        '''Attribute(s):
        '''RSRTM_ATTR_PROTOCOL_SSPI_POLARITY
        '''
        '''Remote-control command(s):
        '''BUS:SSPI:&lt;SSPILine&gt;:POLarity
        '''</summary>
        '''<param name="Line">
        '''This control select configured SSPI line.
        '''
        '''Valid Values: 
        '''RSRTM_VAL_SPI_CLOCK (0) - Clock
        '''RSRTM_VAL_SPI_DATA  (1) - Data
        '''
        '''Default Value: RSRTM_VAL_SPI_CLOCK (0)
        '''</param>
        '''<param name="Polarity">
        '''Selects line polarity.
        '''
        '''Valid Values:
        '''RSRTM_VAL_ACTLOW  (0) - Low active (low = 0)
        '''RSRTM_VAL_ACTHIGH (1) - High active (high = 1)
        '''
        '''Default Value: RSRTM_VAL_ACTLOW (0)
        '''
        '''Attribute:
        '''RSRTM_ATTR_PROTOCOL_SSPI_POLARITY
        '''</param>
        '''<returns>
        '''Returns the status code of this operation.  The status code  either indicates success or describes an error or warning condition.  You examine the status code from each call to an instrument driver function to determine if an error occurred.
        '''
        '''To obtain a text description of the status code, call the rsrtm_error_message function.  To obtain additional information about the error condition, call the rsrtm_GetError function.  To clear the error information from the driver, call the rsrtm_ClearError function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''
        '''Numeric Range (in Hex) Status Code Types
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF VISA Warnings
        '''3FFC0000 to 3FFCFFFF VXIPnP Driver Warnings
        '''
        '''BFFF0000 to BFFFFFFF VISA Errors
        '''BFFC0000 to BFFCFFFF VXIPnP Driver Errors
        '''</returns>
        Public Function ConfigureSSPIPolarity(ByVal Line As Integer, ByVal Polarity As Integer) As Integer
            Dim pInvokeResult As Integer = PInvoke.ConfigureSSPIPolarity(Me._handle, Line, Polarity)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function configures the idle time the data and clock lines are low. A new frame begins when the idle time has expired and the clock line has been inactive during that time. If the time interval between the data words is shorter than the idle time, the words are part of the same frame. And defines if the data of the messages starts with MSB (most significant bit) or LSB (least significant bit). And sets the word length, the number of bits in a message.
        '''
        '''Attribute(s):
        '''RSRTM_ATTR_PROTOCOL_SSPI_INTERFRAME_TIME
        '''RSRTM_ATTR_PROTOCOL_SSPI_BIT_ORDER
        '''RSRTM_ATTR_PROTOCOL_SSPI_WORD_LENGTH
        '''
        '''Remote-control command(s):
        '''BUS:SSPI:BITime
        '''BUS:SSPI:BORDer
        '''BUS:SSPI:SSIZe
        '''</summary>
        '''<param name="Interframe_time">
        '''This control configures the interframe time.
        '''
        '''Valid Values:
        '''16e-9 to 1e-3
        '''
        '''Default Value: 100e-6
        '''
        '''Attribute:
        '''RSRTM_ATTR_PROTOCOL_SSPI_INTERFRAME_TIME
        '''</param>
        '''<param name="Bit_Order">
        '''Select if the data of the messages starts with msb or lsb.
        '''
        '''Valid Values: 
        '''RSRTM_VAL_SPI_MSBF (0) - MSB
        '''RSRTM_VAL_SPI_LSBF (1) - LSB
        '''
        '''Default Value: RSRTM_VAL_SPI_MSBF (0)
        '''
        '''Attribute:
        '''RSRTM_ATTR_PROTOCOL_SSPI_BIT_ORDER
        '''</param>
        '''<param name="Word_Length">
        '''Sets the number of bits in a word.
        '''
        '''Valid Values:  4 to 32
        '''
        '''Default Value: 8
        '''
        '''Attribute:
        '''RSRTM_ATTR_PROTOCOL_SSPI_WORD_LENGTH
        '''</param>
        '''<returns>
        '''Returns the status code of this operation.  The status code  either indicates success or describes an error or warning condition.  You examine the status code from each call to an instrument driver function to determine if an error occurred.
        '''
        '''To obtain a text description of the status code, call the rsrtm_error_message function.  To obtain additional information about the error condition, call the rsrtm_GetError function.  To clear the error information from the driver, call the rsrtm_ClearError function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''
        '''Numeric Range (in Hex) Status Code Types
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF VISA Warnings
        '''3FFC0000 to 3FFCFFFF VXIPnP Driver Warnings
        '''
        '''BFFF0000 to BFFFFFFF VISA Errors
        '''BFFC0000 to BFFCFFFF VXIPnP Driver Errors
        '''</returns>
        Public Function ConfigureSSPIPackets(ByVal Interframe_time As Double, ByVal Bit_Order As Integer, ByVal Word_Length As Integer) As Integer
            Dim pInvokeResult As Integer = PInvoke.ConfigureSSPIPackets(Me._handle, Interframe_time, Bit_Order, Word_Length)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function configures the input channels for the transmitter and receiver signals. 
        '''
        '''Attribute(s):
        '''RSRTM_ATTR_PROTOCOL_UART_SOURCE
        '''
        '''Remote-control command(s):
        '''BUS:UART:DATA:SOURce
        '''</summary>
        '''<param name="Waveform_Source">
        '''Sets the waveform of the clock or data line.
        '''
        '''Valid Values:
        '''RSRTM_VAL_SOURCE_CH1 (1) - Channel 1
        '''RSRTM_VAL_SOURCE_CH2 (2) - Channel 2
        '''RSRTM_VAL_SOURCE_CH3 (3) - Channel 3
        '''RSRTM_VAL_SOURCE_CH4 (4) - Channel 4
        '''
        '''Default Value: RSRTM_VAL_SOURCE_CH1 (1)
        '''
        '''Attribute:
        '''RSRTM_ATTR_PROTOCOL_UART_SOURCE
        '''</param>
        '''<returns>
        '''Returns the status code of this operation.  The status code  either indicates success or describes an error or warning condition.  You examine the status code from each call to an instrument driver function to determine if an error occurred.
        '''
        '''To obtain a text description of the status code, call the rsrtm_error_message function.  To obtain additional information about the error condition, call the rsrtm_GetError function.  To clear the error information from the driver, call the rsrtm_ClearError function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''
        '''Numeric Range (in Hex) Status Code Types
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF VISA Warnings
        '''3FFC0000 to 3FFCFFFF VXIPnP Driver Warnings
        '''
        '''BFFF0000 to BFFFFFFF VISA Errors
        '''BFFC0000 to BFFCFFFF VXIPnP Driver Errors
        '''</returns>
        Public Function ConfigureUARTSource(ByVal Waveform_Source As Integer) As Integer
            Dim pInvokeResult As Integer = PInvoke.ConfigureUARTSource(Me._handle, Waveform_Source)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function selects whether transmitted data is high active (high = 1, Positive) or low active (low = 1, Negative).
        '''
        '''Attribute(s):
        '''RSRTM_ATTR_PROTOCOL_UART_POLARITY
        '''
        '''Remote-control command(s):
        '''BUS:UART:DATA:POLarity
        '''</summary>
        '''<param name="Polarity">
        '''Selects whether transmitted data is high active (high = 1, Positive) or low active (low = 1, Negative).
        '''
        '''Valid Values:
        '''RSRTM_VAL_POSITIVE (0) - Positive
        '''RSRTM_VAL_NEGATIVE (1) - Negative
        '''
        '''Default Value: RSRTM_VAL_POSITIVE (0)
        '''
        '''Attribute:
        '''RSRTM_ATTR_PROTOCOL_UART_POLARITY
        '''</param>
        '''<returns>
        '''Returns the status code of this operation.  The status code  either indicates success or describes an error or warning condition.  You examine the status code from each call to an instrument driver function to determine if an error occurred.
        '''
        '''To obtain a text description of the status code, call the rsrtm_error_message function.  To obtain additional information about the error condition, call the rsrtm_GetError function.  To clear the error information from the driver, call the rsrtm_ClearError function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''
        '''Numeric Range (in Hex) Status Code Types
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF VISA Warnings
        '''3FFC0000 to 3FFCFFFF VXIPnP Driver Warnings
        '''
        '''BFFF0000 to BFFFFFFF VISA Errors
        '''BFFC0000 to BFFCFFFF VXIPnP Driver Errors
        '''</returns>
        Public Function ConfigureUARTPolarity(ByVal Polarity As Integer) As Integer
            Dim pInvokeResult As Integer = PInvoke.ConfigureUARTPolarity(Me._handle, Polarity)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function configures the UART port.
        '''
        '''Attribute(s):
        '''RSRTM_ATTR_PROTOCOL_UART_INTERFRAME_TIME
        '''RSRTM_ATTR_PROTOCOL_UART_WORD_LENGTH
        '''RSRTM_ATTR_PROTOCOL_UART_BIT_RATE
        '''RSRTM_ATTR_PROTOCOL_UART_PARITY
        '''RSRTM_ATTR_PROTOCOL_UART_STOP_BITS
        '''
        '''Remote-control command(s):
        '''BUS:UART:BITime
        '''BUS:UART:SSIZe
        '''BUS:UART:BAUDrate
        '''BUS:UART:PARity
        '''BUS:UART:SBIT
        '''
        '''</summary>
        '''<param name="Interframe_time">
        '''This control configures the interframe time.
        '''
        '''Valid Values:
        '''12.8E-9 to 53.68E-3
        '''
        '''Default Value: 64E-9
        '''
        '''Attribute:
        '''RSRTM_ATTR_PROTOCOL_UART_INTERFRAME_TIME
        '''</param>
        '''<param name="Word_Length">
        '''Sets the number of bits in a word.
        '''
        '''Valid Values:  5 to 9
        '''
        '''Default Value: 8
        '''
        '''Attribute:
        '''RSRTM_ATTR_PROTOCOL_UART_WORD_LENGTH
        '''</param>
        '''<param name="Bit_Rate">
        '''Sets the number of transmitted bits per second.
        '''
        '''Valid Values: 1000 to 78100000
        '''
        '''Default Value: 115200
        '''
        '''Attribute:
        '''RSRTM_ATTR_PROTOCOL_UART_BIT_RATE
        '''</param>
        '''<param name="Parity">
        '''Selects the optional parity bit that is used for error detection.
        '''
        '''Valid Values: 
        '''RSRTM_VAL_UART_NONE  (0) - None
        '''RSRTM_VAL_UART_ODD   (1) - Odd
        '''RSRTM_VAL_UART_EVEN  (2) - Even
        '''
        '''Default Value: RSRTM_VAL_UART_NONE (0)
        '''
        '''Attribute:
        '''RSRTM_ATTR_PROTOCOL_UART_PARITY
        '''</param>
        '''<param name="Stop_bits">
        '''Selects the number of stop bits.
        '''
        '''Valid Values: 
        '''RSRTM_VAL_UART_B1   (0) - 1
        '''RSRTM_VAL_UART_B1_5 (1) - 1.5
        '''RSRTM_VAL_UART_B2   (2) - 2
        '''
        '''Default Value: RSRTM_VAL_UART_B1 (0)
        '''
        '''Attribute:
        '''RSRTM_ATTR_PROTOCOL_UART_STOP_BITS
        '''</param>
        '''<returns>
        '''Returns the status code of this operation.  The status code  either indicates success or describes an error or warning condition.  You examine the status code from each call to an instrument driver function to determine if an error occurred.
        '''
        '''To obtain a text description of the status code, call the rsrtm_error_message function.  To obtain additional information about the error condition, call the rsrtm_GetError function.  To clear the error information from the driver, call the rsrtm_ClearError function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''
        '''Numeric Range (in Hex) Status Code Types
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF VISA Warnings
        '''3FFC0000 to 3FFCFFFF VXIPnP Driver Warnings
        '''
        '''BFFF0000 to BFFFFFFF VISA Errors
        '''BFFC0000 to BFFCFFFF VXIPnP Driver Errors
        '''</returns>
        Public Function ConfigureUART(ByVal Interframe_time As Double, ByVal Word_Length As Integer, ByVal Bit_Rate As Integer, ByVal Parity As Integer, ByVal Stop_bits As Integer) As Integer
            Dim pInvokeResult As Integer = PInvoke.ConfigureUART(Me._handle, Interframe_time, Word_Length, Bit_Rate, Parity, Stop_bits)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function sets the trigger mode for UART/RS-232 interfaces.
        '''
        '''Attribute(s):
        '''RSRTM_ATTR_PROTOCOL_UART_TRIGGER_MODE
        '''
        '''Remote-control command(s):
        '''TRIGger:A:UART:MODE
        '''</summary>
        '''<param name="Mode">
        '''This control select trigger type.
        '''
        '''Valid Values: 
        '''RSRTM_VAL_UART_MODE_RTM_BURSTSTART (0) - Burst start
        '''RSRTM_VAL_UART_MODE_RTM_SBIT       (1) - Start bit
        '''RSRTM_VAL_UART_MODE_RTM_NTHS       (2) - n-th symbol
        '''RSRTM_VAL_UART_MODE_RTM_SYMB       (3) - Symbol
        '''RSRTM_VAL_UART_MODE_RTM_PATT       (4) - Pattern
        '''RSRTM_VAL_UART_MODE_RTM_PERR       (5) - Parity Error
        '''RSRTM_VAL_UART_MODE_RTM_FERR       (6) - Frame Error
        '''RSRTM_VAL_UART_MODE_RTM_BRE        (7) - Break
        '''
        '''Default Value: RSRTM_VAL_UART_MODE_RTM_SBIT (1)
        '''
        '''Attribute:
        '''RSRTM_ATTR_PROTOCOL_UART_TRIGGER_MODE
        '''</param>
        '''<returns>
        '''Returns the status code of this operation.  The status code  either indicates success or describes an error or warning condition.  You examine the status code from each call to an instrument driver function to determine if an error occurred.
        '''
        '''To obtain a text description of the status code, call the rsrtm_error_message function.  To obtain additional information about the error condition, call the rsrtm_GetError function.  To clear the error information from the driver, call the rsrtm_ClearError function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''
        '''Numeric Range (in Hex) Status Code Types
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF VISA Warnings
        '''3FFC0000 to 3FFCFFFF VXIPnP Driver Warnings
        '''
        '''BFFF0000 to BFFFFFFF VISA Errors
        '''BFFC0000 to BFFCFFFF VXIPnP Driver Errors
        '''</returns>
        Public Function ConfigureUARTTriggerType(ByVal Mode As Integer) As Integer
            Dim pInvokeResult As Integer = PInvoke.ConfigureUARTTriggerType(Me._handle, Mode)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function sets trigger pattern for UART/RS-232 interfaces.
        '''
        '''Attribute(s):
        '''RSRTM_ATTR_PROTOCOL_UART_TRIGGER_DATA_PATTERN
        '''RSRTM_ATTR_PROTOCOL_UART_TRIGGER_CONDITION_LENGTH
        '''RSRTM_ATTR_PROTOCOL_UART_TRIGGER_DATA_POSITION_INDEX_MIN
        '''
        '''Remote-control command(s):
        '''TRIGger:A:UART:PATTern
        '''TRIGger:A:UART:PLENgth
        '''TRIGger:A:UART:POFFset
        '''</summary>
        '''<param name="Pattern">
        '''This control defines the bit pattern as trigger condition.
        '''
        '''Valid Values:
        '''not checked
        '''
        '''Default Value:
        '''""
        '''
        '''Attribute:
        '''RSRTM_ATTR_PROTOCOL_UART_TRIGGER_DATA_PATTERN
        '''
        '''Note:
        '''(1) Characters 0, 1, and X are allowed, max 32 bits.
        '''</param>
        '''<param name="Pattern_Length">
        '''Defines how many symbols build up the serial pattern.
        '''
        '''Valid Values: 1 to 3
        '''
        '''Default Value: 1
        '''
        '''Attribute:
        '''RSRTM_ATTR_PROTOCOL_UART_TRIGGER_CONDITION_LENGTH
        '''</param>
        '''<param name="Pattern_Offset">
        '''Sets the number of symbols before the first symbol of the pattern.
        '''
        '''Valid Values: 0 to 4095
        '''
        '''Default Value: 0
        '''
        '''Attribute: 
        '''RSRTM_ATTR_PROTOCOL_UART_TRIGGER_DATA_POSITION_INDEX_MIN
        '''</param>
        '''<returns>
        '''Returns the status code of this operation.  The status code  either indicates success or describes an error or warning condition.  You examine the status code from each call to an instrument driver function to determine if an error occurred.
        '''
        '''To obtain a text description of the status code, call the rsrtm_error_message function.  To obtain additional information about the error condition, call the rsrtm_GetError function.  To clear the error information from the driver, call the rsrtm_ClearError function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''
        '''Numeric Range (in Hex) Status Code Types
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF VISA Warnings
        '''3FFC0000 to 3FFCFFFF VXIPnP Driver Warnings
        '''
        '''BFFF0000 to BFFFFFFF VISA Errors
        '''BFFC0000 to BFFCFFFF VXIPnP Driver Errors
        '''</returns>
        Public Function ConfigureUARTTriggerPattern(ByVal Pattern As String, ByVal Pattern_Length As Integer, ByVal Pattern_Offset As Integer) As Integer
            Dim pInvokeResult As Integer = PInvoke.ConfigureUARTTriggerPattern(Me._handle, Pattern, Pattern_Length, Pattern_Offset)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function configures the input channels for the data bit lines. The suffix &lt;m&gt; selects the bit line Bit0 to Bit3.
        '''
        '''Attribute(s):
        '''RSRTM_ATTR_PARALLEL_BUS_SOURCE
        '''
        '''Remote-control command(s):
        '''BUS:PARallel:DATA&lt;m&gt;:SOURce
        '''</summary>
        '''<param name="Bit">
        '''This control sets the input channel to which the corresponding bit line is connected.
        '''
        '''Valid Values:
        '''RSRTM_VAL_PARALLEL_BIT0 (0) - Bit 0
        '''RSRTM_VAL_PARALLEL_BIT1 (1) - Bit 1
        '''RSRTM_VAL_PARALLEL_BIT2 (2) - Bit 2
        '''RSRTM_VAL_PARALLEL_BIT3 (3) - Bit 3
        '''
        '''Default Value: RSRTM_VAL_PARALLEL_BIT0 (0)
        '''
        '''Attribute(s):
        '''-
        '''</param>
        '''<param name="Channel">
        '''This control selects the channel. 
        '''
        '''Valid Values:
        '''RSRTM_VAL_SOURCE_CH1 (1) - Channel 1
        '''RSRTM_VAL_SOURCE_CH2 (2) - Channel 2
        '''RSRTM_VAL_SOURCE_CH3 (3) - Channel 3
        '''RSRTM_VAL_SOURCE_CH4 (4) - Channel 4
        '''
        '''Default Value: RSRTM_VAL_SOURCE_CH1 (1)
        '''
        '''Attribute(s):
        '''RSRTM_ATTR_PARALLEL_BUS_SOURCE
        '''</param>
        '''<returns>
        '''Returns the status code of this operation.  The status code  either indicates success or describes an error or warning condition.  You examine the status code from each call to an instrument driver function to determine if an error occurred.
        '''
        '''To obtain a text description of the status code, call the rsrtm_error_message function.  To obtain additional information about the error condition, call the rsrtm_GetError function.  To clear the error information from the driver, call the rsrtm_ClearError function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''
        '''Numeric Range (in Hex) Status Code Types
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF VISA Warnings
        '''3FFC0000 to 3FFCFFFF VXIPnP Driver Warnings
        '''
        '''BFFF0000 to BFFFFFFF VISA Errors
        '''BFFC0000 to BFFCFFFF VXIPnP Driver Errors
        '''</returns>
        Public Function ConfigureParallelSource(ByVal Bit As Integer, ByVal Channel As Integer) As Integer
            Dim pInvokeResult As Integer = PInvoke.ConfigureParallelSource(Me._handle, Bit, Channel)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function sets the number of lines to be analyzed.
        '''
        '''Attribute(s):
        '''RSRTM_ATTR_PARALLEL_BUS_ANALYZED_LINES
        '''
        '''Remote-control command(s):
        '''BUS:PARallel:WIDTh
        '''</summary>
        '''<param name="Line">
        '''This control sets the number of lines to be analyzed.
        '''
        '''Valid Values:
        '''1 to 4
        '''
        '''Default Value: 4
        '''
        '''Attribute(s):
        '''RSRTM_ATTR_PARALLEL_BUS_ANALYZED_LINES
        '''</param>
        '''<returns>
        '''Returns the status code of this operation.  The status code  either indicates success or describes an error or warning condition.  You examine the status code from each call to an instrument driver function to determine if an error occurred.
        '''
        '''To obtain a text description of the status code, call the rsrtm_error_message function.  To obtain additional information about the error condition, call the rsrtm_GetError function.  To clear the error information from the driver, call the rsrtm_ClearError function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''
        '''Numeric Range (in Hex) Status Code Types
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF VISA Warnings
        '''3FFC0000 to 3FFCFFFF VXIPnP Driver Warnings
        '''
        '''BFFF0000 to BFFFFFFF VISA Errors
        '''BFFC0000 to BFFCFFFF VXIPnP Driver Errors
        '''</returns>
        Public Function ConfigureParallelAnalyzedLines(ByVal Line As Integer) As Integer
            Dim pInvokeResult As Integer = PInvoke.ConfigureParallelAnalyzedLines(Me._handle, Line)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function defines a destination file for the hardcopy output.
        '''
        '''Attribute(s):
        '''RSRTM_ATTR_HARDCOPY_SELECT_PRINTER
        '''RSRTM_ATTR_HARDCOPY_DEVICE_DESTINATION
        '''RSRTM_ATTR_HARDCOPY_DEVICE_ORIENTATION
        '''RSRTM_ATTR_HARDCOPY_COLOR_SCHEME
        '''RSRTM_ATTR_HARDCOPY_PAGE_SIZE
        '''
        '''Remote-control command(s):
        '''HCOPy:DESTination
        '''SYSTem:COMMunicate:PRINter:SELect
        '''HCOPy:PAGE:ORIentation&lt;Destination&gt;
        '''HCOPy:COLOR:SCHeme
        '''HCOPy:PAGE:SIZE &lt;Size&gt;
        '''</summary>
        '''<param name="Printer_Name">
        '''Selects a configured printer.
        '''
        '''Valid Values:
        '''not checked
        '''
        '''Default Value: ""
        '''
        '''Attribute:
        '''RSRTM_ATTR_HARDCOPY_SELECT_PRINTER
        '''
        '''Note(s):
        '''
        '''(1) Valid names are taken using function Hardcopy Get Printer List.
        '''
        '''</param>
        '''<param name="Page_Orientation">
        '''Defines the page orientation.
        '''
        '''Valid Values:
        '''RSRTM_VAL_HARDCOPY_ORIENTATION_PORTRAIT  (0) - Portrait
        '''RSRTM_VAL_HARDCOPY_ORIENTATION_LANDSCAPE (1) - Landscape
        '''
        '''Default Value: RSRTM_VAL_HARDCOPY_ORIENTATION_LANDSCAPE (1)
        '''
        '''Attribute:
        '''RSRTM_ATTR_HARDCOPY_DEVICE_ORIENTATION
        '''
        '''Note:
        '''
        '''(1)  This setting will be ignored for 
        '''Destination != RSRTM_VAL_HARDCOPY_DESTINATION_PRN (Printer).
        '''
        '''</param>
        '''<param name="Scheme">
        '''This control select the color mode.
        '''
        '''Valid Values: 
        '''RSRTM_VAL_SCHEME_COLOR    (0) - Color
        '''RSRTM_VAL_SCHEME_GRAY     (1) - Grayscale
        '''RSRTM_VAL_SCHEME_INVERTED (2) - Inverted
        '''
        '''Default Value: RSRTM_VAL_SCHEME_COLOR (0)
        '''
        '''Attribute:
        '''RSRTM_ATTR_HARDCOPY_COLOR_SCHEME
        '''</param>
        '''<param name="Size">
        '''Defines the page size.
        '''
        '''Valid Values:
        '''RSRTM_VAL_PAGE_A4 (0) - A4
        '''RSRTM_VAL_PAGE_A5 (1) - A5
        '''RSRTM_VAL_PAGE_B5 (2) - B5
        '''RSRTM_VAL_PAGE_B6 (3) - B6
        '''RSRTM_VAL_PAGE_EX (4) - EXEC
        '''
        '''Default Value: RSRTM_VAL_PAGE_A4 (0)
        '''
        '''Attribute:
        '''RSRTM_ATTR_HARDCOPY_PAGE_SIZE
        '''</param>
        '''<returns>
        '''Returns the status code of this operation.  The status code  either indicates success or describes an error or warning condition.  You examine the status code from each call to an instrument driver function to determine if an error occurred.
        '''
        '''To obtain a text description of the status code, call the rsrtm_error_message function.  To obtain additional information about the error condition, call the rsrtm_GetError function.  To clear the error information from the driver, call the rsrtm_ClearError function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''
        '''Numeric Range (in Hex) Status Code Types
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF VISA Warnings
        '''3FFC0000 to 3FFCFFFF VXIPnP Driver Warnings
        '''
        '''BFFF0000 to BFFFFFFF VISA Errors
        '''BFFC0000 to BFFCFFFF VXIPnP Driver Errors
        '''</returns>
        Public Function ConfigureHardcopyPrinter(ByVal Printer_Name As String, ByVal Page_Orientation As Integer, ByVal Scheme As Integer, ByVal Size As Integer) As Integer
            Dim pInvokeResult As Integer = PInvoke.ConfigureHardcopyPrinter(Me._handle, Printer_Name, Page_Orientation, Scheme, Size)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function defines a destination file for the hardcopy output.
        '''
        '''Attribute(s):
        '''RSRTM_ATTR_HARDCOPY_DEVICE_DESTINATION
        '''RSRTM_ATTR_HARDCOPY_FILE_NAME
        '''RSRTM_ATTR_HARDCOPY_DEVICE_LANGUAGE_OUTPUT_FORMAT
        '''RSRTM_ATTR_HARDCOPY_COLOR_SCHEME
        '''
        '''Remote-control command(s):
        '''HCOPy:DESTination&lt;Destination&gt;
        '''MMEMory:NAME
        '''HCOPy:LANGuage
        '''HCOPy:COLOR:SCHeme
        '''</summary>
        '''<param name="Name">
        '''Defines the file name when an image of the display is stored to a file rather than printed to a printer using the HCOPy:IMMediate command.
        '''
        '''Valid Values:
        '''not checked
        '''
        '''Default Value: "D:\\output"
        '''
        '''Attribute:
        '''RSRTM_ATTR_HARDCOPY_FILE_NAME
        '''
        '''Note(s):
        '''(1) This value has effect only for file output (PNG, JPG, BMP, TIFF)
        '''
        '''(2) If no file extension is set, the appropriate suffix will be set automatically. Suffix depends on file type set in rsspecan_ConfigureHardcopyDevice (Destination)
        '''</param>
        '''<param name="Format">
        '''Defines the output associated with device configuration.
        '''
        '''Valid Values:
        '''RSRTM_VAL_HARDCOPY_DEVICE_LANG_PNG  (0) - PNG
        '''RSRTM_VAL_HARDCOPY_DEVICE_LANG_BMP  (1) - BMP
        '''
        '''Default Value: 0
        '''
        '''Attribute:
        '''RSRTM_ATTR_HARDCOPY_DEVICE_LANGUAGE_OUTPUT_FORMAT
        '''
        '''Note(s):
        '''
        '''(1) PNG - Directs the hardcopy to a file and sets the format to PNG
        '''
        '''(2) Bitmap - Directs the hardcopy to a file and sets the format to bitmap
        '''</param>
        '''<param name="Scheme">
        '''This control select the color mode.
        '''
        '''Valid Values: 
        '''RSRTM_VAL_SCHEME_COLOR    (0) - Color
        '''RSRTM_VAL_SCHEME_GRAY     (1) - Grayscale
        '''RSRTM_VAL_SCHEME_INVERTED (2) - Inverted
        '''
        '''Default Value: RSRTM_VAL_SCHEME_COLOR (0)
        '''
        '''Attribute:
        '''RSRTM_ATTR_HARDCOPY_COLOR_SCHEME
        '''</param>
        '''<returns>
        '''Returns the status code of this operation.  The status code  either indicates success or describes an error or warning condition.  You examine the status code from each call to an instrument driver function to determine if an error occurred.
        '''
        '''To obtain a text description of the status code, call the rsrtm_error_message function.  To obtain additional information about the error condition, call the rsrtm_GetError function.  To clear the error information from the driver, call the rsrtm_ClearError function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''
        '''Numeric Range (in Hex) Status Code Types
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF VISA Warnings
        '''3FFC0000 to 3FFCFFFF VXIPnP Driver Warnings
        '''
        '''BFFF0000 to BFFFFFFF VISA Errors
        '''BFFC0000 to BFFCFFFF VXIPnP Driver Errors
        '''</returns>
        Public Function ConfigureHardcopyFile(ByVal Name As String, ByVal Format As Integer, ByVal Scheme As Integer) As Integer
            Dim pInvokeResult As Integer = PInvoke.ConfigureHardcopyFile(Me._handle, Name, Format, Scheme)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function prints an image of the display to the printer or saves an image to a file or the clipboard.
        '''
        '''Attribute(s):
        '''RSRTM_ATTR_HARDCOPY_PRINT
        '''
        '''Remote-control command(s):
        '''HCOPy:IMMediate
        '''</summary>
        '''<returns>
        '''Returns the status code of this operation.  The status code  either indicates success or describes an error or warning condition.  You examine the status code from each call to an instrument driver function to determine if an error occurred.
        '''
        '''To obtain a text description of the status code, call the rsrtm_error_message function.  To obtain additional information about the error condition, call the rsrtm_GetError function.  To clear the error information from the driver, call the rsrtm_ClearError function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''
        '''Numeric Range (in Hex) Status Code Types
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF VISA Warnings
        '''3FFC0000 to 3FFCFFFF VXIPnP Driver Warnings
        '''
        '''BFFF0000 to BFFFFFFF VISA Errors
        '''BFFC0000 to BFFCFFFF VXIPnP Driver Errors
        '''</returns>
        Public Function HardcopyPrint() As Integer
            Dim pInvokeResult As Integer = PInvoke.HardcopyPrint(Me._handle)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function queries the list of printers under Windows.
        '''
        '''Attribute(s):
        '''RSRTM_ATTR_HARDCOPY_GET_FIRST_PRINTER
        '''RSRTM_ATTR_HARDCOPY_GET_NEXT_PRINTER
        '''
        '''Remote-control command(s):
        '''SYSTem:COMMunicate:PRINter:ENUMerate:FIRSt?
        '''SYSTem:COMMunicate:PRINter:ENUMerate[:NEXT]?
        '''</summary>
        '''<param name="Buffer_Size">
        '''This control indicates the allocated memory in Printer List.
        '''If not enought memory is allocated, function returns the warning in status code.
        '''
        '''Valid Values:
        '''&gt; 0
        '''
        '''Default Value: 512
        '''</param>
        '''<param name="Printer_List">
        '''This control returns list of printers available under  Windows NT system. Names are separated using commas (,).
        '''
        '''Note:
        '''
        '''If no printer is configured an empty string is output.
        '''
        '''</param>
        '''<returns>
        '''Returns the status code of this operation.  The status code  either indicates success or describes an error or warning condition.  You examine the status code from each call to an instrument driver function to determine if an error occurred.
        '''
        '''To obtain a text description of the status code, call the rsrtm_error_message function.  To obtain additional information about the error condition, call the rsrtm_GetError function.  To clear the error information from the driver, call the rsrtm_ClearError function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''
        '''Numeric Range (in Hex) Status Code Types
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF VISA Warnings
        '''3FFC0000 to 3FFCFFFF VXIPnP Driver Warnings
        '''
        '''BFFF0000 to BFFFFFFF VISA Errors
        '''BFFC0000 to BFFCFFFF VXIPnP Driver Errors
        '''</returns>
        Public Function HardcopyGetPrinterList(ByVal Buffer_Size As Integer, ByVal Printer_List As System.Text.StringBuilder) As Integer
            Dim pInvokeResult As Integer = PInvoke.HardcopyGetPrinterList(Me._handle, Buffer_Size, Printer_List)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''Enables the math waveform display.
        '''
        '''Attribute(s):
        '''RSRTM_ATTR_MATH_WAVEFORM_ENABLED
        '''
        '''Remote-control command(s):
        '''CALCulate:MATH&lt;Math&gt;:STATe
        '''</summary>
        '''<param name="Math_Number">
        '''Selects the math waveform.
        '''
        '''Valid Values:
        '''1 to 4
        '''
        '''Default Value: 1
        '''</param>
        '''<param name="Math_Enabled">
        '''Enables the math waveform display.
        '''
        '''Valid Values:
        '''VI_FALSE (0) - Off
        '''VI_TRUE  (1) - On
        '''
        '''Default Value: VI_FALSE (0)
        '''
        '''Attribute:
        '''RSRTM_ATTR_MATH_WAVEFORM_ENABLED
        '''</param>
        '''<returns>
        '''Returns the status code of this operation.  The status code  either indicates success or describes an error or warning condition.  You examine the status code from each call to an instrument driver function to determine if an error occurred.
        '''
        '''To obtain a text description of the status code, call the rsrtm_error_message function.  To obtain additional information about the error condition, call the rsrtm_GetError function.  To clear the error information from the driver, call the rsrtm_ClearError function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''
        '''Numeric Range (in Hex) Status Code Types
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF VISA Warnings
        '''3FFC0000 to 3FFCFFFF VXIPnP Driver Warnings
        '''
        '''BFFF0000 to BFFFFFFF VISA Errors
        '''BFFC0000 to BFFCFFFF VXIPnP Driver Errors
        '''</returns>
        Public Function ConfigureMathEnabled(ByVal Math_Number As Integer, ByVal Math_Enabled As Boolean) As Integer
            Dim pInvokeResult As Integer = PInvoke.ConfigureMathEnabled(Me._handle, Math_Number, System.Convert.ToUInt16(Math_Enabled))
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function sets the vertical position of the specified math waveform in the window.
        '''
        '''Attribute(s):
        '''RSRTM_ATTR_MATH_WAVEFORM_POSITION
        '''
        '''Remote-control command(s):
        '''CALCulate:MATH&lt;m&gt;:POSition
        '''</summary>
        '''<param name="Math_Number">
        '''Selects the math waveform.
        '''
        '''Valid Values:
        '''1 to 4
        '''
        '''Default Value: 1
        '''</param>
        '''<param name="Waveform_Position">
        '''Sets the vertical position of the specified math waveform in the window.
        '''
        '''Valid Values:
        '''-1.880E+02 to 2.120E+02
        '''
        '''Default Value: 0.0
        '''
        '''Attribute:
        '''RSRTM_ATTR_MATH_WAVEFORM_POSITION
        '''</param>
        '''<returns>
        '''Returns the status code of this operation.  The status code  either indicates success or describes an error or warning condition.  You examine the status code from each call to an instrument driver function to determine if an error occurred.
        '''
        '''To obtain a text description of the status code, call the rsrtm_error_message function.  To obtain additional information about the error condition, call the rsrtm_GetError function.  To clear the error information from the driver, call the rsrtm_ClearError function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''
        '''Numeric Range (in Hex) Status Code Types
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF VISA Warnings
        '''3FFC0000 to 3FFCFFFF VXIPnP Driver Warnings
        '''
        '''BFFF0000 to BFFFFFFF VISA Errors
        '''BFFC0000 to BFFCFFFF VXIPnP Driver Errors
        '''</returns>
        Public Function ConfigureMathWaveformPosition(ByVal Math_Number As Integer, ByVal Waveform_Position As Double) As Integer
            Dim pInvokeResult As Integer = PInvoke.ConfigureMathWaveformPosition(Me._handle, Math_Number, Waveform_Position)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function sets the vertical scale for the specified math waveform.
        '''
        '''
        '''Attribute(s):
        '''RSRTM_ATTR_MATH_VERTICAL_SCALE
        '''
        '''Remote-control command(s):
        '''CALCulate:MATH&lt;m&gt;:SCALe
        '''</summary>
        '''<param name="Math_Number">
        '''Selects the math waveform.
        '''
        '''Valid Values:
        '''1 to 4
        '''
        '''Default Value: 1
        '''</param>
        '''<param name="Vertical_Scale">
        '''Sets the vertical scale for the specified math waveform.
        '''
        '''Valid Values:
        '''-1.0E-24 to 5.0E+25
        '''
        '''Default Value: 1.0
        '''
        '''Attribute:
        '''RSRTM_ATTR_MATH_VERTICAL_SCALE
        '''</param>
        '''<returns>
        '''Returns the status code of this operation.  The status code  either indicates success or describes an error or warning condition.  You examine the status code from each call to an instrument driver function to determine if an error occurred.
        '''
        '''To obtain a text description of the status code, call the rsrtm_error_message function.  To obtain additional information about the error condition, call the rsrtm_GetError function.  To clear the error information from the driver, call the rsrtm_ClearError function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''
        '''Numeric Range (in Hex) Status Code Types
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF VISA Warnings
        '''3FFC0000 to 3FFCFFFF VXIPnP Driver Warnings
        '''
        '''BFFF0000 to BFFFFFFF VISA Errors
        '''BFFC0000 to BFFCFFFF VXIPnP Driver Errors
        '''</returns>
        Public Function ConfigureMathScaling(ByVal Math_Number As Integer, ByVal Vertical_Scale As Double) As Integer
            Dim pInvokeResult As Integer = PInvoke.ConfigureMathScaling(Me._handle, Math_Number, Vertical_Scale)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''Configures general mathematics parameters.
        '''
        '''Attribute(s):
        '''RSRTM_ATTR_MATH_ACQUISITION_TYPE
        '''RSRTM_ATTR_MATH_EXPRESSION
        '''
        '''Remote-control command(s):
        '''CALCulate:MATH&lt;Math&gt;[:EXPRession][:DEFine]
        '''CALCulate:MATH&lt;Math&gt;:ARIThmetics
        '''</summary>
        '''<param name="Math_Number">
        '''Selects the math waveform.
        '''
        '''Valid Values:
        '''1 to 4
        '''
        '''Default Value: 1
        '''</param>
        '''<param name="Calculation_Method">
        '''Selects the method to build the resulting math waveform from consecutive acquisitions. The processing is similar to the waveform arithmetics - instead of the acquired waveforms the math waveforms are used to create envelope and average.
        '''
        '''Valid Values:
        '''RSRTM_VAL_OFF      (0) - Off
        '''RSRTM_VAL_ENVELOPE (1) - Envelope
        '''RSRTM_VAL_AVERAGE  (2) - Average
        '''
        '''
        '''Default Value: RSRTM_VAL_OFF (0)
        '''
        '''Attribute:
        '''RSRTM_ATTR_MATH_ACQUISITION_TYPE
        '''
        '''Note(s):
        '''
        '''(1) Off: The data of the current acquisition is recorded according to the decimation settings.
        '''
        '''(2) Envelope: Detects the minimum and maximum values in an sample interval over a number of acquisitions.
        '''
        '''(3) Average: Calculates the average from the data of the current acquisition and a number of acquisitions before.
        '''</param>
        '''<param name="Expression">
        '''Defines the math expression to be calculated for the specified math channel.
        '''
        '''Valid Values:
        '''not checked
        '''
        '''Default Value: ""
        '''
        '''Attribute:
        '''RSRTM_ATTR_MATH_EXPRESSION
        '''</param>
        '''<returns>
        '''Returns the status code of this operation.  The status code  either indicates success or describes an error or warning condition.  You examine the status code from each call to an instrument driver function to determine if an error occurred.
        '''
        '''To obtain a text description of the status code, call the rsrtm_error_message function.  To obtain additional information about the error condition, call the rsrtm_GetError function.  To clear the error information from the driver, call the rsrtm_ClearError function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''
        '''Numeric Range (in Hex) Status Code Types
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF VISA Warnings
        '''3FFC0000 to 3FFCFFFF VXIPnP Driver Warnings
        '''
        '''BFFF0000 to BFFFFFFF VISA Errors
        '''BFFC0000 to BFFCFFFF VXIPnP Driver Errors
        '''</returns>
        Public Function ConfigureMathSetup(ByVal Math_Number As Integer, ByVal Calculation_Method As Integer, ByVal Expression As String) As Integer
            Dim pInvokeResult As Integer = PInvoke.ConfigureMathSetup(Me._handle, Math_Number, Calculation_Method, Expression)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''Defines the frequency range by means of center frequency and frequency span.
        '''
        '''Attribute(s):
        '''RSRTM_ATTR_FFT_CENTER_FREQUENCY
        '''RSRTM_ATTR_FFT_FREQUENCY_SPAN
        '''
        '''Remote-control command(s):
        '''CALCulate:MATH&lt;Math&gt;:FFT:CFRequency
        '''CALCulate:MATH&lt;Math&gt;:FFT:SPAN
        '''</summary>
        '''<param name="Math_Number">
        '''Selects the math waveform.
        '''
        '''Valid Values:
        '''1 to 4
        '''
        '''Default Value: 1
        '''</param>
        '''<param name="Center_Frequency">
        '''Defines the position of the displayed frequency range, which is (Center - Span/2) to (Center + Span/2).
        '''
        '''Valid Values:
        '''0 to 2e12
        '''
        '''Default Value: 500e6 Hz
        '''
        '''Attribute:
        '''RSRTM_ATTR_FFT_CENTER_FREQUENCY
        '''</param>
        '''<param name="Frequency_Span">
        '''Defines the stop frequency of the displayed frequency span.
        '''
        '''Valid Values:
        '''10000 to 4e12
        '''
        '''Default Value: 1e9 Hz
        '''
        '''Attribute:
        '''RSRTM_ATTR_FFT_STOP_FREQUENCY
        '''</param>
        '''<returns>
        '''Returns the status code of this operation.  The status code  either indicates success or describes an error or warning condition.  You examine the status code from each call to an instrument driver function to determine if an error occurred.
        '''
        '''To obtain a text description of the status code, call the rsrtm_error_message function.  To obtain additional information about the error condition, call the rsrtm_GetError function.  To clear the error information from the driver, call the rsrtm_ClearError function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''
        '''Numeric Range (in Hex) Status Code Types
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF VISA Warnings
        '''3FFC0000 to 3FFCFFFF VXIPnP Driver Warnings
        '''
        '''BFFF0000 to BFFFFFFF VISA Errors
        '''BFFC0000 to BFFCFFFF VXIPnP Driver Errors
        '''</returns>
        Public Function ConfigureFFTFrequencyCenterSpan(ByVal Math_Number As Integer, ByVal Center_Frequency As Double, ByVal Frequency_Span As Double) As Integer
            Dim pInvokeResult As Integer = PInvoke.ConfigureFFTFrequencyCenterSpan(Me._handle, Math_Number, Center_Frequency, Frequency_Span)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''Performs FFT calculation for the full frequency span.
        '''
        '''Attribute(s):
        '''RSRTM_ATTR_FFT_FULL_SPAN
        '''
        '''Remote-control command(s):
        '''CALCulate:MATH&lt;Math&gt;:FFT:FULLspan
        '''</summary>
        '''<param name="Math_Number">
        '''Selects the math waveform.
        '''
        '''Valid Values:
        '''1 to 4
        '''
        '''Default Value: 1
        '''</param>
        '''<returns>
        '''Returns the status code of this operation.  The status code  either indicates success or describes an error or warning condition.  You examine the status code from each call to an instrument driver function to determine if an error occurred.
        '''
        '''To obtain a text description of the status code, call the rsrtm_error_message function.  To obtain additional information about the error condition, call the rsrtm_GetError function.  To clear the error information from the driver, call the rsrtm_ClearError function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''
        '''Numeric Range (in Hex) Status Code Types
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF VISA Warnings
        '''3FFC0000 to 3FFCFFFF VXIPnP Driver Warnings
        '''
        '''BFFF0000 to BFFFFFFF VISA Errors
        '''BFFC0000 to BFFCFFFF VXIPnP Driver Errors
        '''</returns>
        Public Function ConfigureFFTFrequencySpanFull(ByVal Math_Number As Integer) As Integer
            Dim pInvokeResult As Integer = PInvoke.ConfigureFFTFrequencySpanFull(Me._handle, Math_Number)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''Defines the frequency range by means of start and stop frequency.
        '''
        '''Attribute(s):
        '''RSRTM_ATTR_FFT_START_FREQUENCY
        '''RSRTM_ATTR_FFT_STOP_FREQUENCY
        '''
        '''Remote-control command(s):
        '''CALCulate:MATH&lt;Math&gt;:FFT:STOP
        '''CALCulate:MATH&lt;Math&gt;:FFT:STARt
        '''</summary>
        '''<param name="Math_Number">
        '''Selects the math waveform.
        '''
        '''Valid Values:
        '''1 to 4
        '''
        '''Default Value: 1
        '''</param>
        '''<param name="Start_Frequency">
        '''Defines the start frequency of the displayed frequency span.
        '''
        '''Valid Values: 0.0 to 20.0e9 Hz
        '''
        '''Default Value: 2.499e6
        '''
        '''Attribute:
        '''RSRTM_ATTR_FFT_START_FREQUENCY
        '''</param>
        '''<param name="Stop_Frequency">
        '''Defines the stop frequency of the displayed frequency span.
        '''
        '''Valid Values: 0.0 to 20.0e9 Hz
        '''
        '''Default Value: 4.999e6 Hz
        '''
        '''Attribute:
        '''RSRTM_ATTR_FFT_STOP_FREQUENCY
        '''</param>
        '''<returns>
        '''Returns the status code of this operation.  The status code  either indicates success or describes an error or warning condition.  You examine the status code from each call to an instrument driver function to determine if an error occurred.
        '''
        '''To obtain a text description of the status code, call the rsrtm_error_message function.  To obtain additional information about the error condition, call the rsrtm_GetError function.  To clear the error information from the driver, call the rsrtm_ClearError function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''
        '''Numeric Range (in Hex) Status Code Types
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF VISA Warnings
        '''3FFC0000 to 3FFCFFFF VXIPnP Driver Warnings
        '''
        '''BFFF0000 to BFFFFFFF VISA Errors
        '''BFFC0000 to BFFCFFFF VXIPnP Driver Errors
        '''</returns>
        Public Function ConfigureFFTFrequencyStartStop(ByVal Math_Number As Integer, ByVal Start_Frequency As Double, ByVal Stop_Frequency As Double) As Integer
            Dim pInvokeResult As Integer = PInvoke.ConfigureFFTFrequencyStartStop(Me._handle, Math_Number, Start_Frequency, Stop_Frequency)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''Defines the FFT frame.
        '''
        '''Attribute(s):
        '''RSRTM_ATTR_FFT_RESOLUTION_BANDWIDTH_COUPLING_ENABLED
        '''RSRTM_ATTR_FFT_RESOLUTION_BANDWIDTH_RATIO
        '''RSRTM_ATTR_FFT_RESOLUTION_BANDWIDTH
        '''
        '''Remote-control command(s):
        '''CALCulate:MATH&lt;Math&gt;:FFT:BANDwidth[:RESolution]:AUTO
        '''CALCulate:MATH&lt;Math&gt;:FFT:BANDwidth[:RESolution]:RATio
        '''CALCulate:MATH&lt;Math&gt;:FFT:BANDwidth[:RESolution][:VALue]
        '''</summary>
        '''<param name="Math_Number">
        '''Selects the math waveform.
        '''
        '''Valid Values:
        '''1 to 4
        '''
        '''Default Value: 1
        '''</param>
        '''<param name="RBW_and_Span_Coupling_Enabled">
        '''Couples the frequency span to the RBW.
        '''
        '''Valid Values:
        '''VI_FALSE (0) - Off
        '''VI_TRUE  (1) - On
        '''
        '''Default Value: VI_TRUE (1)
        '''
        '''Attribute:
        '''RSRTM_ATTR_FFT_RESOLUTION_BANDWIDTH_COUPLING_ENABLED
        '''</param>
        '''<param name="RBW_Ratio">
        '''Defines the ratio resolution bandwidth (Hz) / span (Hz).
        '''
        '''Valid Values:
        '''1 to 32768
        '''
        '''Default Value: 100
        '''
        '''Attribute:
        '''RSRTM_ATTR_FFT_RESOLUTION_BANDWIDTH_RATIO
        '''
        '''Note(s):
        '''
        '''(1) This control is valid only if coupling is enabled.
        '''(2) RTO instrument - maximum value is 1000.
        '''(3) RTM instrument - minimum value is 1024.
        '''</param>
        '''<param name="Resolution_Bandwidth">
        '''Defines the resolution bandwidth.
        '''
        '''Valid Values:
        '''1.0E+002 to 2.0E+006 Hz
        '''
        '''Default Value: 2.0E+6 Hz
        '''
        '''Attribute:
        '''RSRTM_ATTR_FFT_RESOLUTION_BANDWIDTH
        '''
        '''Note(s):
        '''
        '''(1) This control is valid only if coupling is disabled.
        '''</param>
        '''<returns>
        '''Returns the status code of this operation.  The status code  either indicates success or describes an error or warning condition.  You examine the status code from each call to an instrument driver function to determine if an error occurred.
        '''
        '''To obtain a text description of the status code, call the rsrtm_error_message function.  To obtain additional information about the error condition, call the rsrtm_GetError function.  To clear the error information from the driver, call the rsrtm_ClearError function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''
        '''Numeric Range (in Hex) Status Code Types
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF VISA Warnings
        '''3FFC0000 to 3FFCFFFF VXIPnP Driver Warnings
        '''
        '''BFFF0000 to BFFFFFFF VISA Errors
        '''BFFC0000 to BFFCFFFF VXIPnP Driver Errors
        '''</returns>
        Public Function ConfigureFFTResolutionBandwidth(ByVal Math_Number As Integer, ByVal RBW_and_Span_Coupling_Enabled As Boolean, ByVal RBW_Ratio As Integer, ByVal Resolution_Bandwidth As Double) As Integer
            Dim pInvokeResult As Integer = PInvoke.ConfigureFFTResolutionBandwidth(Me._handle, Math_Number, System.Convert.ToUInt16(RBW_and_Span_Coupling_Enabled), RBW_Ratio, Resolution_Bandwidth)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''Queries the effective resolution bandwidth.
        '''
        '''Attribute(s):
        '''RSRTM_ATTR_FFT_EFFECTIVE_RESOLUTION_BANDWIDTH
        '''
        '''Remote-control command(s):
        '''CALCulate:MATH&lt;Math&gt;:FFT:BANDwidth[:RESolution]:ADJusted?
        '''</summary>
        '''<param name="Math_Number">
        '''Selects the math waveform.
        '''
        '''Valid Values:
        '''1 to 4
        '''
        '''Default Value: 1
        '''</param>
        '''<param name="Adjusted_RBW">
        '''Queries the effective resolution bandwidth.
        '''
        '''Attribute:
        '''RSRTM_ATTR_FFT_EFFECTIVE_RESOLUTION_BANDWIDTH
        '''</param>
        '''<returns>
        '''Returns the status code of this operation.  The status code  either indicates success or describes an error or warning condition.  You examine the status code from each call to an instrument driver function to determine if an error occurred.
        '''
        '''To obtain a text description of the status code, call the rsrtm_error_message function.  To obtain additional information about the error condition, call the rsrtm_GetError function.  To clear the error information from the driver, call the rsrtm_ClearError function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''
        '''Numeric Range (in Hex) Status Code Types
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF VISA Warnings
        '''3FFC0000 to 3FFCFFFF VXIPnP Driver Warnings
        '''
        '''BFFF0000 to BFFFFFFF VISA Errors
        '''BFFC0000 to BFFCFFFF VXIPnP Driver Errors
        '''</returns>
        Public Function QueryFFTAdjustedResolutionBandwidth(ByVal Math_Number As Integer, ByRef Adjusted_RBW As Double) As Integer
            Dim pInvokeResult As Integer = PInvoke.QueryFFTAdjustedResolutionBandwidth(Me._handle, Math_Number, Adjusted_RBW)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''Defines the FFT window.
        '''
        '''Attribute(s):
        '''RSRTM_ATTR_FFT_WINDOW_TYPE
        '''
        '''Remote-control command(s):
        '''CALCulate:MATH&lt;Math&gt;:FFT:WINDow:TYPE
        '''</summary>
        '''<param name="Math_Number">
        '''Selects the math waveform.
        '''
        '''Valid Values:
        '''1 to 4
        '''
        '''Default Value: 1
        '''</param>
        '''<param name="Window_Type">
        '''Windowing helps minimize the discontinuities at the end of the measured signal interval and thus reduces the effect of spectral leakage, increasing the frequency resolution.
        '''Various different window functions are provided in the R&amp;S RTM to suit different input signals. Each of the window functions has specific characteristics, including some advantages and some trade-offs. These characteristics need to be considered carefully to find the optimum solution for the measurement task.
        '''
        '''Valid Values:
        '''RSRTM_VAL_RECTANGULAR (0) - Rectangular
        '''RSRTM_VAL_HAMMING     (1) - Hamming
        '''RSRTM_VAL_HANN        (2) - Hann
        '''RSRTM_VAL_BLACKMAN    (3) - Blackman
        '''
        '''Default Value: RSRTM_VAL_BLACKMAN (3)
        '''
        '''Attribute:
        '''RSRTM_ATTR_FFT_WINDOW_TYPE
        '''
        '''Note(s):
        '''
        '''(1) Rectangular: The rectangular window has the best frequency resolution, but a poor amplitude accuracy and is recommended for separating two tones with almost equal amplitudes and a small frequency distance.
        '''
        '''(2) Hamming: The Hamming window is bell shaped and has a good frequency resolution and fair amplitude accuracy. It is recommended for frequency response measurements as well as sine waves, periodic signals and narrow-band noise
        '''
        '''(3) Hann: The Hann window is bell shaped and has a slightly worse frequency resolution but smaller sidelobe level than the Hamming window. The applications are the same.
        '''
        '''(4) Blackman: The Blackman window is bell shaped and has a poor frequency resolution, but very good amplitude accuracy. It is recommended mainly for signals with single frequencies to detect harmonics.
        '''</param>
        '''<returns>
        '''Returns the status code of this operation.  The status code  either indicates success or describes an error or warning condition.  You examine the status code from each call to an instrument driver function to determine if an error occurred.
        '''
        '''To obtain a text description of the status code, call the rsrtm_error_message function.  To obtain additional information about the error condition, call the rsrtm_GetError function.  To clear the error information from the driver, call the rsrtm_ClearError function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''
        '''Numeric Range (in Hex) Status Code Types
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF VISA Warnings
        '''3FFC0000 to 3FFCFFFF VXIPnP Driver Warnings
        '''
        '''BFFF0000 to BFFFFFFF VISA Errors
        '''BFFC0000 to BFFCFFFF VXIPnP Driver Errors
        '''</returns>
        Public Function ConfigureFFTWindowType(ByVal Math_Number As Integer, ByVal Window_Type As Integer) As Integer
            Dim pInvokeResult As Integer = PInvoke.ConfigureFFTWindowType(Me._handle, Math_Number, Window_Type)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''Defines the number of spectrums used for averaging if CALCulate: MATH&lt;m&gt;:ARIThmetics is set to AVERage.
        '''
        '''Attribute(s):
        '''RSRTM_ATTR_FFT_AVERAGING
        '''
        '''Remote-control command(s):
        '''CALCulate:MATH&lt;Math&gt;:FFT:AVERage:COUNt
        '''</summary>
        '''<param name="Math_Number">
        '''Selects the math waveform.
        '''
        '''Valid Values:
        '''1 to 4
        '''
        '''Default Value: 1
        '''</param>
        '''<param name="Number_Of_Spectrums">
        '''Defines the number of spectrums used for averaging.
        '''
        '''Valid Values:
        '''2 to 512
        '''
        '''Default Value: 2
        '''
        '''Attribute:
        '''RSRTM_ATTR_FFT_AVERAGING
        '''</param>
        '''<returns>
        '''Returns the status code of this operation.  The status code  either indicates success or describes an error or warning condition.  You examine the status code from each call to an instrument driver function to determine if an error occurred.
        '''
        '''To obtain a text description of the status code, call the rsrtm_error_message function.  To obtain additional information about the error condition, call the rsrtm_GetError function.  To clear the error information from the driver, call the rsrtm_ClearError function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''
        '''Numeric Range (in Hex) Status Code Types
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF VISA Warnings
        '''3FFC0000 to 3FFCFFFF VXIPnP Driver Warnings
        '''
        '''BFFF0000 to BFFFFFFF VISA Errors
        '''BFFC0000 to BFFCFFFF VXIPnP Driver Errors
        '''</returns>
        Public Function ConfigureFFTAveraging(ByVal Math_Number As Integer, ByVal Number_Of_Spectrums As Integer) As Integer
            Dim pInvokeResult As Integer = PInvoke.ConfigureFFTAveraging(Me._handle, Math_Number, Number_Of_Spectrums)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function defines the scaling unit and sets the vertical scale for the specified math waveform.
        '''
        '''
        '''Attribute(s):
        '''RSRTM_ATTR_FFT_SCALING_UNIT
        '''RSRTM_ATTR_MATH_VERTICAL_SCALE
        '''
        '''Remote-control command(s):
        '''CALCulate:MATH&lt;m&gt;:FFT:MAGNitude:SCALe
        '''CALCulate:MATH&lt;m&gt;:SCALe
        '''</summary>
        '''<param name="Math_Number">
        '''Selects the math waveform.
        '''
        '''Valid Values:
        '''1 to 4
        '''
        '''Default Value: 1
        '''</param>
        '''<param name="Scaling_Unit">
        '''Defines the scaling unit of the y-axis.
        '''
        '''Valid Values:
        '''RSRTM_VAL_FFT_LIN (0) - Linear
        '''RSRTM_VAL_FFT_DBM (1) - DBM
        '''RSRTM_VAL_FFT_DBV (2) - DBV
        '''
        '''
        '''Default Value: RSRTM_VAL_FFT_DBM (1)
        '''
        '''Attribute:
        '''RSRTM_ATTR_FFT_SCALING_UNIT
        '''
        '''Note(s):
        '''
        '''(1) Linear: linear scaling; displays the RMS value of the voltage.
        '''
        '''(2) DBM: logarithmic scaling; related to 1 mW
        '''
        '''(3) DBV: logarithmic scaling; related to 1 Veff
        '''
        '''</param>
        '''<param name="Vertical_Scale">
        '''Sets the vertical scale for the specified math waveform.
        '''
        '''Valid Values:
        '''-1.0E-24 to 5.0E+25
        '''
        '''Default Value: 1
        '''
        '''Attribute:
        '''RSRTM_ATTR_MATH_VERTICAL_SCALE
        '''</param>
        '''<returns>
        '''Returns the status code of this operation.  The status code  either indicates success or describes an error or warning condition.  You examine the status code from each call to an instrument driver function to determine if an error occurred.
        '''
        '''To obtain a text description of the status code, call the rsrtm_error_message function.  To obtain additional information about the error condition, call the rsrtm_GetError function.  To clear the error information from the driver, call the rsrtm_ClearError function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''
        '''Numeric Range (in Hex) Status Code Types
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF VISA Warnings
        '''3FFC0000 to 3FFCFFFF VXIPnP Driver Warnings
        '''
        '''BFFF0000 to BFFFFFFF VISA Errors
        '''BFFC0000 to BFFCFFFF VXIPnP Driver Errors
        '''</returns>
        Public Function ConfigureFFTScaling(ByVal Math_Number As Integer, ByVal Scaling_Unit As Integer, ByVal Vertical_Scale As Double) As Integer
            Dim pInvokeResult As Integer = PInvoke.ConfigureFFTScaling(Me._handle, Math_Number, Scaling_Unit, Vertical_Scale)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function queries the sample rate of data used in an FFT analysis.
        '''
        '''Attribute(s):
        '''RSRTM_ATTR_FFT_SAMPLE_RATE
        '''
        '''Remote-control command(s):
        '''CALCulate:MATH&lt;Math&gt;:FFT:SRATe?
        '''</summary>
        '''<param name="Math_Number">
        '''Selects the math waveform.
        '''
        '''Valid Values:
        '''1 to 4
        '''
        '''Default Value: 1
        '''</param>
        '''<param name="Sample_Rate">
        '''Displays the sample rate of data used in an FFT analysis.
        '''
        '''Attribute:
        '''RSRTM_ATTR_FFT_SAMPLE_RATE
        '''</param>
        '''<returns>
        '''Returns the status code of this operation.  The status code  either indicates success or describes an error or warning condition.  You examine the status code from each call to an instrument driver function to determine if an error occurred.
        '''
        '''To obtain a text description of the status code, call the rsrtm_error_message function.  To obtain additional information about the error condition, call the rsrtm_GetError function.  To clear the error information from the driver, call the rsrtm_ClearError function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''
        '''Numeric Range (in Hex) Status Code Types
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF VISA Warnings
        '''3FFC0000 to 3FFCFFFF VXIPnP Driver Warnings
        '''
        '''BFFF0000 to BFFFFFFF VISA Errors
        '''BFFC0000 to BFFCFFFF VXIPnP Driver Errors
        '''</returns>
        Public Function QueryFFTSampleRate(ByVal Math_Number As Integer, ByRef Sample_Rate As Integer) As Integer
            Dim pInvokeResult As Integer = PInvoke.QueryFFTSampleRate(Me._handle, Math_Number, Sample_Rate)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''Selects the source waveform to be used as a reference.
        '''
        '''Attribute(s):
        '''RSRTM_ATTR_REFERENCE_WAVEFORM_SOURCE
        '''
        '''Remote-control command(s):
        '''REFCurve&lt;ReferenceWfm&gt;:SOURce
        '''</summary>
        '''<param name="Reference_Number">
        '''Selects the reference waveform.
        '''
        '''Valid Values:
        '''1 to 4
        '''
        '''Default Value: 1
        '''</param>
        '''<param name="Source">
        '''Selects the source waveform to be used as a reference.
        '''
        '''Valid Values:
        '''RSRTM_VAL_WAV_CH1 (1) - Channel 1
        '''RSRTM_VAL_WAV_CH2 (2) - Channel 2
        '''RSRTM_VAL_WAV_CH3 (3) - Channel 3
        '''RSRTM_VAL_WAV_CH4 (4) - Channel 4
        '''RSRTM_VAL_WAV_M1  (5) - Math Waveform 1
        '''RSRTM_VAL_WAV_M2  (6) - Math Waveform 2
        '''RSRTM_VAL_WAV_M3  (7) - Math Waveform 3
        '''RSRTM_VAL_WAV_M4  (8) - Math Waveform 4
        '''RSRTM_VAL_WAV_M5  (9) - Math Waveform 4
        '''RSRTM_VAL_WAV_R1 (10) - Reference Waveform 1
        '''RSRTM_VAL_WAV_R2 (11) - Reference Waveform 2
        '''RSRTM_VAL_WAV_R3 (12) - Reference Waveform 3
        '''RSRTM_VAL_WAV_R4 (13) - Reference Waveform 4
        '''
        '''Default Value: RSRTM_VAL_WAV_CH1 (1)
        '''
        '''Attribute:
        '''RSRTM_ATTR_REFERENCE_WAVEFORM_SOURCE
        '''</param>
        '''<returns>
        '''Returns the status code of this operation.  The status code  either indicates success or describes an error or warning condition.  You examine the status code from each call to an instrument driver function to determine if an error occurred.
        '''
        '''To obtain a text description of the status code, call the rsrtm_error_message function.  To obtain additional information about the error condition, call the rsrtm_GetError function.  To clear the error information from the driver, call the rsrtm_ClearError function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''
        '''Numeric Range (in Hex) Status Code Types
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF VISA Warnings
        '''3FFC0000 to 3FFCFFFF VXIPnP Driver Warnings
        '''
        '''BFFF0000 to BFFFFFFF VISA Errors
        '''BFFC0000 to BFFCFFFF VXIPnP Driver Errors
        '''</returns>
        Public Function ConfigureReferenceWaveformSource(ByVal Reference_Number As Integer, ByVal Source As Integer) As Integer
            Dim pInvokeResult As Integer = PInvoke.ConfigureReferenceWaveformSource(Me._handle, Reference_Number, Source)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''Copies the selected source waveform with all its settings to the memory of the reference waveform
        '''
        '''Attribute(s):
        '''RSRTM_ATTR_REFERENCE_WAVEFORM_UPDATE
        '''
        '''Remote-control command(s):
        '''REFCurve&lt;ReferenceWfm&gt;:UPDate
        '''</summary>
        '''<param name="Reference_Number">
        '''Selects the reference waveform.
        '''
        '''Valid Values:
        '''1 to 4
        '''
        '''Default Value: 1
        '''</param>
        '''<returns>
        '''Returns the status code of this operation.  The status code  either indicates success or describes an error or warning condition.  You examine the status code from each call to an instrument driver function to determine if an error occurred.
        '''
        '''To obtain a text description of the status code, call the rsrtm_error_message function.  To obtain additional information about the error condition, call the rsrtm_GetError function.  To clear the error information from the driver, call the rsrtm_ClearError function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''
        '''Numeric Range (in Hex) Status Code Types
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF VISA Warnings
        '''3FFC0000 to 3FFCFFFF VXIPnP Driver Warnings
        '''
        '''BFFF0000 to BFFFFFFF VISA Errors
        '''BFFC0000 to BFFCFFFF VXIPnP Driver Errors
        '''</returns>
        Public Function UpdateReferenceWaveformWithSelectedSource(ByVal Reference_Number As Integer) As Integer
            Dim pInvokeResult As Integer = PInvoke.UpdateReferenceWaveformWithSelectedSource(Me._handle, Reference_Number)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''Enables the reference waveform display in the diagram.
        '''
        '''Attribute(s):
        '''RSRTM_ATTR_REFERENCE_WAVEFORM_DISPLAY_ENABLED
        '''
        '''Remote-control command(s):
        '''REFCurve&lt;ReferenceWfm&gt;:STATe
        '''</summary>
        '''<param name="Reference_Number">
        '''Selects the reference waveform.
        '''
        '''Valid Values:
        '''1 to 4
        '''
        '''Default Value: 1
        '''</param>
        '''<param name="Display_Enabled">
        '''If enabled, the reference waveform is displayed in the diagram.
        '''
        '''Valid Values:
        '''VI_FALSE (0) - Off
        '''VI_TRUE  (1) - On
        '''
        '''Default Value: VI_FALSE (0)
        '''
        '''Attribute:
        '''RSRTM_ATTR_REFERENCE_WAVEFORM_DISPLAY_ENABLED
        '''</param>
        '''<returns>
        '''Returns the status code of this operation.  The status code  either indicates success or describes an error or warning condition.  You examine the status code from each call to an instrument driver function to determine if an error occurred.
        '''
        '''To obtain a text description of the status code, call the rsrtm_error_message function.  To obtain additional information about the error condition, call the rsrtm_GetError function.  To clear the error information from the driver, call the rsrtm_ClearError function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''
        '''Numeric Range (in Hex) Status Code Types
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF VISA Warnings
        '''3FFC0000 to 3FFCFFFF VXIPnP Driver Warnings
        '''
        '''BFFF0000 to BFFFFFFF VISA Errors
        '''BFFC0000 to BFFCFFFF VXIPnP Driver Errors
        '''</returns>
        Public Function ConfigureReferenceWaveformDisplayState(ByVal Reference_Number As Integer, ByVal Display_Enabled As Boolean) As Integer
            Dim pInvokeResult As Integer = PInvoke.ConfigureReferenceWaveformDisplayState(Me._handle, Reference_Number, System.Convert.ToUInt16(Display_Enabled))
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''Loads or saves the reference waveform.
        '''
        '''Attribute(s):
        '''RSRTM_ATTR_REFERENCE_WAVEFORM_LOAD_FROM_FILE
        '''RSRTM_ATTR_REFERENCE_WAVEFORM_SAVE_TO_FILE
        '''RSRTM_ATTR_REFERENCE_WAVEFORM_LOAD_CONFIGURATION
        '''
        '''Remote-control command(s):
        '''REFCurve&lt;ReferenceWfm&gt;:LOAD
        '''REFCurve&lt;ReferenceWfm&gt;:LOAD:STATe
        '''REFCurve&lt;ReferenceWfm&gt;:SAVE
        '''</summary>
        '''<param name="Reference_Wfm">
        '''This control selects the reference waveform.
        '''
        '''Valid Values: 
        '''RSRTM_VAL_REF_WAVEFORM_1 (1) - 1
        '''RSRTM_VAL_REF_WAVEFORM_2 (2) - 2
        '''RSRTM_VAL_REF_WAVEFORM_3 (3) - 3
        '''RSRTM_VAL_REF_WAVEFORM_4 (4) - 4
        '''
        '''Default Value:
        '''RSRTM_VAL_REF_WAVEFORM_1 (1)
        '''</param>
        '''<param name="Operation">
        '''This control selects the type of waveform operation to be performed.
        '''
        '''Valid Values:
        '''RSRTM_VAL_WAV_LOAD     (0) - Load
        '''RSRTM_VAL_WAV_LOAD_CFG (1) - Load Configuration
        '''RSRTM_VAL_WAV_SAVE     (2) - Save
        '''
        '''Default Value: RSRTM_VAL_WAV_LOAD (0)
        '''
        '''Attribute(s):
        '''RSRTM_ATTR_REFERENCE_WAVEFORM_LOAD_FROM_FILE
        '''RSRTM_ATTR_REFERENCE_WAVEFORM_SAVE_TO_FILE
        '''RSRTM_ATTR_REFERENCE_WAVEFORM_LOAD_CONFIGURATION
        '''</param>
        '''<param name="File_Name">
        '''Defines the file name
        '''
        '''Valid Values: not checked
        '''
        '''Default Value: ""
        '''</param>
        '''<returns>
        '''Returns the status code of this operation.  The status code  either indicates success or describes an error or warning condition.  You examine the status code from each call to an instrument driver function to determine if an error occurred.
        '''
        '''To obtain a text description of the status code, call the rsrtm_error_message function.  To obtain additional information about the error condition, call the rsrtm_GetError function.  To clear the error information from the driver, call the rsrtm_ClearError function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''
        '''Numeric Range (in Hex) Status Code Types
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF VISA Warnings
        '''3FFC0000 to 3FFCFFFF VXIPnP Driver Warnings
        '''
        '''BFFF0000 to BFFFFFFF VISA Errors
        '''BFFC0000 to BFFCFFFF VXIPnP Driver Errors
        '''</returns>
        Public Function ReferenceWaveformFileOperations(ByVal Reference_Wfm As Integer, ByVal Operation As Integer, ByVal File_Name As String) As Integer
            Dim pInvokeResult As Integer = PInvoke.ReferenceWaveformFileOperations(Me._handle, Reference_Wfm, Operation, File_Name)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function configures the vertical scaling of the reference waveform.
        '''
        '''Attribute(s):
        '''RSRTM_ATTR_REFERENCE_WAVEFORM_VERTICAL_SCALE
        '''RSRTM_ATTR_REFERENCE_WAVEFORM_VERTICAL_POSITION
        '''
        '''Remote-control command(s):
        '''REFCurve{ReferenceWfm}:VERTical:SCALe
        '''REFCurve&lt;ReferenceWfm&gt;:VERTical:POSition
        '''</summary>
        '''<param name="Reference_Number">
        '''Selects the reference waveform.
        '''
        '''Valid Values:
        '''1 to 4
        '''
        '''Default Value: 1
        '''</param>
        '''<param name="Vertical_Scale">
        '''Sets the scale factor for the reference waveform.
        '''
        '''Valid Values: not checked
        '''
        '''Default Value: 0.5 
        '''
        '''Attribute:
        '''RSRTM_ATTR_REFERENCE_WAVEFORM_VERTICAL_SCALE
        '''
        '''Note(s):
        '''
        '''(1) This control is only available if vertical coupling is set to "Independent".
        '''</param>
        '''<param name="Vertical_Position">
        '''Moves the reference waveform and its horizontal axis up or down in the diagram, if vertical scaling is set to "Independent".
        '''
        '''Valid Values: not checked
        '''
        '''Default Value: 0.0 
        '''
        '''Attribute:
        '''RSRTM_ATTR_REFERENCE_WAVEFORM_VERTICAL_POSITION
        '''</param>
        '''<returns>
        '''Returns the status code of this operation.  The status code  either indicates success or describes an error or warning condition.  You examine the status code from each call to an instrument driver function to determine if an error occurred.
        '''
        '''To obtain a text description of the status code, call the rsrtm_error_message function.  To obtain additional information about the error condition, call the rsrtm_GetError function.  To clear the error information from the driver, call the rsrtm_ClearError function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''
        '''Numeric Range (in Hex) Status Code Types
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF VISA Warnings
        '''3FFC0000 to 3FFCFFFF VXIPnP Driver Warnings
        '''
        '''BFFF0000 to BFFFFFFF VISA Errors
        '''BFFC0000 to BFFCFFFF VXIPnP Driver Errors
        '''</returns>
        Public Function ConfigureReferenceWaveformVerticalScale(ByVal Reference_Number As Integer, ByVal Vertical_Scale As Double, ByVal Vertical_Position As Double) As Integer
            Dim pInvokeResult As Integer = PInvoke.ConfigureReferenceWaveformVerticalScale(Me._handle, Reference_Number, Vertical_Scale, Vertical_Position)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function changes the horizontal scale (timebase) of the reference waveform independent of the channel waveform settings.
        '''
        '''Attribute(s):
        '''RSRTM_ATTR_REFERENCE_WAVEFORM_HORIZONTAL_SCALE
        '''RSRTM_ATTR_REFERENCE_WAVEFORM_HORIZONTAL_POSITION
        '''
        '''Remote-control command(s):
        '''REFCurve&lt;ReferenceWfm&gt;:HORizontal:SCALe
        '''REFCurve&lt;ReferenceWfm&gt;:HORizontal:POSition
        '''</summary>
        '''<param name="Reference_Wfm">
        '''This control selects the reference waveform.
        '''
        '''Valid Values: 
        '''RSRTM_VAL_REF_WAVEFORM_1 (1) - 1
        '''RSRTM_VAL_REF_WAVEFORM_2 (2) - 2
        '''RSRTM_VAL_REF_WAVEFORM_3 (3) - 3
        '''RSRTM_VAL_REF_WAVEFORM_4 (4) - 4
        '''
        '''Default Value:
        '''RSRTM_VAL_REF_WAVEFORM_1 (1)
        '''</param>
        '''<param name="Scale">
        '''This control sets horizontal scale.
        '''
        '''Valid Values: 
        '''not checked
        '''
        '''Default Value:
        '''0.0
        '''
        '''Attribute:
        '''RSRTM_ATTR_REFERENCE_WAVEFORM_HORIZONTAL_SCALE
        '''</param>
        '''<param name="Horizontal_Position">
        '''Changes the horizontal position of the reference waveform independent of the channel waveform settings.
        '''
        '''Valid Values: not checked
        '''
        '''Default Value: 0.0 
        '''
        '''Attribute:
        '''RSRTM_ATTR_REFERENCE_WAVEFORM_HORIZONTAL_POSITION
        '''</param>
        '''<returns>
        '''Returns the status code of this operation.  The status code  either indicates success or describes an error or warning condition.  You examine the status code from each call to an instrument driver function to determine if an error occurred.
        '''
        '''To obtain a text description of the status code, call the rsrtm_error_message function.  To obtain additional information about the error condition, call the rsrtm_GetError function.  To clear the error information from the driver, call the rsrtm_ClearError function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''
        '''Numeric Range (in Hex) Status Code Types
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF VISA Warnings
        '''3FFC0000 to 3FFCFFFF VXIPnP Driver Warnings
        '''
        '''BFFF0000 to BFFFFFFF VISA Errors
        '''BFFC0000 to BFFCFFFF VXIPnP Driver Errors
        '''</returns>
        Public Function ConfigureReferenceWaveformHorizontalScale(ByVal Reference_Wfm As Integer, ByVal Scale As Double, ByVal Horizontal_Position As Double) As Integer
            Dim pInvokeResult As Integer = PInvoke.ConfigureReferenceWaveformHorizontalScale(Me._handle, Reference_Wfm, Scale, Horizontal_Position)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function returns the source waveform - channel, math or reference waveform.
        '''
        '''Attribute(s):
        '''RSRTM_ATTR_REFERENCE_WAVEFORM_CATALOG
        '''
        '''Remote-control command(s):
        '''REFCurve&lt;ReferenceWfm&gt;:SOURce:CATalog?
        '''</summary>
        '''<param name="Reference_Wfm">
        '''This control selects the reference waveform.
        '''
        '''Valid Values: 
        '''RSRTM_VAL_REF_WAVEFORM_1 (1) - 1
        '''RSRTM_VAL_REF_WAVEFORM_2 (2) - 2
        '''RSRTM_VAL_REF_WAVEFORM_3 (3) - 3
        '''RSRTM_VAL_REF_WAVEFORM_4 (4) - 4
        '''
        '''Default Value:
        '''RSRTM_VAL_REF_WAVEFORM_1 (1)
        '''</param>
        '''<param name="Source_Waveform">
        '''Returns the source waveform - channel, math or reference waveform.
        '''
        '''Valid Values: 
        '''RSRTM_VAL_WAVS_RTM_CH1  (1) - Channel 1
        '''RSRTM_VAL_WAVS_RTM_CH2  (4) - Channel 2
        '''RSRTM_VAL_WAVS_RTM_CH3  (7) - Channel 3
        '''RSRTM_VAL_WAVS_RTM_CH4 (10) - Channel 4
        '''RSRTM_VAL_WAVS_RTM_MA1 (13) - Math Waveform 1
        '''RSRTM_VAL_WAVS_RTM_MA2 (14) - Math Waveform 2
        '''RSRTM_VAL_WAVS_RTM_MA3 (15) - Math Waveform 3
        '''RSRTM_VAL_WAVS_RTM_MA4 (16) - Math Waveform 4
        '''RSRTM_VAL_WAVS_RTM_RE1 (18) - Reference Waveform 1
        '''RSRTM_VAL_WAVS_RTM_RE2 (19) - Reference Waveform 2
        '''RSRTM_VAL_WAVS_RTM_RE3 (20) - Reference Waveform 3
        '''RSRTM_VAL_WAVS_RTM_RE4 (21) - Reference Waveform 4
        '''
        '''Attribute:
        '''RSRTM_ATTR_REFERENCE_WAVEFORM_CATALOG
        '''
        '''Notes:
        '''(1) This function is valid for RTM only.
        '''</param>
        '''<returns>
        '''Returns the status code of this operation.  The status code  either indicates success or describes an error or warning condition.  You examine the status code from each call to an instrument driver function to determine if an error occurred.
        '''
        '''To obtain a text description of the status code, call the rsrtm_error_message function.  To obtain additional information about the error condition, call the rsrtm_GetError function.  To clear the error information from the driver, call the rsrtm_ClearError function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''
        '''Numeric Range (in Hex) Status Code Types
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF VISA Warnings
        '''3FFC0000 to 3FFCFFFF VXIPnP Driver Warnings
        '''
        '''BFFF0000 to BFFFFFFF VISA Errors
        '''BFFC0000 to BFFCFFFF VXIPnP Driver Errors
        '''</returns>
        Public Function ReferenceReadWaveformCatalog(ByVal Reference_Wfm As Integer, ByRef Source_Waveform As Integer) As Integer
            Dim pInvokeResult As Integer = PInvoke.ReferenceReadWaveformCatalog(Me._handle, Reference_Wfm, Source_Waveform)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function initiates an acquisition on the channels that you enable with the rsrtm_ConfigureChannel function.  It then waits for the acquisition to complete, and returns the waveform for the channel you specify.  You call the rsrtm_FetchWaveform function to obtain the waveforms for each of the remaining enabled channels without initiating another acquisition.
        '''
        '''Notes:
        '''
        '''(1) After this function executes, each element in the Waveform Array parameter is either a voltage or a value indicating that the oscilloscope could not sample a voltage.
        '''
        '''(2) You configure the interpolation method the oscilloscope uses with the rsrtm_ConfigureInterpolation function.  If you disable interpolation, the oscilloscope does not interpolate points in the waveform.
        '''
        '''Attribute(s):
        '''RSRTM_ATTR_SEND_SW_TRIGGER_AND_WAIT
        '''RSRTM_ATTR_WAVEFORM_HEADER
        '''
        '''Remote-control command(s):
        '''*TRG
        '''*OPC
        '''CHANnel&lt;m&gt;[:WAVeform&lt;n&gt;]:DATA[:VALues]
        '''CHANnel&lt;Channel&gt;[:WAVeform&lt;Waveform&gt;]:DATA:HEADer?
        '''</summary>
        '''<param name="Channel">
        '''This control selects the channel.
        '''
        '''Valid Values: 
        '''RSRTM_VAL_CHANNEL_1   (1) - 1
        '''RSRTM_VAL_CHANNEL_2   (2) - 2
        '''RSRTM_VAL_CHANNEL_3   (3) - 3
        '''RSRTM_VAL_CHANNEL_4   (4) - 4
        '''
        '''Default Value: RSRTM_VAL_CHANNEL_1 (1)
        '''</param>
        '''<param name="Waveform_Size">
        '''Pass the number of elements in the Waveform Array parameter.
        '''
        '''Default Value: None
        '''
        '''
        '''</param>
        '''<param name="Maximum_Time">
        '''Pass the maximum length of time in which to allow the read waveform operation to complete.    
        '''
        '''If the operation does not complete within this time interval, the function returns the RSRTM_ERROR_MAX_TIME_EXCEEDED (0xBFFA2003) error code.  When this occurs, you can call rsrtm_Abort to cancel the read waveform operation and return the oscilloscope to the Idle state.
        '''
        '''Units:  milliseconds.  
        '''
        '''Valid Values:
        '''not checked
        '''
        '''Default Value: 5000 (ms)
        '''
        '''Notes:
        '''
        '''(1) The Maximum Time parameter applies only to this function.  It has no effect on other timeout parameters or attributes.
        '''
        '''</param>
        '''<param name="Waveform_Array">
        '''Returns the waveform that the oscilloscope acquires.  
        '''
        '''Note(s):
        '''
        '''(1) You configure the interpolation method the oscilloscope uses with the rsrtm_ConfigureInterpolation function.  If you disable interpolation, the oscilloscope does not interpolate points in the waveform.  If the oscilloscope cannot sample a value for a point in the waveform, the driver sets the corresponding element in the Waveform Array to an IEEE defined NaN (Not a Number) value and the function returns RSRTM_WARN_INVALID_WFM_ELEMENT.
        '''</param>
        '''<param name="Actual_Points">
        '''Indicates the number of points the function places in the Waveform Array parameter.
        '''
        '''</param>
        '''<param name="Initial_X">
        '''Indicates the time of the first point in the Waveform Array.  The time is relative to the trigger event.  
        '''
        '''For example, if the oscilloscope acquires the first point in the Waveform Array 1 second before the trigger, this parameter returns the value -1.0.  If the acquisition of the first point occurs at the same time as the trigger, this parameter returns the value 0.0.
        '''
        '''Units:  seconds
        '''</param>
        '''<param name="X_Increment">
        '''Indicates the length of time between points in the Waveform Array.  
        '''
        '''Units:  seconds
        '''</param>
        '''<returns>
        '''Returns the status code of this operation.  The status code  either indicates success or describes an error or warning condition.  You examine the status code from each call to an instrument driver function to determine if an error occurred.
        '''
        '''To obtain a text description of the status code, call the rsrtm_error_message function.  To obtain additional information about the error condition, call the rsrtm_GetError function.  To clear the error information from the driver, call the rsrtm_ClearError function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''
        '''Numeric Range (in Hex) Status Code Types
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF VISA Warnings
        '''3FFC0000 to 3FFCFFFF VXIPnP Driver Warnings
        '''
        '''BFFF0000 to BFFFFFFF VISA Errors
        '''BFFC0000 to BFFCFFFF VXIPnP Driver Errors
        '''</returns>
        Public Function ReadWaveform(ByVal Channel As Integer, ByVal Waveform_Size As Integer, ByVal Maximum_Time As Integer, ByVal Waveform_Array() As Double, ByRef Actual_Points As Integer, ByRef Initial_X As Double, ByRef X_Increment As Double) As Integer
            Dim pInvokeResult As Integer = PInvoke.ReadWaveform(Me._handle, Channel, Waveform_Size, Maximum_Time, Waveform_Array, Actual_Points, Initial_X, X_Increment)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function initiates an acquisition on the channels that you enable with the rsrtm_ConfigureChannel function.  It then waits for the acquisition to complete, obtains a main waveform measurement on the channel you specify, and returns the measurement value.  You specify a particular measurement type, such as rise time, frequency, and voltage peak-to-peak.  You can call the rsrtm_FetchMainWaveformMeasurement function separately for any other waveform measurement that you want to obtain on a specific channel without initiating another acquisition.
        '''
        '''Attribute(s):
        '''RSRTM_ATTR_MAIN_MEASUREMENT_RESULT
        '''
        '''Remote-control command(s):
        '''*TRG
        '''*OPC
        '''MEASurement&lt;m&gt;:RESult?
        '''</summary>
        '''<param name="Measurement">
        '''Selects waveform measurement.
        '''
        '''Valid Values:
        '''1 to 4
        '''
        '''Default Value: 1
        '''</param>
        '''<param name="Measurement_Function">
        '''Selects the result type.
        '''
        '''Valid Values:
        '''RSRTM_VAL_MEAS_FREQUENCY (1)  - Frequency
        '''RSRTM_VAL_MEAS_PERIOD    (2)  - Period
        '''RSRTM_VAL_MEAS_PEAK      (3)  - Peak Peak
        '''RSRTM_VAL_MEAS_UPEAK     (4)  - Peak Upper
        '''RSRTM_VAL_MEAS_LPEAK     (5)  - Peak Lower
        '''RSRTM_VAL_MEAS_PPC       (6)  - Positive Pulses Count
        '''RSRTM_VAL_MEAS_NPC       (7)  - Negative Pulses Count
        '''RSRTM_VAL_MEAS_REC       (8)  - Rising Edges Count
        '''RSRTM_VAL_MEAS_FEC       (9)  - Falling Edges Count
        '''RSRTM_VAL_MEAS_HIGH      (10)  - High
        '''RSRTM_VAL_MEAS_LOW       (11)  - Low
        '''RSRTM_VAL_MEAS_AMP       (12)  - Amplitude
        '''RSRTM_VAL_MEAS_MEAN      (13)  - Mean Value
        '''RSRTM_VAL_MEAS_RMS       (14)  - RMS Value
        '''RSRTM_VAL_MEAS_RTM       (15)  - Rise Time
        '''RSRTM_VAL_MEAS_FTIM      (16)  - Falling Time
        '''RSRTM_VAL_MEAS_PDCY      (17)  - Duty Cycle Positive
        '''RSRTM_VAL_MEAS_NDCY      (18)  - Duty Cycle Negative
        '''RSRTM_VAL_MEAS_PPW       (19)  - Pulse Width Positive
        '''RSRTM_VAL_MEAS_NPW       (20)  - Pulse Width Negative
        '''RSRTM_VAL_MEAS_CYCM      (21)  - Cycle Mean
        '''RSRTM_VAL_MEAS_CYCR      (22)  - Cycle RMS
        '''RSRTM_VAL_MEAS_SSTDD     (23)  - Standard Deviation
        '''RSRTM_VAL_MEAS_TFR       (24)  - Trigger Frequency
        '''RSRTM_VAL_MEAS_TPER      (25)  - Trigger Period
        '''
        '''Default Value: RSRTM_VAL_MEAS_FREQUENCY (1)
        '''</param>
        '''<param name="Maximum_Time">
        '''Pass the maximum length of time in which to allow the read waveform operation to complete.    
        '''
        '''If the operation does not complete within this time interval, the function returns the RSRTM_ERROR_MAX_TIME_EXCEEDED (0xBFFA2003) error code.  When this occurs, you can call rsrtm_Abort to cancel the read waveform operation and return the oscilloscope to the Idle state.
        '''
        '''Valid Values:
        '''not checked
        '''
        '''Default Value: 5000 ms
        '''</param>
        '''<param name="Measurement_Result">
        '''Returns the measured value.  
        '''
        '''Units:  The units depend on the Measurement Function you select as shown below.
        '''
        '''    Rise Time            - seconds
        '''    Fall Time            - seconds
        '''    Frequency            - hertz
        '''    Period               - seconds
        '''    Voltage RMS          - volts
        '''    Voltage RMS (Cycle)  - volts
        '''    Voltage Max          - volts
        '''    Voltage Min          - volts
        '''    Voltage Vpp          - volts
        '''    Voltage High         - volts
        '''    Voltage Low          - volts
        '''    Voltage Avg.         - volts
        '''    Voltage Avg. (Cycle) - volts
        '''    Width Negative       - seconds
        '''    Width Positive       - seconds
        '''    Duty Cycle Negative  - percent
        '''    Duty Cycle Positive  - percent
        '''    Amplitude            - volts
        '''
        '''
        '''
        '''</param>
        '''<returns>
        '''Returns the status code of this operation.  The status code  either indicates success or describes an error or warning condition.  You examine the status code from each call to an instrument driver function to determine if an error occurred.
        '''
        '''To obtain a text description of the status code, call the rsrtm_error_message function.  To obtain additional information about the error condition, call the rsrtm_GetError function.  To clear the error information from the driver, call the rsrtm_ClearError function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''
        '''Numeric Range (in Hex) Status Code Types
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF VISA Warnings
        '''3FFC0000 to 3FFCFFFF VXIPnP Driver Warnings
        '''
        '''BFFF0000 to BFFFFFFF VISA Errors
        '''BFFC0000 to BFFCFFFF VXIPnP Driver Errors
        '''</returns>
        Public Function ReadMainWaveformMeasurement(ByVal Measurement As Integer, ByVal Measurement_Function As Integer, ByVal Maximum_Time As Integer, ByRef Measurement_Result As Double) As Integer
            Dim pInvokeResult As Integer = PInvoke.ReadMainWaveformMeasurement(Me._handle, Measurement, Measurement_Function, Maximum_Time, Measurement_Result)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function initiates a waveform acquisition.  After you call this function, the oscilloscope leaves the Idle state and waits for a trigger.  The oscilloscope acquires a waveform for each channel you have enabled with the  rsrtm_ConfigureChannel function.
        '''
        '''Attribute(s):
        '''RSRTM_ATTR_RUN_SINGLE
        '''RSRTM_ATTR_RUN_CONTINUOUS
        '''
        '''Remote-control command(s):
        '''SINGle
        '''RUN
        '''</summary>
        '''<param name="Action">
        '''Select action to be performed.
        '''
        '''Valid Values:
        '''RSRTM_VAL_INIT_SINGLE     (0) - Single
        '''RSRTM_VAL_INIT_CONTINUOUS (1) - Continuous
        '''
        '''Default Value: RSRTM_VAL_INIT_SINGLE (0)
        '''
        '''Attribute:
        '''RSRTM_ATTR_RUN_SINGLE
        '''RSRTM_ATTR_RUN_CONTINUOUS
        '''
        '''Note(s):
        '''
        '''(1) Single: Starts a defined number of acquisition cycles.
        '''
        '''(2) Continuous: Starts the continuous acquisition.
        '''</param>
        '''<returns>
        '''Returns the status code of this operation.  The status code  either indicates success or describes an error or warning condition.  You examine the status code from each call to an instrument driver function to determine if an error occurred.
        '''
        '''To obtain a text description of the status code, call the rsrtm_error_message function.  To obtain additional information about the error condition, call the rsrtm_GetError function.  To clear the error information from the driver, call the rsrtm_ClearError function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''
        '''Numeric Range (in Hex) Status Code Types
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF VISA Warnings
        '''3FFC0000 to 3FFCFFFF VXIPnP Driver Warnings
        '''
        '''BFFF0000 to BFFFFFFF VISA Errors
        '''BFFC0000 to BFFCFFFF VXIPnP Driver Errors
        '''</returns>
        Public Function InitiateAcquisition(ByVal Action As Integer) As Integer
            Dim pInvokeResult As Integer = PInvoke.InitiateAcquisition(Me._handle, Action)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''Sends software trigger and waits for operation complete.
        '''
        '''Attribute(s):
        '''RSRTM_ATTR_SEND_SW_TRIGGER_AND_WAIT
        '''
        '''Remote-control command(s):
        '''*TRG
        '''*OPC
        '''</summary>
        '''<param name="Maximum_Time">
        '''Pass the maximum length of time (in milliseconds) in which to allow the read waveform operation to complete.    
        '''
        '''If the operation does not complete within this time interval, the function returns the RSRTM_ERROR_MAX_TIME_EXCEEDED (0xBFFA2003) error code.  When this occurs, you can call rsrtm_Abort to cancel the read waveform operation and return the oscilloscope to the Idle state.
        '''
        '''Valid Values:
        '''not checked
        '''
        '''Default Value: 5000 ms
        '''</param>
        '''<returns>
        '''Returns the status code of this operation.  The status code  either indicates success or describes an error or warning condition.  You examine the status code from each call to an instrument driver function to determine if an error occurred.
        '''
        '''To obtain a text description of the status code, call the rsrtm_error_message function.  To obtain additional information about the error condition, call the rsrtm_GetError function.  To clear the error information from the driver, call the rsrtm_ClearError function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''
        '''Numeric Range (in Hex) Status Code Types
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF VISA Warnings
        '''3FFC0000 to 3FFCFFFF VXIPnP Driver Warnings
        '''
        '''BFFF0000 to BFFFFFFF VISA Errors
        '''BFFC0000 to BFFCFFFF VXIPnP Driver Errors
        '''</returns>
        Public Function SendSoftwareTrigger(ByVal Maximum_Time As Integer) As Integer
            Dim pInvokeResult As Integer = PInvoke.SendSoftwareTrigger(Me._handle, Maximum_Time)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function returns the waveform the oscilloscope acquires for the channel you specify.  The waveform is from an acquisition that you previously initiated.  
        '''
        '''You use the rsrtm_InitiateAcquisition function to start an acquisition on the channels that you enable with the rsrtm_ConfigureChannel function.  The oscilloscope acquires waveforms for the enabled channels concurrently. You must call this function separately for each enabled channel to obtain the waveforms.
        '''
        '''You can call the rsrtm_ReadWaveform function instead of the rsrtm_InitiateAcquisition function.  The rsrtm_ReadWaveform function starts an acquisition on all enabled channels, waits for the acquisition to complete, and returns the waveform for the channel you specify.  You call this function to obtain the waveforms for each of the remaining channels.
        '''
        '''Notes:
        '''
        '''(1) After this function executes, each element in the Waveform Array parameter is either a voltage or a value indicating that the oscilloscope could not sample a voltage.
        '''
        '''(2) You configure the interpolation method the oscilloscope uses with the rsrtm_ConfigureInterpolation function.  If you disable interpolation, the oscilloscope does not interpolate points in the waveform.
        '''
        '''(3) This function does not check the instrument status.   Typically, you call this function only in a sequence of calls to other low-level driver functions.  The sequence performs one operation.  You use the low-level functions to optimize one or more aspects of interaction with the instrument.  If you want to check the instrument status, call the rsrtm_error_query function at the conclusion of the sequence.
        '''
        '''Attribute(s):
        '''RSRTM_ATTR_WAVEFORM_HEADER
        '''
        '''Remote-control command(s):
        '''CHANnel&lt;m&gt;[:WAVeform&lt;n&gt;]:DATA[:VALues]
        '''</summary>
        '''<param name="Channel">
        '''This control selects the channel.
        '''
        '''Valid Values: 
        '''RSRTM_VAL_CHANNEL_1   (1) - 1
        '''RSRTM_VAL_CHANNEL_2   (2) - 2
        '''RSRTM_VAL_CHANNEL_3   (3) - 3
        '''RSRTM_VAL_CHANNEL_4   (4) - 4
        '''
        '''Default Value: RSRTM_VAL_CHANNEL_1 (1)
        '''</param>
        '''<param name="Waveform_Size">
        '''Pass the number of elements in the Waveform Array parameter.
        '''
        '''Default Value: None
        '''
        '''
        '''</param>
        '''<param name="Waveform_Array">
        '''Returns the waveform that the oscilloscope acquires.  
        '''
        '''Note(s):
        '''
        '''(1) You configure the interpolation method the oscilloscope uses with the rsrtm_ConfigureInterpolation function.  If you disable interpolation, the oscilloscope does not interpolate points in the waveform.  If the oscilloscope cannot sample a value for a point in the waveform, the driver sets the corresponding element in the Waveform Array to an IEEE defined NaN (Not a Number) value and the function returns RSRTM_WARN_INVALID_WFM_ELEMENT.
        '''</param>
        '''<param name="Actual_Points">
        '''Indicates the number of points the function places in the Waveform Array parameter.
        '''
        '''</param>
        '''<param name="Initial_X">
        '''Indicates the time of the first point in the Waveform Array.  The time is relative to the trigger event.  
        '''
        '''For example, if the oscilloscope acquires the first point in the Waveform Array 1 second before the trigger, this parameter returns the value -1.0.  If the acquisition of the first point occurs at the same time as the trigger, this parameter returns the value 0.0.
        '''
        '''Units:  seconds  
        '''
        '''</param>
        '''<param name="X_Increment">
        '''Indicates the length of time between points in the Waveform Array.  
        '''
        '''Units:  seconds
        '''</param>
        '''<returns>
        '''Returns the status code of this operation.  The status code  either indicates success or describes an error or warning condition.  You examine the status code from each call to an instrument driver function to determine if an error occurred.
        '''
        '''To obtain a text description of the status code, call the rsrtm_error_message function.  To obtain additional information about the error condition, call the rsrtm_GetError function.  To clear the error information from the driver, call the rsrtm_ClearError function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''
        '''Numeric Range (in Hex) Status Code Types
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF VISA Warnings
        '''3FFC0000 to 3FFCFFFF VXIPnP Driver Warnings
        '''
        '''BFFF0000 to BFFFFFFF VISA Errors
        '''BFFC0000 to BFFCFFFF VXIPnP Driver Errors
        '''</returns>
        Public Function FetchWaveform(ByVal Channel As Integer, ByVal Waveform_Size As Integer, ByVal Waveform_Array() As Double, ByRef Actual_Points As Integer, ByRef Initial_X As Double, ByRef X_Increment As Double) As Integer
            Dim pInvokeResult As Integer = PInvoke.FetchWaveform(Me._handle, Channel, Waveform_Size, Waveform_Array, Actual_Points, Initial_X, X_Increment)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''Returns the header of waveform data. The header contains  attributes of the waveform.
        '''
        '''Attribute(s):
        '''-
        '''
        '''Remote-control command(s):
        '''CHANnel&lt;m&gt;:DATA:HEADer?
        '''</summary>
        '''<param name="Channel">
        '''This control selects the channel.
        '''
        '''Valid Values: 
        '''RSRTM_VAL_CHANNEL_1   (1) - 1
        '''RSRTM_VAL_CHANNEL_2   (2) - 2
        '''RSRTM_VAL_CHANNEL_3   (3) - 3
        '''RSRTM_VAL_CHANNEL_4   (4) - 4
        '''
        '''Default Value: RSRTM_VAL_CHANNEL_1 (1)
        '''</param>
        '''<param name="X_Start">
        '''X Start in seconds.
        '''</param>
        '''<param name="X_Stop">
        '''X Stop in seconds.
        '''</param>
        '''<param name="Record_Length">
        '''Record length of the waveform in Samples.
        '''</param>
        '''<param name="Values_per_Sample">
        '''Number of values per sample interval, usually 1.
        '''</param>
        '''<returns>
        '''Returns the status code of this operation.  The status code  either indicates success or describes an error or warning condition.  You examine the status code from each call to an instrument driver function to determine if an error occurred.
        '''
        '''To obtain a text description of the status code, call the rsrtm_error_message function.  To obtain additional information about the error condition, call the rsrtm_GetError function.  To clear the error information from the driver, call the rsrtm_ClearError function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''
        '''Numeric Range (in Hex) Status Code Types
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF VISA Warnings
        '''3FFC0000 to 3FFCFFFF VXIPnP Driver Warnings
        '''
        '''BFFF0000 to BFFFFFFF VISA Errors
        '''BFFC0000 to BFFCFFFF VXIPnP Driver Errors
        '''</returns>
        Public Function FetchWaveformHeader(ByVal Channel As Integer, ByRef X_Start As Double, ByRef X_Stop As Double, ByRef Record_Length As Integer, ByRef Values_per_Sample As Integer) As Integer
            Dim pInvokeResult As Integer = PInvoke.FetchWaveformHeader(Me._handle, Channel, X_Start, X_Stop, Record_Length, Values_per_Sample)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function returns the data of the envelope. The envelope consists of two waveforms. Use this command only for envelope waveforms. for all other channel waveforms use CHANnel&lt;m&gt;: DATA.
        '''
        '''Note(s):
        '''(1) This function is available only for RTM.
        '''
        '''Attribute(s):
        '''RSRTM_ATTR_WAVEFORM_ENVELOPE
        '''RSRTM_ATTR_WAVEFORM_ENVELOPE_HEADER
        '''
        '''Remote-control command(s):
        '''CHANnel&lt;Channel&gt;:DATA:ENVelope:HEADer?
        '''CHANnel&lt;Channel&gt;:DATA:ENVelope?
        '''</summary>
        '''<param name="Channel">
        '''This control selects the channel.
        '''
        '''Valid Values: 
        '''RSRTM_VAL_CHANNEL_1 (1) - 1
        '''RSRTM_VAL_CHANNEL_2 (2) - 2
        '''RSRTM_VAL_CHANNEL_3 (3) - 3
        '''RSRTM_VAL_CHANNEL_4 (4) - 4
        '''
        '''Default Value: RSRTM_VAL_CHANNEL_1 (1)
        '''</param>
        '''<param name="Waveform_Size">
        '''Pass the number of elements in the Waveform Array parameter.
        '''
        '''Default Value: None
        '''
        '''
        '''</param>
        '''<param name="Waveform_Array">
        '''Returns the data of the envelope. The envelope consists of two waveforms.
        '''
        '''Attribute:
        '''RSRTM_ATTR_WAVEFORM_ENVELOPE
        '''
        '''</param>
        '''<param name="Actual_Points">
        '''Indicates the number of points the function places in the Waveform Array parameter.
        '''
        '''</param>
        '''<param name="Initial_X">
        '''Indicates the time of the first point in the Waveform Array.  The time is relative to the trigger event.  
        '''
        '''For example, if the oscilloscope acquires the first point in the Waveform Array 1 second before the trigger, this parameter returns the value -1.0.  If the acquisition of the first point occurs at the same time as the trigger, this parameter returns the value 0.0.
        '''
        '''Units:  seconds
        '''</param>
        '''<param name="X_Increment">
        '''Indicates the length of time between points in the Waveform Array.  
        '''
        '''Units:  seconds
        '''</param>
        '''<returns>
        '''Returns the status code of this operation.  The status code  either indicates success or describes an error or warning condition.  You examine the status code from each call to an instrument driver function to determine if an error occurred.
        '''
        '''To obtain a text description of the status code, call the rsrtm_error_message function.  To obtain additional information about the error condition, call the rsrtm_GetError function.  To clear the error information from the driver, call the rsrtm_ClearError function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''
        '''Numeric Range (in Hex) Status Code Types
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF VISA Warnings
        '''3FFC0000 to 3FFCFFFF VXIPnP Driver Warnings
        '''
        '''BFFF0000 to BFFFFFFF VISA Errors
        '''BFFC0000 to BFFCFFFF VXIPnP Driver Errors
        '''</returns>
        Public Function FetchEnvelopeWaveform(ByVal Channel As Integer, ByVal Waveform_Size As Integer, ByVal Waveform_Array() As Double, ByRef Actual_Points As Integer, ByRef Initial_X As Double, ByRef X_Increment As Double) As Integer
            Dim pInvokeResult As Integer = PInvoke.FetchEnvelopeWaveform(Me._handle, Channel, Waveform_Size, Waveform_Array, Actual_Points, Initial_X, X_Increment)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''Returns information on the envelope waveform.
        '''
        '''Attribute(s):
        '''RSRTM_ATTR_MATH_WAVEFORM_HEADER
        '''
        '''Remote-control command(s):
        '''CHANnel&lt;m&gt;:DATA:ENVelope:HEADer?
        '''</summary>
        '''<param name="Channel">
        '''This control selects the channel.
        '''
        '''Valid Values: 
        '''RSRTM_VAL_CHANNEL_1 (1) - 1
        '''RSRTM_VAL_CHANNEL_2 (2) - 2
        '''RSRTM_VAL_CHANNEL_3 (3) - 3
        '''RSRTM_VAL_CHANNEL_4 (4) - 4
        '''
        '''Default Value: RSRTM_VAL_CHANNEL_1 (1)
        '''</param>
        '''<param name="X_Start">
        '''X Start in seconds.
        '''</param>
        '''<param name="X_Stop">
        '''X Stop in seconds.
        '''</param>
        '''<param name="Record_Length">
        '''Record length of the waveform in Samples.
        '''</param>
        '''<param name="Values_per_Sample">
        '''Number of values per sample interval, usually 2.
        '''</param>
        '''<returns>
        '''Returns the status code of this operation.  The status code  either indicates success or describes an error or warning condition.  You examine the status code from each call to an instrument driver function to determine if an error occurred.
        '''
        '''To obtain a text description of the status code, call the rsrtm_error_message function.  To obtain additional information about the error condition, call the rsrtm_GetError function.  To clear the error information from the driver, call the rsrtm_ClearError function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''
        '''Numeric Range (in Hex) Status Code Types
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF VISA Warnings
        '''3FFC0000 to 3FFCFFFF VXIPnP Driver Warnings
        '''
        '''BFFF0000 to BFFFFFFF VISA Errors
        '''BFFC0000 to BFFCFFFF VXIPnP Driver Errors
        '''</returns>
        Public Function FetchEnvelopeWaveformHeader(ByVal Channel As Integer, ByRef X_Start As Double, ByRef X_Stop As Double, ByRef Record_Length As Integer, ByRef Values_per_Sample As Integer) As Integer
            Dim pInvokeResult As Integer = PInvoke.FetchEnvelopeWaveformHeader(Me._handle, Channel, X_Start, X_Stop, Record_Length, Values_per_Sample)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function returns the data of the math waveform points.  
        '''
        '''Attribute(s):
        '''no attribute
        '''
        '''Remote-control command(s):
        '''CALCulate:MATH&lt;Math&gt;:DATA[:VALues]?
        '''</summary>
        '''<param name="Math_Number">
        '''Selects the math waveform.
        '''
        '''Valid Values:
        '''1 to 4
        '''
        '''Default Value: 1
        '''</param>
        '''<param name="Waveform_Size">
        '''Pass the number of elements in the Waveform Array parameter.
        '''
        '''Default Value: None
        '''
        '''
        '''</param>
        '''<param name="Waveform_Array">
        '''Returns the vertical values - voltages of recorded waveform samples, or magnitudes of a spectrum.  
        '''
        '''</param>
        '''<param name="Actual_Points">
        '''Indicates the number of points the function places in the Waveform Array parameter.
        '''
        '''</param>
        '''<returns>
        '''Returns the status code of this operation.  The status code  either indicates success or describes an error or warning condition.  You examine the status code from each call to an instrument driver function to determine if an error occurred.
        '''
        '''To obtain a text description of the status code, call the rsrtm_error_message function.  To obtain additional information about the error condition, call the rsrtm_GetError function.  To clear the error information from the driver, call the rsrtm_ClearError function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''
        '''Numeric Range (in Hex) Status Code Types
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF VISA Warnings
        '''3FFC0000 to 3FFCFFFF VXIPnP Driver Warnings
        '''
        '''BFFF0000 to BFFFFFFF VISA Errors
        '''BFFC0000 to BFFCFFFF VXIPnP Driver Errors
        '''</returns>
        Public Function FetchMathWaveform(ByVal Math_Number As Integer, ByVal Waveform_Size As Integer, ByVal Waveform_Array() As Double, ByRef Actual_Points As Integer) As Integer
            Dim pInvokeResult As Integer = PInvoke.FetchMathWaveform(Me._handle, Math_Number, Waveform_Size, Waveform_Array, Actual_Points)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''Returns the header of math waveform data. The header contains  attributes of the waveform.
        '''
        '''Attribute(s):
        '''RSRTM_ATTR_MATH_WAVEFORM_HEADER
        '''
        '''Remote-control command(s):
        '''CALCulate:MATH&lt;Math&gt;:DATA:HEADer?
        '''</summary>
        '''<param name="Math_Number">
        '''Selects the math waveform.
        '''
        '''Valid Values:
        '''1 to 4
        '''
        '''Default Value: 1
        '''</param>
        '''<param name="X_Start">
        '''X Start in seconds.
        '''</param>
        '''<param name="X_Stop">
        '''X Stop in seconds.
        '''</param>
        '''<param name="Record_Length">
        '''Record length of the waveform in Samples.
        '''</param>
        '''<param name="Values_per_Sample">
        '''Number of values per sample interval, usually 1.
        '''</param>
        '''<returns>
        '''Returns the status code of this operation.  The status code  either indicates success or describes an error or warning condition.  You examine the status code from each call to an instrument driver function to determine if an error occurred.
        '''
        '''To obtain a text description of the status code, call the rsrtm_error_message function.  To obtain additional information about the error condition, call the rsrtm_GetError function.  To clear the error information from the driver, call the rsrtm_ClearError function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''
        '''Numeric Range (in Hex) Status Code Types
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF VISA Warnings
        '''3FFC0000 to 3FFCFFFF VXIPnP Driver Warnings
        '''
        '''BFFF0000 to BFFFFFFF VISA Errors
        '''BFFC0000 to BFFCFFFF VXIPnP Driver Errors
        '''</returns>
        Public Function FetchMathWaveformHeader(ByVal Math_Number As Integer, ByRef X_Start As Double, ByRef X_Stop As Double, ByRef Record_Length As Integer, ByRef Values_per_Sample As Integer) As Integer
            Dim pInvokeResult As Integer = PInvoke.FetchMathWaveformHeader(Me._handle, Math_Number, X_Start, X_Stop, Record_Length, Values_per_Sample)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function returns information on the reference waveform.
        '''
        '''Attribute(s):
        '''no attribute
        '''
        '''Remote-control command(s):
        '''REFCurve&lt;ReferenceWfm&gt;:DATA?
        '''</summary>
        '''<param name="Reference_Wfm">
        '''This control selects the reference waveform.
        '''
        '''Valid Values: 
        '''RSRTM_VAL_REF_WAVEFORM_1 (1) - 1
        '''RSRTM_VAL_REF_WAVEFORM_2 (2) - 2
        '''RSRTM_VAL_REF_WAVEFORM_3 (3) - 3
        '''RSRTM_VAL_REF_WAVEFORM_4 (4) - 4
        '''
        '''Default Value:
        '''RSRTM_VAL_REF_WAVEFORM_1 (1)
        '''</param>
        '''<param name="Waveform_Size">
        '''Pass the number of elements in the Waveform Array parameter.
        '''
        '''Valid Values:
        '''Not Checked
        '''
        '''Default Value: 1
        '''</param>
        '''<param name="Waveform_Array">
        '''Returns the vertical values - voltages of recorded waveform samples, or magnitudes of a spectrum.  
        '''</param>
        '''<param name="Actual_Points">
        '''Indicates the number of points the function places in the Waveform Array parameter.
        '''</param>
        '''<returns>
        '''Returns the status code of this operation.  The status code  either indicates success or describes an error or warning condition.  You examine the status code from each call to an instrument driver function to determine if an error occurred.
        '''
        '''To obtain a text description of the status code, call the rsrtm_error_message function.  To obtain additional information about the error condition, call the rsrtm_GetError function.  To clear the error information from the driver, call the rsrtm_ClearError function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''
        '''Numeric Range (in Hex) Status Code Types
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF VISA Warnings
        '''3FFC0000 to 3FFCFFFF VXIPnP Driver Warnings
        '''
        '''BFFF0000 to BFFFFFFF VISA Errors
        '''BFFC0000 to BFFCFFFF VXIPnP Driver Errors
        '''</returns>
        Public Function FetchReferenceWaveform(ByVal Reference_Wfm As Integer, ByVal Waveform_Size As Integer, ByVal Waveform_Array() As Double, ByRef Actual_Points As Integer) As Integer
            Dim pInvokeResult As Integer = PInvoke.FetchReferenceWaveform(Me._handle, Reference_Wfm, Waveform_Size, Waveform_Array, Actual_Points)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''Returns information on the reference waveform.
        '''
        '''Attribute(s):
        '''RSRTM_ATTR_REFERENCE_WAVEFORM_HEADER
        '''
        '''Remote-control command(s):
        '''REFCurve&lt;ReferenceWfm&gt;:DATA:HEADer?
        '''</summary>
        '''<param name="Reference_Wfm">
        '''This control selects the reference waveform.
        '''
        '''Valid Values: 
        '''RSRTM_VAL_REF_WAVEFORM_1 (1) - 1
        '''RSRTM_VAL_REF_WAVEFORM_2 (2) - 2
        '''RSRTM_VAL_REF_WAVEFORM_3 (3) - 3
        '''RSRTM_VAL_REF_WAVEFORM_4 (4) - 4
        '''
        '''Default Value:
        '''RSRTM_VAL_REF_WAVEFORM_1 (1)
        '''</param>
        '''<param name="X_Start">
        '''X Start in seconds.
        '''</param>
        '''<param name="X_Stop">
        '''X Stop in seconds.
        '''</param>
        '''<param name="Record_Length">
        '''Record length of the waveform in Samples.
        '''</param>
        '''<param name="Values_per_Sample">
        '''Number of values per sample interval, usually 2.
        '''</param>
        '''<returns>
        '''Returns the status code of this operation.  The status code  either indicates success or describes an error or warning condition.  You examine the status code from each call to an instrument driver function to determine if an error occurred.
        '''
        '''To obtain a text description of the status code, call the rsrtm_error_message function.  To obtain additional information about the error condition, call the rsrtm_GetError function.  To clear the error information from the driver, call the rsrtm_ClearError function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''
        '''Numeric Range (in Hex) Status Code Types
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF VISA Warnings
        '''3FFC0000 to 3FFCFFFF VXIPnP Driver Warnings
        '''
        '''BFFF0000 to BFFFFFFF VISA Errors
        '''BFFC0000 to BFFCFFFF VXIPnP Driver Errors
        '''</returns>
        Public Function FetchReferenceWaveformHeader(ByVal Reference_Wfm As Integer, ByRef X_Start As Double, ByRef X_Stop As Double, ByRef Record_Length As Integer, ByRef Values_per_Sample As Integer) As Integer
            Dim pInvokeResult As Integer = PInvoke.FetchReferenceWaveformHeader(Me._handle, Reference_Wfm, X_Start, X_Stop, Record_Length, Values_per_Sample)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function obtains a main waveform measurement on the channel you specify, and returns the measurement value.  You specify a particular measurement type, such as rise time, frequency, and voltage peak-to-peak.
        '''
        '''Attribute(s):
        '''RSRTM_ATTR_MAIN_MEASUREMENT_RESULT
        '''
        '''Remote-control command(s):
        '''MEASurement&lt;m&gt;:RESult?
        '''</summary>
        '''<param name="Measurement">
        '''Selects waveform measurement.
        '''
        '''Valid Values:
        '''1 to 4
        '''
        '''Default Value: 1
        '''</param>
        '''<param name="Measurement_Function">
        '''Selects the result type.
        '''
        '''Valid Values:
        '''RSRTM_VAL_MEAS_FREQUENCY (1)  - Frequency
        '''RSRTM_VAL_MEAS_PERIOD    (2)  - Period
        '''RSRTM_VAL_MEAS_PEAK      (3)  - Peak Peak
        '''RSRTM_VAL_MEAS_UPEAK     (4)  - Peak Upper
        '''RSRTM_VAL_MEAS_LPEAK     (5)  - Peak Lower
        '''RSRTM_VAL_MEAS_PPC       (6)  - Positive Pulses Count
        '''RSRTM_VAL_MEAS_NPC       (7)  - Negative Pulses Count
        '''RSRTM_VAL_MEAS_REC       (8)  - Rising Edges Count
        '''RSRTM_VAL_MEAS_FEC       (9)  - Falling Edges Count
        '''RSRTM_VAL_MEAS_HIGH      (10)  - High
        '''RSRTM_VAL_MEAS_LOW       (11)  - Low
        '''RSRTM_VAL_MEAS_AMP       (12)  - Amplitude
        '''RSRTM_VAL_MEAS_MEAN      (13)  - Mean Value
        '''RSRTM_VAL_MEAS_RMS       (14)  - RMS Value
        '''RSRTM_VAL_MEAS_RTM       (15)  - Rise Time
        '''RSRTM_VAL_MEAS_FTIM      (16)  - Falling Time
        '''RSRTM_VAL_MEAS_PDCY      (17)  - Duty Cycle Positive
        '''RSRTM_VAL_MEAS_NDCY      (18)  - Duty Cycle Negative
        '''RSRTM_VAL_MEAS_PPW       (19)  - Pulse Width Positive
        '''RSRTM_VAL_MEAS_NPW       (20)  - Pulse Width Negative
        '''RSRTM_VAL_MEAS_CYCM      (21)  - Cycle Mean
        '''RSRTM_VAL_MEAS_CYCR      (22)  - Cycle RMS
        '''RSRTM_VAL_MEAS_SSTDD     (23)  - Standard Deviation
        '''RSRTM_VAL_MEAS_TFR       (24)  - Trigger Frequency
        '''RSRTM_VAL_MEAS_TPER      (25)  - Trigger Period
        '''
        '''Default Value: RSRTM_VAL_MEAS_FREQUENCY (1)
        '''</param>
        '''<param name="Measurement_Result">
        '''Returns the measured value.  
        '''
        '''Units:  The units depend on the Measurement Function you select as shown below.
        '''
        '''    Rise Time            - seconds
        '''    Fall Time            - seconds
        '''    Frequency            - hertz
        '''    Period               - seconds
        '''    Voltage RMS          - volts
        '''    Voltage RMS (Cycle)  - volts
        '''    Voltage Max          - volts
        '''    Voltage Min          - volts
        '''    Voltage Vpp          - volts
        '''    Voltage High         - volts
        '''    Voltage Low          - volts
        '''    Voltage Avg.         - volts
        '''    Voltage Avg. (Cycle) - volts
        '''    Width Negative       - seconds
        '''    Width Positive       - seconds
        '''    Duty Cycle Negative  - percent
        '''    Duty Cycle Positive  - percent
        '''    Amplitude            - volts
        '''
        '''
        '''
        '''</param>
        '''<returns>
        '''Returns the status code of this operation.  The status code  either indicates success or describes an error or warning condition.  You examine the status code from each call to an instrument driver function to determine if an error occurred.
        '''
        '''To obtain a text description of the status code, call the rsrtm_error_message function.  To obtain additional information about the error condition, call the rsrtm_GetError function.  To clear the error information from the driver, call the rsrtm_ClearError function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''
        '''Numeric Range (in Hex) Status Code Types
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF VISA Warnings
        '''3FFC0000 to 3FFCFFFF VXIPnP Driver Warnings
        '''
        '''BFFF0000 to BFFFFFFF VISA Errors
        '''BFFC0000 to BFFCFFFF VXIPnP Driver Errors
        '''</returns>
        Public Function FetchMainWaveformMeasurement(ByVal Measurement As Integer, ByVal Measurement_Function As Integer, ByRef Measurement_Result As Double) As Integer
            Dim pInvokeResult As Integer = PInvoke.FetchMainWaveformMeasurement(Me._handle, Measurement, Measurement_Function, Measurement_Result)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function aborts an acquisition and returns the oscilloscope to the Idle state.  You initiate an acquisition with the rsrtm_InitiateAcquisition function.
        '''
        '''Notes:
        '''
        '''(1) This function does not check the instrument status.   Typically, you call this function only in a sequence of calls to other low-level driver functions.  The sequence performs one operation.  You use the low-level functions to optimize one or more aspects of interaction with the instrument.  If you want to check the instrument status, call the rsrtm_error_query function at the conclusion of the sequence.
        '''
        '''Attribute(s):
        '''RSRTM_ATTR_STOP
        '''
        '''Remote-control command(s):
        '''STOP
        '''</summary>
        '''<returns>
        '''Returns the status code of this operation.  The status code  either indicates success or describes an error or warning condition.  You examine the status code from each call to an instrument driver function to determine if an error occurred.
        '''
        '''To obtain a text description of the status code, call the rsrtm_error_message function.  To obtain additional information about the error condition, call the rsrtm_GetError function.  To clear the error information from the driver, call the rsrtm_ClearError function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''
        '''Numeric Range (in Hex) Status Code Types
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF VISA Warnings
        '''3FFC0000 to 3FFCFFFF VXIPnP Driver Warnings
        '''
        '''BFFF0000 to BFFFFFFF VISA Errors
        '''BFFC0000 to BFFCFFFF VXIPnP Driver Errors
        '''</returns>
        Public Function Abort() As Integer
            Dim pInvokeResult As Integer = PInvoke.Abort(Me._handle)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function resets the instrument to a known state and sends initialization commands to the instrument.  The initialization commands set instrument settings such as Headers Off, Short Command form, and Data Transfer Binary to the state necessary for the operation of the instrument driver.
        '''
        '''Attribute(s):
        '''-
        '''
        '''Remote-control command(s):
        '''*RST
        '''</summary>
        '''<returns>
        '''Returns the status code of this operation.  The status code  either indicates success or describes an error or warning condition.  You examine the status code from each call to an instrument driver function to determine if an error occurred.
        '''
        '''To obtain a text description of the status code, call the rsrtm_error_message function.  To obtain additional information about the error condition, call the rsrtm_GetError function.  To clear the error information from the driver, call the rsrtm_ClearError function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''
        '''Numeric Range (in Hex) Status Code Types
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF VISA Warnings
        '''3FFC0000 to 3FFCFFFF VXIPnP Driver Warnings
        '''
        '''BFFF0000 to BFFFFFFF VISA Errors
        '''BFFC0000 to BFFCFFFF VXIPnP Driver Errors
        '''</returns>
        Public Function reset() As Integer
            Dim pInvokeResult As Integer = PInvoke.reset(Me._handle)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function runs the instrument's self test routine and returns the test result(s). 
        '''
        '''Attribute(s):
        '''RSRTM_ATTR_SELF_TEST_QUERY
        '''
        '''Remote-control command(s):
        '''*TST?
        '''*OPC
        '''</summary>
        '''<param name="Self_Test_Result">
        '''This control contains the value returned from the instrument self test.  Zero means success.  For any other code, see the device's operator's manual.
        '''
        '''Self-Test Code    Description
        '''---------------------------------------
        '''   0              Passed self test
        '''   1              Self test failed
        '''
        '''
        '''</param>
        '''<param name="Self_Test_Message">
        '''Returns the self-test response string from the instrument. See the device's operation manual for an explanation of the string's contents.
        '''
        '''You must pass a ViChar array with at least 256 bytes.
        '''</param>
        '''<returns>
        '''Returns the status code of this operation.  The status code  either indicates success or describes an error or warning condition.  You examine the status code from each call to an instrument driver function to determine if an error occurred.
        '''
        '''To obtain a text description of the status code, call the rsrtm_error_message function.  To obtain additional information about the error condition, call the rsrtm_GetError function.  To clear the error information from the driver, call the rsrtm_ClearError function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''
        '''Numeric Range (in Hex) Status Code Types
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF VISA Warnings
        '''3FFC0000 to 3FFCFFFF VXIPnP Driver Warnings
        '''
        '''BFFF0000 to BFFFFFFF VISA Errors
        '''BFFC0000 to BFFCFFFF VXIPnP Driver Errors
        '''</returns>
        Public Function self_test(ByRef Self_Test_Result As Short, ByVal Self_Test_Message As System.Text.StringBuilder) As Integer
            Dim pInvokeResult As Integer = PInvoke.self_test(Me._handle, Self_Test_Result, Self_Test_Message)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function returns the revision numbers of the instrument driver and instrument firmware.
        '''
        '''Attribute(s):
        '''RSRTM_ATTR_SPECIFIC_DRIVER_REVISION
        '''RSRTM_ATTR_INSTRUMENT_FIRMWARE_REVISION
        '''
        '''Remote-control command(s):
        '''-
        '''</summary>
        '''<param name="Instrument_Driver_Revision">
        '''Returns the instrument driver software revision numbers in the form of a string.
        '''
        '''You must pass a ViChar array with at least 256 bytes.
        '''</param>
        '''<param name="Firmware_Revision">
        '''Returns the instrument firmware revision numbers in the form of a string.
        '''
        '''You must pass a ViChar array with at least 256 bytes.
        '''
        '''</param>
        '''<returns>
        '''Returns the status code of this operation.  The status code  either indicates success or describes an error or warning condition.  You examine the status code from each call to an instrument driver function to determine if an error occurred.
        '''
        '''To obtain a text description of the status code, call the rsrtm_error_message function.  To obtain additional information about the error condition, call the rsrtm_GetError function.  To clear the error information from the driver, call the rsrtm_ClearError function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''
        '''Numeric Range (in Hex) Status Code Types
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF VISA Warnings
        '''3FFC0000 to 3FFCFFFF VXIPnP Driver Warnings
        '''
        '''BFFF0000 to BFFFFFFF VISA Errors
        '''BFFC0000 to BFFCFFFF VXIPnP Driver Errors
        '''</returns>
        Public Function revision_query(ByVal Instrument_Driver_Revision As System.Text.StringBuilder, ByVal Firmware_Revision As System.Text.StringBuilder) As Integer
            Dim pInvokeResult As Integer = PInvoke.revision_query(Me._handle, Instrument_Driver_Revision, Firmware_Revision)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function reads an error code and a message from the instrument's error queue.
        '''
        '''Attribute(s):
        '''RSRTM_ATTR_SYSTEM_ERROR
        '''
        '''Remote-control command(s):
        '''SYSTem:ERRor?
        '''</summary>
        '''<param name="Error_Code">
        '''Returns the error code read from the instrument's error queue.
        '''
        '''
        '''</param>
        '''<param name="Error_Message">
        '''Returns the error message string read from the instrument's error message queue.
        '''
        '''You must pass a ViChar array with at least 256 bytes.
        '''
        '''</param>
        '''<returns>
        '''Returns the status code of this operation.  The status code  either indicates success or describes an error or warning condition.  You examine the status code from each call to an instrument driver function to determine if an error occurred.
        '''
        '''To obtain a text description of the status code, call the rsrtm_error_message function.  To obtain additional information about the error condition, call the rsrtm_GetError function.  To clear the error information from the driver, call the rsrtm_ClearError function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''
        '''Numeric Range (in Hex) Status Code Types
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF VISA Warnings
        '''3FFC0000 to 3FFCFFFF VXIPnP Driver Warnings
        '''
        '''BFFF0000 to BFFFFFFF VISA Errors
        '''BFFC0000 to BFFCFFFF VXIPnP Driver Errors
        '''</returns>
        Public Function error_query(ByRef Error_Code As Integer, ByVal Error_Message As System.Text.StringBuilder) As Integer
            Dim pInvokeResult As Integer = PInvoke.error_query(Me._handle, Error_Code, Error_Message)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''Queries the error/event queue for all unread items and removes them from the queue. The response is a comma separated list of error number and a short description of the error in FIFO order.
        '''Positive error numbers are instrument-dependent. Negative error numbers are reserved by the SCPI standard.
        '''
        '''Attribute(s):
        '''RSRTM_ATTR_SYST_ERR_LIST
        '''
        '''Remote-control command(s):
        '''SYSTem:ERRor:ALL?
        '''</summary>
        '''<param name="Buffer_Size">
        '''Sets the size of Errors string.
        '''
        '''Valid Values:
        '''&gt; 0
        '''
        '''Default Value:
        '''1024
        '''</param>
        '''<param name="Errors">
        '''Returns the error message string read from the instrument's error message queue.
        '''
        '''
        '''
        '''</param>
        '''<returns>
        '''Returns the status code of this operation. The status code either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rsspecan_error_message function.
        '''
        '''The general meaning of the status code is as follows:
        '''
        '''Value Meaning
        '''-------------------------------
        '''0 Success
        '''Positive Values Warnings
        '''Negative Values Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''
        '''Numeric Range (in Hex) Status Code Types
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF VISA Warnings
        '''3FFC0000 to 3FFCFFFF VXIPnP Driver Warnings
        '''
        '''BFFF0000 to BFFFFFFF VISA Errors
        '''BFFC0000 to BFFCFFFF VXIPnP Driver Errors
        '''</returns>
        Public Function ErrorList(ByVal Buffer_Size As Integer, ByVal Errors As System.Text.StringBuilder) As Integer
            Dim pInvokeResult As Integer = PInvoke.ErrorList(Me._handle, Buffer_Size, Errors)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function defines an instrument name.
        '''
        '''Attribute(s):
        '''RSRTM_ATTR_INSTRUMENT_NAME
        '''
        '''Remote-control command(s):
        '''SYSTem:NAME
        '''</summary>
        '''<param name="Name">
        '''Defines the name.
        '''
        '''Valid Values:
        '''not checked
        '''
        '''Default Value:
        '''""
        '''
        '''Attribute:
        '''RSRTM_ATTR_INSTRUMENT_NAME
        '''</param>
        '''<returns>
        '''Returns the status code of this operation.  The status code  either indicates success or describes an error or warning condition.  You examine the status code from each call to an instrument driver function to determine if an error occurred.
        '''
        '''To obtain a text description of the status code, call the rsrtm_error_message function.  To obtain additional information about the error condition, call the rsrtm_GetError function.  To clear the error information from the driver, call the rsrtm_ClearError function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''
        '''Numeric Range (in Hex) Status Code Types
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF VISA Warnings
        '''3FFC0000 to 3FFCFFFF VXIPnP Driver Warnings
        '''
        '''BFFF0000 to BFFFFFFF VISA Errors
        '''BFFC0000 to BFFCFFFF VXIPnP Driver Errors
        '''</returns>
        Public Function ConfigureInstrumentName(ByVal Name As String) As Integer
            Dim pInvokeResult As Integer = PInvoke.ConfigureInstrumentName(Me._handle, Name)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function resets all STATUS:QUESTIONALBLE registers.
        '''
        '''Attribute(s):
        '''RSRTM_ATTR_RESET_STATUS_REGISTER
        '''
        '''Remote-control command(s):
        '''STATus:PRESet
        '''</summary>
        '''<returns>
        '''Returns the status code of this operation.  The status code  either indicates success or describes an error or warning condition.  You examine the status code from each call to an instrument driver function to determine if an error occurred.
        '''
        '''To obtain a text description of the status code, call the rsrtm_error_message function.  To obtain additional information about the error condition, call the rsrtm_GetError function.  To clear the error information from the driver, call the rsrtm_ClearError function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''
        '''Numeric Range (in Hex) Status Code Types
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF VISA Warnings
        '''3FFC0000 to 3FFCFFFF VXIPnP Driver Warnings
        '''
        '''BFFF0000 to BFFFFFFF VISA Errors
        '''BFFC0000 to BFFCFFFF VXIPnP Driver Errors
        '''</returns>
        Public Function ResetStatusRegisters() As Integer
            Dim pInvokeResult As Integer = PInvoke.ResetStatusRegisters(Me._handle)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function sets the status reporting system.
        '''
        '''Note:
        '''
        '''(1) For detailed description of Status Reporting System see also operating manual.
        '''
        '''Attribute(s):
        '''RSRTM_ATTR_REGISTER
        '''
        '''Remote-control command(s):
        '''STATus:OPERation:CONDition
        '''STATus:OPERation:ENABle
        '''STATus:OPERation:NTRansition
        '''STATus:OPERation:PTRansition
        '''STATus:OPERation[:EVENt]
        '''STATus:QUEStionable:CONDition
        '''STATus:QUEStionable:ENABle
        '''STATus:QUEStionable:NTRansition
        '''STATus:QUEStionable:PTRansition
        '''STATus:QUEStionable[:EVENt]
        '''STATus:QUEStionable:COVerload:CONDition
        '''STATus:QUEStionable:COVerload:ENABle
        '''STATus:QUEStionable:COVerload:NTRansition
        '''STATus:QUEStionable:COVerload:PTRansition
        '''STATus:QUEStionable:COVerload[:EVENt]
        '''STATus:QUEStionable:LIMit:CONDition
        '''STATus:QUEStionable:LIMit:ENABle
        '''STATus:QUEStionable:LIMit:NTRansition
        '''STATus:QUEStionable:LIMit:PTRansition
        '''STATus:QUEStionable:LIMit[:EVENt]
        '''STATus:QUEStionable:MASK:CONDition
        '''STATus:QUEStionable:MASK:ENABle
        '''STATus:QUEStionable:MASK:NTRansition
        '''STATus:QUEStionable:MASK:PTRansition
        '''STATus:QUEStionable:MASK[:EVENt]
        '''
        '''</summary>
        '''<param name="Register_Type">
        '''This control selects type of the registers that will be configured. 
        '''
        '''Valid Values:
        '''RSRTM_VAL_REG_OPER (0) - Operation
        '''RSRTM_VAL_REG_QUES (1) - Questionable
        '''
        '''Default Value: RSRTM_VAL_REG_OPER (0)
        '''</param>
        '''<param name="Status_Register">
        '''This control selects the registers that will be configured. 
        '''
        '''Valid Values:
        '''RSRTM_VAL_REG_NONE     (0) - None
        '''RSRTM_VAL_REG_COV      (1) - Channel Overload
        '''RSRTM_VAL_REG_LIM      (2) - Limit
        '''RSRTM_VAL_REG_MASK     (3) - Mask
        '''RSRTM_VAL_REG_NO_ALIGN (4) - No Align Data
        '''
        '''Default Value: RSRTM_VAL_REG_NONE (0)
        '''</param>
        '''<param name="Register_Part">
        '''This control selects the registers that will be configured. 
        '''
        '''Valid Values:
        '''RSRTM_VAL_REG_COND   (0) - Condition
        '''RSRTM_VAL_REG_ENABLE (1) - Enabled
        '''RSRTM_VAL_REG_EVENT  (2) - Event
        '''RSRTM_VAL_REG_NTR    (3) - N Transition
        '''RSRTM_VAL_REG_PTR    (4) - P Transition
        '''
        '''Default Value: RSRTM_VAL_REG_COND  (0)
        '''</param>
        '''<param name="Register_Value">
        '''Value of selected register.
        '''
        '''Note:
        '''
        '''For detailed description of Status Reporting System see also operating manual.
        '''</param>
        '''<returns>
        '''Returns the status code of this operation. The status code either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rsspecan_error_message function.
        '''
        '''The general meaning of the status code is as follows:
        '''
        '''Value Meaning
        '''-------------------------------
        '''0 Success
        '''Positive Values Warnings
        '''Negative Values Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''
        '''Numeric Range (in Hex) Status Code Types
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF VISA Warnings
        '''3FFC0000 to 3FFCFFFF VXIPnP Driver Warnings
        '''
        '''BFFF0000 to BFFFFFFF VISA Errors
        '''BFFC0000 to BFFCFFFF VXIPnP Driver Errors
        '''</returns>
        Public Function SetStatusRegister(ByVal Register_Type As Integer, ByVal Status_Register As Integer, ByVal Register_Part As Integer, ByVal Register_Value As Integer) As Integer
            Dim pInvokeResult As Integer = PInvoke.SetStatusRegister(Me._handle, Register_Type, Status_Register, Register_Part, Register_Value)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function queries the status reporting system.
        '''
        '''Note:
        '''
        '''(1) For detailed description of Status Reporting System see also operating manual.
        '''
        '''Attribute(s):
        '''RSRTM_ATTR_REGISTER
        '''
        '''Remote-control command(s):
        '''STATus:OPERation:CONDition
        '''STATus:OPERation:ENABle
        '''STATus:OPERation:NTRansition
        '''STATus:OPERation:PTRansition
        '''STATus:OPERation[:EVENt]
        '''STATus:QUEStionable:CONDition
        '''STATus:QUEStionable:ENABle
        '''STATus:QUEStionable:NTRansition
        '''STATus:QUEStionable:PTRansition
        '''STATus:QUEStionable[:EVENt]
        '''STATus:QUEStionable:COVerload:CONDition
        '''STATus:QUEStionable:COVerload:ENABle
        '''STATus:QUEStionable:COVerload:NTRansition
        '''STATus:QUEStionable:COVerload:PTRansition
        '''STATus:QUEStionable:COVerload[:EVENt]
        '''STATus:QUEStionable:LIMit:CONDition
        '''STATus:QUEStionable:LIMit:ENABle
        '''STATus:QUEStionable:LIMit:NTRansition
        '''STATus:QUEStionable:LIMit:PTRansition
        '''STATus:QUEStionable:LIMit[:EVENt]
        '''STATus:QUEStionable:MASK:CONDition
        '''STATus:QUEStionable:MASK:ENABle
        '''STATus:QUEStionable:MASK:NTRansition
        '''STATus:QUEStionable:MASK:PTRansition
        '''STATus:QUEStionable:MASK[:EVENt]
        '''
        '''</summary>
        '''<param name="Register_Type">
        '''This control selects type of the registers that will be queried. 
        '''
        '''Valid Values:
        '''RSRTM_VAL_REG_OPER (0) - Operation
        '''RSRTM_VAL_REG_QUES (1) - Questionable
        '''
        '''Default Value: RSRTM_VAL_REG_OPER (0)
        '''</param>
        '''<param name="Status_Register">
        '''This control selects the registers that will be configured. 
        '''
        '''Valid Values:
        '''RSRTM_VAL_REG_NONE     (0) - None
        '''RSRTM_VAL_REG_COV      (1) - Channel Overload
        '''RSRTM_VAL_REG_LIM      (2) - Limit
        '''RSRTM_VAL_REG_MASK     (3) - Mask
        '''RSRTM_VAL_REG_NO_ALIGN (4) - No Align Data
        '''
        '''Default Value: RSRTM_VAL_REG_NONE (0)
        '''</param>
        '''<param name="Register_Part">
        '''This control selects the registers that will be queried. 
        '''
        '''Valid Values:
        '''RSRTM_VAL_REG_COND   (0) - Condition
        '''RSRTM_VAL_REG_ENABLE (1) - Enabled
        '''RSRTM_VAL_REG_EVENT  (2) - Event
        '''RSRTM_VAL_REG_NTR    (3) - N Transition
        '''RSRTM_VAL_REG_PTR    (4) - P Transition
        '''
        '''Default Value: RSRTM_VAL_REG_COND  (0)
        '''</param>
        '''<param name="Register_Value">
        '''Returns value of selected register.
        '''
        '''Note:
        '''
        '''For detailed description of Status Reporting System see also operating manual.
        '''</param>
        '''<returns>
        '''Returns the status code of this operation. The status code either indicates success or describes an error or warning condition. You examine the status code from each call to an instrument driver function to determine if an error occurred. To obtain a text description of the status code, call the rsspecan_error_message function.
        '''
        '''The general meaning of the status code is as follows:
        '''
        '''Value Meaning
        '''-------------------------------
        '''0 Success
        '''Positive Values Warnings
        '''Negative Values Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''
        '''Numeric Range (in Hex) Status Code Types
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF VISA Warnings
        '''3FFC0000 to 3FFCFFFF VXIPnP Driver Warnings
        '''
        '''BFFF0000 to BFFFFFFF VISA Errors
        '''BFFC0000 to BFFCFFFF VXIPnP Driver Errors
        '''</returns>
        Public Function GetStatusRegister(ByVal Register_Type As Integer, ByVal Status_Register As Integer, ByVal Register_Part As Integer, ByRef Register_Value As Integer) As Integer
            Dim pInvokeResult As Integer = PInvoke.GetStatusRegister(Me._handle, Register_Type, Status_Register, Register_Part, Register_Value)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function writes a user-specified string to the instrument.
        '''
        '''Note:  This function bypasses IVI attribute state caching.  Therefore, when you call this function, the cached values for all attributes will be invalidated.
        '''</summary>
        '''<param name="Write_Buffer">
        '''Pass the string to be written to the instrument.
        '''</param>
        '''<returns>
        '''Returns the status code of this operation.  The status code  either indicates success or describes an error or warning condition.  You examine the status code from each call to an instrument driver function to determine if an error occurred.
        '''
        '''To obtain a text description of the status code, call the rsrtm_error_message function.  To obtain additional information about the error condition, call the rsrtm_GetError function.  To clear the error information from the driver, call the rsrtm_ClearError function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''
        '''Numeric Range (in Hex) Status Code Types
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF VISA Warnings
        '''3FFC0000 to 3FFCFFFF VXIPnP Driver Warnings
        '''
        '''BFFF0000 to BFFFFFFF VISA Errors
        '''BFFC0000 to BFFCFFFF VXIPnP Driver Errors
        '''</returns>
        Public Function WriteInstrData(ByVal Write_Buffer As String) As Integer
            Dim pInvokeResult As Integer = PInvoke.WriteInstrData(Me._handle, Write_Buffer)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function reads data from the instrument.
        '''</summary>
        '''<param name="Number_of_Bytes_To_Read">
        '''Pass the maximum number of bytes to read from the instruments.  
        '''
        '''Valid Values: 
        '''not checked
        '''
        '''Default Value:  256
        '''
        '''
        '''</param>
        '''<param name="Read_Buffer">
        '''After this function executes, this parameter contains the data that was read from the instrument.
        '''</param>
        '''<param name="Num_Bytes_Read">
        '''Returns the number of bytes actually read from the instrument and stored in the Read Buffer.
        '''</param>
        '''<returns>
        '''Returns the status code of this operation.  The status code  either indicates success or describes an error or warning condition.  You examine the status code from each call to an instrument driver function to determine if an error occurred.
        '''
        '''To obtain a text description of the status code, call the rsrtm_error_message function.  To obtain additional information about the error condition, call the rsrtm_GetError function.  To clear the error information from the driver, call the rsrtm_ClearError function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''
        '''Numeric Range (in Hex) Status Code Types
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF VISA Warnings
        '''3FFC0000 to 3FFCFFFF VXIPnP Driver Warnings
        '''
        '''BFFF0000 to BFFFFFFF VISA Errors
        '''BFFC0000 to BFFCFFFF VXIPnP Driver Errors
        '''</returns>
        Public Function ReadInstrData(ByVal Number_of_Bytes_To_Read As Integer, ByVal Read_Buffer As System.Text.StringBuilder, ByRef Num_Bytes_Read As UInteger) As Integer
            Dim pInvokeResult As Integer = PInvoke.ReadInstrData(Me._handle, Number_of_Bytes_To_Read, Read_Buffer, Num_Bytes_Read)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function queries the ViBoolean value.
        '''
        '''
        '''</summary>
        '''<param name="Command">
        '''The query to be sent to the instrument.
        '''
        '''Default Value:  ""
        '''</param>
        '''<param name="Value">
        '''Returns the ViBoolean value
        '''
        '''</param>
        '''<returns>
        '''Returns the status code of this operation.  The status code  either indicates success or describes an error or warning condition.  You examine the status code from each call to an instrument driver function to determine if an error occurred.
        '''
        '''To obtain a text description of the status code, call the rsrtm_error_message function.  To obtain additional information about the error condition, call the rsrtm_GetError function.  To clear the error information from the driver, call the rsrtm_ClearError function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''
        '''Numeric Range (in Hex) Status Code Types
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF VISA Warnings
        '''3FFC0000 to 3FFCFFFF VXIPnP Driver Warnings
        '''
        '''BFFF0000 to BFFFFFFF VISA Errors
        '''BFFC0000 to BFFCFFFF VXIPnP Driver Errors
        '''</returns>
        Public Function QueryViBoolean(ByVal Command As String, ByRef Value As Boolean) As Integer
            Dim ValueAsUShort As UShort
            Dim pInvokeResult As Integer = PInvoke.QueryViBoolean(Me._handle, Command, ValueAsUShort)
            Value = System.Convert.ToBoolean(ValueAsUShort)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function queries the ViInt32 value.
        '''
        '''
        '''</summary>
        '''<param name="Command">
        '''The query to be sent to the instrument.
        '''
        '''Default Value:  ""
        '''</param>
        '''<param name="Value">
        '''Returns the ViInt32 value
        '''
        '''</param>
        '''<returns>
        '''Returns the status code of this operation.  The status code  either indicates success or describes an error or warning condition.  You examine the status code from each call to an instrument driver function to determine if an error occurred.
        '''
        '''To obtain a text description of the status code, call the rsrtm_error_message function.  To obtain additional information about the error condition, call the rsrtm_GetError function.  To clear the error information from the driver, call the rsrtm_ClearError function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''
        '''Numeric Range (in Hex) Status Code Types
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF VISA Warnings
        '''3FFC0000 to 3FFCFFFF VXIPnP Driver Warnings
        '''
        '''BFFF0000 to BFFFFFFF VISA Errors
        '''BFFC0000 to BFFCFFFF VXIPnP Driver Errors
        '''</returns>
        Public Function QueryViInt32(ByVal Command As String, ByRef Value As Integer) As Integer
            Dim pInvokeResult As Integer = PInvoke.QueryViInt32(Me._handle, Command, Value)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function queries the ViReal64 value.
        '''
        '''
        '''</summary>
        '''<param name="Command">
        '''The query to be sent to the instrument.
        '''
        '''Default Value:  ""
        '''</param>
        '''<param name="Value">
        '''Returns the ViReal64 value
        '''
        '''</param>
        '''<returns>
        '''Returns the status code of this operation.  The status code  either indicates success or describes an error or warning condition.  You examine the status code from each call to an instrument driver function to determine if an error occurred.
        '''
        '''To obtain a text description of the status code, call the rsrtm_error_message function.  To obtain additional information about the error condition, call the rsrtm_GetError function.  To clear the error information from the driver, call the rsrtm_ClearError function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''
        '''Numeric Range (in Hex) Status Code Types
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF VISA Warnings
        '''3FFC0000 to 3FFCFFFF VXIPnP Driver Warnings
        '''
        '''BFFF0000 to BFFFFFFF VISA Errors
        '''BFFC0000 to BFFCFFFF VXIPnP Driver Errors
        '''</returns>
        Public Function QueryViReal64(ByVal Command As String, ByRef Value As Double) As Integer
            Dim pInvokeResult As Integer = PInvoke.QueryViReal64(Me._handle, Command, Value)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function queries the ViString value.
        '''
        '''
        '''</summary>
        '''<param name="Command">
        '''The query to be sent to the instrument.
        '''
        '''Default Value:  ""
        '''</param>
        '''<param name="Buffer_Size">
        '''Pass the number of bytes in the ViChar array you specify for the  Value parameter.  
        '''
        '''If the current value of the attribute, including the terminating NUL byte, contains more bytes that you indicate in this parameter, the function copies Buffer Size - 1 bytes into the buffer, places an ASCII NUL byte at the end of the buffer, and returns the buffer size you must pass to get the entire value.  For example, if the value is "123456" and the Buffer Size is 4, the function places "123" into the buffer and returns 7.
        '''
        '''If you pass a negative number, the function copies the value to the buffer regardless of the number of bytes in the value.
        '''
        '''If you pass 0, you can pass VI_NULL for the Value buffer parameter.
        '''
        '''Default Value: 512
        '''</param>
        '''<param name="Value">
        '''Returns the string value.
        '''
        '''</param>
        '''<returns>
        '''Returns the status code of this operation.  The status code  either indicates success or describes an error or warning condition.  You examine the status code from each call to an instrument driver function to determine if an error occurred.
        '''
        '''To obtain a text description of the status code, call the rsrtm_error_message function.  To obtain additional information about the error condition, call the rsrtm_GetError function.  To clear the error information from the driver, call the rsrtm_ClearError function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''
        '''Numeric Range (in Hex) Status Code Types
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF VISA Warnings
        '''3FFC0000 to 3FFCFFFF VXIPnP Driver Warnings
        '''
        '''BFFF0000 to BFFFFFFF VISA Errors
        '''BFFC0000 to BFFCFFFF VXIPnP Driver Errors
        '''</returns>
        Public Function QueryViString(ByVal Command As String, ByVal Buffer_Size As Integer, ByVal Value As System.Text.StringBuilder) As Integer
            Dim pInvokeResult As Integer = PInvoke.QueryViString(Me._handle, Command, Buffer_Size, Value)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function provides mass storage capabilities for the instrument.
        '''
        '''Attribute(s):
        '''RSRTM_ATTR_DELETE_FILE
        '''RSRTM_ATTR_CREATE_DIRECTORY
        '''RSRTM_ATTR_CURRENT_DIRECTORY
        '''RSRTM_ATTR_REMOVE_DIRECTORY
        '''RSRTM_ATTR_CHANGE_DRIVE
        '''
        '''Remote-control command(s):
        '''MMEMory:COPY
        '''MMEMory:MOVE
        '''MMEMory:DELete
        '''MMEMory:MDIRectory
        '''MMEMory:CDIRectory
        '''MMEMory:RDIRectory
        '''MMEMory:MSIS
        '''</summary>
        '''<param name="Operation">
        '''This control selects the type of memory operation to be performed.
        '''
        '''Valid Values:
        '''RSRTM_VAL_FILE_COPY    (0) - Copy
        '''RSRTM_VAL_FILE_MOVE    (1) - Move
        '''RSRTM_VAL_FILE_DELETE  (2) - Delete File
        '''RSRTM_VAL_FILE_NEW_DIR (3) - New Directory
        '''RSRTM_VAL_FILE_CDIR    (4) - Change Directory
        '''RSRTM_VAL_FILE_RDIR    (5) - Delete Directory
        '''RSRTM_VAL_FILE_CDRIVE  (6) - Change Drive
        '''
        '''Default Value: RSRTM_VAL_FILE_NEW_DIR (3)
        '''
        '''Note(s):
        '''
        '''(1) New Directory
        '''This command creates a new directory. Put the directory name into Source control (Example '/INT/SETTINGS/DATA').
        '''
        '''(2) Copy:
        '''This command copies the files indicated. The indication of the file name may include the path and the drive. Use Source (Example '/INT/SETTINGS/SET.SET') and Destination (Example '/INT/SETTINGS/SET2.SET') controls to define file names.
        '''
        '''(3) Move
        '''This command renames existing files. Use Source (Example 'SET.SET') and Destination (Example 'SET2.SET') controls to define file names.
        '''
        '''(3) Delete File:
        '''This command deletes the files indicated. The indication of the file name contains the path and, optionally, the drive. The file name includes indication of the path and may also include the drive. Use Source control to define files to be deleted (Example 'TEST01.HCP').
        '''
        '''(4) Delete Directory:
        '''This command deletes the directory indicated. The directory name includes indication of the path and may also include the drive.  Use Source control to define directory name (Example '/INT/SETTINGS/DATA'). 
        '''
        '''(5) Change Directory:
        '''This command changes the current directory. In addition to the path name, the indication of the directory may contain the drive name.  Put the directory name into Source control (Example '/INT/SETTINGS/DATA').
        '''
        '''(6) Change Drive:
        '''This command changes to the drive indicated. The drive may be for example the internal hard disk '/INT'. 
        '''</param>
        '''<param name="Source">
        '''This control specifies the source of the operation to be performed. If the operation requires a single parameter, this control specifies that parameter.
        '''
        '''Valid Values:
        '''not checked
        '''
        '''Default Value: "/INT"
        '''
        '''Attribute:
        '''RSRTM_ATTR_DELETE_FILE
        '''RSRTM_ATTR_CREATE_DIRECTORY
        '''RSRTM_ATTR_CURRENT_DIRECTORY
        '''RSRTM_ATTR_REMOVE_DIRECTORY
        '''RSRTM_ATTR_CHANGE_DRIVE
        '''</param>
        '''<param name="Destination">
        '''This control specifies the destination of the operation to be performed.
        '''
        '''Valid Values: not tested
        '''
        '''Default Value: ""
        '''
        '''</param>
        '''<returns>
        '''Returns the status code of this operation.  The status code  either indicates success or describes an error or warning condition.  You examine the status code from each call to an instrument driver function to determine if an error occurred.
        '''
        '''To obtain a text description of the status code, call the rsrtm_error_message function.  To obtain additional information about the error condition, call the rsrtm_GetError function.  To clear the error information from the driver, call the rsrtm_ClearError function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''
        '''Numeric Range (in Hex) Status Code Types
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF VISA Warnings
        '''3FFC0000 to 3FFCFFFF VXIPnP Driver Warnings
        '''
        '''BFFF0000 to BFFFFFFF VISA Errors
        '''BFFC0000 to BFFCFFFF VXIPnP Driver Errors
        '''</returns>
        Public Function FileManagerOperations(ByVal Operation As Integer, ByVal Source As String, ByVal Destination As String) As Integer
            Dim pInvokeResult As Integer = PInvoke.FileManagerOperations(Me._handle, Operation, Source, Destination)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''Returns the number of files and subdirectories of the current or of a specified directory. The number includes the parent directory strings "." and ".." so that it corresponds to the number of strings returned by the rsrtm_FileDirectoryContent function after the initial numeric parameters.
        '''
        '''Attribute(s):
        '''-
        '''
        '''Remote-control command(s):
        '''MMEMory:CATalog:LENGth?
        '''</summary>
        '''<param name="Directory">
        '''This control specifies the directory in which the command will be performed.
        '''
        '''Valid Values: not tested
        '''
        '''Default Value: "/INT"
        '''
        '''</param>
        '''<param name="Number_of_Files_And_Folders">
        '''Returns the number of files and subdirectories of the current or of a specified directory.
        '''</param>
        '''<returns>
        '''Returns the status code of this operation.  The status code  either indicates success or describes an error or warning condition.  You examine the status code from each call to an instrument driver function to determine if an error occurred.
        '''
        '''To obtain a text description of the status code, call the rsrtm_error_message function.  To obtain additional information about the error condition, call the rsrtm_GetError function.  To clear the error information from the driver, call the rsrtm_ClearError function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''
        '''Numeric Range (in Hex) Status Code Types
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF VISA Warnings
        '''3FFC0000 to 3FFCFFFF VXIPnP Driver Warnings
        '''
        '''BFFF0000 to BFFFFFFF VISA Errors
        '''BFFC0000 to BFFCFFFF VXIPnP Driver Errors
        '''</returns>
        Public Function FileCount(ByVal Directory As String, ByRef Number_of_Files_And_Folders As Integer) As Integer
            Dim pInvokeResult As Integer = PInvoke.FileCount(Me._handle, Directory, Number_of_Files_And_Folders)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function reads the indicated directory. According to DOS convention, wild card characters can be entered in order to query eg. a list of all file of a certain type.
        '''
        '''Attribute(s):
        '''-
        '''
        '''Remote-control command(s):
        '''MMEMory:CATalog?
        '''</summary>
        '''<param name="Directory">
        '''This control specifies the directory in which the command will be performed.
        '''
        '''Valid Values: not tested
        '''
        '''Default Value: "/INT"
        '''
        '''</param>
        '''<param name="Buffer_Size">
        '''Pass the number of bytes in the ViChar array you specify for the Output parameter.  
        '''
        '''If the current value of the attribute, including the terminating NUL byte, contains more bytes that you indicate in this parameter, the function copies Buffer Size - 1 bytes into the buffer, places an ASCII NUL byte at the end of the buffer, and returns the buffer size you must pass to get the entire value.  For example, if the value is "123456" and the Buffer Size is 4, the function places "123" into the buffer and returns 7.
        '''
        '''If you pass a negative number, the function copies the value to the buffer regardless of the number of bytes in the value.
        '''
        '''If you pass 0, you can pass VI_NULL for the Attribute Value buffer parameter.
        '''
        '''</param>
        '''<param name="Output">
        '''This indicator returns the files in the indicated directory as comma separated strings, for example: 'SPOOL1.WMF','SPOOL2.WMF','SPOOL3.WMF'
        '''
        '''The buffer must be of type ViChar and have at least as many bytes as indicated in the Buffer Size parameter.
        '''
        '''If the current value of the attribute, including the terminating NUL byte, contains more bytes that you indicate in this parameter, the function copies Buffer Size - 1 bytes into the buffer, places an ASCII NUL byte at the end of the buffer, and returns the buffer size you must pass to get the entire value.  For example, if the value is "123456" and the Buffer Size is 4, the function places "123" into the buffer and returns 7.
        '''
        '''If you specify 0 for the Buffer Size parameter, you can pass VI_NULL for this parameter.
        '''</param>
        '''<returns>
        '''Returns the status code of this operation.  The status code  either indicates success or describes an error or warning condition.  You examine the status code from each call to an instrument driver function to determine if an error occurred.
        '''
        '''To obtain a text description of the status code, call the rsrtm_error_message function.  To obtain additional information about the error condition, call the rsrtm_GetError function.  To clear the error information from the driver, call the rsrtm_ClearError function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''
        '''Numeric Range (in Hex) Status Code Types
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF VISA Warnings
        '''3FFC0000 to 3FFCFFFF VXIPnP Driver Warnings
        '''
        '''BFFF0000 to BFFFFFFF VISA Errors
        '''BFFC0000 to BFFCFFFF VXIPnP Driver Errors
        '''</returns>
        Public Function FileDirectoryContent(ByVal Directory As String, ByVal Buffer_Size As Integer, ByVal Output As System.Text.StringBuilder) As Integer
            Dim pInvokeResult As Integer = PInvoke.FileDirectoryContent(Me._handle, Directory, Buffer_Size, Output)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''Returns the number of subdirectories of the current or of a specified directory. The number includes the parent directory strings "." and ".." so that it corresponds to the number of strings returned by the rsrtm_FileSubdirectories.
        '''
        '''Attribute(s):
        '''-
        '''
        '''Remote-control command(s):
        '''MMEMory:DCATalog:LENGth?
        '''</summary>
        '''<param name="Directory">
        '''This control specifies the directory in which the command will be performed.
        '''
        '''Valid Values: not tested
        '''
        '''Default Value: "/INT"
        '''
        '''</param>
        '''<param name="Number_of_Subdirectories">
        '''Returns the number of files and subdirectories of the current or of a specified directory.
        '''</param>
        '''<returns>
        '''Returns the status code of this operation.  The status code  either indicates success or describes an error or warning condition.  You examine the status code from each call to an instrument driver function to determine if an error occurred.
        '''
        '''To obtain a text description of the status code, call the rsrtm_error_message function.  To obtain additional information about the error condition, call the rsrtm_GetError function.  To clear the error information from the driver, call the rsrtm_ClearError function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''
        '''Numeric Range (in Hex) Status Code Types
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF VISA Warnings
        '''3FFC0000 to 3FFCFFFF VXIPnP Driver Warnings
        '''
        '''BFFF0000 to BFFFFFFF VISA Errors
        '''BFFC0000 to BFFCFFFF VXIPnP Driver Errors
        '''</returns>
        Public Function FileSubdirectoriesCount(ByVal Directory As String, ByRef Number_of_Subdirectories As Integer) As Integer
            Dim pInvokeResult As Integer = PInvoke.FileSubdirectoriesCount(Me._handle, Directory, Number_of_Subdirectories)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''Returns the subdirectories of the current or of a specified directory.
        '''
        '''Attribute(s):
        '''-
        '''
        '''Remote-control command(s):
        '''MMEMory:DCATalog?
        '''</summary>
        '''<param name="Directory">
        '''This control specifies the directory in which the command will be performed.
        '''
        '''Valid Values: not tested
        '''
        '''Default Value: "/INT"
        '''
        '''</param>
        '''<param name="Buffer_Size">
        '''Pass the number of bytes in the ViChar array you specify for the Output parameter.  
        '''
        '''If the current value of the attribute, including the terminating NUL byte, contains more bytes that you indicate in this parameter, the function copies Buffer Size - 1 bytes into the buffer, places an ASCII NUL byte at the end of the buffer, and returns the buffer size you must pass to get the entire value.  For example, if the value is "123456" and the Buffer Size is 4, the function places "123" into the buffer and returns 7.
        '''
        '''If you pass a negative number, the function copies the value to the buffer regardless of the number of bytes in the value.
        '''
        '''If you pass 0, you can pass VI_NULL for the Attribute Value buffer parameter.
        '''
        '''</param>
        '''<param name="Output">
        '''This indicator returns the files in the indicated directory as comma separated strings, for example: 'SPOOL1.WMF','SPOOL2.WMF','SPOOL3.WMF'
        '''
        '''The buffer must be of type ViChar and have at least as many bytes as indicated in the Buffer Size parameter.
        '''
        '''If the current value of the attribute, including the terminating NUL byte, contains more bytes that you indicate in this parameter, the function copies Buffer Size - 1 bytes into the buffer, places an ASCII NUL byte at the end of the buffer, and returns the buffer size you must pass to get the entire value.  For example, if the value is "123456" and the Buffer Size is 4, the function places "123" into the buffer and returns 7.
        '''
        '''If you specify 0 for the Buffer Size parameter, you can pass VI_NULL for this parameter.
        '''</param>
        '''<returns>
        '''Returns the status code of this operation.  The status code  either indicates success or describes an error or warning condition.  You examine the status code from each call to an instrument driver function to determine if an error occurred.
        '''
        '''To obtain a text description of the status code, call the rsrtm_error_message function.  To obtain additional information about the error condition, call the rsrtm_GetError function.  To clear the error information from the driver, call the rsrtm_ClearError function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''
        '''Numeric Range (in Hex) Status Code Types
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF VISA Warnings
        '''3FFC0000 to 3FFCFFFF VXIPnP Driver Warnings
        '''
        '''BFFF0000 to BFFFFFFF VISA Errors
        '''BFFC0000 to BFFCFFFF VXIPnP Driver Errors
        '''</returns>
        Public Function FileSubdirectories(ByVal Directory As String, ByVal Buffer_Size As Integer, ByVal Output As System.Text.StringBuilder) As Integer
            Dim pInvokeResult As Integer = PInvoke.FileSubdirectories(Me._handle, Directory, Buffer_Size, Output)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''Returns a list of the drives of the instrument.
        '''
        '''Attribute(s):
        '''RSRTM_ATTR_DRIVES
        '''
        '''Remote-control command(s):
        '''MMEMory:DRIVes?
        '''</summary>
        '''<param name="Buffer_Size">
        '''Pass the number of bytes in the ViChar array you specify for the Output parameter.  
        '''
        '''If the current value of the attribute, including the terminating NUL byte, contains more bytes that you indicate in this parameter, the function copies Buffer Size - 1 bytes into the buffer, places an ASCII NUL byte at the end of the buffer, and returns the buffer size you must pass to get the entire value.  For example, if the value is "123456" and the Buffer Size is 4, the function places "123" into the buffer and returns 7.
        '''
        '''If you pass a negative number, the function copies the value to the buffer regardless of the number of bytes in the value.
        '''
        '''If you pass 0, you can pass VI_NULL for the Attribute Value buffer parameter.
        '''
        '''</param>
        '''<param name="Output">
        '''Returns a list of the drives of the instrument.
        '''
        '''Attribute:
        '''RSRTM_ATTR_DRIVES
        '''</param>
        '''<returns>
        '''Returns the status code of this operation.  The status code  either indicates success or describes an error or warning condition.  You examine the status code from each call to an instrument driver function to determine if an error occurred.
        '''
        '''To obtain a text description of the status code, call the rsrtm_error_message function.  To obtain additional information about the error condition, call the rsrtm_GetError function.  To clear the error information from the driver, call the rsrtm_ClearError function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''
        '''Numeric Range (in Hex) Status Code Types
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF VISA Warnings
        '''3FFC0000 to 3FFCFFFF VXIPnP Driver Warnings
        '''
        '''BFFF0000 to BFFFFFFF VISA Errors
        '''BFFC0000 to BFFCFFFF VXIPnP Driver Errors
        '''</returns>
        Public Function FileDrives(ByVal Buffer_Size As Integer, ByVal Output As System.Text.StringBuilder) As Integer
            Dim pInvokeResult As Integer = PInvoke.FileDrives(Me._handle, Buffer_Size, Output)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function is used to read data from the instrument and write it to a user specified file on the host computer.
        '''
        '''Attribute(s):
        '''-
        '''
        '''Remote-control command(s):
        '''MMEMory:DATA? &lt;file_name&gt;
        '''
        '''</summary>
        '''<param name="Source">
        '''This control selects file for the data transfer from instrument to control computer.
        '''
        '''Valid Values: not tested
        '''
        '''Default Value: "/INT/SETTINGS/SET01.SET"
        '''
        '''</param>
        '''<param name="Destination">
        '''This control defines destination file to which the data transfer from instrument to control computer applies.
        '''
        '''Valid Values: not tested
        '''
        '''Default Value: "\\test.hcp"
        '''
        '''</param>
        '''<returns>
        '''Returns the status code of this operation.  The status code  either indicates success or describes an error or warning condition.  You examine the status code from each call to an instrument driver function to determine if an error occurred.
        '''
        '''To obtain a text description of the status code, call the rsrtm_error_message function.  To obtain additional information about the error condition, call the rsrtm_GetError function.  To clear the error information from the driver, call the rsrtm_ClearError function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''
        '''Numeric Range (in Hex) Status Code Types
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF VISA Warnings
        '''3FFC0000 to 3FFCFFFF VXIPnP Driver Warnings
        '''
        '''BFFF0000 to BFFFFFFF VISA Errors
        '''BFFC0000 to BFFCFFFF VXIPnP Driver Errors
        '''</returns>
        Public Function ReadToFileFromInstrument(ByVal Source As String, ByVal Destination As String) As Integer
            Dim pInvokeResult As Integer = PInvoke.ReadToFileFromInstrument(Me._handle, Source, Destination)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function is used to read data from the host computer and write it to a user specified file in the instrument.
        '''
        '''Attribute(s):
        '''-
        '''
        '''Remote-control command(s):
        '''MMEMory:DATA &lt;file_name&gt;[,&lt;block data&gt;]
        '''
        '''</summary>
        '''<param name="Source">
        '''This control selects file for the data transfer from control computer to instrument.
        '''
        '''Valid Values: not tested
        '''
        '''Default Value: "\\test.hcp"
        '''
        '''</param>
        '''<param name="Destination">
        '''This control defines destination file to which the data transfer from control computer to instrument applies.
        '''
        '''Valid Values: not tested
        '''
        '''Default Value: "/INT/SETTINGS/SET01.SET"
        '''
        '''</param>
        '''<returns>
        '''Returns the status code of this operation.  The status code  either indicates success or describes an error or warning condition.  You examine the status code from each call to an instrument driver function to determine if an error occurred.
        '''
        '''To obtain a text description of the status code, call the rsrtm_error_message function.  To obtain additional information about the error condition, call the rsrtm_GetError function.  To clear the error information from the driver, call the rsrtm_ClearError function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''
        '''Numeric Range (in Hex) Status Code Types
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF VISA Warnings
        '''3FFC0000 to 3FFCFFFF VXIPnP Driver Warnings
        '''
        '''BFFF0000 to BFFFFFFF VISA Errors
        '''BFFC0000 to BFFCFFFF VXIPnP Driver Errors
        '''</returns>
        Public Function WriteFromFileToInstrument(ByVal Source As String, ByVal Destination As String) As Integer
            Dim pInvokeResult As Integer = PInvoke.WriteFromFileToInstrument(Me._handle, Source, Destination)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        '''<summary>
        '''This function allows to provide data set operation for Save/Recall items of memory subsystem.
        '''
        '''The various drives can be addressed via the "mass storage unit specifier" &lt;msus&gt; using the conventional DOS syntax. The internal hard disk is addressed by "D:", the floppy disk drive by "A:".
        '''
        '''The file names &lt;file_name&gt; are indicated as string parameters with the commands being enclosed in quotation marks. They also comply with DOS conventions. DOS file names consist of max. 8 ASCII characters and an extension of up to three characters
        '''separated from the file name by a dot "." Both, the dot and the extension are optional. The dot is not part of the file name. DOS file names do not distinguish between uppercase and lowercase notation. All letters and digits are permitted as well as the special characters "_", "^", "$", "~", "!", "#", "%", "&amp;", "-", "{", "}", "(", ")", "@" and "`". Reserved file names are CLOCK$, CON, AUX, COM1 to COM4, LPT1 to LPT3,
        '''NUL and PRN. The two characters "*" and "?" have the function of so-called "wildcards", i.e., they are variables for
        '''selection of several files. The question mark "?" replaces exactly one character, the asterisk means any
        '''of the remaining characters in the file name. "*.*" thus means all files in a directory.
        '''
        '''Attribute(s):
        '''-
        '''
        '''Remote-control command(s):
        '''MMEMory:STORe:STATe
        '''MMEMory:LOAD:STATe
        '''</summary>
        '''<param name="Operation">
        '''This control selects the type of memory operation to be performed.
        '''
        '''Valid Values:
        '''RSRTM_VAL_MEM_SAVE    (0) - Save
        '''RSRTM_VAL_MEM_RECALL  (1) - Recall
        '''
        '''Notes:
        '''
        '''(1) Save:
        '''This command stores the current device settings in a series of files which have the indicated file name, but different extensions. The file name includes indication of the path and may also include the drive name. The path name complies with DOS conventions.
        '''
        '''(2) Recall:
        '''This command loads device settings from files.The contents of the file are loaded and set as the new device state. The file name includes indication of the path and may also include the drive name. The path name complies with DOS conventions.
        '''</param>
        '''<param name="State_Number">
        '''Defines save and recall state position.
        '''
        '''Valid Values:
        '''not checked
        '''
        '''Default Value: 1
        '''</param>
        '''<param name="Path">
        '''This control specifies the source of the operation to be performed. 
        '''
        '''Valid Values: 
        '''not checked
        '''
        '''Default Value: "/INT/SETTINGS"
        '''
        '''Attribute:
        '''-
        '''</param>
        '''<returns>
        '''Returns the status code of this operation.  The status code  either indicates success or describes an error or warning condition.  You examine the status code from each call to an instrument driver function to determine if an error occurred.
        '''
        '''To obtain a text description of the status code, call the rsrtm_error_message function.  To obtain additional information about the error condition, call the rsrtm_GetError function.  To clear the error information from the driver, call the rsrtm_ClearError function.
        '''          
        '''The general meaning of the status code is as follows:
        '''
        '''Value                  Meaning
        '''-------------------------------
        '''0                      Success
        '''Positive Values        Warnings
        '''Negative Values        Errors
        '''
        '''This instrument driver also returns errors and warnings defined by other sources. The following table defines the ranges of additional status codes that this driver can return. The table lists the different include files that contain the defined constants for the particular status codes:
        '''
        '''Numeric Range (in Hex) Status Code Types
        '''-------------------------------------------------
        '''3FFF0000 to 3FFFFFFF VISA Warnings
        '''3FFC0000 to 3FFCFFFF VXIPnP Driver Warnings
        '''
        '''BFFF0000 to BFFFFFFF VISA Errors
        '''BFFC0000 to BFFCFFFF VXIPnP Driver Errors
        '''</returns>
        Public Function DataSetFileOperations(ByVal Operation As Integer, ByVal State_Number As Integer, ByVal Path As String) As Integer
            Dim pInvokeResult As Integer = PInvoke.DataSetFileOperations(Me._handle, Operation, State_Number, Path)
            PInvoke.TestForError(Me._handle, pInvokeResult)
            Return pInvokeResult
        End Function
        
        Public Overloads Sub Dispose() Implements System.IDisposable.Dispose
            Me.Dispose(true)
            System.GC.SuppressFinalize(Me)
        End Sub
        
        Private Overloads Sub Dispose(ByVal disposing As Boolean)
            If (Me._disposed = false) Then
                PInvoke.close(Me._handle)
                Me._handle = New System.Runtime.InteropServices.HandleRef(Nothing, System.IntPtr.Zero)
            End If
            Me._disposed = true
        End Sub
        
        Protected Overrides Sub Finalize()
            Me.Dispose(false)
        End Sub
        
        Public Overloads Function GetInt32(ByVal propertyId As rsrtmProperties, ByVal repeatedCapabilityOrChannel As String) As Integer
            Dim val As Integer
            PInvoke.TestForError(Me._handle, PInvoke.GetAttributeViInt32(Me._handle, repeatedCapabilityOrChannel, CType(propertyId,Integer), val))
            Return val
        End Function
        
        Public Overloads Function GetInt32(ByVal propertyId As rsrtmProperties) As Integer
            Return Me.GetInt32(propertyId, "")
        End Function
        
        Public Overloads Function GetDouble(ByVal propertyId As rsrtmProperties, ByVal repeatedCapabilityOrChannel As String) As Double
            Dim val As Double
            PInvoke.TestForError(Me._handle, PInvoke.GetAttributeViReal64(Me._handle, repeatedCapabilityOrChannel, CType(propertyId,Integer), val))
            Return val
        End Function
        
        Public Overloads Function GetDouble(ByVal propertyId As rsrtmProperties) As Double
            Return Me.GetDouble(propertyId, "")
        End Function
        
        Public Overloads Function GetString(ByVal propertyId As rsrtmProperties, ByVal repeatedCapabilityOrChannel As String) As String
            Dim newVal As System.Text.StringBuilder = New System.Text.StringBuilder(512)
            Dim size As Integer = PInvoke.GetAttributeViString(Me._handle, repeatedCapabilityOrChannel, CType(propertyId,Integer), 512, newVal)
            If (size < 0) Then
                PInvoke.ThrowError(Me._handle, size)
            Else
                If (size > 0) Then
                    newVal.Capacity = size
                    PInvoke.TestForError(Me._handle, PInvoke.GetAttributeViString(Me._handle, repeatedCapabilityOrChannel, CType(propertyId,Integer), size, newVal))
                End If
            End If
            Return newVal.ToString
        End Function
        
        Public Overloads Function GetString(ByVal propertyId As rsrtmProperties) As String
            Return Me.GetString(propertyId, "")
        End Function
        
        Public Overloads Function GetBoolean(ByVal propertyId As rsrtmProperties, ByVal repeatedCapabilityOrChannel As String) As Boolean
            Dim val As UShort
            PInvoke.TestForError(Me._handle, PInvoke.GetAttributeViBoolean(Me._handle, repeatedCapabilityOrChannel, CType(propertyId,Integer), val))
            Return System.Convert.ToBoolean(val)
        End Function
        
        Public Overloads Function GetBoolean(ByVal propertyId As rsrtmProperties) As Boolean
            Return Me.GetBoolean(propertyId, "")
        End Function
        
        Public Overloads Sub SetInt32(ByVal propertyId As rsrtmProperties, ByVal repeatedCapabilityOrChannel As String, ByVal val As Integer)
            PInvoke.TestForError(Me._handle, PInvoke.SetAttributeViInt32(Me._handle, repeatedCapabilityOrChannel, CType(propertyId,Integer), val))
        End Sub
        
        Public Overloads Sub SetInt32(ByVal propertyId As rsrtmProperties, ByVal val As Integer)
            Me.SetInt32(propertyId, "", val)
        End Sub
        
        Public Overloads Sub SetDouble(ByVal propertyId As rsrtmProperties, ByVal repeatedCapabilityOrChannel As String, ByVal val As Double)
            PInvoke.TestForError(Me._handle, PInvoke.SetAttributeViReal64(Me._handle, repeatedCapabilityOrChannel, CType(propertyId,Integer), val))
        End Sub
        
        Public Overloads Sub SetDouble(ByVal propertyId As rsrtmProperties, ByVal val As Double)
            Me.SetDouble(propertyId, "", val)
        End Sub
        
        Public Overloads Sub SetString(ByVal propertyId As rsrtmProperties, ByVal repeatedCapabilityOrChannel As String, ByVal val As String)
            PInvoke.TestForError(Me._handle, PInvoke.SetAttributeViString(Me._handle, repeatedCapabilityOrChannel, CType(propertyId,Integer), val))
        End Sub
        
        Public Overloads Sub SetString(ByVal propertyId As rsrtmProperties, ByVal val As String)
            Me.SetString(propertyId, "", val)
        End Sub
        
        Public Overloads Sub SetBoolean(ByVal propertyId As rsrtmProperties, ByVal repeatedCapabilityOrChannel As String, ByVal val As Boolean)
            PInvoke.TestForError(Me._handle, PInvoke.SetAttributeViBoolean(Me._handle, repeatedCapabilityOrChannel, CType(propertyId,Integer), System.Convert.ToUInt16(val)))
        End Sub
        
        Public Overloads Sub SetBoolean(ByVal propertyId As rsrtmProperties, ByVal val As Boolean)
            Me.SetBoolean(propertyId, "", val)
        End Sub
        
        Private Class PInvoke
            
<DllImport ("rsrtm_32.dll", EntryPoint:="rsrtm_init", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function init (ByVal Resource_Name As String, ByVal ID_Query As UShort, ByVal Reset_Device As UShort, ByRef Instrument_Handle As System.IntPtr) As Integer
End Function

<DllImport ("rsrtm_32.dll", EntryPoint:="rsrtm_InitWithOptions", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function InitWithOptions (ByVal Resource_Name As String, ByVal ID_Query As UShort, ByVal Reset_Device As UShort, ByVal Option_String As String, ByRef Instrument_Handle As System.IntPtr) As Integer
End Function

<DllImport ("rsrtm_32.dll", EntryPoint:="rsrtm_Autoset", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function Autoset (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef) As Integer
End Function

<DllImport ("rsrtm_32.dll", EntryPoint:="rsrtm_ConfigureAcquisitionType", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function ConfigureAcquisitionType (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Channel As Integer, ByVal Acquisition_Type As Integer) As Integer
End Function

<DllImport ("rsrtm_32.dll", EntryPoint:="rsrtm_ConfigureAcquisitionRecord", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function ConfigureAcquisitionRecord (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Time_Per_Record As Double, ByVal Acquisition_Start_Time__Offset_ As Double) As Integer
End Function

<DllImport ("rsrtm_32.dll", EntryPoint:="rsrtm_ConfigureTimeBase", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function ConfigureTimeBase (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Time_Scale As Double, ByVal Reference_Point As Integer) As Integer
End Function

<DllImport ("rsrtm_32.dll", EntryPoint:="rsrtm_ConfigureRecordLength", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function ConfigureRecordLength (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Record_Length As Integer) As Integer
End Function

<DllImport ("rsrtm_32.dll", EntryPoint:="rsrtm_ConfigureRollMode", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function ConfigureRollMode (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Mode As UShort) As Integer
End Function

<DllImport ("rsrtm_32.dll", EntryPoint:="rsrtm_QueryDivisions", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function QueryDivisions (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByRef Divisions As Integer) As Integer
End Function

<DllImport ("rsrtm_32.dll", EntryPoint:="rsrtm_QuerySampleRate", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function QuerySampleRate (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByRef Sample_Rate As Double) As Integer
End Function

<DllImport ("rsrtm_32.dll", EntryPoint:="rsrtm_QueryAcquisitionTime", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function QueryAcquisitionTime (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByRef Acquisition_Time As Double) As Integer
End Function

<DllImport ("rsrtm_32.dll", EntryPoint:="rsrtm_ConfigureWaveformAcquisitionRate", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function ConfigureWaveformAcquisitionRate (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Waveform_Rate As Integer) As Integer
End Function

<DllImport ("rsrtm_32.dll", EntryPoint:="rsrtm_QueryADCSampleRate", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function QueryADCSampleRate (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByRef ADC_Sample_Rate As Double) As Integer
End Function

<DllImport ("rsrtm_32.dll", EntryPoint:="rsrtm_ConfigureResolutionEnhancement", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function ConfigureResolutionEnhancement (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Resolution_Enhancement As Integer) As Integer
End Function

<DllImport ("rsrtm_32.dll", EntryPoint:="rsrtm_ConfigureInterpolation", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function ConfigureInterpolation (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Interpolation As Integer) As Integer
End Function

<DllImport ("rsrtm_32.dll", EntryPoint:="rsrtm_ConfigureWaveformArithmetic", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function ConfigureWaveformArithmetic (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Channel As Integer, ByVal Arithmetic As Integer) As Integer
End Function

<DllImport ("rsrtm_32.dll", EntryPoint:="rsrtm_ConfigureFilterFrequency", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function ConfigureFilterFrequency (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Filter_Frequency As Double) As Integer
End Function

<DllImport ("rsrtm_32.dll", EntryPoint:="rsrtm_QueryWaveformSamplesRange", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function QueryWaveformSamplesRange (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Channel As Integer, ByRef Samples As Integer) As Integer
End Function

<DllImport ("rsrtm_32.dll", EntryPoint:="rsrtm_ConfigureNumberOfAverages", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function ConfigureNumberOfAverages (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Number_of_Averages As Integer) As Integer
End Function

<DllImport ("rsrtm_32.dll", EntryPoint:="rsrtm_ConfigureNumberOfWaveforms", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function ConfigureNumberOfWaveforms (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Number_Of_Waveforms As Integer) As Integer
End Function

<DllImport ("rsrtm_32.dll", EntryPoint:="rsrtm_ConfigureChannel", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function ConfigureChannel (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Channel As Integer, ByVal Channel_Enabled As UShort, ByVal Vertical_Range As Double, ByVal Vertical_Offset As Double, ByVal Vertical_Coupling As Integer) As Integer
End Function

<DllImport ("rsrtm_32.dll", EntryPoint:="rsrtm_ConfigureChannelOffset", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function ConfigureChannelOffset (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Channel As Integer, ByVal Offset As Double) As Integer
End Function

<DllImport ("rsrtm_32.dll", EntryPoint:="rsrtm_ConfigureChannelVerticalScale", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function ConfigureChannelVerticalScale (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Channel As Integer, ByVal Vertical_Scale As Double) As Integer
End Function

<DllImport ("rsrtm_32.dll", EntryPoint:="rsrtm_ConfigureChannelThreshold", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function ConfigureChannelThreshold (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Channel As Integer, ByVal Threshold As Double) As Integer
End Function

<DllImport ("rsrtm_32.dll", EntryPoint:="rsrtm_ConfigureChannelBandwidth", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function ConfigureChannelBandwidth (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Channel As Integer, ByVal Bandwidth As Integer) As Integer
End Function

<DllImport ("rsrtm_32.dll", EntryPoint:="rsrtm_ConfigureChannelPolarity", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function ConfigureChannelPolarity (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Channel As Integer, ByVal Polarity As Integer) As Integer
End Function

<DllImport ("rsrtm_32.dll", EntryPoint:="rsrtm_ConfigureChannelOverload", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function ConfigureChannelOverload (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Channel As Integer, ByVal Overload As UShort) As Integer
End Function

<DllImport ("rsrtm_32.dll", EntryPoint:="rsrtm_ConfigureChannelSkew", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function ConfigureChannelSkew (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Channel As Integer, ByVal Deskew_Value As Double) As Integer
End Function

<DllImport ("rsrtm_32.dll", EntryPoint:="rsrtm_ConfigureProbe", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function ConfigureProbe (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Channel As Integer, ByVal Channel_Visible As UShort, ByVal Offset As Double) As Integer
End Function

<DllImport ("rsrtm_32.dll", EntryPoint:="rsrtm_QueryProbeCharacteristics", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function QueryProbeCharacteristics (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Channel As Integer, ByVal Buffer_Size As Integer, ByVal Type As System.Text.StringBuilder, ByVal Name As System.Text.StringBuilder, ByRef Input_Impedance As Double, ByRef Input_Capacitance As Double, ByVal Attenuation As System.Text.StringBuilder, ByRef Bandwidth As Double) As Integer
End Function

<DllImport ("rsrtm_32.dll", EntryPoint:="rsrtm_ConfigureProbeMicroButtonAction", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function ConfigureProbeMicroButtonAction (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Channel As Integer, ByVal Micro_Button_Action As Integer) As Integer
End Function

<DllImport ("rsrtm_32.dll", EntryPoint:="rsrtm_QueryProbeDCOffset", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function QueryProbeDCOffset (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Channel As Integer, ByRef DC_Offset As Double) As Integer
End Function

<DllImport ("rsrtm_32.dll", EntryPoint:="rsrtm_ConfigureProbeAdditionalOffset", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function ConfigureProbeAdditionalOffset (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Channel As Integer, ByVal Probe_Offset As Double) As Integer
End Function

<DllImport ("rsrtm_32.dll", EntryPoint:="rsrtm_ConfigureProbeVoltmeterState", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function ConfigureProbeVoltmeterState (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Channel As Integer, ByVal Probe_Active As UShort) As Integer
End Function

<DllImport ("rsrtm_32.dll", EntryPoint:="rsrtm_ConfigureProbeAttenuationUnit", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function ConfigureProbeAttenuationUnit (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Channel As Integer, ByVal Unit As Integer) As Integer
End Function

<DllImport ("rsrtm_32.dll", EntryPoint:="rsrtm_ConfigureProbeAttenuationManual", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function ConfigureProbeAttenuationManual (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Channel As Integer, ByVal Attenuation As Double) As Integer
End Function

<DllImport ("rsrtm_32.dll", EntryPoint:="rsrtm_QueryProbeAttributes", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function QueryProbeAttributes (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Channel As Integer, ByVal Buffer_Size As Integer, ByVal Software_Version As System.Text.StringBuilder, ByVal Production_Date As System.Text.StringBuilder, ByVal Part_Number As System.Text.StringBuilder, ByVal Serial_Number As System.Text.StringBuilder) As Integer
End Function

<DllImport ("rsrtm_32.dll", EntryPoint:="rsrtm_QueryProbeBuildNumber", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function QueryProbeBuildNumber (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Channel As Integer, ByRef Build_Number As Integer) As Integer
End Function

<DllImport ("rsrtm_32.dll", EntryPoint:="rsrtm_ConfigureTrigger", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function ConfigureTrigger (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Trigger As Integer, ByVal Trigger_Type As Integer) As Integer
End Function

<DllImport ("rsrtm_32.dll", EntryPoint:="rsrtm_ConfigureTriggerSource", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function ConfigureTriggerSource (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Trigger As Integer, ByVal Channel As Integer) As Integer
End Function

<DllImport ("rsrtm_32.dll", EntryPoint:="rsrtm_ConfigureExternalTriggerCoupling", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function ConfigureExternalTriggerCoupling (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal External_Coupling As Integer) As Integer
End Function

<DllImport ("rsrtm_32.dll", EntryPoint:="rsrtm_ConfigureTriggerBState", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function ConfigureTriggerBState (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal State As UShort) As Integer
End Function

<DllImport ("rsrtm_32.dll", EntryPoint:="rsrtm_ConfigureTriggerModifier", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function ConfigureTriggerModifier (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Trigger As Integer, ByVal Trigger_Modifier As Integer) As Integer
End Function

<DllImport ("rsrtm_32.dll", EntryPoint:="rsrtm_ConfigureTriggerEventCount", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function ConfigureTriggerEventCount (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Event_Count As Integer) As Integer
End Function

<DllImport ("rsrtm_32.dll", EntryPoint:="rsrtm_TriggerLevelAutoFind", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function TriggerLevelAutoFind (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Trigger As Integer) As Integer
End Function

<DllImport ("rsrtm_32.dll", EntryPoint:="rsrtm_ConfigureTriggerChannelLevel", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function ConfigureTriggerChannelLevel (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Trigger As Integer, ByVal Channel As Integer, ByVal Trigger_Level As Double) As Integer
End Function

<DllImport ("rsrtm_32.dll", EntryPoint:="rsrtm_ConfigureTriggerHysteresis", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function ConfigureTriggerHysteresis (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Trigger As Integer, ByVal Hysteresis As Integer) As Integer
End Function

<DllImport ("rsrtm_32.dll", EntryPoint:="rsrtm_ConfigureEdgeTriggerSource", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function ConfigureEdgeTriggerSource (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Trigger As Integer, ByVal Channel As Integer, ByVal Trigger_Source As Integer, ByVal Trigger_Level As Double, ByVal Trigger_Slope As Integer) As Integer
End Function

<DllImport ("rsrtm_32.dll", EntryPoint:="rsrtm_ConfigureEdgeTriggerCoupling", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function ConfigureEdgeTriggerCoupling (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Coupling As Integer) As Integer
End Function

<DllImport ("rsrtm_32.dll", EntryPoint:="rsrtm_ConfigureEdgeTriggerFilter", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function ConfigureEdgeTriggerFilter (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Filter_Type As Integer, ByVal Filter_State As UShort) As Integer
End Function

<DllImport ("rsrtm_32.dll", EntryPoint:="rsrtm_ConfigureWidthTriggerSource", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function ConfigureWidthTriggerSource (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Trigger_Source As Integer, ByVal Trigger_Level As Double, ByVal Width As Double, ByVal Width_Delta As Double, ByVal Width_Polarity As Integer, ByVal Width_Condition As Integer) As Integer
End Function

<DllImport ("rsrtm_32.dll", EntryPoint:="rsrtm_ConfigurePatternTriggerSource", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function ConfigurePatternTriggerSource (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Pattern_Source As String, ByVal Pattern_Function As Integer, ByVal Pattern_Condition As UShort) As Integer
End Function

<DllImport ("rsrtm_32.dll", EntryPoint:="rsrtm_ConfigureVideoTriggerSource", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function ConfigureVideoTriggerSource (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Standard As Integer, ByVal Polarity As Integer, ByVal Field As Integer, ByVal Line As Integer) As Integer
End Function

<DllImport ("rsrtm_32.dll", EntryPoint:="rsrtm_ConfigureTriggerDelay", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function ConfigureTriggerDelay (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Delay_Time As Double) As Integer
End Function

<DllImport ("rsrtm_32.dll", EntryPoint:="rsrtm_ConfigureSignalStyle", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function ConfigureSignalStyle (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Style As Integer) As Integer
End Function

<DllImport ("rsrtm_32.dll", EntryPoint:="rsrtm_ConfigureDisplayIntensity", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function ConfigureDisplayIntensity (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Element As Integer, ByVal Intensity As Double) As Integer
End Function

<DllImport ("rsrtm_32.dll", EntryPoint:="rsrtm_ConfigureColorAndBrightness", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function ConfigureColorAndBrightness (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Palette As Integer) As Integer
End Function

<DllImport ("rsrtm_32.dll", EntryPoint:="rsrtm_ConfigureDisplayGridStyle", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function ConfigureDisplayGridStyle (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Style As Integer) As Integer
End Function

<DllImport ("rsrtm_32.dll", EntryPoint:="rsrtm_ConfigureDisplayLanguage", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function ConfigureDisplayLanguage (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Language As Integer) As Integer
End Function

<DllImport ("rsrtm_32.dll", EntryPoint:="rsrtm_ConfigureDiagramMode", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function ConfigureDiagramMode (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Mode As Integer) As Integer
End Function

<DllImport ("rsrtm_32.dll", EntryPoint:="rsrtm_MarkerSearch", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function MarkerSearch (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Marker_Action As Integer) As Integer
End Function

<DllImport ("rsrtm_32.dll", EntryPoint:="rsrtm_ConfigurePersistence", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function ConfigurePersistence (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Enable As UShort, ByVal Infinite As UShort, ByVal Time As Double) As Integer
End Function

<DllImport ("rsrtm_32.dll", EntryPoint:="rsrtm_ClearPersistence", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function ClearPersistence (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef) As Integer
End Function

<DllImport ("rsrtm_32.dll", EntryPoint:="rsrtm_ConfigurePersistenceTimeAuto", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function ConfigurePersistenceTimeAuto (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal AutoPersist As UShort) As Integer
End Function

<DllImport ("rsrtm_32.dll", EntryPoint:="rsrtm_ConfigureSourceX", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function ConfigureSourceX (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Source As Integer) As Integer
End Function

<DllImport ("rsrtm_32.dll", EntryPoint:="rsrtm_ConfigureSourceY1", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function ConfigureSourceY1 (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Source As Integer) As Integer
End Function

<DllImport ("rsrtm_32.dll", EntryPoint:="rsrtm_ConfigureSourceY2", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function ConfigureSourceY2 (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Source As Integer) As Integer
End Function

<DllImport ("rsrtm_32.dll", EntryPoint:="rsrtm_ConfigureIntensityControl", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function ConfigureIntensityControl (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Mode As Integer) As Integer
End Function

<DllImport ("rsrtm_32.dll", EntryPoint:="rsrtm_ConfigureSourceIntensity", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function ConfigureSourceIntensity (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Source As Integer) As Integer
End Function

<DllImport ("rsrtm_32.dll", EntryPoint:="rsrtm_ConfigureIntensityTreshold", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function ConfigureIntensityTreshold (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Treshold As Double) As Integer
End Function

<DllImport ("rsrtm_32.dll", EntryPoint:="rsrtm_ConfigureZoomWindowState", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function ConfigureZoomWindowState (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Zoom_Enabled As UShort) As Integer
End Function

<DllImport ("rsrtm_32.dll", EntryPoint:="rsrtm_ConfigureZoomReferencePoint", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function ConfigureZoomReferencePoint (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Position As Double) As Integer
End Function

<DllImport ("rsrtm_32.dll", EntryPoint:="rsrtm_ConfigureZoomDiagramTimebase", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function ConfigureZoomDiagramTimebase (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Scale As Double) As Integer
End Function

<DllImport ("rsrtm_32.dll", EntryPoint:="rsrtm_ConfigureZoomOffsetOfTriggerPoint", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function ConfigureZoomOffsetOfTriggerPoint (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Time As Double) As Integer
End Function

<DllImport ("rsrtm_32.dll", EntryPoint:="rsrtm_ConfigureMeasurement", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function ConfigureMeasurement (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Measurement As Integer, ByVal Measurement_State As UShort) As Integer
End Function

<DllImport ("rsrtm_32.dll", EntryPoint:="rsrtm_ConfigureMeasurementSource", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function ConfigureMeasurementSource (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Measurement As Integer, ByVal Signal_Source As Integer, ByVal Reference_Source As Integer) As Integer
End Function

<DllImport ("rsrtm_32.dll", EntryPoint:="rsrtm_ConfigureAmplitudeTimeMainMeasurement", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function ConfigureAmplitudeTimeMainMeasurement (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Measurement As Integer, ByVal Measurement_Function As Integer) As Integer
End Function

<DllImport ("rsrtm_32.dll", EntryPoint:="rsrtm_ConfigureDelayMeasuremenSlope", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function ConfigureDelayMeasuremenSlope (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Measurement As Integer, ByVal Source_1_Slope As Integer, ByVal Source_2_Slope As Integer) As Integer
End Function

<DllImport ("rsrtm_32.dll", EntryPoint:="rsrtm_QueryMeasurementCategory", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function QueryMeasurementCategory (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Measurement As Integer, ByRef Category As Integer) As Integer
End Function

<DllImport ("rsrtm_32.dll", EntryPoint:="rsrtm_ConfigureReferenceLevelMode", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function ConfigureReferenceLevelMode (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Relative_Mode As Integer) As Integer
End Function

<DllImport ("rsrtm_32.dll", EntryPoint:="rsrtm_ConfigureUserReferenceLevel", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function ConfigureUserReferenceLevel (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Lower_Level As Double, ByVal Upper_Level As Double, ByVal Middle_Level As Double) As Integer
End Function

<DllImport ("rsrtm_32.dll", EntryPoint:="rsrtm_ConfigureCursor", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function ConfigureCursor (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Cursor_State As UShort, ByVal Source As Integer, ByVal Type As Integer) As Integer
End Function

<DllImport ("rsrtm_32.dll", EntryPoint:="rsrtm_AllCursorsOff", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function AllCursorsOff (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef) As Integer
End Function

<DllImport ("rsrtm_32.dll", EntryPoint:="rsrtm_ConfigureCursorPosition", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function ConfigureCursorPosition (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Cursor As Integer, ByVal X_Position As Double, ByVal Y_Position As Double) As Integer
End Function

<DllImport ("rsrtm_32.dll", EntryPoint:="rsrtm_ConfigureCursorCoupling", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function ConfigureCursorCoupling (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal X_Coupling As UShort, ByVal Y_Coupling As UShort) As Integer
End Function

<DllImport ("rsrtm_32.dll", EntryPoint:="rsrtm_SetCursorPosition", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function SetCursorPosition (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Cursor As Integer, ByVal Position As Integer) As Integer
End Function

<DllImport ("rsrtm_32.dll", EntryPoint:="rsrtm_SetFFTAnalysisCursorToPeak", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function SetFFTAnalysisCursorToPeak (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Cursor As Integer, ByVal Peak As Integer) As Integer
End Function

<DllImport ("rsrtm_32.dll", EntryPoint:="rsrtm_ConfigureCursorWaveformTracking", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function ConfigureCursorWaveformTracking (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Tracking As UShort) As Integer
End Function

<DllImport ("rsrtm_32.dll", EntryPoint:="rsrtm_ConfigureCursorAdjustment", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function ConfigureCursorAdjustment (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Adjustment As UShort) As Integer
End Function

<DllImport ("rsrtm_32.dll", EntryPoint:="rsrtm_ConfigureCursorRatioMeasurementUnit", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function ConfigureCursorRatioMeasurementUnit (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Direction As Integer, ByVal Measurement_Unit As Integer) As Integer
End Function

<DllImport ("rsrtm_32.dll", EntryPoint:="rsrtm_QueryCursorRatioMeasurement", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function QueryCursorRatioMeasurement (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Direction As Integer, ByRef Ratio_Measurement As Double) As Integer
End Function

<DllImport ("rsrtm_32.dll", EntryPoint:="rsrtm_QueryCursorDistance", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function QueryCursorDistance (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Direction As Integer, ByRef Cursor_Distance As Double) As Integer
End Function

<DllImport ("rsrtm_32.dll", EntryPoint:="rsrtm_QueryCursorInverseDistance", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function QueryCursorInverseDistance (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByRef Cursor_Distance As Double) As Integer
End Function

<DllImport ("rsrtm_32.dll", EntryPoint:="rsrtm_QueryCursorVoltageInverseDistance", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function QueryCursorVoltageInverseDistance (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByRef Cursor_Distance As Double) As Integer
End Function

<DllImport ("rsrtm_32.dll", EntryPoint:="rsrtm_QueryCursorPosition", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function QueryCursorPosition (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByRef Data As Double) As Integer
End Function

<DllImport ("rsrtm_32.dll", EntryPoint:="rsrtm_ConfigureCursorPeakExcursion", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function ConfigureCursorPeakExcursion (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Peak_Excursion As Integer) As Integer
End Function

<DllImport ("rsrtm_32.dll", EntryPoint:="rsrtm_ConfigureQuickMeasurements", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function ConfigureQuickMeasurements (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Measurement As Integer, ByVal Quick_Measurements_Enabled As UShort) As Integer
End Function

<DllImport ("rsrtm_32.dll", EntryPoint:="rsrtm_QueryQuickMeasurementResults", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function QueryQuickMeasurementResults (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Measurement As Integer, ByVal Array_Size As Integer, <[In], Out> Results As Double()) As Integer
End Function

<DllImport ("rsrtm_32.dll", EntryPoint:="rsrtm_ConfigureAutomaticMeasurement", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function ConfigureAutomaticMeasurement (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Measurement As Integer, ByVal State As UShort, ByVal Number_Of_Waveforms As Integer) As Integer
End Function

<DllImport ("rsrtm_32.dll", EntryPoint:="rsrtm_ResetAutomaticMeasurement", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function ResetAutomaticMeasurement (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Measurement As Integer) As Integer
End Function

<DllImport ("rsrtm_32.dll", EntryPoint:="rsrtm_QueryAutomaticMeasurementNumberOfWaveforms", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function QueryAutomaticMeasurementNumberOfWaveforms (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Measurement As Integer, ByRef Number_Of_Waveforms As Integer) As Integer
End Function

<DllImport ("rsrtm_32.dll", EntryPoint:="rsrtm_QueryAutomaticMeasurementResult", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function QueryAutomaticMeasurementResult (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Measurement As Integer, ByVal Result_Type As Integer, ByRef Result As Double) As Integer
End Function

<DllImport ("rsrtm_32.dll", EntryPoint:="rsrtm_SampleMode", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function SampleMode (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByRef Sample_Mode As Integer) As Integer
End Function

<DllImport ("rsrtm_32.dll", EntryPoint:="rsrtm_ActualSampleRate", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function ActualSampleRate (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByRef Sample_Rate As Double) As Integer
End Function

<DllImport ("rsrtm_32.dll", EntryPoint:="rsrtm_AutoProbeSenseValue", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function AutoProbeSenseValue (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Channel As Integer, ByVal Buffer_Size As Integer, ByVal Auto_Probe_Sense_Value As System.Text.StringBuilder) As Integer
End Function

<DllImport ("rsrtm_32.dll", EntryPoint:="rsrtm_ConfigureMaskTestEnable", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function ConfigureMaskTestEnable (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal State As UShort) As Integer
End Function

<DllImport ("rsrtm_32.dll", EntryPoint:="rsrtm_ConfigureMaskTest", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function ConfigureMaskTest (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Source As Integer, ByVal Action As Integer) As Integer
End Function

<DllImport ("rsrtm_32.dll", EntryPoint:="rsrtm_MaskCopyChannel", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function MaskCopyChannel (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef) As Integer
End Function

<DllImport ("rsrtm_32.dll", EntryPoint:="rsrtm_MaskLoad", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function MaskLoad (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Name As String) As Integer
End Function

<DllImport ("rsrtm_32.dll", EntryPoint:="rsrtm_MaskStore", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function MaskStore (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Name As String) As Integer
End Function

<DllImport ("rsrtm_32.dll", EntryPoint:="rsrtm_ConfigureMaskVerticalOffset", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function ConfigureMaskVerticalOffset (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Y_Position As Double) As Integer
End Function

<DllImport ("rsrtm_32.dll", EntryPoint:="rsrtm_ConfigureMaskVerticalScaling", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function ConfigureMaskVerticalScaling (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Y_Stretch As Double) As Integer
End Function

<DllImport ("rsrtm_32.dll", EntryPoint:="rsrtm_ConfigureMaskVerticalWidth", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function ConfigureMaskVerticalWidth (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Y_Width As Double) As Integer
End Function

<DllImport ("rsrtm_32.dll", EntryPoint:="rsrtm_ConfigureMaskHorizontalWidth", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function ConfigureMaskHorizontalWidth (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal X_Width As Double) As Integer
End Function

<DllImport ("rsrtm_32.dll", EntryPoint:="rsrtm_QueryMaskAcquisitions", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function QueryMaskAcquisitions (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByRef Total_Count As Integer) As Integer
End Function

<DllImport ("rsrtm_32.dll", EntryPoint:="rsrtm_QueryMaskHitCount", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function QueryMaskHitCount (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByRef Acquistions As Integer) As Integer
End Function

<DllImport ("rsrtm_32.dll", EntryPoint:="rsrtm_ConfigureSearchState", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function ConfigureSearchState (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal State As UShort) As Integer
End Function

<DllImport ("rsrtm_32.dll", EntryPoint:="rsrtm_ConfigureSearchCondition", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function ConfigureSearchCondition (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Action As Integer) As Integer
End Function

<DllImport ("rsrtm_32.dll", EntryPoint:="rsrtm_ConfigureSearchSource", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function ConfigureSearchSource (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Search_Source As Integer) As Integer
End Function

<DllImport ("rsrtm_32.dll", EntryPoint:="rsrtm_ConfigureEdgeTriggerSearch", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function ConfigureEdgeTriggerSearch (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Trigger_Slope As Integer, ByVal Trigger_Level As Double, ByVal Trigger_Hystersis As Double) As Integer
End Function

<DllImport ("rsrtm_32.dll", EntryPoint:="rsrtm_ConfigureWidthTriggerSearch", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function ConfigureWidthTriggerSearch (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Level As Double, ByVal Level_Delta As Double, ByVal Width As Double, ByVal Width_Delta As Double, ByVal Polarity As Integer, ByVal Range As Integer) As Integer
End Function

<DllImport ("rsrtm_32.dll", EntryPoint:="rsrtm_ConfigurePeakTriggerSearch", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function ConfigurePeakTriggerSearch (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Polarity As Integer, ByVal Limit As Double) As Integer
End Function

<DllImport ("rsrtm_32.dll", EntryPoint:="rsrtm_ConfigureRiseTimeTriggerSearch", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function ConfigureRiseTimeTriggerSearch (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Polarity As Integer, ByVal Upper_Level As Double, ByVal Lower_Level As Double, ByVal Range As Integer, ByVal Time As Double, ByVal Delta_Time As Double) As Integer
End Function

<DllImport ("rsrtm_32.dll", EntryPoint:="rsrtm_ConfigureRuntTriggerSearch", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function ConfigureRuntTriggerSearch (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Polarity As Integer, ByVal Upper_Level As Double, ByVal Lower_Level As Double, ByVal Range As Integer, ByVal Width As Double, ByVal Delta_Width As Double) As Integer
End Function

<DllImport ("rsrtm_32.dll", EntryPoint:="rsrtm_ConfigureShowResultDiagram", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function ConfigureShowResultDiagram (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Show_Result As UShort) As Integer
End Function

<DllImport ("rsrtm_32.dll", EntryPoint:="rsrtm_QueryNumberOfResults", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function QueryNumberOfResults (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByRef Number_Of_Results As Integer) As Integer
End Function

<DllImport ("rsrtm_32.dll", EntryPoint:="rsrtm_QuerySearchResult", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function QuerySearchResult (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Result_Number As Integer, ByRef X_Position As Double, ByRef Y_Position As Double, ByRef Result_Type As Integer, ByRef Polarity As Integer, ByRef Voltage_Width As Double) As Integer
End Function

<DllImport ("rsrtm_32.dll", EntryPoint:="rsrtm_QueryAllSearchResults", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function QueryAllSearchResults (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Array_Size As Integer, <[In], Out> X_Position As Double(), <[In], Out> Y_Position As Double(), <[In], Out> Result_Type As Integer(), <[In], Out> Polarity As Integer(), <[In], Out> Voltage_Width As Double(), ByRef Number_Of_Results As Integer) As Integer
End Function

<DllImport ("rsrtm_32.dll", EntryPoint:="rsrtm_ConfigureDecodeState", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function ConfigureDecodeState (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal State As UShort) As Integer
End Function

<DllImport ("rsrtm_32.dll", EntryPoint:="rsrtm_ConfigureBusProtocol", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function ConfigureBusProtocol (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Protocol As Integer) As Integer
End Function

<DllImport ("rsrtm_32.dll", EntryPoint:="rsrtm_ConfigureProtocolDisplay", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function ConfigureProtocolDisplay (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Format As Integer, ByVal Height As Integer, ByVal Display_Lines As UShort, ByVal Vertical_Position As Double) As Integer
End Function

<DllImport ("rsrtm_32.dll", EntryPoint:="rsrtm_ConfigureI2CSource", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function ConfigureI2CSource (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Line As Integer, ByVal Waveform_Source As Integer) As Integer
End Function

<DllImport ("rsrtm_32.dll", EntryPoint:="rsrtm_ConfigureI2CTriggerSetting", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function ConfigureI2CTriggerSetting (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Access As Integer, ByVal Address_length As Integer, ByVal Device_Address As String, ByVal Trigger_Mode As Integer, ByVal Pattern_Length As Integer, ByVal Pattern As String, ByVal Pattern_Offset As Integer) As Integer
End Function

<DllImport ("rsrtm_32.dll", EntryPoint:="rsrtm_ConfigureSPISource", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function ConfigureSPISource (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Line As Integer, ByVal Waveform_Source As Integer) As Integer
End Function

<DllImport ("rsrtm_32.dll", EntryPoint:="rsrtm_ConfigureSPIPolarity", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function ConfigureSPIPolarity (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Line As Integer, ByVal Polarity As Integer) As Integer
End Function

<DllImport ("rsrtm_32.dll", EntryPoint:="rsrtm_ConfigureSPIWord", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function ConfigureSPIWord (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Bit_Order As Integer, ByVal Word_Length As Integer) As Integer
End Function

<DllImport ("rsrtm_32.dll", EntryPoint:="rsrtm_ConfigureSPITriggerType", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function ConfigureSPITriggerType (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Mode As Integer) As Integer
End Function

<DllImport ("rsrtm_32.dll", EntryPoint:="rsrtm_ConfigureSPITriggerData", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function ConfigureSPITriggerData (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Offset As Integer, ByVal Bit_Pattern_Length As Integer, ByVal Bit_Pattern As String) As Integer
End Function

<DllImport ("rsrtm_32.dll", EntryPoint:="rsrtm_ConfigureSSPISource", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function ConfigureSSPISource (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Line As Integer, ByVal Waveform_Source As Integer) As Integer
End Function

<DllImport ("rsrtm_32.dll", EntryPoint:="rsrtm_ConfigureSSPIPolarity", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function ConfigureSSPIPolarity (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Line As Integer, ByVal Polarity As Integer) As Integer
End Function

<DllImport ("rsrtm_32.dll", EntryPoint:="rsrtm_ConfigureSSPIPackets", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function ConfigureSSPIPackets (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Interframe_time As Double, ByVal Bit_Order As Integer, ByVal Word_Length As Integer) As Integer
End Function

<DllImport ("rsrtm_32.dll", EntryPoint:="rsrtm_ConfigureUARTSource", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function ConfigureUARTSource (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Waveform_Source As Integer) As Integer
End Function

<DllImport ("rsrtm_32.dll", EntryPoint:="rsrtm_ConfigureUARTPolarity", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function ConfigureUARTPolarity (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Polarity As Integer) As Integer
End Function

<DllImport ("rsrtm_32.dll", EntryPoint:="rsrtm_ConfigureUART", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function ConfigureUART (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Interframe_time As Double, ByVal Word_Length As Integer, ByVal Bit_Rate As Integer, ByVal Parity As Integer, ByVal Stop_bits As Integer) As Integer
End Function

<DllImport ("rsrtm_32.dll", EntryPoint:="rsrtm_ConfigureUARTTriggerType", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function ConfigureUARTTriggerType (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Mode As Integer) As Integer
End Function

<DllImport ("rsrtm_32.dll", EntryPoint:="rsrtm_ConfigureUARTTriggerPattern", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function ConfigureUARTTriggerPattern (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Pattern As String, ByVal Pattern_Length As Integer, ByVal Pattern_Offset As Integer) As Integer
End Function

<DllImport ("rsrtm_32.dll", EntryPoint:="rsrtm_ConfigureParallelSource", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function ConfigureParallelSource (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Bit As Integer, ByVal Channel As Integer) As Integer
End Function

<DllImport ("rsrtm_32.dll", EntryPoint:="rsrtm_ConfigureParallelAnalyzedLines", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function ConfigureParallelAnalyzedLines (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Line As Integer) As Integer
End Function

<DllImport ("rsrtm_32.dll", EntryPoint:="rsrtm_ConfigureHardcopyPrinter", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function ConfigureHardcopyPrinter (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Printer_Name As String, ByVal Page_Orientation As Integer, ByVal Scheme As Integer, ByVal Size As Integer) As Integer
End Function

<DllImport ("rsrtm_32.dll", EntryPoint:="rsrtm_ConfigureHardcopyFile", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function ConfigureHardcopyFile (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Name As String, ByVal Format As Integer, ByVal Scheme As Integer) As Integer
End Function

<DllImport ("rsrtm_32.dll", EntryPoint:="rsrtm_HardcopyPrint", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function HardcopyPrint (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef) As Integer
End Function

<DllImport ("rsrtm_32.dll", EntryPoint:="rsrtm_HardcopyGetPrinterList", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function HardcopyGetPrinterList (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Buffer_Size As Integer, ByVal Printer_List As System.Text.StringBuilder) As Integer
End Function

<DllImport ("rsrtm_32.dll", EntryPoint:="rsrtm_ConfigureMathEnabled", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function ConfigureMathEnabled (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Math_Number As Integer, ByVal Math_Enabled As UShort) As Integer
End Function

<DllImport ("rsrtm_32.dll", EntryPoint:="rsrtm_ConfigureMathWaveformPosition", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function ConfigureMathWaveformPosition (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Math_Number As Integer, ByVal Waveform_Position As Double) As Integer
End Function

<DllImport ("rsrtm_32.dll", EntryPoint:="rsrtm_ConfigureMathScaling", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function ConfigureMathScaling (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Math_Number As Integer, ByVal Vertical_Scale As Double) As Integer
End Function

<DllImport ("rsrtm_32.dll", EntryPoint:="rsrtm_ConfigureMathSetup", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function ConfigureMathSetup (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Math_Number As Integer, ByVal Calculation_Method As Integer, ByVal Expression As String) As Integer
End Function

<DllImport ("rsrtm_32.dll", EntryPoint:="rsrtm_ConfigureFFTFrequencyCenterSpan", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function ConfigureFFTFrequencyCenterSpan (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Math_Number As Integer, ByVal Center_Frequency As Double, ByVal Frequency_Span As Double) As Integer
End Function

<DllImport ("rsrtm_32.dll", EntryPoint:="rsrtm_ConfigureFFTFrequencySpanFull", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function ConfigureFFTFrequencySpanFull (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Math_Number As Integer) As Integer
End Function

<DllImport ("rsrtm_32.dll", EntryPoint:="rsrtm_ConfigureFFTFrequencyStartStop", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function ConfigureFFTFrequencyStartStop (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Math_Number As Integer, ByVal Start_Frequency As Double, ByVal Stop_Frequency As Double) As Integer
End Function

<DllImport ("rsrtm_32.dll", EntryPoint:="rsrtm_ConfigureFFTResolutionBandwidth", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function ConfigureFFTResolutionBandwidth (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Math_Number As Integer, ByVal RBW_and_Span_Coupling_Enabled As UShort, ByVal RBW_Ratio As Integer, ByVal Resolution_Bandwidth As Double) As Integer
End Function

<DllImport ("rsrtm_32.dll", EntryPoint:="rsrtm_QueryFFTAdjustedResolutionBandwidth", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function QueryFFTAdjustedResolutionBandwidth (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Math_Number As Integer, ByRef Adjusted_RBW As Double) As Integer
End Function

<DllImport ("rsrtm_32.dll", EntryPoint:="rsrtm_ConfigureFFTWindowType", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function ConfigureFFTWindowType (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Math_Number As Integer, ByVal Window_Type As Integer) As Integer
End Function

<DllImport ("rsrtm_32.dll", EntryPoint:="rsrtm_ConfigureFFTAveraging", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function ConfigureFFTAveraging (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Math_Number As Integer, ByVal Number_Of_Spectrums As Integer) As Integer
End Function

<DllImport ("rsrtm_32.dll", EntryPoint:="rsrtm_ConfigureFFTScaling", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function ConfigureFFTScaling (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Math_Number As Integer, ByVal Scaling_Unit As Integer, ByVal Vertical_Scale As Double) As Integer
End Function

<DllImport ("rsrtm_32.dll", EntryPoint:="rsrtm_QueryFFTSampleRate", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function QueryFFTSampleRate (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Math_Number As Integer, ByRef Sample_Rate As Integer) As Integer
End Function

<DllImport ("rsrtm_32.dll", EntryPoint:="rsrtm_ConfigureReferenceWaveformSource", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function ConfigureReferenceWaveformSource (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Reference_Number As Integer, ByVal Source As Integer) As Integer
End Function

<DllImport ("rsrtm_32.dll", EntryPoint:="rsrtm_UpdateReferenceWaveformWithSelectedSource", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function UpdateReferenceWaveformWithSelectedSource (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Reference_Number As Integer) As Integer
End Function

<DllImport ("rsrtm_32.dll", EntryPoint:="rsrtm_ConfigureReferenceWaveformDisplayState", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function ConfigureReferenceWaveformDisplayState (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Reference_Number As Integer, ByVal Display_Enabled As UShort) As Integer
End Function

<DllImport ("rsrtm_32.dll", EntryPoint:="rsrtm_ReferenceWaveformFileOperations", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function ReferenceWaveformFileOperations (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Reference_Wfm As Integer, ByVal Operation As Integer, ByVal File_Name As String) As Integer
End Function

<DllImport ("rsrtm_32.dll", EntryPoint:="rsrtm_ConfigureReferenceWaveformVerticalScale", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function ConfigureReferenceWaveformVerticalScale (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Reference_Number As Integer, ByVal Vertical_Scale As Double, ByVal Vertical_Position As Double) As Integer
End Function

<DllImport ("rsrtm_32.dll", EntryPoint:="rsrtm_ConfigureReferenceWaveformHorizontalScale", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function ConfigureReferenceWaveformHorizontalScale (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Reference_Wfm As Integer, ByVal Scale As Double, ByVal Horizontal_Position As Double) As Integer
End Function

<DllImport ("rsrtm_32.dll", EntryPoint:="rsrtm_ReferenceReadWaveformCatalog", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function ReferenceReadWaveformCatalog (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Reference_Wfm As Integer, ByRef Source_Waveform As Integer) As Integer
End Function

<DllImport ("rsrtm_32.dll", EntryPoint:="rsrtm_ReadWaveform", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function ReadWaveform (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Channel As Integer, ByVal Waveform_Size As Integer, ByVal Maximum_Time As Integer, <[In], Out> Waveform_Array As Double(), ByRef Actual_Points As Integer, ByRef Initial_X As Double, ByRef X_Increment As Double) As Integer
End Function

<DllImport ("rsrtm_32.dll", EntryPoint:="rsrtm_ReadMainWaveformMeasurement", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function ReadMainWaveformMeasurement (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Measurement As Integer, ByVal Measurement_Function As Integer, ByVal Maximum_Time As Integer, ByRef Measurement_Result As Double) As Integer
End Function

<DllImport ("rsrtm_32.dll", EntryPoint:="rsrtm_InitiateAcquisition", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function InitiateAcquisition (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Action As Integer) As Integer
End Function

<DllImport ("rsrtm_32.dll", EntryPoint:="rsrtm_SendSoftwareTrigger", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function SendSoftwareTrigger (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Maximum_Time As Integer) As Integer
End Function

<DllImport ("rsrtm_32.dll", EntryPoint:="rsrtm_FetchWaveform", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function FetchWaveform (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Channel As Integer, ByVal Waveform_Size As Integer, <[In], Out> Waveform_Array As Double(), ByRef Actual_Points As Integer, ByRef Initial_X As Double, ByRef X_Increment As Double) As Integer
End Function

<DllImport ("rsrtm_32.dll", EntryPoint:="rsrtm_FetchWaveformHeader", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function FetchWaveformHeader (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Channel As Integer, ByRef X_Start As Double, ByRef X_Stop As Double, ByRef Record_Length As Integer, ByRef Values_per_Sample As Integer) As Integer
End Function

<DllImport ("rsrtm_32.dll", EntryPoint:="rsrtm_FetchEnvelopeWaveform", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function FetchEnvelopeWaveform (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Channel As Integer, ByVal Waveform_Size As Integer, <[In], Out> Waveform_Array As Double(), ByRef Actual_Points As Integer, ByRef Initial_X As Double, ByRef X_Increment As Double) As Integer
End Function

<DllImport ("rsrtm_32.dll", EntryPoint:="rsrtm_FetchEnvelopeWaveformHeader", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function FetchEnvelopeWaveformHeader (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Channel As Integer, ByRef X_Start As Double, ByRef X_Stop As Double, ByRef Record_Length As Integer, ByRef Values_per_Sample As Integer) As Integer
End Function

<DllImport ("rsrtm_32.dll", EntryPoint:="rsrtm_FetchMathWaveform", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function FetchMathWaveform (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Math_Number As Integer, ByVal Waveform_Size As Integer, <[In], Out> Waveform_Array As Double(), ByRef Actual_Points As Integer) As Integer
End Function

<DllImport ("rsrtm_32.dll", EntryPoint:="rsrtm_FetchMathWaveformHeader", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function FetchMathWaveformHeader (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Math_Number As Integer, ByRef X_Start As Double, ByRef X_Stop As Double, ByRef Record_Length As Integer, ByRef Values_per_Sample As Integer) As Integer
End Function

<DllImport ("rsrtm_32.dll", EntryPoint:="rsrtm_FetchReferenceWaveform", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function FetchReferenceWaveform (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Reference_Wfm As Integer, ByVal Waveform_Size As Integer, <[In], Out> Waveform_Array As Double(), ByRef Actual_Points As Integer) As Integer
End Function

<DllImport ("rsrtm_32.dll", EntryPoint:="rsrtm_FetchReferenceWaveformHeader", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function FetchReferenceWaveformHeader (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Reference_Wfm As Integer, ByRef X_Start As Double, ByRef X_Stop As Double, ByRef Record_Length As Integer, ByRef Values_per_Sample As Integer) As Integer
End Function

<DllImport ("rsrtm_32.dll", EntryPoint:="rsrtm_FetchMainWaveformMeasurement", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function FetchMainWaveformMeasurement (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Measurement As Integer, ByVal Measurement_Function As Integer, ByRef Measurement_Result As Double) As Integer
End Function

<DllImport ("rsrtm_32.dll", EntryPoint:="rsrtm_Abort", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function Abort (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef) As Integer
End Function

<DllImport ("rsrtm_32.dll", EntryPoint:="rsrtm_reset", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function reset (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef) As Integer
End Function

<DllImport ("rsrtm_32.dll", EntryPoint:="rsrtm_self_test", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function self_test (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByRef Self_Test_Result As Short, ByVal Self_Test_Message As System.Text.StringBuilder) As Integer
End Function

<DllImport ("rsrtm_32.dll", EntryPoint:="rsrtm_revision_query", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function revision_query (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Instrument_Driver_Revision As System.Text.StringBuilder, ByVal Firmware_Revision As System.Text.StringBuilder) As Integer
End Function

<DllImport ("rsrtm_32.dll", EntryPoint:="rsrtm_error_query", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function error_query (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByRef Error_Code As Integer, ByVal Error_Message As System.Text.StringBuilder) As Integer
End Function

<DllImport ("rsrtm_32.dll", EntryPoint:="rsrtm_ErrorList", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function ErrorList (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Buffer_Size As Integer, ByVal Errors As System.Text.StringBuilder) As Integer
End Function

<DllImport ("rsrtm_32.dll", EntryPoint:="rsrtm_ConfigureInstrumentName", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function ConfigureInstrumentName (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Name As String) As Integer
End Function

<DllImport ("rsrtm_32.dll", EntryPoint:="rsrtm_ResetStatusRegisters", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function ResetStatusRegisters (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef) As Integer
End Function

<DllImport ("rsrtm_32.dll", EntryPoint:="rsrtm_SetStatusRegister", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function SetStatusRegister (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Register_Type As Integer, ByVal Status_Register As Integer, ByVal Register_Part As Integer, ByVal Register_Value As Integer) As Integer
End Function

<DllImport ("rsrtm_32.dll", EntryPoint:="rsrtm_GetStatusRegister", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function GetStatusRegister (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Register_Type As Integer, ByVal Status_Register As Integer, ByVal Register_Part As Integer, ByRef Register_Value As Integer) As Integer
End Function

<DllImport ("rsrtm_32.dll", EntryPoint:="rsrtm_WriteInstrData", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function WriteInstrData (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Write_Buffer As String) As Integer
End Function

<DllImport ("rsrtm_32.dll", EntryPoint:="rsrtm_ReadInstrData", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function ReadInstrData (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Number_of_Bytes_To_Read As Integer, ByVal Read_Buffer As System.Text.StringBuilder, ByRef Num_Bytes_Read As UInteger) As Integer
End Function

<DllImport ("rsrtm_32.dll", EntryPoint:="rsrtm_QueryViBoolean", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function QueryViBoolean (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Command As String, ByRef Value As UShort) As Integer
End Function

<DllImport ("rsrtm_32.dll", EntryPoint:="rsrtm_QueryViInt32", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function QueryViInt32 (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Command As String, ByRef Value As Integer) As Integer
End Function

<DllImport ("rsrtm_32.dll", EntryPoint:="rsrtm_QueryViReal64", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function QueryViReal64 (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Command As String, ByRef Value As Double) As Integer
End Function

<DllImport ("rsrtm_32.dll", EntryPoint:="rsrtm_QueryViString", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function QueryViString (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Command As String, ByVal Buffer_Size As Integer, ByVal Value As System.Text.StringBuilder) As Integer
End Function

<DllImport ("rsrtm_32.dll", EntryPoint:="rsrtm_FileManagerOperations", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function FileManagerOperations (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Operation As Integer, ByVal Source As String, ByVal Destination As String) As Integer
End Function

<DllImport ("rsrtm_32.dll", EntryPoint:="rsrtm_FileCount", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function FileCount (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Directory As String, ByRef Number_of_Files_And_Folders As Integer) As Integer
End Function

<DllImport ("rsrtm_32.dll", EntryPoint:="rsrtm_FileDirectoryContent", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function FileDirectoryContent (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Directory As String, ByVal Buffer_Size As Integer, ByVal Output As System.Text.StringBuilder) As Integer
End Function

<DllImport ("rsrtm_32.dll", EntryPoint:="rsrtm_FileSubdirectoriesCount", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function FileSubdirectoriesCount (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Directory As String, ByRef Number_of_Subdirectories As Integer) As Integer
End Function

<DllImport ("rsrtm_32.dll", EntryPoint:="rsrtm_FileSubdirectories", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function FileSubdirectories (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Directory As String, ByVal Buffer_Size As Integer, ByVal Output As System.Text.StringBuilder) As Integer
End Function

<DllImport ("rsrtm_32.dll", EntryPoint:="rsrtm_FileDrives", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function FileDrives (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Buffer_Size As Integer, ByVal Output As System.Text.StringBuilder) As Integer
End Function

<DllImport ("rsrtm_32.dll", EntryPoint:="rsrtm_ReadToFileFromInstrument", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function ReadToFileFromInstrument (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Source As String, ByVal Destination As String) As Integer
End Function

<DllImport ("rsrtm_32.dll", EntryPoint:="rsrtm_WriteFromFileToInstrument", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function WriteFromFileToInstrument (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Source As String, ByVal Destination As String) As Integer
End Function

<DllImport ("rsrtm_32.dll", EntryPoint:="rsrtm_DataSetFileOperations", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function DataSetFileOperations (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Operation As Integer, ByVal State_Number As Integer, ByVal Path As String) As Integer
End Function

<DllImport ("rsrtm_32.dll", EntryPoint:="rsrtm_close", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function close (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef) As Integer
End Function

<DllImport ("rsrtm_32.dll", EntryPoint:="rsrtm_error_message", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function error_message (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Error_Code As Integer, ByVal Error_Message_2 As System.Text.StringBuilder) As Integer
End Function

<DllImport ("rsrtm_32.dll", EntryPoint:="rsrtm_GetAttributeViInt32", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function GetAttributeViInt32 (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Channel_Name As String, ByVal Attribute_ID As Integer, ByRef Attribute_Value As Integer) As Integer
End Function

<DllImport ("rsrtm_32.dll", EntryPoint:="rsrtm_GetAttributeViReal64", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function GetAttributeViReal64 (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Channel_Name As String, ByVal Attribute_ID As Integer, ByRef Attribute_Value As Double) As Integer
End Function

<DllImport ("rsrtm_32.dll", EntryPoint:="rsrtm_GetAttributeViString", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function GetAttributeViString (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Channel_Name As String, ByVal Attribute_ID As Integer, ByVal Buffer_Size As Integer, ByVal Attribute_Value As System.Text.StringBuilder) As Integer
End Function

<DllImport ("rsrtm_32.dll", EntryPoint:="rsrtm_GetAttributeViBoolean", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function GetAttributeViBoolean (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Channel_Name As String, ByVal Attribute_ID As Integer, ByRef Attribute_Value As UShort) As Integer
End Function

<DllImport ("rsrtm_32.dll", EntryPoint:="rsrtm_GetAttributeViSession", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function GetAttributeViSession (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Channel_Name As String, ByVal Attribute_ID As Integer, ByRef Attribute_Value As System.Runtime.InteropServices.HandleRef) As Integer
End Function

<DllImport ("rsrtm_32.dll", EntryPoint:="rsrtm_GetAttributeRepeatedCapabilityIds", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function GetAttributeRepeatedCapabilityIds (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Attribute_ID As UInteger, ByVal Buffer_Size As Integer, ByVal Repeated_Capability_Id_s_ As System.Text.StringBuilder) As Integer
End Function

<DllImport ("rsrtm_32.dll", EntryPoint:="rsrtm_GetAttributeRepeatedCapabilityIdNames", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function GetAttributeRepeatedCapabilityIdNames (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Attribute_ID As UInteger, ByVal Repeated_Capability_Id As String, ByVal Buffer_Size As Integer, ByVal Repeated_Capability_Id_Name_s_ As System.Text.StringBuilder) As Integer
End Function

<DllImport ("rsrtm_32.dll", EntryPoint:="rsrtm_SetAttributeViInt32", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function SetAttributeViInt32 (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Channel_Name As String, ByVal Attribute_ID As Integer, ByVal Attribute_Value As Integer) As Integer
End Function

<DllImport ("rsrtm_32.dll", EntryPoint:="rsrtm_SetAttributeViReal64", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function SetAttributeViReal64 (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Channel_Name As String, ByVal Attribute_ID As Integer, ByVal Attribute_Value As Double) As Integer
End Function

<DllImport ("rsrtm_32.dll", EntryPoint:="rsrtm_SetAttributeViString", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function SetAttributeViString (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Channel_Name As String, ByVal Attribute_ID As Integer, ByVal Attribute_Value As String) As Integer
End Function

<DllImport ("rsrtm_32.dll", EntryPoint:="rsrtm_SetAttributeViBoolean", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function SetAttributeViBoolean (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Channel_Name As String, ByVal Attribute_ID As Integer, ByVal Attribute_Value As UShort) As Integer
End Function

<DllImport ("rsrtm_32.dll", EntryPoint:="rsrtm_SetAttributeViSession", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function SetAttributeViSession (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByVal Channel_Name As String, ByVal Attribute_ID As Integer, ByVal Attribute_Value As System.Runtime.InteropServices.HandleRef) As Integer
End Function

<DllImport ("rsrtm_32.dll", EntryPoint:="rsrtm_GetError", CallingConvention:=CallingConvention.StdCall)> _
Public Shared Function GetError (ByVal Instrument_Handle As System.Runtime.InteropServices.HandleRef, ByRef Code As Integer, ByVal BufferSize As Integer, ByVal Description As System.Text.StringBuilder) As Integer
End Function

            
            Public Shared Function TestForError(ByVal handle As System.Runtime.InteropServices.HandleRef, ByVal status As Integer) As Integer
                If (status < 0) Then
                    PInvoke.ThrowError(handle, status)
                End If
                Return status
            End Function
            
            Public Shared Function ThrowError(ByVal handle As System.Runtime.InteropServices.HandleRef, ByVal code As Integer) As Integer
                Dim status As Integer
                Dim size As Integer = PInvoke.GetError(handle, status, 0, Nothing)
                Dim msg As System.Text.StringBuilder = New System.Text.StringBuilder
                If (size >= 0) Then
                    msg.Capacity = size
                    PInvoke.GetError(handle, status, size, msg)
                End If
                Throw New System.Runtime.InteropServices.ExternalException(msg.ToString, code)
            End Function
        End Class
    End Class
    
    Public Class rsrtmConstants
        
        Public Const Channel1 As Integer = 1
        
        Public Const Channel2 As Integer = 2
        
        Public Const Channel3 As Integer = 3
        
        Public Const Channel4 As Integer = 4
        
        Public Const ChannelExt As Integer = 5
        
        Public Const Sample As Integer = 0
        
        Public Const PeakDetect As Integer = 1
        
        Public Const HiRes As Integer = 2
        
        Public Const WaveformSamplesDefault As Integer = 0
        
        Public Const WaveformSamplesMaximum As Integer = 1
        
        Public Const WaveformSamplesDisplayMaximum As Integer = 2
        
        Public Const RateAuto As Integer = 0
        
        Public Const RateMaxSam As Integer = 2
        
        Public Const RateMaxWav As Integer = 1
        
        Public Const RealTime As Integer = 0
        
        Public Const EquivalentTime As Integer = 1
        
        Public Const SineX As Integer = 0
        
        Public Const Linear As Integer = 1
        
        Public Const SampleHold As Integer = 2
        
        Public Const Off As Integer = 0
        
        Public Const Envelope As Integer = 1
        
        Public Const Average As Integer = 2
        
        Public Const Ac As Integer = 0
        
        Public Const Dc As Integer = 1
        
        Public Const DcLimit As Integer = 2
        
        Public Const BwFull As Integer = 0
        
        Public Const Bw400 As Integer = 1
        
        Public Const Bw200 As Integer = 2
        
        Public Const Bw20 As Integer = 3
        
        Public Const PolarityNorm As Integer = 0
        
        Public Const PolarityInv As Integer = 1
        
        Public Const ProbeButtonNoAction As Integer = 0
        
        Public Const ProbeButtonRunContinuous As Integer = 1
        
        Public Const ProbeButtonRunSingle As Integer = 2
        
        Public Const ProbeButtonAutoset As Integer = 3
        
        Public Const ProbeUnitV As Integer = 0
        
        Public Const ProbeUnitA As Integer = 1
        
        Public Const TriggerA As Integer = 0
        
        Public Const TriggerB As Integer = 1
        
        Public Const EdgeTrigger As Integer = 0
        
        Public Const WidthTrigger As Integer = 1
        
        Public Const VideoTrigger As Integer = 2
        
        Public Const PatternTrigger As Integer = 3
        
        Public Const BusTrigger As Integer = 4
        
        Public Const External As Integer = 5
        
        Public Const Line As Integer = 6
        
        Public Const CouplingAc As Integer = 0
        
        Public Const CouplingDc As Integer = 1
        
        Public Const TriggerAuto As Integer = 0
        
        Public Const TriggerNormal As Integer = 1
        
        Public Const TriggerDelay As Integer = 2
        
        Public Const TriggerEvents As Integer = 3
        
        Public Const HysteresisAuto As Integer = 0
        
        Public Const HysteresisSmall As Integer = 1
        
        Public Const HysteresisMedium As Integer = 2
        
        Public Const HysteresisLarge As Integer = 3
        
        Public Const Positive As Integer = 0
        
        Public Const Negative As Integer = 1
        
        Public Const Either As Integer = 2
        
        Public Const Channelrtm1 As Integer = 1
        
        Public Const Channelrtm2 As Integer = 2
        
        Public Const Channelrtm3 As Integer = 3
        
        Public Const Channelrtm4 As Integer = 4
        
        Public Const CouplingDirect As Integer = 0
        
        Public Const CouplingAlternating As Integer = 1
        
        Public Const CouplingHighfreq As Integer = 2
        
        Public Const TriggerFilterLow As Integer = 0
        
        Public Const TriggerFilterHigh As Integer = 1
        
        Public Const Shorter As Integer = 0
        
        Public Const Longer As Integer = 1
        
        Public Const Within As Integer = 2
        
        Public Const Outside As Integer = 3
        
        Public Const TrgPatternAnd As Integer = 0
        
        Public Const TrgPatternOr As Integer = 1
        
        Public Const TvEventEven As Integer = 0
        
        Public Const TvEventOdd As Integer = 1
        
        Public Const TvEventAnyField As Integer = 2
        
        Public Const TvEventLine As Integer = 3
        
        Public Const TvEventAnyLine As Integer = 4
        
        Public Const TvStandartPal As Integer = 0
        
        Public Const TvStandartNtsc As Integer = 1
        
        Public Const TvStandartSecam As Integer = 2
        
        Public Const TvStandartPalm As Integer = 3
        
        Public Const TvStandartI576 As Integer = 4
        
        Public Const TvStandartP720 As Integer = 5
        
        Public Const TvStandartP1080 As Integer = 6
        
        Public Const TvStandartI1080 As Integer = 7
        
        Public Const SignalStyleVectors As Integer = 0
        
        Public Const SignalStyleDots As Integer = 1
        
        Public Const DisplayBackground As Integer = 0
        
        Public Const DisplayGrid As Integer = 1
        
        Public Const DisplayWaveform As Integer = 2
        
        Public Const ColorNorm As Integer = 0
        
        Public Const ColorInverse As Integer = 1
        
        Public Const ColorFcolor As Integer = 2
        
        Public Const ColorInvcolor As Integer = 3
        
        Public Const GridLines As Integer = 0
        
        Public Const GridCross As Integer = 1
        
        Public Const GridNone As Integer = 2
        
        Public Const DisplayEnglish As Integer = 0
        
        Public Const DisplayGerman As Integer = 1
        
        Public Const DisplayYt As Integer = 0
        
        Public Const DisplayXy As Integer = 1
        
        Public Const MarkerActionSet As Integer = 0
        
        Public Const MarkerActionNext As Integer = 1
        
        Public Const MarkerActionPrev As Integer = 2
        
        Public Const MarkerActionClear As Integer = 3
        
        Public Const MarkerActionAclear As Integer = 4
        
        Public Const SourceCh1 As Integer = 1
        
        Public Const SourceCh2 As Integer = 2
        
        Public Const SourceCh3 As Integer = 3
        
        Public Const SourceCh4 As Integer = 4
        
        Public Const SourceNone As Integer = 0
        
        Public Const ZmodeAnalog As Integer = 0
        
        Public Const ZmodeDigital As Integer = 1
        
        Public Const ZmodeOff As Integer = 2
        
        Public Const Measurement1 As Integer = 1
        
        Public Const Measurement2 As Integer = 2
        
        Public Const Measurement3 As Integer = 3
        
        Public Const Measurement4 As Integer = 4
        
        Public Const Measurement5 As Integer = 5
        
        Public Const Measurement6 As Integer = 6
        
        Public Const Measurement7 As Integer = 7
        
        Public Const Measurement8 As Integer = 8
        
        Public Const MeasurementSourceNone As Integer = 0
        
        Public Const MeasurementSourceCh1 As Integer = 1
        
        Public Const MeasurementSourceCh2 As Integer = 2
        
        Public Const MeasurementSourceCh3 As Integer = 3
        
        Public Const MeasurementSourceCh4 As Integer = 4
        
        Public Const MeasurementSourceM1 As Integer = 5
        
        Public Const MeasurementSourceM2 As Integer = 6
        
        Public Const MeasurementSourceM3 As Integer = 7
        
        Public Const MeasurementSourceM4 As Integer = 8
        
        Public Const MeasurementSourceM5 As Integer = 9
        
        Public Const MeasurementSourceR1 As Integer = 10
        
        Public Const MeasurementSourceR2 As Integer = 11
        
        Public Const MeasurementSourceR3 As Integer = 12
        
        Public Const MeasurementSourceR4 As Integer = 13
        
        Public Const MeasFrequency As Integer = 1
        
        Public Const MeasPeriod As Integer = 2
        
        Public Const MeasPeak As Integer = 3
        
        Public Const MeasUpeak As Integer = 4
        
        Public Const MeasLpeak As Integer = 5
        
        Public Const MeasPpc As Integer = 6
        
        Public Const MeasNpc As Integer = 7
        
        Public Const MeasRec As Integer = 8
        
        Public Const MeasFec As Integer = 9
        
        Public Const MeasHigh As Integer = 10
        
        Public Const MeasLow As Integer = 11
        
        Public Const MeasAmp As Integer = 12
        
        Public Const MeasMean As Integer = 13
        
        Public Const MeasRms As Integer = 14
        
        Public Const MeasRtm As Integer = 15
        
        Public Const MeasFtim As Integer = 16
        
        Public Const MeasPdcy As Integer = 17
        
        Public Const MeasNdcy As Integer = 18
        
        Public Const MeasPpw As Integer = 19
        
        Public Const MeasCycm As Integer = 21
        
        Public Const MeasCycr As Integer = 22
        
        Public Const MeasSstdd As Integer = 23
        
        Public Const MeasTfr As Integer = 24
        
        Public Const MeasTper As Integer = 25
        
        Public Const MeasSlopePos As Integer = 0
        
        Public Const MeasSlopeNeg As Integer = 1
        
        Public Const MeasRelativeTen As Integer = 0
        
        Public Const MeasRelativeFive As Integer = 2
        
        Public Const WavCh1 As Integer = 1
        
        Public Const WavCh2 As Integer = 2
        
        Public Const WavCh3 As Integer = 3
        
        Public Const WavCh4 As Integer = 4
        
        Public Const WavM1 As Integer = 5
        
        Public Const WavM2 As Integer = 6
        
        Public Const WavM3 As Integer = 7
        
        Public Const WavM4 As Integer = 8
        
        Public Const WavM5 As Integer = 9
        
        Public Const WavR1 As Integer = 10
        
        Public Const WavR2 As Integer = 11
        
        Public Const WavR3 As Integer = 12
        
        Public Const WavR4 As Integer = 13
        
        Public Const CursorHorizontal As Integer = 0
        
        Public Const CursorVertical As Integer = 1
        
        Public Const CursorPaired As Integer = 2
        
        Public Const CursorHrat As Integer = 3
        
        Public Const CursorVrat As Integer = 4
        
        Public Const CursorPpc As Integer = 5
        
        Public Const CursorNpc As Integer = 6
        
        Public Const CursorRec As Integer = 7
        
        Public Const CursorFec As Integer = 8
        
        Public Const CursorMean As Integer = 9
        
        Public Const CursorRms As Integer = 10
        
        Public Const CursorRtim As Integer = 11
        
        Public Const CursorFtim As Integer = 12
        
        Public Const CursorPeak As Integer = 13
        
        Public Const CursorUpe As Integer = 14
        
        Public Const CursorLpe As Integer = 15
        
        Public Const Cursor1 As Integer = 1
        
        Public Const Cursor2 As Integer = 2
        
        Public Const Cursor3 As Integer = 3
        
        Public Const CursorPositionAutoset As Integer = 0
        
        Public Const CursorPositionReset As Integer = 1
        
        Public Const CursorPeakNext As Integer = 0
        
        Public Const CursorPeakPrevious As Integer = 1
        
        Public Const UnitRatio As Integer = 0
        
        Public Const UnitPct As Integer = 1
        
        Public Const UnitDegree As Integer = 2
        
        Public Const UnitRad As Integer = 3
        
        Public Const AutomaticMeasurementAverage As Integer = 0
        
        Public Const AutomaticMeasurementDeviation As Integer = 1
        
        Public Const AutomaticMeasurementMinimum As Integer = 2
        
        Public Const AutomaticMeasurementMaximum As Integer = 3
        
        Public Const MaskcondRun As Integer = 0
        
        Public Const MaskcondStop As Integer = 1
        
        Public Const MaskcondPause As Integer = 2
        
        Public Const SearchcondEdge As Integer = 0
        
        Public Const SearchcondWidth As Integer = 1
        
        Public Const SearchcondPeak As Integer = 2
        
        Public Const MeasurementSourceC1 As Integer = 0
        
        Public Const MeasurementSourceC2 As Integer = 1
        
        Public Const MeasurementSourceC3 As Integer = 2
        
        Public Const MeasurementSourceC4 As Integer = 3
        
        Public Const MeasurementSourceMa1 As Integer = 4
        
        Public Const MeasurementSourceMa2 As Integer = 5
        
        Public Const MeasurementSourceMa3 As Integer = 6
        
        Public Const MeasurementSourceMa4 As Integer = 7
        
        Public Const MeasurementSourceRe1 As Integer = 8
        
        Public Const MeasurementSourceRe2 As Integer = 9
        
        Public Const MeasurementSourceRe3 As Integer = 10
        
        Public Const MeasurementSourceRe4 As Integer = 11
        
        Public Const PtypeRtmParallel As Integer = 0
        
        Public Const PtypeRtmCparallel As Integer = 1
        
        Public Const PtypeRtmI2c As Integer = 2
        
        Public Const PtypeRtmSpi As Integer = 3
        
        Public Const PtypeRtmSspi As Integer = 4
        
        Public Const PtypeRtmUart As Integer = 5
        
        Public Const PformatAsci As Integer = 0
        
        Public Const PformatHex As Integer = 1
        
        Public Const PformatBin As Integer = 2
        
        Public Const PformatDec As Integer = 3
        
        Public Const PheightSmall As Integer = 0
        
        Public Const PheightMedium As Integer = 1
        
        Public Const PheightLarge As Integer = 2
        
        Public Const I2cScl As Integer = 0
        
        Public Const I2cSda As Integer = 1
        
        Public Const I2cTriggerRead As Integer = 1
        
        Public Const I2cTriggerWrite As Integer = 2
        
        Public Const LengthNormal As Integer = 0
        
        Public Const LengthExtended As Integer = 1
        
        Public Const TriggerModeStart As Integer = 0
        
        Public Const TriggerModeRestart As Integer = 1
        
        Public Const TriggerModeStop As Integer = 2
        
        Public Const TriggerModeMissing As Integer = 3
        
        Public Const TriggerModePatt As Integer = 4
        
        Public Const SpiClock As Integer = 0
        
        Public Const SpiData As Integer = 1
        
        Public Const SpiCsel As Integer = 2
        
        Public Const Actlow As Integer = 0
        
        Public Const Acthigh As Integer = 1
        
        Public Const SpiMsbf As Integer = 0
        
        Public Const SpiLsbf As Integer = 1
        
        Public Const SpiModeBurststart As Integer = 0
        
        Public Const SpiModeBurstend As Integer = 1
        
        Public Const SpiModeBit As Integer = 2
        
        Public Const SpiModePattern As Integer = 3
        
        Public Const UartNone As Integer = 0
        
        Public Const UartOdd As Integer = 1
        
        Public Const UartEven As Integer = 2
        
        Public Const UartB1 As Integer = 0
        
        Public Const UartB15 As Integer = 1
        
        Public Const UartB2 As Integer = 2
        
        Public Const UartModeRtmBurststart As Integer = 0
        
        Public Const UartModeRtmSbit As Integer = 1
        
        Public Const UartModeRtmNths As Integer = 2
        
        Public Const UartModeRtmSymb As Integer = 3
        
        Public Const UartModeRtmPatt As Integer = 4
        
        Public Const UartModeRtmPerr As Integer = 5
        
        Public Const UartModeRtmFerr As Integer = 6
        
        Public Const UartModeRtmBre As Integer = 7
        
        Public Const ParallelBit0 As Integer = 0
        
        Public Const ParallelBit1 As Integer = 1
        
        Public Const ParallelBit2 As Integer = 2
        
        Public Const ParallelBit3 As Integer = 3
        
        Public Const HardcopyOrientationPortrait As Integer = 0
        
        Public Const HardcopyOrientationLandscape As Integer = 1
        
        Public Const SchemeColor As Integer = 0
        
        Public Const SchemeGray As Integer = 1
        
        Public Const SchemeInverted As Integer = 2
        
        Public Const PageA4 As Integer = 0
        
        Public Const PageA5 As Integer = 1
        
        Public Const PageB5 As Integer = 2
        
        Public Const PageB6 As Integer = 3
        
        Public Const PageEx As Integer = 4
        
        Public Const HardcopyDeviceLangPng As Integer = 0
        
        Public Const HardcopyDeviceLangBmp As Integer = 1
        
        Public Const Rectangular As Integer = 0
        
        Public Const Hamming As Integer = 1
        
        Public Const Hann As Integer = 2
        
        Public Const Blackman As Integer = 3
        
        Public Const FftLin As Integer = 0
        
        Public Const FftDbm As Integer = 1
        
        Public Const FftDbv As Integer = 2
        
        Public Const WavLoad As Integer = 0
        
        Public Const WavLoadCfg As Integer = 1
        
        Public Const WavSave As Integer = 2
        
        Public Const RefWaveform1 As Integer = 1
        
        Public Const RefWaveform2 As Integer = 2
        
        Public Const RefWaveform3 As Integer = 3
        
        Public Const RefWaveform4 As Integer = 4
        
        Public Const InitSingle As Integer = 0
        
        Public Const InitContinuous As Integer = 1
        
        Public Const RegOper As Integer = 1
        
        Public Const RegQues As Integer = 0
        
        Public Const RegNone As Integer = 0
        
        Public Const RegCov As Integer = 1
        
        Public Const RegLim As Integer = 2
        
        Public Const RegMask As Integer = 3
        
        Public Const RegNoAlign As Integer = 4
        
        Public Const RegCond As Integer = 0
        
        Public Const RegEnable As Integer = 1
        
        Public Const RegEvent As Integer = 2
        
        Public Const RegNtr As Integer = 3
        
        Public Const RegPtr As Integer = 4
        
        Public Const FileCopy As Integer = 0
        
        Public Const FileMove As Integer = 1
        
        Public Const FileDelete As Integer = 2
        
        Public Const FileNewDir As Integer = 3
        
        Public Const FileCdir As Integer = 4
        
        Public Const FileRdir As Integer = 5
        
        Public Const FileCdrive As Integer = 6
        
        Public Const MemSave As Integer = 0
        
        Public Const MemRecall As Integer = 1
        
        Public Const MeasNpw As Integer = 20
        
        Public Const MeasAmpt As Integer = 0
        
        Public Const MeasRelativeTwenty As Integer = 1
        
        Public Const MeasRelativeUser As Integer = 3
        
        Public Const Amptime As Integer = 0
        
        Public Const SearchcondRunt As Integer = 3
        
        Public Const SearchcondRtime As Integer = 4
        
        Public Const UartTriggerBurststart As Integer = 0
        
        Public Const UartTriggerSbit As Integer = 1
        
        Public Const UartTriggerNths As Integer = 2
        
        Public Const UartTriggerSymb As Integer = 3
        
        Public Const UartTriggerPatt As Integer = 4
        
        Public Const UartTriggerPerr As Integer = 5
        
        Public Const UartTriggerFerr As Integer = 6
        
        Public Const UartTriggerBre As Integer = 7
        
        Public Const HardcopyLangGdi As Integer = 0
        
        Public Const HardcopyLangBmp As Integer = 1
        
        Public Const HardcopyLangPng As Integer = 2
        
        Public Const HardcopyDeviceMem As Integer = 0
        
        Public Const HardcopyDevicePrint As Integer = 1
    End Class
    
    Public Enum rsrtmProperties
        
        '''<summary>
        '''System.Int32
        '''</summary>
        RsAttrRangeCheck = 1050002
        
        '''<summary>
        '''System.Boolean
        '''</summary>
        RsAttrQueryInstrumentStatus = 1050003
        
        '''<summary>
        '''System.Boolean
        '''</summary>
        RsAttrCache = 1050004
        
        '''<summary>
        '''System.Boolean
        '''</summary>
        RsAttrSimulate = 1050005
        
        '''<summary>
        '''System.Boolean
        '''</summary>
        RsAttrRecordCoercions = 1050006
        
        '''<summary>
        '''System.Boolean
        '''</summary>
        RsAttrInterchangeCheck = 1050021
        
        '''<summary>
        '''System.Boolean
        '''</summary>
        RsAttrSpy = 1050022
        
        '''<summary>
        '''System.Boolean
        '''</summary>
        RsAttrUseSpecificSimulation = 1050023
        
        '''<summary>
        '''System.String
        '''</summary>
        RsAttrClassDriverDescription = 1050518
        
        '''<summary>
        '''System.String
        '''</summary>
        RsAttrClassDriverPrefix = 1050301
        
        '''<summary>
        '''System.String
        '''</summary>
        RsAttrClassDriverVendor = 1050517
        
        '''<summary>
        '''System.String
        '''</summary>
        RsAttrClassDriverRevision = 1050552
        
        '''<summary>
        '''System.Int32
        '''</summary>
        RsAttrClassDriverClassSpecMajorVersion = 1050519
        
        '''<summary>
        '''System.Int32
        '''</summary>
        RsAttrClassDriverClassSpecMinorVersion = 1050520
        
        '''<summary>
        '''System.String
        '''</summary>
        RsAttrSpecificDriverDescription = 1050514
        
        '''<summary>
        '''System.String
        '''</summary>
        RsAttrSpecificDriverPrefix = 1050302
        
        '''<summary>
        '''System.String
        '''</summary>
        RsAttrSpecificDriverLocator = 1050303
        
        '''<summary>
        '''System.String
        '''</summary>
        RsAttrSpecificDriverVendor = 1050513
        
        '''<summary>
        '''System.String
        '''</summary>
        RsAttrSpecificDriverRevision = 1050551
        
        '''<summary>
        '''System.Int32
        '''</summary>
        RsAttrSpecificDriverClassSpecMajorVersion = 1050515
        
        '''<summary>
        '''System.Int32
        '''</summary>
        RsAttrSpecificDriverClassSpecMinorVersion = 1050516
        
        '''<summary>
        '''System.String
        '''</summary>
        RsAttrSupportedInstrumentModels = 1050327
        
        '''<summary>
        '''System.String
        '''</summary>
        RsAttrGroupCapabilities = 1050401
        
        '''<summary>
        '''System.String
        '''</summary>
        RsAttrFunctionCapabilities = 1050402
        
        '''<summary>
        '''System.Int32
        '''</summary>
        RsAttrChannelCount = 1050203
        
        '''<summary>
        '''System.String
        '''</summary>
        RsAttrDriverSetup = 1050007
        
        '''<summary>
        '''System.String
        '''</summary>
        RsAttrInstrumentManufacturer = 1050511
        
        '''<summary>
        '''System.String
        '''</summary>
        RsAttrInstrumentModel = 1050512
        
        '''<summary>
        '''System.String
        '''</summary>
        RsAttrInstrumentFirmwareRevision = 1050510
        
        '''<summary>
        '''System.String
        '''</summary>
        RsAttrOptionsList = 1050591
        
        '''<summary>
        '''System.String
        '''</summary>
        RsAttrIoResourceDescriptor = 1050304
        
        '''<summary>
        '''System.String
        '''</summary>
        RsAttrLogicalName = 1050305
        
        '''<summary>
        '''System.Int32
        '''</summary>
        RsAttrPrimaryError = 1050101
        
        '''<summary>
        '''System.Int32
        '''</summary>
        RsAttrSecondaryError = 1050102
        
        '''<summary>
        '''System.String
        '''</summary>
        RsAttrErrorElaboration = 1050103
        
        '''<summary>
        '''System.IntPtr
        '''</summary>
        RsAttrVisaRmSession = 1050321
        
        '''<summary>
        '''System.IntPtr
        '''</summary>
        RsAttrIoSession = 1050322
        
        '''<summary>
        '''System.String
        '''</summary>
        RsAttrIoSessionType = 1050324
        
        '''<summary>
        '''System.Int32
        '''</summary>
        RsAttrSpecificDriverMajorVersion = 1050503
        
        '''<summary>
        '''System.Int32
        '''</summary>
        RsAttrSpecificDriverMinorVersion = 1050504
        
        '''<summary>
        '''System.Int32
        '''</summary>
        RsAttrSpecificDriverMinorMinorVersion = 1050590
        
        '''<summary>
        '''System.Int32
        '''</summary>
        RsAttrClassDriverMajorVersion = 1050505
        
        '''<summary>
        '''System.Int32
        '''</summary>
        RsAttrClassDriverMinorVersion = 1050506
        
        '''<summary>
        '''System.Int32
        '''</summary>
        RsAttrEngineMajorVersion = 1050501
        
        '''<summary>
        '''System.Int32
        '''</summary>
        RsAttrEngineMinorVersion = 1050502
        
        '''<summary>
        '''System.String
        '''</summary>
        RsAttrEngineRevision = 1050553
        
        '''<summary>
        '''System.Int32
        '''</summary>
        RsAttrOpcCallback = 1050602
        
        '''<summary>
        '''System.Int32
        '''</summary>
        RsAttrCheckStatusCallback = 1050603
        
        '''<summary>
        '''System.Int32
        '''</summary>
        RsAttrOpcTimeout = 1051001
        
        '''<summary>
        '''System.Int32
        '''</summary>
        AcquisitionType = 1150001
        
        '''<summary>
        '''System.Int32
        '''</summary>
        WaveformAcquisitionType = 1150002
        
        '''<summary>
        '''System.Double
        '''</summary>
        FilterFrequency = 1150613
        
        '''<summary>
        '''System.Int32
        '''</summary>
        Interpolation = 1150003
        
        '''<summary>
        '''System.Int32
        '''</summary>
        NumAverages = 1150004
        
        '''<summary>
        '''System.Int32
        '''</summary>
        NumberOfWaveforms = 1150614
        
        '''<summary>
        '''System.Int32
        '''</summary>
        SampleMode = 1150005
        
        '''<summary>
        '''System.Int32
        '''</summary>
        WaveformRate = 1150469
        
        '''<summary>
        '''System.Double
        '''</summary>
        HorzTimePerRecord = 1150007
        
        '''<summary>
        '''System.Int32
        '''</summary>
        HorzRecordLength = 1150000
        
        '''<summary>
        '''System.Double
        '''</summary>
        HorzScale = 1150009
        
        '''<summary>
        '''System.Double
        '''</summary>
        AcqusitionStartTime = 1150010
        
        '''<summary>
        '''System.Double
        '''</summary>
        AcquisitionTime = 1150012
        
        '''<summary>
        '''System.Double
        '''</summary>
        HorzAdcSampleRate = 1150014
        
        '''<summary>
        '''System.Double
        '''</summary>
        HorzSampleRate = 1150610
        
        '''<summary>
        '''System.String
        '''</summary>
        Autoscale = 1150015
        
        '''<summary>
        '''System.Int32
        '''</summary>
        HorzDivisions = 1150016
        
        '''<summary>
        '''System.Int32
        '''</summary>
        HorzReference = 1150017
        
        '''<summary>
        '''System.Boolean
        '''</summary>
        RollMode = 1150612
        
        '''<summary>
        '''System.String
        '''</summary>
        ProbeType = 1150313
        
        '''<summary>
        '''System.String
        '''</summary>
        ProbeName = 1150314
        
        '''<summary>
        '''System.Double
        '''</summary>
        ProbeInputImpedance = 1150315
        
        '''<summary>
        '''System.Double
        '''</summary>
        ProbeInputCapacitance = 1150316
        
        '''<summary>
        '''System.String
        '''</summary>
        ProbeAttenuation = 1150023
        
        '''<summary>
        '''System.Double
        '''</summary>
        ProbeBandwidth = 1150024
        
        '''<summary>
        '''System.Double
        '''</summary>
        ProbeDcOffset = 1150471
        
        '''<summary>
        '''System.Double
        '''</summary>
        ProbeAdditionalOffset = 1150472
        
        '''<summary>
        '''System.Boolean
        '''</summary>
        ProbeVoltmeterState = 1150473
        
        '''<summary>
        '''System.Int32
        '''</summary>
        ProbeAttenuationUnit = 1150645
        
        '''<summary>
        '''System.Double
        '''</summary>
        ProbeAttenuationManual = 1150646
        
        '''<summary>
        '''System.Int32
        '''</summary>
        ProbeMicroButtonAction = 1150319
        
        '''<summary>
        '''System.String
        '''</summary>
        ProbeSoftwareVersion = 1150320
        
        '''<summary>
        '''System.String
        '''</summary>
        ProbeProductionDate = 1150321
        
        '''<summary>
        '''System.String
        '''</summary>
        ProbePartNumber = 1150322
        
        '''<summary>
        '''System.Int32
        '''</summary>
        ProbeBuildNumber = 1150474
        
        '''<summary>
        '''System.String
        '''</summary>
        ProbeSerialNumber = 1150323
        
        '''<summary>
        '''System.Boolean
        '''</summary>
        ChannelEnabled = 1150025
        
        '''<summary>
        '''System.Double
        '''</summary>
        VerticalRange = 1150026
        
        '''<summary>
        '''System.Double
        '''</summary>
        VerticalOffset = 1150027
        
        '''<summary>
        '''System.Int32
        '''</summary>
        VerticalCoupling = 1150028
        
        '''<summary>
        '''System.Double
        '''</summary>
        VerticalScale = 1150029
        
        '''<summary>
        '''System.Double
        '''</summary>
        ChannelOffset = 1150030
        
        '''<summary>
        '''System.Int32
        '''</summary>
        ChannelBandwidthLimit = 1150031
        
        '''<summary>
        '''System.Int32
        '''</summary>
        ChannelPolarity = 1150615
        
        '''<summary>
        '''System.Boolean
        '''</summary>
        ChannelOverload = 1150032
        
        '''<summary>
        '''System.Double
        '''</summary>
        ChannelSkew = 1150033
        
        '''<summary>
        '''System.Double
        '''</summary>
        ChannelThreshold = 1150034
        
        '''<summary>
        '''System.Int32
        '''</summary>
        TriggerType = 1150037
        
        '''<summary>
        '''System.Int32
        '''</summary>
        TriggerSource = 1150038
        
        '''<summary>
        '''System.Int32
        '''</summary>
        ExternalTriggerCoupling = 1150616
        
        '''<summary>
        '''System.Double
        '''</summary>
        TriggerLevel = 1150039
        
        '''<summary>
        '''System.Int32
        '''</summary>
        TriggerHysteresis = 1150493
        
        '''<summary>
        '''System.Boolean
        '''</summary>
        TriggerState = 1150482
        
        '''<summary>
        '''System.Int32
        '''</summary>
        TriggerModifier = 1150040
        
        '''<summary>
        '''System.Int32
        '''</summary>
        TriggerEventCount = 1150489
        
        '''<summary>
        '''System.String
        '''</summary>
        TriggerLevelAutoFind = 1150041
        
        '''<summary>
        '''System.Double
        '''</summary>
        TriggerDelay = 1150488
        
        '''<summary>
        '''System.Int32
        '''</summary>
        TriggerSlope = 1150045
        
        '''<summary>
        '''System.Int32
        '''</summary>
        TriggerCoupling = 1150490
        
        '''<summary>
        '''System.Boolean
        '''</summary>
        TriggerFilter = 1150491
        
        '''<summary>
        '''System.Int32
        '''</summary>
        TvTriggerEvent = 1150051
        
        '''<summary>
        '''System.Int32
        '''</summary>
        TvTriggerLineNumber = 1150052
        
        '''<summary>
        '''System.Int32
        '''</summary>
        TvTriggerPolarity = 1150053
        
        '''<summary>
        '''System.Int32
        '''</summary>
        TvStandard = 1150477
        
        '''<summary>
        '''System.Double
        '''</summary>
        Width = 1150481
        
        '''<summary>
        '''System.Double
        '''</summary>
        WidthDelta = 1150480
        
        '''<summary>
        '''System.Int32
        '''</summary>
        WidthPolarity = 1150478
        
        '''<summary>
        '''System.Int32
        '''</summary>
        WidthCondition = 1150479
        
        '''<summary>
        '''System.String
        '''</summary>
        TriggerPatternSource = 1150494
        
        '''<summary>
        '''System.Int32
        '''</summary>
        TriggerPatternFunction = 1150495
        
        '''<summary>
        '''System.Boolean
        '''</summary>
        TriggerPatternPointState = 1150496
        
        '''<summary>
        '''System.Int32
        '''</summary>
        WaveformSamples = 1150500
        
        '''<summary>
        '''System.String
        '''</summary>
        RunSingle = 1150130
        
        '''<summary>
        '''System.String
        '''</summary>
        RunContinuous = 1150131
        
        '''<summary>
        '''System.String
        '''</summary>
        [Stop] = 1150132
        
        '''<summary>
        '''System.String
        '''</summary>
        SendSwTrigger = 1150134
        
        '''<summary>
        '''System.Double
        '''</summary>
        MainMeasurementResult = 1150508
        
        '''<summary>
        '''System.Int32
        '''</summary>
        AmptMainMeasurement = 1150147
        
        '''<summary>
        '''System.String
        '''</summary>
        MeasDelaySlope = 1150617
        
        '''<summary>
        '''System.Int32
        '''</summary>
        MeasCategory = 1150618
        
        '''<summary>
        '''System.Int32
        '''</summary>
        MeasRelativeMode = 1150619
        
        '''<summary>
        '''System.Double
        '''</summary>
        MeasRelativeLowerLevel = 1150620
        
        '''<summary>
        '''System.Double
        '''</summary>
        MeasRelativeUpperLevel = 1150621
        
        '''<summary>
        '''System.Double
        '''</summary>
        MeasRelativeMiddleLevel = 1150622
        
        '''<summary>
        '''System.Boolean
        '''</summary>
        MeasurementEnabled = 1150136
        
        '''<summary>
        '''System.Int32
        '''</summary>
        MeasurementCategory = 1150138
        
        '''<summary>
        '''System.String
        '''</summary>
        QuickMeasurementsEnable = 1150139
        
        '''<summary>
        '''System.String
        '''</summary>
        QuickMeasurementsDisable = 1150140
        
        '''<summary>
        '''System.String
        '''</summary>
        ClearMeasurementStatisticData = 1150141
        
        '''<summary>
        '''System.Boolean
        '''</summary>
        CursorEnabled = 1150173
        
        '''<summary>
        '''System.String
        '''</summary>
        AllCursorsOff = 1150174
        
        '''<summary>
        '''System.Int32
        '''</summary>
        CursorMeasurementType = 1150175
        
        '''<summary>
        '''System.Int32
        '''</summary>
        CursorSource = 1150176
        
        '''<summary>
        '''System.Boolean
        '''</summary>
        CursorTracking = 1150177
        
        '''<summary>
        '''System.Double
        '''</summary>
        CursorXPosition = 1150178
        
        '''<summary>
        '''System.Boolean
        '''</summary>
        CursorXPositionCoupling = 1150179
        
        '''<summary>
        '''System.Double
        '''</summary>
        CursorYPosition = 1150180
        
        '''<summary>
        '''System.Boolean
        '''</summary>
        CursorYPositionCoupling = 1150181
        
        '''<summary>
        '''System.String
        '''</summary>
        CursorAutoset = 1150647
        
        '''<summary>
        '''System.String
        '''</summary>
        CursorReset = 1150648
        
        '''<summary>
        '''System.String
        '''</summary>
        CursorPeakNext = 1150649
        
        '''<summary>
        '''System.String
        '''</summary>
        CursorPeakPrevious = 1150650
        
        '''<summary>
        '''System.Boolean
        '''</summary>
        CursorAdjustment = 1150507
        
        '''<summary>
        '''System.Int32
        '''</summary>
        CursorXRatioMeasurementUnit = 1150187
        
        '''<summary>
        '''System.Int32
        '''</summary>
        CursorYRatioMeasurementUnit = 1150189
        
        '''<summary>
        '''System.Double
        '''</summary>
        CursorXRatioMeasurement = 1150188
        
        '''<summary>
        '''System.Double
        '''</summary>
        CursorYRatioMeasurement = 1150190
        
        '''<summary>
        '''System.Double
        '''</summary>
        CursorDistance = 1150183
        
        '''<summary>
        '''System.Double
        '''</summary>
        CursorInverseDistance = 1150184
        
        '''<summary>
        '''System.Double
        '''</summary>
        CursorVoltageInverseDistance = 1150503
        
        '''<summary>
        '''System.Double
        '''</summary>
        CursorPosition = 1150506
        
        '''<summary>
        '''System.Int32
        '''</summary>
        CursorPeakExcursion = 1150186
        
        '''<summary>
        '''System.Boolean
        '''</summary>
        AutomaticMeasurementState = 1150651
        
        '''<summary>
        '''System.Int32
        '''</summary>
        AutomaticMeasurementNumberOfWaveforms = 1150652
        
        '''<summary>
        '''System.String
        '''</summary>
        ResetAutomaticMeasurement = 1150653
        
        '''<summary>
        '''System.Int32
        '''</summary>
        AutomaticMeasurementNumberOfMeasuredWaveforms = 1150666
        
        '''<summary>
        '''System.Double
        '''</summary>
        AutomaticMeasurementResult = 1150654
        
        '''<summary>
        '''System.String
        '''</summary>
        MathWaveformHeader = 1150337
        
        '''<summary>
        '''System.Boolean
        '''</summary>
        MathWaveformEnabled = 1150235
        
        '''<summary>
        '''System.Double
        '''</summary>
        MathWaveformPosition = 1150623
        
        '''<summary>
        '''System.Double
        '''</summary>
        MathVerticalScale = 1150624
        
        '''<summary>
        '''System.Int32
        '''</summary>
        MathAcquisitionType = 1150236
        
        '''<summary>
        '''System.String
        '''</summary>
        MathExpression = 1150237
        
        '''<summary>
        '''System.Double
        '''</summary>
        FftCenterFrequency = 1150241
        
        '''<summary>
        '''System.Double
        '''</summary>
        FftFrequencySpan = 1150242
        
        '''<summary>
        '''System.String
        '''</summary>
        FftFullSpan = 1150243
        
        '''<summary>
        '''System.Double
        '''</summary>
        FftStartFrequency = 1150244
        
        '''<summary>
        '''System.Double
        '''</summary>
        FftStopFrequency = 1150245
        
        '''<summary>
        '''System.Int32
        '''</summary>
        FftAveraging = 1150509
        
        '''<summary>
        '''System.Int32
        '''</summary>
        FftWindowType = 1150246
        
        '''<summary>
        '''System.Double
        '''</summary>
        FftResolutionBandwidth = 1150254
        
        '''<summary>
        '''System.Boolean
        '''</summary>
        FftResolutionBandwidthCouplingEnabled = 1150255
        
        '''<summary>
        '''System.Int32
        '''</summary>
        FftResolutionBandwidthRatio = 1150256
        
        '''<summary>
        '''System.Double
        '''</summary>
        FftEffectiveResolutionBandwidth = 1150257
        
        '''<summary>
        '''System.Int32
        '''</summary>
        FftScalingUnit = 1150625
        
        '''<summary>
        '''System.Int32
        '''</summary>
        FftSampleRate = 1150655
        
        '''<summary>
        '''System.String
        '''</summary>
        ReferenceWaveformHeader = 1150511
        
        '''<summary>
        '''System.Int32
        '''</summary>
        ReferenceWaveformSource = 1150270
        
        '''<summary>
        '''System.String
        '''</summary>
        ReferenceWaveformUpdate = 1150276
        
        '''<summary>
        '''System.Boolean
        '''</summary>
        ReferenceWaveformDisplayEnabled = 1150271
        
        '''<summary>
        '''System.String
        '''</summary>
        ReferenceWaveformLoadFromFile = 1150512
        
        '''<summary>
        '''System.String
        '''</summary>
        ReferenceWaveformLoadConfiguration = 1150513
        
        '''<summary>
        '''System.String
        '''</summary>
        ReferenceWaveformSaveToFile = 1150514
        
        '''<summary>
        '''System.String
        '''</summary>
        ReferenceWaveformCatalog = 1150515
        
        '''<summary>
        '''System.Double
        '''</summary>
        ReferenceWaveformVerticalScale = 1150281
        
        '''<summary>
        '''System.Double
        '''</summary>
        ReferenceWaveformVerticalPosition = 1150282
        
        '''<summary>
        '''System.Double
        '''</summary>
        ReferenceWaveformHorizontalScale = 1150516
        
        '''<summary>
        '''System.Double
        '''</summary>
        ReferenceWaveformHorizontalPosition = 1150611
        
        '''<summary>
        '''System.Boolean
        '''</summary>
        MaskEnabled = 1150517
        
        '''<summary>
        '''System.Int32
        '''</summary>
        MaskSource = 1150525
        
        '''<summary>
        '''System.Int32
        '''</summary>
        MaskTest = 1150526
        
        '''<summary>
        '''System.String
        '''</summary>
        MaskCopyChannel = 1150518
        
        '''<summary>
        '''System.Int32
        '''</summary>
        MaskHitCount = 1150522
        
        '''<summary>
        '''System.Int32
        '''</summary>
        MaskCount = 1150521
        
        '''<summary>
        '''System.String
        '''</summary>
        MaskStore = 1150524
        
        '''<summary>
        '''System.String
        '''</summary>
        MaskLoad = 1150523
        
        '''<summary>
        '''System.Double
        '''</summary>
        MaskVerticalOffset = 1150519
        
        '''<summary>
        '''System.Double
        '''</summary>
        MaskVerticalScaling = 1150520
        
        '''<summary>
        '''System.Double
        '''</summary>
        MaskVerticalWidth = 1150528
        
        '''<summary>
        '''System.Double
        '''</summary>
        MaskHorizontalWidth = 1150527
        
        '''<summary>
        '''System.Boolean
        '''</summary>
        SearchState = 1150626
        
        '''<summary>
        '''System.Int32
        '''</summary>
        SearchCondition = 1150627
        
        '''<summary>
        '''System.Int32
        '''</summary>
        SearchSource = 1150628
        
        '''<summary>
        '''System.Int32
        '''</summary>
        SearchTriggerEdgeSlope = 1150629
        
        '''<summary>
        '''System.Double
        '''</summary>
        SearchTriggerEdgeLevel = 1150630
        
        '''<summary>
        '''System.Double
        '''</summary>
        SearchTriggerEdgeHystersis = 1150631
        
        '''<summary>
        '''System.Double
        '''</summary>
        SearchTriggerWidthLevel = 1150632
        
        '''<summary>
        '''System.Double
        '''</summary>
        SearchTriggerWidthHystersis = 1150633
        
        '''<summary>
        '''System.Double
        '''</summary>
        SearchTriggerWidthWidth = 1150634
        
        '''<summary>
        '''System.Double
        '''</summary>
        SearchTriggerWidthDelta = 1150635
        
        '''<summary>
        '''System.Int32
        '''</summary>
        SearchTriggerWidthPolarity = 1150636
        
        '''<summary>
        '''System.Int32
        '''</summary>
        SearchTriggerWidthRange = 1150637
        
        '''<summary>
        '''System.Int32
        '''</summary>
        SearchTriggerPeakPolarity = 1150638
        
        '''<summary>
        '''System.Double
        '''</summary>
        SearchTriggerPeakLimit = 1150639
        
        '''<summary>
        '''System.Int32
        '''</summary>
        SearchTriggerRiseTimePolarity = 1150656
        
        '''<summary>
        '''System.Double
        '''</summary>
        SearchTriggerRiseTimeLevel = 1150657
        
        '''<summary>
        '''System.Int32
        '''</summary>
        SearchTriggerRiseTimeRange = 1150658
        
        '''<summary>
        '''System.Double
        '''</summary>
        SearchTriggerRiseTimeReferenceTime = 1150659
        
        '''<summary>
        '''System.Double
        '''</summary>
        SearchTriggerRiseTimeDeltaTime = 1150660
        
        '''<summary>
        '''System.Int32
        '''</summary>
        SearchTriggerRuntPolarity = 1150661
        
        '''<summary>
        '''System.Double
        '''</summary>
        SearchTriggerRuntLevel = 1150662
        
        '''<summary>
        '''System.Int32
        '''</summary>
        SearchTriggerRuntRange = 1150663
        
        '''<summary>
        '''System.Double
        '''</summary>
        SearchTriggerRuntWidth = 1150664
        
        '''<summary>
        '''System.Double
        '''</summary>
        SearchTriggerRuntDeltaWidth = 1150665
        
        '''<summary>
        '''System.Boolean
        '''</summary>
        SearchShowResult = 1150640
        
        '''<summary>
        '''System.Int32
        '''</summary>
        SearchNumberOfResults = 1150641
        
        '''<summary>
        '''System.Boolean
        '''</summary>
        ProtocolState = 1150577
        
        '''<summary>
        '''System.Int32
        '''</summary>
        ProtocolType = 1150578
        
        '''<summary>
        '''System.Int32
        '''</summary>
        ProtocolDisplayFormat = 1150579
        
        '''<summary>
        '''System.Int32
        '''</summary>
        ProtocolDisplayHeight = 1150580
        
        '''<summary>
        '''System.Boolean
        '''</summary>
        ProtocolDisplayLines = 1150581
        
        '''<summary>
        '''System.Double
        '''</summary>
        ProtocolDisplayVertical = 1150582
        
        '''<summary>
        '''System.Int32
        '''</summary>
        ProtocolI2cSource = 1150350
        
        '''<summary>
        '''System.Int32
        '''</summary>
        ProtocolI2cTriggerAccess = 1150529
        
        '''<summary>
        '''System.Int32
        '''</summary>
        ProtocolI2cTriggerAddressType = 1150531
        
        '''<summary>
        '''System.String
        '''</summary>
        ProtocolI2cTriggerAddress = 1150530
        
        '''<summary>
        '''System.Int32
        '''</summary>
        ProtocolI2cTriggerMode = 1150532
        
        '''<summary>
        '''System.Int32
        '''</summary>
        ProtocolI2cTriggerConditionLength = 1150534
        
        '''<summary>
        '''System.String
        '''</summary>
        ProtocolI2cTriggerBitPattern = 1150533
        
        '''<summary>
        '''System.Int32
        '''</summary>
        ProtocolI2cTriggerFirstByteOffset = 1150535
        
        '''<summary>
        '''System.Int32
        '''</summary>
        ProtocolSpiSource = 1150382
        
        '''<summary>
        '''System.Int32
        '''</summary>
        ProtocolSpiPolarity = 1150383
        
        '''<summary>
        '''System.Int32
        '''</summary>
        ProtocolSpiBitOrder = 1150380
        
        '''<summary>
        '''System.Int32
        '''</summary>
        ProtocolSpiWordLength = 1150381
        
        '''<summary>
        '''System.Int32
        '''</summary>
        ProtocolSpiTriggerMode = 1150537
        
        '''<summary>
        '''System.Int32
        '''</summary>
        ProtocolSpiTriggerOffset = 1150388
        
        '''<summary>
        '''System.Int32
        '''</summary>
        ProtocolSpiBitPatternLength = 1150539
        
        '''<summary>
        '''System.String
        '''</summary>
        ProtocolSpiBitPattern = 1150536
        
        '''<summary>
        '''System.Int32
        '''</summary>
        ProtocolSspiSource = 1150609
        
        '''<summary>
        '''System.Int32
        '''</summary>
        ProtocolSspiPolarity = 1150594
        
        '''<summary>
        '''System.Double
        '''</summary>
        ProtocolSspiInterframeTime = 1150597
        
        '''<summary>
        '''System.Int32
        '''</summary>
        ProtocolSspiBitOrder = 1150598
        
        '''<summary>
        '''System.Int32
        '''</summary>
        ProtocolSspiWordLength = 1150599
        
        '''<summary>
        '''System.Int32
        '''</summary>
        ProtocolUartSource = 1150600
        
        '''<summary>
        '''System.Int32
        '''</summary>
        ProtocolUartPolarity = 1150601
        
        '''<summary>
        '''System.Double
        '''</summary>
        ProtocolUartInterframeTime = 1150605
        
        '''<summary>
        '''System.Int32
        '''</summary>
        ProtocolUartWordLength = 1150606
        
        '''<summary>
        '''System.Int32
        '''</summary>
        ProtocolUartBitRate = 1150604
        
        '''<summary>
        '''System.Int32
        '''</summary>
        ProtocolUartParity = 1150405
        
        '''<summary>
        '''System.Int32
        '''</summary>
        ProtocolUartStopBits = 1150603
        
        '''<summary>
        '''System.Int32
        '''</summary>
        ProtocolUartTriggerMode = 1150540
        
        '''<summary>
        '''System.String
        '''</summary>
        ProtocolUartTriggerDataPattern = 1150541
        
        '''<summary>
        '''System.Int32
        '''</summary>
        ProtocolUartTriggerDataPositionIndexMin = 1150542
        
        '''<summary>
        '''System.Int32
        '''</summary>
        ProtocolUartTriggerConditionLength = 1150543
        
        '''<summary>
        '''System.Int32
        '''</summary>
        ParallelBusSource = 1150607
        
        '''<summary>
        '''System.Int32
        '''</summary>
        ParallelBusAnalyzedLines = 1150608
        
        '''<summary>
        '''System.Int32
        '''</summary>
        DisplayStyle = 1150574
        
        '''<summary>
        '''System.Int32
        '''</summary>
        ColorAndBrightness = 1150547
        
        '''<summary>
        '''System.Int32
        '''</summary>
        SignalStyle = 1150427
        
        '''<summary>
        '''System.Int32
        '''</summary>
        DiagramGridStyle = 1150550
        
        '''<summary>
        '''System.Double
        '''</summary>
        WaveformIntensity = 1150573
        
        '''<summary>
        '''System.Double
        '''</summary>
        BackgroundIntensity = 1150545
        
        '''<summary>
        '''System.Double
        '''</summary>
        GridIntensity = 1150546
        
        '''<summary>
        '''System.Int32
        '''</summary>
        DisplayLanguage = 1150549
        
        '''<summary>
        '''System.Int32
        '''</summary>
        DiagramMode = 1150548
        
        '''<summary>
        '''System.Boolean
        '''</summary>
        PersistenceState = 1150422
        
        '''<summary>
        '''System.Boolean
        '''</summary>
        InfinitePersistence = 1150423
        
        '''<summary>
        '''System.Double
        '''</summary>
        PersistenceTime = 1150424
        
        '''<summary>
        '''System.Boolean
        '''</summary>
        PersistenceTimeAuto = 1150544
        
        '''<summary>
        '''System.String
        '''</summary>
        PersistenceClear = 1150572
        
        '''<summary>
        '''System.Int32
        '''</summary>
        XyXSource = 1150551
        
        '''<summary>
        '''System.Int32
        '''</summary>
        XyYSource = 1150552
        
        '''<summary>
        '''System.Int32
        '''</summary>
        XyY2Source = 1150554
        
        '''<summary>
        '''System.Int32
        '''</summary>
        XyZSource = 1150553
        
        '''<summary>
        '''System.Double
        '''</summary>
        XyZTreshold = 1150556
        
        '''<summary>
        '''System.Int32
        '''</summary>
        XyIntensityControl = 1150555
        
        '''<summary>
        '''System.Boolean
        '''</summary>
        ZoomWindowState = 1150557
        
        '''<summary>
        '''System.Double
        '''</summary>
        ZoomDiagramTimebase = 1150558
        
        '''<summary>
        '''System.Double
        '''</summary>
        ZoomOffsetOfTriggerPoint = 1150559
        
        '''<summary>
        '''System.Double
        '''</summary>
        ZoomReferencePoint = 1150560
        
        '''<summary>
        '''System.String
        '''</summary>
        MarkerSet = 1150561
        
        '''<summary>
        '''System.String
        '''</summary>
        MarkerClear = 1150562
        
        '''<summary>
        '''System.String
        '''</summary>
        MarkerClearAll = 1150563
        
        '''<summary>
        '''System.String
        '''</summary>
        MarkerNext = 1150564
        
        '''<summary>
        '''System.String
        '''</summary>
        MarkerPrevious = 1150565
        
        '''<summary>
        '''System.String
        '''</summary>
        Drives = 1150297
        
        '''<summary>
        '''System.String
        '''</summary>
        ChangeDrive = 1150298
        
        '''<summary>
        '''System.String
        '''</summary>
        CurrentDirectory = 1150299
        
        '''<summary>
        '''System.String
        '''</summary>
        CreateDirectory = 1150300
        
        '''<summary>
        '''System.String
        '''</summary>
        RemoveDirectory = 1150301
        
        '''<summary>
        '''System.String
        '''</summary>
        DeleteFile = 1150302
        
        '''<summary>
        '''System.String
        '''</summary>
        HardcopyFileName = 1150303
        
        '''<summary>
        '''System.Int32
        '''</summary>
        HardcopyLanguage = 1150575
        
        '''<summary>
        '''System.Int32
        '''</summary>
        HardcopyDeviceDestination = 1150455
        
        '''<summary>
        '''System.Int32
        '''</summary>
        HardcopyColorScheme = 1150571
        
        '''<summary>
        '''System.Int32
        '''</summary>
        HardcopyDeviceLanguageOutputFormat = 1150456
        
        '''<summary>
        '''System.Int32
        '''</summary>
        HardcopyDeviceOrientation = 1150457
        
        '''<summary>
        '''System.Int32
        '''</summary>
        HardcopyPageSize = 1150567
        
        '''<summary>
        '''System.String
        '''</summary>
        HardcopyPrint = 1150458
        
        '''<summary>
        '''System.String
        '''</summary>
        HardcopySelectPrinter = 1150459
        
        '''<summary>
        '''System.String
        '''</summary>
        HardcopyGetFirstPrinter = 1150460
        
        '''<summary>
        '''System.String
        '''</summary>
        HardcopyGetNextPrinter = 1150461
        
        '''<summary>
        '''System.String
        '''</summary>
        IdQueryResponse = 1150304
        
        '''<summary>
        '''System.Int32
        '''</summary>
        Calibration = 1150305
        
        '''<summary>
        '''System.Int32
        '''</summary>
        SelfTestQuery = 1150306
        
        '''<summary>
        '''System.String
        '''</summary>
        SystemError = 1150307
        
        '''<summary>
        '''System.String
        '''</summary>
        SystErrList = 1150642
        
        '''<summary>
        '''System.String
        '''</summary>
        InstrumentName = 1150568
        
        '''<summary>
        '''System.String
        '''</summary>
        ResetStatusRegister = 1150643
        
        '''<summary>
        '''System.Int32
        '''</summary>
        Register = 1150570
    End Enum
End Namespace
